(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[   3448867,      60959]
NotebookOptionsPosition[   3447330,      60901]
NotebookOutlinePosition[   3447668,      60916]
CellTagsIndexPosition[   3447625,      60913]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Heaviside-\[CapitalTheta] auf der komplexen Ebene\
\>", "Title",
 CellChangeTimes->{{3.627285735267653*^9, 3.627285745499449*^9}}],

Cell["\<\
Dieses Worksheet soll eine spezielle Wahl einer analytischen Erweiterung der \
Heaviside-Funktion untersuchen, welche rechtfertigt, dass mein \
Integrationsverfahren auch mit gro\[SZ]en Extradimensionen funktioniert. Dies \
tangiert im wesentlichen Appendix E.2 der Masterarbeit und wird im Haupttext \
nicht besprochen.\
\>", "Text",
 CellChangeTimes->{{3.627285749352721*^9, 3.627285803339302*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"funk", "[", 
   RowBox[{"k_", ",", "z_"}], "]"}], " ", "=", " ", 
  FractionBox[
   RowBox[{"1", "+", 
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"-", "2"}], "k"}], "]"}]}], 
   RowBox[{"1", "+", 
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"-", "2"}], "k", "*", "z"}], "]"}]}]]}]], "Input",
 CellChangeTimes->{{3.618630758645495*^9, 3.618630793287245*^9}, {
   3.618630879999338*^9, 3.618630882262323*^9}, {3.6186309416804333`*^9, 
   3.618630963704123*^9}, {3.618631441306102*^9, 3.618631442674629*^9}, {
   3.618631773712578*^9, 3.618631786945932*^9}, {3.6186338586907997`*^9, 
   3.618633868649295*^9}, 3.618634031804854*^9, {3.618634992810442*^9, 
   3.618634992919931*^9}, {3.627285939584023*^9, 3.627285977242062*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "+", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", "k"}]]}], 
  RowBox[{"1", "+", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", "k", " ", "z"}]]}]]], "Output",
 CellChangeTimes->{{3.618630779055735*^9, 3.618630799104109*^9}, 
   3.618630964398757*^9, 3.618631318980852*^9, 3.618631443138954*^9, {
   3.6186317782235193`*^9, 3.6186317872406816`*^9}, 3.6186338689191027`*^9, 
   3.618634032155303*^9, 3.6186349935066767`*^9, 3.621832359619355*^9, 
   3.627285721536607*^9, {3.6272859688537207`*^9, 3.62728597792277*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\[CapitalUDoubleDot]bersichtsplots (Manipulates)", "Section",
 CellChangeTimes->{{3.627286157022222*^9, 3.62728616611204*^9}}],

Cell["\<\
Hier erkennt man, dass die Funktion die Theta-Eigenschaft gut \
erf\[UDoubleDot]llt auf dem reellen Zahlenstrahl.\
\>", "Text",
 CellChangeTimes->{{3.627286620778368*^9, 3.62728663765012*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"funk", "[", 
      RowBox[{"k", " ", ",", "z"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.1"}], ",", "1.1"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"{", 
    RowBox[{"k", ",", " ", "0.05", ",", "20"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.618632693329578*^9, 3.6186326992911587`*^9}, {
   3.621833478534573*^9, 3.621833492911665*^9}, 3.627285981738443*^9, {
   3.627286294798873*^9, 3.627286353629767*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`k$$ = 8.08, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`k$$], 0.05, 20}}, Typeset`size$$ = {
    360., {109., 114.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`k$10083$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`k$$ = 0.05}, 
      "ControllerVariables" :> {
        Hold[$CellContext`k$$, $CellContext`k$10083$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Plot[
        $CellContext`funk[$CellContext`k$$, $CellContext`z], {$CellContext`z, \
-2, 2}, PlotRange -> {-0.1, 1.1}], 
      "Specifications" :> {{$CellContext`k$$, 0.05, 20}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{407., {153., 160.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.618632699838353*^9, 3.6186338700115137`*^9, 3.618634033501951*^9, 
   3.621832359826034*^9, 3.621833493288121*^9, 3.6272857217660627`*^9, 
   3.62728598193822*^9, {3.627286299207035*^9, 3.627286354755169*^9}}]
}, Open  ]],

Cell["\<\
Hier erkennt man, dass die Funktion wirklich die Theta-Eigenschaft gut erf\
\[UDoubleDot]llt auf dem komplexen Einheitskreis:\
\>", "Text",
 CellChangeTimes->{{3.627286602032009*^9, 3.627286617448886*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Abs", "@", 
     RowBox[{"funk", "[", 
      RowBox[{"m", ",", " ", 
       RowBox[{"Exp", "[", 
        RowBox[{"I", " ", "\[CurlyPhi]"}], "]"}]}], "]"}]}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"\[CurlyPhi]", ",", "0", ",", 
      RowBox[{"2", "\[Pi]"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"GridLines", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Pi]", "/", "2"}], ",", " ", "\[Pi]", ",", 
         RowBox[{"3", 
          RowBox[{"\[Pi]", "/", "2"}]}], ",", " ", 
         RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
       RowBox[{"{", "1", "}"}]}], "}"}]}]}], "\[IndentingNewLine]", "]"}], 
  "~", "Manipulate", "~", 
  RowBox[{"{", 
   RowBox[{"m", ",", "0.05", ",", "20"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.618634066701049*^9, 3.618634135480729*^9}, {
   3.618634178766004*^9, 3.61863426449708*^9}, {3.618634450597107*^9, 
   3.61863450119486*^9}, {3.6186349342888937`*^9, 3.618634935857699*^9}, 
   3.627286002348278*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`m$$ = 12.74, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`m$$], 0.05, 20}}, Typeset`size$$ = {
    360., {113., 118.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`m$2716$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`m$$ = 0.05}, 
      "ControllerVariables" :> {
        Hold[$CellContext`m$$, $CellContext`m$2716$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Plot[
        Abs[
         $CellContext`funk[$CellContext`m$$, 
          Exp[I $CellContext`\[CurlyPhi]]]], {$CellContext`\[CurlyPhi], 0, 2 
         Pi}, GridLines -> {{Pi/2, Pi, 3 (Pi/2), 2 Pi}, {1}}], 
      "Specifications" :> {{$CellContext`m$$, 0.05, 20}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{407., {168., 175.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.6186341029655037`*^9, 3.618634135822462*^9}, {
   3.618634200799179*^9, 3.6186342646377077`*^9}, {3.6186344509070683`*^9, 
   3.618634501549868*^9}, 3.618634936225707*^9, 3.6218323598829613`*^9, 
   3.627285721949357*^9, 3.627286004055572*^9}]
}, Open  ]],

Cell["\<\
Hier erkennt man, dass h\[ODoubleDot]here Regularisierungswerte m zu immer \
besserer Theta-Aufl\[ODoubleDot]sung f\[UDoubleDot]hren.\
\>", "Text",
 CellChangeTimes->{{3.627286568233459*^9, 3.627286592731089*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Abs", "@", 
     RowBox[{"funk", "[", 
      RowBox[{"m", ",", " ", 
       RowBox[{"Exp", "[", 
        RowBox[{"I", " ", "\[CurlyPhi]"}], "]"}]}], "]"}]}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"\[CurlyPhi]", ",", "0", ",", 
      RowBox[{"\[Pi]", "/", "2"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"GridLines", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Pi]", "/", "2"}], ",", " ", "\[Pi]", ",", 
         RowBox[{"3", 
          RowBox[{"\[Pi]", "/", "2"}]}], ",", " ", 
         RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
       RowBox[{"{", "1", "}"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotRange", "\[Rule]", " ", 
     RowBox[{"1", "+", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{"+", "1"}]}], "}"}], "/", "100"}]}]}]}], 
   "\[IndentingNewLine]", "]"}], "~", "Manipulate", "~", 
  RowBox[{"{", 
   RowBox[{"m", ",", "0.05", ",", "20"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.627286475698316*^9, 3.627286562555068*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`m$$ = 7.859999999999999, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`m$$], 0.05, 20}}, Typeset`size$$ = {
    360., {114., 118.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`m$16897$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`m$$ = 0.05}, 
      "ControllerVariables" :> {
        Hold[$CellContext`m$$, $CellContext`m$16897$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Plot[
        Abs[
         $CellContext`funk[$CellContext`m$$, 
          Exp[I $CellContext`\[CurlyPhi]]]], {$CellContext`\[CurlyPhi], 0, Pi/
         2}, GridLines -> {{Pi/2, Pi, 3 (Pi/2), 2 Pi}, {1}}, PlotRange -> 
        1 + {-1, 
            Plus[1]}/100], "Specifications" :> {{$CellContext`m$$, 0.05, 20}},
       "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{407., {157., 164.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.6272864693923283`*^9, 3.6272864774149942`*^9}, 
   3.6272865118679247`*^9, {3.627286543837513*^9, 3.627286562785494*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Abs", "@", 
    RowBox[{"funk", "[", 
     RowBox[{"I", " ", "y"}], "]"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"GridLines", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"n", " ", 
         RowBox[{"\[Pi]", "/", "2"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", 
          RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.618634405836793*^9, 3.618634446328141*^9}, {
  3.621833845990522*^9, 3.621833907456994*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwBkQJu/SFib1JlAgAAACgAAAACAAAAfedN8v//E8C5OtNK3DP8P+Z7FvXb
/BPAYing14h//D9OEN/3t/kTwG9lW73hzPw/IDlw/W/zE8B2rRvL0Wz9P8KK
kgjg5hPA/Vea4WDD/j8rH1sLvOMTwOXg0kkiHv8/lLMjDpjgE8D1MGkNFXv/
P2XctBNQ2hPA5Llhf/AdAEAILtcewM0TwONOBR/H7QBAccKfIZzKE8DXaysf
KCUBQNpWaCR4xxPAqhYF+gJeAUCrf/kpMMETwJsrh7Fj1AFAFBTCLAy+E8CF
omljChICQHyoii/ouhPAcfuQuGxRAkBO0Rs1oLQTwNbKhJSw1QJAt2XkN3yx
E8DcYhkFuxoDQCD6rDpYrhPA6gZoFtNhA0DxIj5AEKgTwCmyBPyL9gNAlHRg
S4CbE8Blh3njFj0FQP0IKU5cmBPA+/c8O3yVBUBmnfFQOJUTwPoW90vb8AVA
N8aCVvCOE8A27XDJJLEGQKBaS1nMixPAeRT5RWUWB0AI7xNcqIgTwLu46hpM
fwdA2helYWCCE8C49ctI3VwIQEOsbWQ8fxPAmpVLv/nRCECsQDZnGHwTwPk8
pYyhSwlAfWnHbNB1E8BaPUacq00KQCC76XdAaRPAICPAtKuVDECJT7J6HGYT
wC116IIIOA1A8uN6ffhiE8DiyFR31uENQMMMDIOwXBPAo50FDOlND0AsodSF
jFkTwObB1GqwCBBAlDWdiGhWE8DKhgK8WW8QQGZeLo4gUBPABY1nVAVNEUDO
8vaQ/EwTwGIXFzHrxBFAN4e/k9hJE8C9wa+wiEMSQKAbiJa0RhPAAvS8KnLJ
EkAIsFCZkEMTwAjSDIhNVxNAASAF0LRAE8BdK449UOATQLTWJTo=
     "]], 
    LineBox[CompressedData["
1:eJw1mHk4VO/7x8cwZjHDzCi0yBbKkqIo4jmliLKkUMmSbAmhSJI2VIr2FC22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     "]], LineBox[CompressedData["
1:eJw12Gk8Vd/3B3DzTMa+IkkoIioSoXVMGTJGEpVCEiUpkqmUlCGJMhRCUkjG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     "]], 
    LineBox[CompressedData["
1:eJw1mHk8lP33xmfG7AYzU0nkCW1ClL0s5yiFhxJSEUkl0ULW0KKnSCVLtlQk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     "]], LineBox[CompressedData["
1:eJwBcQKO/SFib1JlAgAAACYAAAACAAAAzUBQY7pAE0BdK449UOATQIq3dWU3
QhNAhuxojtOWE0CcWTccu0UTQLUVveiU9BJAr/v40j5JE0Br9xhPj1wSQMKd
uonCTBNA2xm0Y9PNEUDUP3xARlATQIn+vByORxFA+oP/rU1XE0Cweng7kVEQ
QA0mwWTRWhNAIJQxrz/BD0AgyIIbVV4TQJzgzJhY6w5ARQwGiVxlE0BGpmCS
4F8NQFiuxz/gaBNAUfR82LmoDEBqUIn2Y2wTQCerys9d+gtAkJQMZGtzE0A2
csQznbUKQKM2zhrvdhNAXo9cuiYeCkC22I/RcnoTQMiIoiRUjQlA2xwTP3qB
E0AuLYfn730IQCalGRqJjxNA0gAdV02eBkA5R9vQDJMTQKzuRB7OMQZATOmc
h5CWE0CbWfolXckFQHEtIPWXnRNA23+os8YDBUCEz+GrG6ETQFdoqWs7pgRA
lnGjYp+kE0A5XS4a8ksEQLy1JtCmqxNAL4qTBX6gA0DPV+iGKq8TQBoKVHkG
TwNA4vmpPa6yE0D3BlbfNgADQAc+Lau1uRNApCAPow9qAkBSxjOGxMcTQKM6
Go+LWAFAZWj1PEjLE0AxEt4FLhkBQHgKt/PLzhNADucnwqXbAECdTjph09UT
QKVeJ6LGZQBA6NZAPOLjE0BkbWodxhn/P/p4AvNl5xNAaB0rMXi0/j8NG8Sp
6eoTQLKtUgzNUf4/Ml9HF/HxE0AirGWq+ZP9P0UBCc509RNAuYub2aE4/T9Y
o8qE+PgTQDKIgoGN3/w/akWMO3z8E0AJf9ilp4j8P33nTfL//xNAuTrTStwz
/D/WmgYs
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.6000000000000001},
  GridLines->
   NCache[{{Rational[-3, 2] Pi, -Pi, Rational[-1, 2] Pi, 0, Rational[1, 2] Pi,
       Pi, Rational[3, 2] 
      Pi}, {}}, {{-4.71238898038469, -3.141592653589793, -1.5707963267948966`,
       0, 1.5707963267948966`, 3.141592653589793, 4.71238898038469}, {}}],
  Method->{},
  PlotRange->{{-5, 5}, {0.5000000216123385, 4.96905609302743}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.618634421799204*^9, 3.6186344465113153`*^9}, 
   3.621832360120007*^9, {3.6218338464749393`*^9, 3.621833908394412*^9}, 
   3.627285722224752*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exportplots", "Section",
 CellChangeTimes->{{3.627286172982983*^9, 3.627286174366362*^9}}],

Cell["", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3d-Plots", "Section",
 CellChangeTimes->{{3.6272861829496403`*^9, 3.627286184639179*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"fun", " ", "=", " ", 
     RowBox[{
      RowBox[{"funk", "[", 
       RowBox[{"19.5", ",", "#"}], "]"}], "&"}]}], "}"}], ",", 
   RowBox[{"ParametricPlot", "[", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
     "just", " ", "need", " ", "a", " ", "vis", " ", "function", " ", "that", 
      " ", "will", " ", "allow", " ", "x", " ", "and", " ", "y", " ", "to", 
      " ", "be", " ", "in", " ", "the", " ", "color", " ", "function"}], 
     "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"color", " ", "and", " ", "mesh", " ", "functions", " ", 
        RowBox[{"don", "'"}], "t", " ", "trigger", " ", "refinement"}], ",", 
       RowBox[{
       "so", " ", "just", " ", "use", " ", "a", " ", "big", " ", "grid"}]}], 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"PlotPoints", "\[Rule]", "50"}], ",", 
     RowBox[{"MaxRecursion", "\[Rule]", "0"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "50"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRangeClipping", "\[Rule]", "False"}], ",", 
     RowBox[{"(*", 
      RowBox[{
      "turn", " ", "off", " ", "scaling", " ", "so", " ", "we", " ", "can", 
       " ", "do", " ", "computations", " ", "with", " ", "the", " ", "actual",
        " ", "complex", " ", "values"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Hue", "[", "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"hue", " ", "according", " ", "to", " ", "argument"}], ",", 
           RowBox[{
            RowBox[{"with", " ", "shift", " ", "so", " ", "arg", 
             RowBox[{"(", "z", ")"}]}], "\[Equal]", 
            RowBox[{"0", " ", "is", " ", "red"}]}]}], "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Rescale", "[", 
           RowBox[{
            RowBox[{"Arg", "[", 
             RowBox[{"fun", "[", 
              RowBox[{"#", "+", 
               RowBox[{"I", " ", "#2"}]}], "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "\[Pi]"}], ",", "\[Pi]"}], "}"}], ",", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}], "+", "0.5"}]}], "]"}], ",", "1",
           ",", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"fudge", " ", "brightness", " ", "a", " ", 
             RowBox[{"bit", ":", "\[IndentingNewLine]", 
              RowBox[{
              "0.1", " ", "keeps", " ", "things", " ", "from", " ", "getting",
                " ", "too", " ", "dark"}]}]}], ",", "\[IndentingNewLine]", 
            RowBox[{
            "2", " ", "forces", " ", "some", " ", "actual", " ", "bright", 
             " ", "areas"}]}], "*)"}], "\[IndentingNewLine]", 
          RowBox[{"Rescale", "[", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{"fun", "[", 
              RowBox[{"#", "+", 
               RowBox[{"I", " ", "#2"}]}], "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "1.6"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.21", ",", "1"}], "}"}]}], "]"}]}], "]"}], "&"}], 
       ")"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
       "mesh", " ", "lines", " ", "according", " ", "to", " ", "magnitude"}], 
       ",", 
       RowBox[{
        RowBox[{
        "scaled", " ", "to", " ", "avoid", " ", "the", " ", "pole", " ", "at",
          " ", "z"}], "=", "1"}]}], "*)"}], 
     RowBox[{"MeshFunctions", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{"fun", "[", 
          RowBox[{"#1", "+", 
           RowBox[{"I", " ", "#2"}]}], "]"}], "]"}], "&"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", " ", "True"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ImageSize", "\[Rule]", " ", "Medium"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", " ", "All"}], ",", "\[IndentingNewLine]", 
     RowBox[{"FrameTicksStyle", "\[Rule]", " ", 
      RowBox[{"(", 
       RowBox[{"FontOpacity", "\[Rule]", " ", "0.5"}], ")"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"FontSize", "\[Rule]", "10"}], "}"}]}]}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{"for", " ", "export"}], " ", "*)"}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.618630918731388*^9, 3.618630919094636*^9}, {
  3.618631443792197*^9, 3.618631444474784*^9}, {3.618632717918118*^9, 
  3.61863276798846*^9}, {3.618634270199703*^9, 3.618634272030711*^9}, {
  3.6186349205653687`*^9, 3.618634921712338*^9}, {3.6272860899290752`*^9, 
  3.6272860914982557`*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxk3Qc41u3bB3BJPQ0pDS2VaEjS1hLapZK2VEJpLy0aSshKdhKydwgJKd1a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   "], {{
     {Hue[0.67, 0.6, 0.6], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtl3uQz1UUwC9qX7+X/e1vyXqtRy3NxLJLocJUiNYuq2k8Fu1GFrUhrfcj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         "]], 
        PolygonBox[CompressedData["
1:eJxMnQW0ltXztk/3ObTdit2B2CKgYmIAYoBYiIUFiIqKIjZ2Y2BiYSIKBqHY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         "]], PolygonBox[CompressedData["
1:eJwtmHt4zUcax+ekcpGTc8tJ3NJGsFuiJa6p0G2I1VRDkSgqbDTaxCV1LaFJ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         "]], PolygonBox[CompressedData["
1:eJwl0U8ow3EcxvHHzLANs81ykFLLwWmEpXBwYBzmz0EcKOOgHbi4WDsMKeXP
AScOnFysJTmwbHFxUkopW5TaRRRlqznJe+3wque79X1+v8/n1xRYHFswSHLB
hOYq6YQfnhEkz2IOHTapHW810p9R8pRJA5wd/GdH0iotGYp3Cx1TnG3kPhyS
d7GHUYc0AhM2yqU4psn9ZqmB5/vhI/egFzmnVF8pDaGrTmpFG3LcySKJxgo6
kScf2SU3nePIkF/wiqdaaYcBb+DkbIEVZxYpVCJFkSGnkIaH567SeYEgeQYB
rFRLEQziuFR6xDo5xJ1leOGiy4c1coIZrjGPCLOd44GcZkcpbMNMRzfeyd/s
9Asx7LPjO+TJW7zrJrz4MRVnLMwa5nsc8D3ucUu+xBWi7OgUkwizuxgSZDd7
+KWzhY4Jsh/DiDODkY5OZMkf+MQ/W9BK1g==
         "]]}]}, {}, {}, {}, {}}, {
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1Ed0TUEABuCRKNF7r9GiR+8LNrFhwwYL7eiiW7Bhw4ajk6KkkESJkiiJ
Ft1B9L5hw0bvvX+Xxff+e887M/PunX9e/ITZw2eVCSEM8REjo+seTCKVy/yg
sy/GspZzfCLBgFGsoIQ3xMeGMIJlFPOMxmVDGMYSCnlC3XLWZBH5PKJ6+RAG
M59cHlCxQggDmEkmt4iNC6EXU0jnCr9IrBjCeNazgY2kkEoa6WxiM1vYSgaZ
ZJHNNraTQy557GAnuxhdN4TdcqKcxGSmMJVpTGcGycxkFrOZw1zmMZ8F5Jtn
pVzFatawlnWsZwMbSSGVNNLZxGa2sJUMMskim21sJ4dc8tjBTnZFv5891j4h
j3OMoxyhmCIOc4iDHKCQAvazj73Gn5Ql0b3r/RRQyAEOcojDFFHMEY5yjOPR
+pRE83CK05zhLOc4zzrG0YWf9riUNCbTkxhu6kQGyfQnjvu6k8M8BlGNhzq2
m4UkUYfHuljAYobSiKc6W8RShtOC17p9guWMpC0fnYGzrGEMnfjurFwihYl0
pxtdSaRLdJboREc60J52JNCWNrSmFS2JpwXNaUZTmpBUyRmicTSvTKQr3ehO
D3rSi970oS/96M8ABtLI+PKyHGWJJYYyBP5497/5Fe0BP/jON77yhc984iMf
eM873vKG17ziJS94zjMaWuKBvM897nKH29ziJje4zjWucoVSLnOJizQwzwVZ
X9ZDLUMdalOLmtSgOtWoShUq/3/EYGhQpVAheheoRlCFYOv//S/+BSACsYc=

       "],
       VertexColors->None]}, {}, {}, 
     {GrayLevel[0], Opacity[0.3], 
      LineBox[{2501, 2502, 2633, 2665, 2769, 2832, 2872, 2948, 2993, 3044, 
       3090, 3166, 3228, 3263, 3368, 3435, 3470, 3561, 3612, 3658, 3718, 3771,
        3828, 3869, 3966, 4034, 4065, 4169, 4230, 4271, 4344, 4389, 4441, 
       4487, 4566, 4629, 4664, 4769, 4836, 4871, 4959, 5009, 5055, 5112, 5169,
        5227, 5267, 5366, 5434, 5466},
       VertexColors->None], 
      LineBox[{2503, 2529, 2634, 2676, 2779, 2835, 2880, 2951, 2999, 3049, 
       3096, 3175, 3230, 3273, 3378, 3437, 3479, 3567, 3617, 3664, 3721, 3779,
        3832, 3877, 3976, 4035, 4075, 4177, 4234, 4279, 4347, 4395, 4446, 
       4493, 4575, 4631, 4674, 4779, 4838, 4880, 4965, 5014, 5061, 5115, 5177,
        5230, 5277, 5377, 5435, 5476},
       VertexColors->None], 
      LineBox[{2537, 2600, 2652, 2675, 2693, 2778, 2817, 2857, 2914, 2974, 
       3028, 3075, 3126, 3213, 3250, 3272, 3290, 3377, 3419, 3457, 3518, 3598,
        3643, 3694, 3742, 3812, 3854, 3915, 4018, 4052, 4117, 4215, 4256, 
       4312, 4368, 4425, 4472, 4524, 4614, 4651, 4673, 4691, 4778, 4820, 4858,
        4918, 4995, 5040, 5090, 5138, 5211, 5252, 5276, 5294, 5376, 5418, 
       5453, 5517},
       VertexColors->None], LineBox[{2620, 2590, 2566},
       VertexColors->None], LineBox[{2631, 2623, 2575, 2551},
       VertexColors->None], 
      LineBox[{5492, 5475, 5452, 5417, 5375, 5293, 5275, 5251, 5210, 5137, 
       5089, 5039, 4994, 4917, 4857, 4819, 4777, 4690, 4672, 4650, 4613, 4523,
        4471, 4424, 4367, 4311, 4255, 4214, 4176, 4091, 4074, 4051, 4017, 
       3975, 3893, 3876, 3853, 3811, 3741, 3693, 3642, 3597, 3517, 3456, 3418,
        3376, 3289, 3271, 3249, 3212, 3125, 3074, 3027, 2973, 2913, 2856, 
       2816, 2777, 2692, 2674, 2651, 2599, 2528, 2519},
       VertexColors->None], LineBox[{5546, 5516, 5564},
       VertexColors->None], LineBox[{5550, 5502, 5532},
       VertexColors->None], LineBox[{5565, 5548, 5500, 5530},
       VertexColors->None], 
      LineBox[{2504, 2530, 2635, 2677, 2780, 2836, 2881, 2952, 3000, 3050, 
       3097, 3176, 3231, 3274, 3379, 3438, 3480, 3568, 3618, 3665, 3722, 3780,
        3833, 3878, 3977, 4036, 4076, 4178, 4235, 4280, 4348, 4396, 4447, 
       4494, 4576, 4632, 4675, 4780, 4839, 4881, 4966, 5015, 5062, 5116, 5178,
        5231, 5278, 5378, 5436, 5477},
       VertexColors->None], 
      LineBox[{2505, 2531, 2636, 2678, 2781, 2837, 2882, 2953, 3001, 3051, 
       3098, 3177, 3232, 3275, 3380, 3439, 3481, 3569, 3619, 3666, 3723, 3781,
        3834, 3879, 3978, 4037, 4077, 4179, 4236, 4281, 4349, 4397, 4448, 
       4495, 4577, 4633, 4676, 4781, 4840, 4882, 4967, 5016, 5063, 5117, 5179,
        5232, 5279, 5379, 5437, 5478},
       VertexColors->None], 
      LineBox[{2506, 2532, 2637, 2679, 2782, 2838, 2883, 2954, 3002, 3052, 
       3099, 3178, 3233, 3276, 3381, 3440, 3482, 3570, 3620, 3667, 3724, 3782,
        3835, 3880, 3979, 4038, 4078, 4180, 4237, 4282, 4350, 4398, 4449, 
       4496, 4578, 4634, 4677, 4782, 4841, 4883, 4968, 5017, 5064, 5118, 5180,
        5233, 5280, 5380, 5438, 5479},
       VertexColors->None], 
      LineBox[{2507, 2533, 2638, 2680, 2783, 2839, 2884, 2955, 3003, 3053, 
       3100, 3179, 3234, 3277, 3382, 3441, 3483, 3571, 3621, 3668, 3725, 3783,
        3836, 3881, 3980, 4039, 4079, 4181, 4238, 4283, 4351, 4399, 4450, 
       4497, 4579, 4635, 4678, 4783, 4842, 4884, 4969, 5018, 5065, 5119, 5181,
        5234, 5281, 5381, 5439, 5480},
       VertexColors->None], 
      LineBox[{2508, 2534, 2639, 2681, 2784, 2840, 2885, 2956, 3004, 3054, 
       3101, 3180, 3235, 3278, 3383, 3442, 3484, 3572, 3622, 3669, 3726, 3784,
        3837, 3882, 3981, 4040, 4080, 4182, 4239, 4284, 4352, 4400, 4451, 
       4498, 4580, 4636, 4679, 4784, 4843, 4885, 4970, 5019, 5066, 5120, 5182,
        5235, 5282, 5382, 5440, 5481},
       VertexColors->None], 
      LineBox[{2509, 2535, 2640, 2682, 2785, 2841, 2886, 2957, 3005, 3055, 
       3102, 3181, 3236, 3279, 3384, 3443, 3485, 3573, 3623, 3670, 3727, 3785,
        3838, 3883, 3982, 4041, 4081, 4183, 4240, 4285, 4353, 4401, 4452, 
       4499, 4581, 4637, 4680, 4785, 4844, 4886, 4971, 5020, 5067, 5121, 5183,
        5236, 5283, 5383, 5441, 5482},
       VertexColors->None], 
      LineBox[{2510, 2536, 2641, 2683, 2786, 2833, 2847, 2873, 2887, 2958, 
       2994, 3018, 3045, 3056, 3103, 3182, 3237, 3280, 3385, 3444, 3486, 3574,
        3613, 3633, 3659, 3671, 3728, 3772, 3802, 3829, 3839, 3884, 3983, 
       4042, 4082, 4184, 4231, 4246, 4272, 4286, 4354, 4390, 4415, 4442, 4453,
        4500, 4582, 4638, 4681, 4786, 4845, 4887, 4972, 5010, 5030, 5056, 
       5068, 5122, 5170, 5201, 5228, 5237, 5284, 5384, 5442, 5483},
       VertexColors->None], LineBox[CompressedData["
1:eJwVzz0oBAAAhuFPt/j/OT+ZcJPJwnaTwSAZdBYyKINBd2wyKIvBJkkmmZBR
N0vmSzJRNmKXcpPyGJ7pnd7S2lZlsyXJAo9tyQuj7ckiG+zyTrEjGaPMLIfU
afDJ13/vTFbZ54xLnih3JVV2OOScJiPdySTzLHHELa/8kJ5kgj2uafDGN8u9
yQGn3HBHoS8ZZ5oV1jnhmV+Git6Yo84HX7T2J8PUOOaKex4oDCRTVKixzQVN
SoPJDCtU+QMHfy6r
       "],
       VertexColors->None], LineBox[CompressedData["
1:eJwNwytoQgEAhtH/gsX5fgWTXi1aVmaRpQWDyGCoZXKDWAyiZkHBYrCJiBjF
MIZRzEPMlyGmCTbDugzUMvwOHLPWLrYMSW/cOaUD4w9SmQ32uOeNpkt6Zp4j
rmnzl2eabqnKAZfccM+0RyqxwxHnvDLmlZ74yneO+cUjLzR80iP7XNLmiX+s
+KUhZ1xxQ0dASvGFFuuc8of/TAalLAtc0OaZzpAUZYsTfnLLbzrCUoYldjnh
B69MRKQcLTZ5BypbL+s=
       "],
       VertexColors->None], LineBox[CompressedData["
1:eJwNwy1oAgEAhuHPcIi/2/wpBlG34orFFVkyGERE5CyCQZNB1DxQWLGLHLIo
BhkXx7KI+RhiUlgz2MWgRd8HnmSrV+26JFW48Uh7Jr1SjR0OueWVKZ/0ziLH
/KXDI09M+aUmR7S54pavAcnkB8ec8cJEUMqyzDonXPKf7gcpzgw/adPhgWcW
H6U+v/jDFY0nKc08G2xzyh1vfAlJOZY4p8MTvWEpxh4tfnPNPxoR6Y0mB7S4
4IXPUanABru8A673Lzw=
       "],
       VertexColors->None], LineBox[CompressedData["
1:eJwNyT0oBAAABtDPch3n/5gM8rewWFhkMhgukTqLkuxcrEJZmC9JRhkko8y6
zJd0E2WzmGUg5Q1veiNbtdWdtiQrvLQnb4x2JGtsc0SLX8ZKyTwV6jzQ5I9y
p2eLE+5o0GKqK6myT50rPil2JzMss84Zj7xT7EmGmeaYO5p88E2lN9nlknsa
FPqSSRbY45QLXkl/MsEcS1zT5ItSORlikwNueeKZwkAyS5VDzrnhh/HBZJEN
avwDmj4tog==
       "],
       VertexColors->None], LineBox[CompressedData["
1:eJwNyT0rBAAABuD3Jp3z/bEZyMdksbDIZDBckuGMwmQ5YhVKwizpMsog3egH
6H7ADboJ2Sxm6SJ5hmd6xjZ3VquFJCs8F5NXxjuTNaoc0+KXiVKyQJlTajT5
Y6jLs8U5dRq0mO5OKhxwyS2fFHuSWbY544on3in2JqPMcEKdJh98U+5L9rjh
kQZtSv3JIvtcUOOFwkAyxTzL3NHki67BZIQNDnngjTYdQ8kcFY645p4fJoeT
JdbZ5R9Hyi8b
       "],
       VertexColors->None], LineBox[CompressedData["
1:eJwNyT0rBAAABuCXiXPn22i48jFZLCwyGQwXWc6oy2RwiVUoCbOkyyiDdKMf
ID/gBt2EbBazdBHP8ExPuVZf2+5Ksspzb/LKRCFZp84RbX6Z7EsWqXBCgxZ/
jBU9m5zR5Ik2M6Wkyj4X3PBJoT+ZY4tTLnnkncJAUmaWY5q0+OCbymCyyzUP
PNGhOJQsscc5DV7oHk6mWWCFW1p8URpJxqlxwD1vdOgZTeapcsgVd/wwNZYs
s8EO/3pqL2s=
       "],
       VertexColors->None], 
      LineBox[{2517, 2526, 2597, 2649, 2672, 2690, 2775, 2814, 2854, 2911, 
       2971, 3025, 3072, 3094, 3110, 3173, 3210, 3247, 3269, 3287, 3374, 3416,
        3454, 3477, 3493, 3565, 3595, 3640, 3691, 3739, 3809, 3851, 3874, 
       3891, 3973, 4015, 4049, 4072, 4089, 4174, 4212, 4253, 4309, 4365, 4422,
        4469, 4491, 4507, 4573, 4611, 4648, 4670, 4688, 4775, 4817, 4855, 
       4878, 4894, 4963, 4992, 5037, 5087, 5135, 5208, 5249, 5273, 5291, 5373,
        5415, 5450, 5473, 5490},
       VertexColors->None], 
      LineBox[{2518, 2527, 2598, 2650, 2673, 2691, 2776, 2815, 2855, 2912, 
       2972, 3026, 3073, 3095, 3111, 3174, 3211, 3248, 3270, 3288, 3375, 3417,
        3455, 3478, 3494, 3566, 3596, 3641, 3692, 3740, 3810, 3852, 3875, 
       3892, 3974, 4016, 4050, 4073, 4090, 4175, 4213, 4254, 4310, 4366, 4423,
        4470, 4492, 4508, 4574, 4612, 4649, 4671, 4689, 4776, 4818, 4856, 
       4879, 4895, 4964, 4993, 5038, 5088, 5136, 5209, 5250, 5274, 5292, 5374,
        5416, 5451, 5474, 5491},
       VertexColors->None], 
      LineBox[{2538, 2601, 2653, 2718, 2818, 2858, 2915, 2975, 3029, 3076, 
       3127, 3214, 3251, 3315, 3420, 3458, 3519, 3599, 3644, 3695, 3743, 3813,
        3855, 3916, 4019, 4053, 4118, 4216, 4257, 4313, 4369, 4426, 4473, 
       4525, 4615, 4652, 4716, 4821, 4859, 4919, 4996, 5041, 5091, 5139, 5212,
        5253, 5316, 5419, 5454, 5518},
       VertexColors->None], 
      LineBox[{2539, 2602, 2654, 2719, 2819, 2859, 2916, 2976, 3030, 3077, 
       3128, 3215, 3252, 3316, 3421, 3459, 3520, 3600, 3645, 3696, 3744, 3814,
        3856, 3917, 4020, 4054, 4119, 4217, 4258, 4314, 4370, 4427, 4474, 
       4526, 4616, 4653, 4717, 4822, 4860, 4920, 4997, 5042, 5092, 5140, 5213,
        5254, 5317, 5420, 5455, 5519},
       VertexColors->None], 
      LineBox[{2540, 2603, 2655, 2720, 2820, 2860, 2917, 2977, 3031, 3078, 
       3129, 3216, 3253, 3317, 3422, 3460, 3521, 3601, 3646, 3697, 3745, 3815,
        3857, 3918, 4021, 4055, 4120, 4218, 4259, 4315, 4371, 4428, 4475, 
       4527, 4617, 4654, 4718, 4823, 4861, 4921, 4998, 5043, 5093, 5141, 5214,
        5255, 5318, 5421, 5456, 5520},
       VertexColors->None], 
      LineBox[{2541, 2604, 2656, 2721, 2821, 2861, 2918, 2978, 3006, 3035, 
       3060, 3079, 3130, 3217, 3254, 3318, 3423, 3461, 3522, 3602, 3624, 3649,
        3676, 3698, 3746, 3816, 3858, 3919, 4022, 4056, 4121, 4219, 4260, 
       4316, 4372, 4402, 4432, 4457, 4476, 4528, 4618, 4655, 4719, 4824, 4862,
        4922, 4999, 5021, 5046, 5073, 5094, 5142, 5215, 5256, 5319, 5422, 
       5457, 5521},
       VertexColors->None], 
      LineBox[{2542, 2605, 2657, 2722, 2822, 2842, 2864, 2894, 2919, 2979, 
       3007, 3036, 3061, 3080, 3131, 3183, 3220, 3239, 3255, 3319, 3424, 3445,
        3462, 3495, 3523, 3603, 3625, 3650, 3677, 3699, 3747, 3786, 3820, 
       3842, 3859, 3920, 4023, 4057, 4122, 4220, 4241, 4263, 4293, 4317, 4373,
        4403, 4433, 4458, 4477, 4529, 4583, 4621, 4640, 4656, 4720, 4825, 
       4846, 4863, 4896, 4923, 5000, 5022, 5047, 5074, 5095, 5143, 5184, 5219,
        5239, 5257, 5320, 5423, 5458, 5522},
       VertexColors->None], LineBox[CompressedData["
1:eJwNzitLAwAAhdErhjEf8zVFWFo1OTAuKP4A3eyCwyAIPkDFolU0iWI2uLBs
GlgMIojRNtC8ImtiMHjCKR833Gprv7k3lGSdQTEpjCTLNGnxQGE0qVBjjR3a
PPPJD8WxpM4Bd3To8svWeHLCBR1eKJeSBVbZ5Ig273wzPGFDg2ue6PFHZTI5
44YOr3wxN5Us0WSXcx7pU5pOqtQ4pMeAzOjUueSeLh/0mS8nK2xzyhVvLM76
zgbH3PIPF8wsuw==
       "],
       VertexColors->None], LineBox[CompressedData["
1:eJwNyr0rBAAAh+HfleHufJzPpG5htV2MN5A/4Dp2RQYlopCFTWISmQ1uuNl0
ZTFIyWi7Yr5Ft8mgPMOzvL2zG3vN3UKSBv1SUiwnS2xyzgPFwaRKjQbbtHjm
kx/KQ0mdfe5o0+GXjeHkmAvavDA1ksyzwjqHtHjnm4GKhybXPNHlj+pocsoN
bV75YnosWWSVHc54pEdlPJmjxgFd+hQmdOpcck+HD3rMTCbLbHHCFW+UppIF
1jjiln+DHC0G
       "],
       VertexColors->None], LineBox[CompressedData["
1:eJwNzj0oBAAAhuGPMtydn/Ob1A2y2sSibiC7n7NLukGhKMrCJjGJzAYG801X
FoOUjCbqzLfIJoM8w7O9wzu+vrO83ZFkke9CUigmc2xwwi2FUlJhiiU2ueOR
Fj+UupMqu1zT5J1fZnuSOqfc88RIbzLJAmvsc8crX3T1aVjhggc++KNSTo64
5J5nPhntT2aoscUxDdqUB/xTY48GLToHkwmqnHFDkzfajA0l89Q55JwXisPJ
NKsccMU/rsAtRA==
       "],
       VertexColors->None], LineBox[CompressedData["
1:eJwNzj0oBAAAhuFPSrnzd36S1JWy2sSibiCzLuyUblBnoCgLm8QkMhvccPNN
VxaDlIwm6sy3yCYDz/Bs7/DObO9V6z1J1vjuTwqFZJkdzrinUEzKzFNllwaP
dPhhYCCpsM8tbd75ZWkwqXFOkycmh5I5VtnikAavfNE3rGGdKx744I/ySHLC
NU2e+WSqlCyyQZ1TWnQpjfpngwNadOgdS2apcMEdbd7oMj2erFDjmEteKE4k
C2xyxA3/4WAtlA==
       "],
       VertexColors->None], LineBox[CompressedData["
1:eJwNzj0oBAAABtBPWbg7P4fSpWSw2vws6gayipzBdoNukFsoViZJGZTMBjdc
2W5SFoOUjCaKjLfIJoM3vP1N1Ztruz1JVvnpSwr9yRLbnHDDF6VCMss6O7R4
4INfSsWkyh5X3PHGH4ulpMEpbR4ZH0hmWKHOAS1e+KYymMyxwQX3vJOhZJIt
jmnzxCeV4WSBGk2O6NClXPanxj4dPugdSaapcsY1d7zSZWI0WabBObc8UxxL
5tnkkEv+AWVTLdg=
       "],
       VertexColors->None], LineBox[CompressedData["
1:eJwNzz0oBAAYgOHvBgPOOY6iS7EY2fwsZCCLRXIGw8WgG/wshMWARboyKJkp
N1wZ1E1XFoOUjDdRJ4Phlssm5Rme3vkdWtte3EpERJ6f1ohkW8QsG5xxxxep
9ogRxthniU1KPFGjTjoZ8aspnWGXa6q888dUR0SBc8o805+KGGWaeY5Y54AS
b3zTpK8zIss4y1zyyAeJdMQgq5xwS5kGL3yS7YqYZIEcp+xwTIUGmW6v5Nij
Qp2WTMQwMxS54YEqTWo0GOiJmCNPgSIX3PNKR2/EBCsccsU/A0Q3cw==
       "],
       VertexColors->None], LineBox[CompressedData["
1:eJwNxjsoBAAcwOE/g/I85zHQpUxGlPIo0S1YJCUMBo9BN5wshMWARVIGJTPl
lDKoG3RlMUjJeKUoMhhukU3yDV+/X/vCymS2LCKy/FRG1FZFDDLKMrfsc8En
ieqITnrZYIosOe4p8k6yJuJXE5pmjSNOKdBQG/Gqfwz5RTIcUOSKB1rrIroY
ZoxtltgkxzNffNOSiEjRxzTH5LnjjZ76iHLamWOXc64o8cgHqWTEAOPMsMcq
O+QpUd0Q0UQv+8ywTp4X3qlojJiggzSHnHFDgW+KlGhrihhhngyHHHHNE3XN
Ed30M8slW5zwD+VPPx8=
       "],
       VertexColors->None], LineBox[{2550, 2574, 2622, 2630},
       VertexColors->None], LineBox[{2552, 2576, 2606},
       VertexColors->None], LineBox[{2553, 2577, 2607},
       VertexColors->None], LineBox[{2554, 2578, 2608},
       VertexColors->None], LineBox[{2555, 2579, 2609},
       VertexColors->None], LineBox[{2556, 2580, 2610},
       VertexColors->None], LineBox[{2557, 2581, 2611},
       VertexColors->None], LineBox[{2558, 2582, 2612},
       VertexColors->None], LineBox[{2559, 2583, 2613},
       VertexColors->None], LineBox[{2560, 2584, 2614},
       VertexColors->None], LineBox[{2561, 2585, 2615},
       VertexColors->None], LineBox[{2562, 2586, 2616},
       VertexColors->None], LineBox[{2563, 2587, 2617},
       VertexColors->None], LineBox[{2564, 2588, 2618},
       VertexColors->None], LineBox[{2565, 2589, 2619},
       VertexColors->None], LineBox[{5531, 5501, 5549, 5566},
       VertexColors->None], LineBox[{5533, 5503, 5551},
       VertexColors->None], LineBox[{5534, 5504, 5552},
       VertexColors->None], LineBox[{5535, 5505, 5553},
       VertexColors->None], LineBox[{5536, 5506, 5554},
       VertexColors->None], LineBox[{5537, 5507, 5555},
       VertexColors->None], LineBox[{5538, 5508, 5556},
       VertexColors->None], LineBox[{5539, 5509, 5557},
       VertexColors->None], LineBox[{5540, 5510, 5558},
       VertexColors->None], LineBox[{5541, 5511, 5559},
       VertexColors->None], LineBox[{5542, 5512, 5560},
       VertexColors->None], LineBox[{5543, 5513, 5561},
       VertexColors->None], LineBox[{5544, 5514, 5562},
       VertexColors->None], LineBox[{5545, 5515, 5563},
       VertexColors->None], LineBox[{2700, 2730, 2791, 2827, 2767, 2749, 2700},
       VertexColors->None], LineBox[{2701, 2731, 2792, 2828, 2768, 2750, 2701},
       VertexColors->None], LineBox[{2702, 2732, 2793, 2751, 2702},
       VertexColors->None], LineBox[{2703, 2733, 2794, 2752, 2703},
       VertexColors->None], LineBox[{2704, 2734, 2795, 2753, 2704},
       VertexColors->None], LineBox[{2705, 2735, 2796, 2754, 2705},
       VertexColors->None], LineBox[{2706, 2736, 2797, 2755, 2706},
       VertexColors->None], LineBox[{2707, 2737, 2798, 2756, 2707},
       VertexColors->None], LineBox[{2708, 2738, 2799, 2757, 2708},
       VertexColors->None], LineBox[{2709, 2739, 2800, 2758, 2709},
       VertexColors->None], LineBox[{2710, 2740, 2801, 2759, 2710},
       VertexColors->None], LineBox[{2711, 2741, 2802, 2760, 2711},
       VertexColors->None], LineBox[{2712, 2742, 2803, 2761, 2712},
       VertexColors->None], LineBox[{2713, 2743, 2804, 2762, 2713},
       VertexColors->None], LineBox[{2714, 2744, 2805, 2763, 2714},
       VertexColors->None], LineBox[{2715, 2745, 2806, 2764, 2715},
       VertexColors->None], LineBox[{2716, 2746, 2807, 2765, 2716},
       VertexColors->None], LineBox[{2717, 2747, 2808, 2766, 2717},
       VertexColors->None], 
      LineBox[{2902, 2927, 2987, 3015, 3034, 2992, 2947, 2938, 2902},
       VertexColors->None], LineBox[{2903, 2928, 2988, 3016, 2990, 2939, 2903},
       VertexColors->None], LineBox[{2904, 2929, 2989, 3017, 2991, 2940, 2904},
       VertexColors->None], LineBox[{2905, 2930, 2963, 2941, 2905},
       VertexColors->None], LineBox[{2906, 2931, 2964, 2942, 2906},
       VertexColors->None], LineBox[{2907, 2932, 2965, 2943, 2907},
       VertexColors->None], LineBox[{2908, 2933, 2966, 2944, 2908},
       VertexColors->None], LineBox[{2909, 2934, 2967, 2945, 2909},
       VertexColors->None], LineBox[{2910, 2935, 2968, 2946, 2910},
       VertexColors->None], LineBox[{3112, 3139, 3191, 3219, 3165, 3152, 3112},
       VertexColors->None], LineBox[{3113, 3140, 3192, 3153, 3113},
       VertexColors->None], LineBox[{3114, 3141, 3193, 3154, 3114},
       VertexColors->None], LineBox[{3115, 3142, 3194, 3155, 3115},
       VertexColors->None], LineBox[{3116, 3143, 3195, 3156, 3116},
       VertexColors->None], LineBox[{3117, 3144, 3196, 3157, 3117},
       VertexColors->None], LineBox[{3118, 3145, 3197, 3158, 3118},
       VertexColors->None], LineBox[{3119, 3146, 3198, 3159, 3119},
       VertexColors->None], LineBox[{3120, 3147, 3199, 3160, 3120},
       VertexColors->None], LineBox[{3121, 3148, 3200, 3161, 3121},
       VertexColors->None], LineBox[{3122, 3149, 3201, 3162, 3122},
       VertexColors->None], LineBox[{3123, 3150, 3202, 3163, 3123},
       VertexColors->None], LineBox[{3124, 3151, 3203, 3164, 3124},
       VertexColors->None], LineBox[{3296, 3327, 3392, 3428, 3366, 3347, 3296},
       VertexColors->None], LineBox[{3297, 3328, 3393, 3429, 3367, 3348, 3297},
       VertexColors->None], LineBox[{3298, 3329, 3394, 3349, 3298},
       VertexColors->None], LineBox[{3299, 3330, 3395, 3350, 3299},
       VertexColors->None], LineBox[{3300, 3331, 3396, 3351, 3300},
       VertexColors->None], LineBox[{3301, 3332, 3397, 3352, 3301},
       VertexColors->None], LineBox[{3302, 3333, 3398, 3353, 3302},
       VertexColors->None], LineBox[{3303, 3334, 3399, 3354, 3303},
       VertexColors->None], LineBox[{3304, 3335, 3400, 3355, 3304},
       VertexColors->None], LineBox[{3305, 3336, 3401, 3356, 3305},
       VertexColors->None], LineBox[{3306, 3337, 3402, 3357, 3306},
       VertexColors->None], LineBox[{3307, 3338, 3403, 3358, 3307},
       VertexColors->None], LineBox[{3308, 3339, 3404, 3359, 3308},
       VertexColors->None], LineBox[{3309, 3340, 3405, 3360, 3309},
       VertexColors->None], LineBox[{3310, 3341, 3406, 3361, 3310},
       VertexColors->None], LineBox[{3311, 3342, 3407, 3362, 3311},
       VertexColors->None], LineBox[{3312, 3343, 3408, 3363, 3312},
       VertexColors->None], LineBox[{3313, 3344, 3409, 3364, 3313},
       VertexColors->None], LineBox[{3314, 3345, 3410, 3365, 3314},
       VertexColors->None], LineBox[{3503, 3531, 3578, 3611, 3560, 3546, 3503},
       VertexColors->None], LineBox[{3504, 3532, 3579, 3547, 3504},
       VertexColors->None], LineBox[{3505, 3533, 3580, 3548, 3505},
       VertexColors->None], LineBox[{3506, 3534, 3581, 3549, 3506},
       VertexColors->None], LineBox[{3507, 3535, 3582, 3550, 3507},
       VertexColors->None], LineBox[{3508, 3536, 3583, 3551, 3508},
       VertexColors->None], LineBox[{3509, 3537, 3584, 3552, 3509},
       VertexColors->None], LineBox[{3510, 3538, 3585, 3553, 3510},
       VertexColors->None], LineBox[{3511, 3539, 3586, 3554, 3511},
       VertexColors->None], LineBox[{3512, 3540, 3587, 3555, 3512},
       VertexColors->None], LineBox[{3513, 3541, 3588, 3556, 3513},
       VertexColors->None], LineBox[{3514, 3542, 3589, 3557, 3514},
       VertexColors->None], LineBox[{3515, 3543, 3590, 3558, 3515},
       VertexColors->None], LineBox[{3516, 3544, 3591, 3559, 3516},
       VertexColors->None], 
      LineBox[{3685, 3707, 3755, 3794, 3819, 3770, 3717, 3713, 3685},
       VertexColors->None], LineBox[{3686, 3708, 3756, 3795, 3763, 3714, 3686},
       VertexColors->None], LineBox[{3687, 3709, 3757, 3796, 3764, 3715, 3687},
       VertexColors->None], LineBox[{3688, 3710, 3758, 3797, 3765, 3716, 3688},
       VertexColors->None], LineBox[{3735, 3759, 3798, 3766, 3735},
       VertexColors->None], LineBox[{3736, 3760, 3799, 3767, 3736},
       VertexColors->None], LineBox[{3737, 3761, 3800, 3768, 3737},
       VertexColors->None], LineBox[{3738, 3762, 3801, 3769, 3738},
       VertexColors->None], LineBox[{3897, 3928, 3991, 4025, 3964, 3946, 3897},
       VertexColors->None], LineBox[{3898, 3929, 3992, 4026, 3965, 3947, 3898},
       VertexColors->None], LineBox[{3899, 3930, 3993, 3948, 3899},
       VertexColors->None], LineBox[{3900, 3931, 3994, 3949, 3900},
       VertexColors->None], LineBox[{3901, 3932, 3995, 3950, 3901},
       VertexColors->None], LineBox[{3902, 3933, 3996, 3951, 3902},
       VertexColors->None], LineBox[{3903, 3934, 3997, 3952, 3903},
       VertexColors->None], LineBox[{3904, 3935, 3998, 3953, 3904},
       VertexColors->None], LineBox[{3905, 3936, 3999, 3954, 3905},
       VertexColors->None], LineBox[{3906, 3937, 4000, 3955, 3906},
       VertexColors->None], LineBox[{3907, 3938, 4001, 3956, 3907},
       VertexColors->None], LineBox[{3908, 3939, 4002, 3957, 3908},
       VertexColors->None], LineBox[{3909, 3940, 4003, 3958, 3909},
       VertexColors->None], LineBox[{3910, 3941, 4004, 3959, 3910},
       VertexColors->None], LineBox[{3911, 3942, 4005, 3960, 3911},
       VertexColors->None], LineBox[{3912, 3943, 4006, 3961, 3912},
       VertexColors->None], LineBox[{3913, 3944, 4007, 3962, 3913},
       VertexColors->None], LineBox[{3914, 3945, 4008, 3963, 3914},
       VertexColors->None], LineBox[{4099, 4130, 4190, 4225, 4167, 4149, 4099},
       VertexColors->None], LineBox[{4100, 4131, 4191, 4226, 4168, 4150, 4100},
       VertexColors->None], LineBox[{4101, 4132, 4192, 4151, 4101},
       VertexColors->None], LineBox[{4102, 4133, 4193, 4152, 4102},
       VertexColors->None], LineBox[{4103, 4134, 4194, 4153, 4103},
       VertexColors->None], LineBox[{4104, 4135, 4195, 4154, 4104},
       VertexColors->None], LineBox[{4105, 4136, 4196, 4155, 4105},
       VertexColors->None], LineBox[{4106, 4137, 4197, 4156, 4106},
       VertexColors->None], LineBox[{4107, 4138, 4198, 4157, 4107},
       VertexColors->None], LineBox[{4108, 4139, 4199, 4158, 4108},
       VertexColors->None], LineBox[{4109, 4140, 4200, 4159, 4109},
       VertexColors->None], LineBox[{4110, 4141, 4201, 4160, 4110},
       VertexColors->None], LineBox[{4111, 4142, 4202, 4161, 4111},
       VertexColors->None], LineBox[{4112, 4143, 4203, 4162, 4112},
       VertexColors->None], LineBox[{4113, 4144, 4204, 4163, 4113},
       VertexColors->None], LineBox[{4114, 4145, 4205, 4164, 4114},
       VertexColors->None], LineBox[{4115, 4146, 4206, 4165, 4115},
       VertexColors->None], LineBox[{4116, 4147, 4207, 4166, 4116},
       VertexColors->None], 
      LineBox[{4301, 4325, 4381, 4411, 4431, 4388, 4343, 4335, 4301},
       VertexColors->None], LineBox[{4302, 4326, 4382, 4412, 4385, 4336, 4302},
       VertexColors->None], LineBox[{4303, 4327, 4383, 4413, 4386, 4337, 4303},
       VertexColors->None], LineBox[{4304, 4328, 4384, 4414, 4387, 4338, 4304},
       VertexColors->None], LineBox[{4305, 4329, 4359, 4339, 4305},
       VertexColors->None], LineBox[{4306, 4330, 4360, 4340, 4306},
       VertexColors->None], LineBox[{4307, 4331, 4361, 4341, 4307},
       VertexColors->None], LineBox[{4308, 4332, 4362, 4342, 4308},
       VertexColors->None], LineBox[{4509, 4537, 4591, 4620, 4565, 4551, 4509},
       VertexColors->None], LineBox[{4510, 4538, 4592, 4552, 4510},
       VertexColors->None], LineBox[{4511, 4539, 4593, 4553, 4511},
       VertexColors->None], LineBox[{4512, 4540, 4594, 4554, 4512},
       VertexColors->None], LineBox[{4513, 4541, 4595, 4555, 4513},
       VertexColors->None], LineBox[{4514, 4542, 4596, 4556, 4514},
       VertexColors->None], LineBox[{4515, 4543, 4597, 4557, 4515},
       VertexColors->None], LineBox[{4516, 4544, 4598, 4558, 4516},
       VertexColors->None], LineBox[{4517, 4545, 4599, 4559, 4517},
       VertexColors->None], LineBox[{4518, 4546, 4600, 4560, 4518},
       VertexColors->None], LineBox[{4519, 4547, 4601, 4561, 4519},
       VertexColors->None], LineBox[{4520, 4548, 4602, 4562, 4520},
       VertexColors->None], LineBox[{4521, 4549, 4603, 4563, 4521},
       VertexColors->None], LineBox[{4522, 4550, 4604, 4564, 4522},
       VertexColors->None], LineBox[{4697, 4728, 4793, 4829, 4767, 4748, 4697},
       VertexColors->None], LineBox[{4698, 4729, 4794, 4830, 4768, 4749, 4698},
       VertexColors->None], LineBox[{4699, 4730, 4795, 4750, 4699},
       VertexColors->None], LineBox[{4700, 4731, 4796, 4751, 4700},
       VertexColors->None], LineBox[{4701, 4732, 4797, 4752, 4701},
       VertexColors->None], LineBox[{4702, 4733, 4798, 4753, 4702},
       VertexColors->None], LineBox[{4703, 4734, 4799, 4754, 4703},
       VertexColors->None], LineBox[{4704, 4735, 4800, 4755, 4704},
       VertexColors->None], LineBox[{4705, 4736, 4801, 4756, 4705},
       VertexColors->None], LineBox[{4706, 4737, 4802, 4757, 4706},
       VertexColors->None], LineBox[{4707, 4738, 4803, 4758, 4707},
       VertexColors->None], LineBox[{4708, 4739, 4804, 4759, 4708},
       VertexColors->None], LineBox[{4709, 4740, 4805, 4760, 4709},
       VertexColors->None], LineBox[{4710, 4741, 4806, 4761, 4710},
       VertexColors->None], LineBox[{4711, 4742, 4807, 4762, 4711},
       VertexColors->None], LineBox[{4712, 4743, 4808, 4763, 4712},
       VertexColors->None], LineBox[{4713, 4744, 4809, 4764, 4713},
       VertexColors->None], LineBox[{4714, 4745, 4810, 4765, 4714},
       VertexColors->None], LineBox[{4715, 4746, 4811, 4766, 4715},
       VertexColors->None], LineBox[{4904, 4931, 4976, 5008, 4958, 4945, 4904},
       VertexColors->None], LineBox[{4905, 4932, 4977, 4946, 4905},
       VertexColors->None], LineBox[{4906, 4933, 4978, 4947, 4906},
       VertexColors->None], LineBox[{4907, 4934, 4979, 4948, 4907},
       VertexColors->None], LineBox[{4908, 4935, 4980, 4949, 4908},
       VertexColors->None], LineBox[{4909, 4936, 4981, 4950, 4909},
       VertexColors->None], LineBox[{4910, 4937, 4982, 4951, 4910},
       VertexColors->None], LineBox[{4911, 4938, 4983, 4952, 4911},
       VertexColors->None], LineBox[{4912, 4939, 4984, 4953, 4912},
       VertexColors->None], LineBox[{4913, 4940, 4985, 4954, 4913},
       VertexColors->None], LineBox[{4914, 4941, 4986, 4955, 4914},
       VertexColors->None], LineBox[{4915, 4942, 4987, 4956, 4915},
       VertexColors->None], LineBox[{4916, 4943, 4988, 4957, 4916},
       VertexColors->None], 
      LineBox[{5082, 5103, 5151, 5192, 5218, 5168, 5111, 5108, 5082},
       VertexColors->None], LineBox[{5083, 5104, 5152, 5193, 5160, 5109, 5083},
       VertexColors->None], LineBox[{5084, 5105, 5153, 5194, 5161, 5110, 5084},
       VertexColors->None], LineBox[{5129, 5154, 5195, 5162, 5129},
       VertexColors->None], LineBox[{5130, 5155, 5196, 5163, 5130},
       VertexColors->None], LineBox[{5131, 5156, 5197, 5164, 5131},
       VertexColors->None], LineBox[{5132, 5157, 5198, 5165, 5132},
       VertexColors->None], LineBox[{5133, 5158, 5199, 5166, 5133},
       VertexColors->None], LineBox[{5134, 5159, 5200, 5167, 5134},
       VertexColors->None], LineBox[{5298, 5328, 5391, 5426, 5364, 5346, 5298},
       VertexColors->None], LineBox[{5299, 5329, 5392, 5427, 5365, 5347, 5299},
       VertexColors->None], LineBox[{5300, 5330, 5393, 5348, 5300},
       VertexColors->None], LineBox[{5301, 5331, 5394, 5349, 5301},
       VertexColors->None], LineBox[{5302, 5332, 5395, 5350, 5302},
       VertexColors->None], LineBox[{5303, 5333, 5396, 5351, 5303},
       VertexColors->None], LineBox[{5304, 5334, 5397, 5352, 5304},
       VertexColors->None], LineBox[{5305, 5335, 5398, 5353, 5305},
       VertexColors->None], LineBox[{5306, 5336, 5399, 5354, 5306},
       VertexColors->None], LineBox[{5307, 5337, 5400, 5355, 5307},
       VertexColors->None], LineBox[{5308, 5338, 5401, 5356, 5308},
       VertexColors->None], LineBox[{5309, 5339, 5402, 5357, 5309},
       VertexColors->None], LineBox[{5310, 5340, 5403, 5358, 5310},
       VertexColors->None], LineBox[{5311, 5341, 5404, 5359, 5311},
       VertexColors->None], LineBox[{5312, 5342, 5405, 5360, 5312},
       VertexColors->None], LineBox[{5313, 5343, 5406, 5361, 5313},
       VertexColors->None], LineBox[{5314, 5344, 5407, 5362, 5314},
       VertexColors->None], LineBox[{5315, 5345, 5408, 5363, 5315},
       VertexColors->None]}}},
   VertexColors->{
     Hue[0.5515486632992987, 1, 0.21], 
     Hue[0.5515486632992987, 1, 0.21], 
     Hue[0.5515486632992987, 1, 0.21], 
     Hue[0.5515486632992987, 1, 0.21], 
     Hue[0.5515486632992987, 1, 0.21], 
     Hue[0.5515486632992987, 1, 0.21000000000000002`], 
     Hue[0.5515486632992987, 1, 0.21000000000000021`], 
     Hue[0.5515486632992989, 1, 0.2100000000000015], 
     Hue[0.5515486632992999, 1, 0.21000000000001012`], 
     Hue[0.5515486632993057, 1, 0.21000000000006835`], 
     Hue[0.551548663299346, 1, 0.21000000000046176`], 
     Hue[0.5515486632996187, 1, 0.21000000000311908`], 
     Hue[0.55154866330146, 1, 0.21000000002106775`], 
     Hue[0.5515486633138968, 1, 0.21000000014230152`], 
     Hue[0.5515486633979019, 1, 0.21000000096117097`], 
     Hue[0.5515486639653107, 1, 0.21000000649219774`], 
     Hue[0.5515486677978553, 1, 0.21000004385133944`], 
     Hue[0.5515486936846657, 1, 0.210000296192574], 
     Hue[0.5515488685369327, 1, 0.21000200062954955`], 
     Hue[0.5515500496007931, 1, 0.21001351348521738`], 
     Hue[0.5515580284254163, 1, 0.21009129002153368`], 
     Hue[0.5516119835992145, 1, 0.21061723796572981`], 
     Hue[0.5519792939055541, 1, 0.2141977255703204], 
     Hue[0.5545984411752992, 1, 0.23972701555217074`], 
     Hue[0.5818577926407216, 1, 0.5036668310905273], 
     Hue[0.969690870658577, 1, 0.9732212308782693], 
     Hue[0.9969502221239994, 1, 0.7318407002431545], 
     Hue[0.9995693693937446, 1, 0.7077276559414497], 
     Hue[0.9999366797000843, 1, 0.7043351053769494], 
     Hue[0.9999906348738823, 1, 0.7038365425089924], 
     Hue[0.9999986136985056, 1, 0.7037628108279274], 
     Hue[0.9999997947623659, 1, 0.7037518966056808], 
     Hue[0.999999969614633, 1, 0.7037502807919248], 
     Hue[0.9999999955014435, 1, 0.703750041571273], 
     Hue[0.999999999333988, 1, 0.7037500061546337], 
     Hue[0.9999999999013968, 1, 0.7037500009111946], 
     Hue[0.9999999999854018, 1, 0.7037500001349025], 
     Hue[0.9999999999978387, 1, 0.7037500000199723], 
     Hue[0.99999999999968, 1, 0.703750000002957], 
     Hue[0.9999999999999526, 1, 0.7037500000004377], 
     Hue[0.999999999999993, 1, 0.7037500000000648], 
     Hue[0.999999999999999, 1, 0.7037500000000096], 
     Hue[0.9999999999999999, 1, 0.7037500000000014], 
     Hue[1., 1, 0.7037500000000002], 
     Hue[1., 1, 0.7037500000000001], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.8555670852054492, 1, 0.21], 
     Hue[0.8555670852054492, 1, 0.21], 
     Hue[0.8555670852054492, 1, 0.21], 
     Hue[0.8555670852054492, 1, 0.21], 
     Hue[0.8555670852054492, 1, 0.21], 
     Hue[0.8555670852054492, 1, 0.21000000000000002`], 
     Hue[0.8555670852054493, 1, 0.21000000000000021`], 
     Hue[0.8555670852054496, 1, 0.2100000000000015], 
     Hue[0.8555670852054518, 1, 0.21000000000001012`], 
     Hue[0.8555670852054666, 1, 0.21000000000006835`], 
     Hue[0.8555670852055666, 1, 0.21000000000046176`], 
     Hue[0.8555670852062415, 1, 0.21000000000311908`], 
     Hue[0.8555670852108003, 1, 0.21000000002106775`], 
     Hue[0.8555670852415928, 1, 0.21000000014230152`], 
     Hue[0.8555670854495793, 1, 0.21000000096117097`], 
     Hue[0.8555670868544175, 1, 0.2100000064921976], 
     Hue[0.8555670963433512, 1, 0.21000004385133336`], 
     Hue[0.8555671604360177, 1, 0.21000029619229615`], 
     Hue[0.8555675933467702, 1, 0.2100020006168735], 
     Hue[0.8555705173800201, 1, 0.2100135129068938], 
     Hue[0.8555902654678337, 1, 0.21009126363470623`], 
     Hue[0.8557235530047599, 1, 0.21061603348542643`], 
     Hue[0.8566192754044026, 1, 0.21414257617990481`], 
     Hue[0.8624646737173665, 1, 0.23714818101596827`], 
     Hue[0.8938243627800058, 1, 0.35917740108575724`], 
     Hue[0.9617427224254433, 1, 0.5977024832974579], 
     Hue[0.9931024114880828, 1, 0.6865707397312631], 
     Hue[0.9989478098010466, 1, 0.7011885489040031], 
     Hue[0.9998435322006892, 1, 0.7033704581407715], 
     Hue[0.9999768197376155, 1, 0.7036938020494113], 
     Hue[0.999996567825429, 1, 0.7037416797376235], 
     Hue[0.9999994918586791, 1, 0.703748768180544], 
     Hue[0.9999999247694316, 1, 0.7037498176288509], 
     Hue[0.9999999888620981, 1, 0.703749972999919], 
     Hue[0.9999999983510317, 1, 0.7037499960026335], 
     Hue[0.99999999975587, 1, 0.7037499994081893], 
     Hue[0.9999999999638565, 1, 0.7037499999123823], 
     Hue[0.999999999994649, 1, 0.7037499999870281], 
     Hue[0.9999999999992077, 1, 0.7037499999980795], 
     Hue[0.9999999999998828, 1, 0.7037499999997158], 
     Hue[0.9999999999999827, 1, 0.7037499999999579], 
     Hue[0.9999999999999974, 1, 0.7037499999999938], 
     Hue[0.9999999999999997, 1, 0.7037499999999991], 
     Hue[0.9999999999999999, 1, 0.7037499999999999], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.1595855071115997`, 1, 0.21], 
     Hue[1.1595855071115997`, 1, 0.21], 
     Hue[1.1595855071115997`, 1, 0.21], 
     Hue[1.1595855071115997`, 1, 0.21], 
     Hue[1.1595855071115997`, 1, 0.21], 
     Hue[1.1595855071115997`, 1, 0.21000000000000002`], 
     Hue[1.1595855071115997`, 1, 0.21000000000000021`], 
     Hue[1.1595855071115992`, 1, 0.2100000000000015], 
     Hue[1.159585507111597, 1, 0.21000000000001012`], 
     Hue[1.159585507111581, 1, 0.21000000000006835`], 
     Hue[1.1595855071114742`, 1, 0.21000000000046176`], 
     Hue[1.1595855071107524`, 1, 0.21000000000311908`], 
     Hue[1.1595855071058754`, 1, 0.21000000002106775`], 
     Hue[1.159585507072935, 1, 0.21000000014230152`], 
     Hue[1.1595855068504408`, 1, 0.21000000096117097`], 
     Hue[1.15958550534761, 1, 0.21000000649219763`], 
     Hue[1.1595854951967894`, 1, 0.21000004385133364`], 
     Hue[1.159585426633428, 1, 0.21000029619230995`], 
     Hue[1.1595849635254445`, 1, 0.21000200061750332`], 
     Hue[1.1595818355228467`, 1, 0.21001351293562645`], 
     Hue[1.1595607095874354`, 1, 0.2100912649452139], 
     Hue[1.1594181089079099`, 1, 0.21061609316447627`], 
     Hue[1.1584591910815472`, 1, 0.21414526516845003`], 
     Hue[1.1521758158695474`, 1, 0.23726081829683066`], 
     Hue[1.1178060212025733`, 1, 0.362005515582697], 
     Hue[1.0417794859090266`, 1, 0.6050525712164903], 
     Hue[1.0074096912420525`, 1, 0.6885480225639634], 
     Hue[1.0011263160300525`, 1, 0.7015073844121977], 
     Hue[1.0001673982036898`, 1, 0.7034182540493776], 
     Hue[1.0000247975241645`, 1, 0.7037008912861513], 
     Hue[1.000003671588753, 1, 0.7037427295864425], 
     Hue[1.0000005435861552`, 1, 0.7037489236171113], 
     Hue[1.0000000804781717`, 1, 0.7037498406413983], 
     Hue[1.0000000119148102`, 1, 0.7037499764069336], 
     Hue[1.0000000017639898`, 1, 0.7037499965070425], 
     Hue[1.0000000002611589`, 1, 0.7037499994828671], 
     Hue[1.0000000000386646`, 1, 0.7037499999234383], 
     Hue[1.0000000000057243`, 1, 0.703749999988665], 
     Hue[1.0000000000008475`, 1, 0.7037499999983219], 
     Hue[1.0000000000001255`, 1, 0.7037499999997516], 
     Hue[1.0000000000000187`, 1, 0.7037499999999631], 
     Hue[1.0000000000000027`, 1, 0.7037499999999945], 
     Hue[1.0000000000000004`, 1, 0.7037499999999992], 
     Hue[1., 1, 0.7037499999999999], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.4636039290177503`, 1, 0.21], 
     Hue[1.4636039290177503`, 1, 0.21], 
     Hue[1.4636039290177503`, 1, 0.21], 
     Hue[1.4636039290177503`, 1, 0.21], 
     Hue[1.4636039290177503`, 1, 0.21], 
     Hue[1.4636039290177503`, 1, 0.21000000000000002`], 
     Hue[1.4636039290177503`, 1, 0.21000000000000021`], 
     Hue[1.46360392901775, 1, 0.2100000000000015], 
     Hue[1.4636039290177494`, 1, 0.21000000000001012`], 
     Hue[1.4636039290177452`, 1, 0.21000000000006835`], 
     Hue[1.4636039290177165`, 1, 0.21000000000046176`], 
     Hue[1.4636039290175225`, 1, 0.21000000000311908`], 
     Hue[1.4636039290162108`, 1, 0.21000000002106775`], 
     Hue[1.463603929007352, 1, 0.21000000014230152`], 
     Hue[1.463603928947515, 1, 0.21000000096117097`], 
     Hue[1.4636039285433475`, 1, 0.21000000649219774`], 
     Hue[1.4636039258134121`, 1, 0.21000004385133955`], 
     Hue[1.4636039073741436`, 1, 0.2100002961925786], 
     Hue[1.4636037828262287`, 1, 0.21000200062976], 
     Hue[1.4636029415495004`, 1, 0.2100135134948194], 
     Hue[1.4635972581726586`, 1, 0.2100912904598038], 
     Hue[1.4635588242750295`, 1, 0.21061725802230455`], 
     Hue[1.4632971212000931`, 1, 0.21419865984313397`], 
     Hue[1.4614280290623671`, 1, 0.23977624525759672`], 
     Hue[1.4415430283105986`, 1, 0.5109374027265032], 
     Hue[1.0220609007071517`, 1, 0.992116979548938], 
     Hue[1.0021758999553831`, 1, 0.7327048994732172], 
     Hue[1.0003068078176571`, 1, 0.7078384334112299], 
     Hue[1.0000451047427206`, 1, 0.704351168337323], 
     Hue[1.0000066708450916`, 1, 0.7038389133463756], 
     Hue[1.0000009874682498`, 1, 0.7037631616714557], 
     Hue[1.0000001461915213`, 1, 0.703751948544633], 
     Hue[1.0000000216436067`, 1, 0.703750288481419], 
     Hue[1.0000000032043381`, 1, 0.7037500427097022], 
     Hue[1.0000000004744027`, 1, 0.7037500063231782], 
     Hue[1.0000000000702354`, 1, 0.7037500009361476], 
     Hue[1.0000000000103983`, 1, 0.7037500001385968], 
     Hue[1.0000000000015394`, 1, 0.7037500000205194], 
     Hue[1.0000000000002278`, 1, 0.7037500000030379], 
     Hue[1.0000000000000338`, 1, 0.7037500000004498], 
     Hue[1.0000000000000049`, 1, 0.7037500000000667], 
     Hue[1.0000000000000007`, 1, 0.7037500000000099], 
     Hue[1., 1, 0.7037500000000015], 
     Hue[1., 1, 0.7037500000000002], 
     Hue[1., 1, 0.7037500000000001], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.7676223509239007, 1, 0.21], 
     Hue[0.7676223509239007, 1, 0.21], 
     Hue[0.7676223509239007, 1, 0.21], 
     Hue[0.7676223509239007, 1, 0.21], 
     Hue[0.7676223509239007, 1, 0.21], 
     Hue[0.7676223509239007, 1, 0.21000000000000002`], 
     Hue[0.7676223509239009, 1, 0.21000000000000021`], 
     Hue[0.7676223509239012, 1, 0.2100000000000015], 
     Hue[0.767622350923904, 1, 0.21000000000001012`], 
     Hue[0.7676223509239226, 1, 0.21000000000006835`], 
     Hue[0.7676223509240486, 1, 0.21000000000046176`], 
     Hue[0.7676223509248999, 1, 0.21000000000311908`], 
     Hue[0.7676223509306501, 1, 0.21000000002106775`], 
     Hue[0.7676223509694892, 1, 0.21000000014230152`], 
     Hue[0.7676223512318265, 1, 0.21000000096117097`], 
     Hue[0.767622353003775, 1, 0.21000000649219766`], 
     Hue[0.7676223649723433, 1, 0.2100000438513353], 
     Hue[0.767622445813639, 1, 0.21000029619238592`], 
     Hue[0.7676229918532739, 1, 0.21000200062096896`], 
     Hue[0.7676266800491236, 1, 0.21001351309373506`], 
     Hue[0.7676515913487046, 1, 0.21009127215747084`], 
     Hue[0.7678198311005218, 1, 0.21061642186716176`], 
     Hue[0.7689551357721114, 1, 0.2141601559581766], 
     Hue[0.776567406756815, 1, 0.23790673505113533`], 
     Hue[0.8235781239325133, 1, 0.38108631720156577`], 
     Hue[0.9440442269913872, 1, 0.6546423490052113], 
     Hue[0.9910549441670856, 1, 0.6998867205497598], 
     Hue[0.9986672151517894, 1, 0.7032729971807229], 
     Hue[0.999802519823379, 1, 0.703681506288683], 
     Hue[0.999970759575196, 1, 0.7037399062405317], 
     Hue[0.9999956708747771, 1, 0.7037485066422466], 
     Hue[0.9999993590706269, 1, 0.7037497789306011], 
     Hue[0.9999999051102617, 1, 0.7037499672711307], 
     Hue[0.9999999859515574, 1, 0.7037499951544961], 
     Hue[0.9999999979201257, 1, 0.7037499992826226], 
     Hue[0.9999999996920742, 1, 0.7037499998937922], 
     Hue[0.9999999999544116, 1, 0.7037499999842759], 
     Hue[0.9999999999932506, 1, 0.7037499999976721], 
     Hue[0.9999999999990008, 1, 0.7037499999996554], 
     Hue[0.999999999999852, 1, 0.703749999999949], 
     Hue[0.9999999999999781, 1, 0.7037499999999924], 
     Hue[0.9999999999999968, 1, 0.7037499999999989], 
     Hue[0.9999999999999996, 1, 0.7037499999999998], 
     Hue[0.9999999999999999, 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.0716407728300523`, 1, 0.21], 
     Hue[1.0716407728300523`, 1, 0.21], 
     Hue[1.0716407728300523`, 1, 0.21], 
     Hue[1.0716407728300523`, 1, 0.21], 
     Hue[1.0716407728300523`, 1, 0.21], 
     Hue[1.0716407728300523`, 1, 0.21000000000000002`], 
     Hue[1.0716407728300523`, 1, 0.21000000000000021`], 
     Hue[1.071640772830052, 1, 0.2100000000000015], 
     Hue[1.071640772830051, 1, 0.21000000000001012`], 
     Hue[1.0716407728300428`, 1, 0.21000000000006835`], 
     Hue[1.0716407728299875`, 1, 0.21000000000046176`], 
     Hue[1.071640772829615, 1, 0.21000000000311908`], 
     Hue[1.0716407728270978`, 1, 0.21000000002106775`], 
     Hue[1.0716407728100954`, 1, 0.21000000014230152`], 
     Hue[1.071640772695253, 1, 0.21000000096117097`], 
     Hue[1.0716407719195553`, 1, 0.2100000064921976], 
     Hue[1.0716407666801313`, 1, 0.21000004385133225`], 
     Hue[1.0716407312906318`, 1, 0.21000029619224556`], 
     Hue[1.071640492254274, 1, 0.2100020006145659], 
     Hue[1.0716388777299675`, 1, 0.21001351280161976`], 
     Hue[1.0716279742536945`, 1, 0.21009125883352664`], 
     Hue[1.0715544079817951`, 1, 0.21061581497121662`], 
     Hue[1.0710611723041836`, 1, 0.21413276833031902`], 
     Hue[1.067889283614982, 1, 0.23674710208883298`], 
     Hue[1.0519534581893222`, 1, 0.3500204956031475], 
     Hue[1.0196873146407304`, 1, 0.5739042741244275], 
     Hue[1.0037514892150703`, 1, 0.679530029310073], 
     Hue[1.0005796005258687`, 1, 0.700025624386338], 
     Hue[1.0000863648482572`, 1, 0.7031954539269637], 
     Hue[1.0000127985763578`, 1, 0.7036678299016774], 
     Hue[1.0000018951000849`, 1, 0.7037378331793609], 
     Hue[1.0000002805757784`, 1, 0.7037481986667444], 
     Hue[1.0000000415394206`, 1, 0.7037497333115746], 
     Hue[1.000000006149921, 1, 0.7037499605167175], 
     Hue[1.000000000910497, 1, 0.7037499941544929], 
     Hue[1.0000000001347993`, 1, 0.7037499991345717], 
     Hue[1.0000000000199571`, 1, 0.7037499998718733], 
     Hue[1.0000000000029547`, 1, 0.7037499999810308], 
     Hue[1.0000000000004374`, 1, 0.7037499999971916], 
     Hue[1.0000000000000648`, 1, 0.7037499999995843], 
     Hue[1.0000000000000095`, 1, 0.7037499999999385], 
     Hue[1.0000000000000013`, 1, 0.7037499999999909], 
     Hue[1.0000000000000002`, 1, 0.7037499999999987], 
     Hue[1., 1, 0.7037499999999998], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.375659194736204, 1, 0.21], 
     Hue[1.375659194736204, 1, 0.21], 
     Hue[1.375659194736204, 1, 0.21], 
     Hue[1.375659194736204, 1, 0.21], 
     Hue[1.375659194736204, 1, 0.21], 
     Hue[1.375659194736204, 1, 0.21000000000000002`], 
     Hue[1.375659194736204, 1, 0.21000000000000021`], 
     Hue[1.3756591947362038`, 1, 0.2100000000000015], 
     Hue[1.3756591947362016`, 1, 0.21000000000001012`], 
     Hue[1.3756591947361885`, 1, 0.21000000000006835`], 
     Hue[1.3756591947360992`, 1, 0.21000000000046176`], 
     Hue[1.375659194735496, 1, 0.21000000000311908`], 
     Hue[1.3756591947314218`, 1, 0.21000000002106775`], 
     Hue[1.375659194703904, 1, 0.21000000014230152`], 
     Hue[1.3756591945180352`, 1, 0.21000000096117097`], 
     Hue[1.3756591932625908`, 1, 0.21000000649219774`], 
     Hue[1.3756591847827313`, 1, 0.21000004385133852`], 
     Hue[1.3756591275057755`, 1, 0.21000029619253172`], 
     Hue[1.3756587406293728`, 1, 0.21000200062762042`], 
     Hue[1.375656127435763, 1, 0.21001351339720042`], 
     Hue[1.375638474439293, 1, 0.21009128600437793`], 
     Hue[1.3755191344053717`, 1, 0.21061705420604734`], 
     Hue[1.3747083174790895`, 1, 0.2141891904192185], 
     Hue[1.3690096698007386`, 1, 0.2392868381477764], 
     Hue[1.3188671723401322`, 1, 0.454928651487954], 
     Hue[1.0567920223960723`, 1, 0.8465538326947286], 
     Hue[1.0066495249354654`, 1, 0.7241136384889318], 
     Hue[1.0009508772571145`, 1, 0.7067156362941702], 
     Hue[1.0001400603308324`, 1, 0.7041879354570145], 
     Hue[1.000020720296911, 1, 0.703814811565545], 
     Hue[1.000003067300441, 1, 0.7037595948180524], 
     Hue[1.0000004541068312`, 1, 0.7037514205024846], 
     Hue[1.0000000672304283`, 1, 0.7037502103053712], 
     Hue[1.0000000099534727`, 1, 0.7037500311357401], 
     Hue[1.0000000014736132`, 1, 0.7037500046096514], 
     Hue[1.0000000002181686`, 1, 0.7037500006824596], 
     Hue[1.0000000000323, 1, 0.7037500001010383], 
     Hue[1.000000000004782, 1, 0.7037500000149588], 
     Hue[1.0000000000007079`, 1, 0.7037500000022147], 
     Hue[1.0000000000001048`, 1, 0.703750000000328], 
     Hue[1.0000000000000155`, 1, 0.7037500000000486], 
     Hue[1.0000000000000022`, 1, 0.7037500000000072], 
     Hue[1.0000000000000004`, 1, 0.7037500000000011], 
     Hue[1., 1, 0.7037500000000002], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.6796776166423545, 1, 0.21], 
     Hue[0.6796776166423545, 1, 0.21], 
     Hue[0.6796776166423545, 1, 0.21], 
     Hue[0.6796776166423545, 1, 0.21], 
     Hue[0.6796776166423545, 1, 0.21], 
     Hue[0.6796776166423545, 1, 0.21000000000000002`], 
     Hue[0.6796776166423546, 1, 0.21000000000000021`], 
     Hue[0.6796776166423548, 1, 0.2100000000000015], 
     Hue[0.6796776166423574, 1, 0.21000000000001012`], 
     Hue[0.6796776166423744, 1, 0.21000000000006835`], 
     Hue[0.679677616642489, 1, 0.21000000000046176`], 
     Hue[0.6796776166432633, 1, 0.21000000000311908`], 
     Hue[0.6796776166484932, 1, 0.21000000002106775`], 
     Hue[0.6796776166838187, 1, 0.21000000014230152`], 
     Hue[0.6796776169224228, 1, 0.21000000096117097`], 
     Hue[0.6796776185340676, 1, 0.21000000649219772`], 
     Hue[0.6796776294198694, 1, 0.21000004385133741`], 
     Hue[0.6796777029476777, 1, 0.21000029619248153`], 
     Hue[0.6796781995896831, 1, 0.21000200062533103`], 
     Hue[0.6796815541801774, 1, 0.2100135132927481], 
     Hue[0.6797042144031116, 1, 0.2100912812376874], 
     Hue[0.6798573520321868, 1, 0.2106168363411872], 
     Hue[0.6808953536888942, 1, 0.2141791285277435], 
     Hue[0.688070114873941, 1, 0.23878898929957154`], 
     Hue[0.7424633640386675, 1, 0.4199297156228068], 
     Hue[0.9372142526036867, 1, 0.7555938464707719], 
     Hue[0.9916075017684134, 1, 0.7153741876312926], 
     Hue[0.9987822629534603, 1, 0.7055225898278669], 
     Hue[0.9998202646101677, 1, 0.7040134512959795], 
     Hue[0.9999734022392429, 1, 0.7037890259873848], 
     Hue[0.9999960624621771, 1, 0.7037557782846178], 
     Hue[0.9999994170526713, 1, 0.7037508554865454], 
     Hue[0.9999999136946768, 1, 0.7037501266551586], 
     Hue[0.9999999872224851, 1, 0.7037500187513228], 
     Hue[0.9999999981082868, 1, 0.7037500027761366], 
     Hue[0.9999999997199316, 1, 0.7037500004110075], 
     Hue[0.9999999999585358, 1, 0.7037500000608498], 
     Hue[0.9999999999938612, 1, 0.7037500000090089], 
     Hue[0.9999999999990912, 1, 0.7037500000013338], 
     Hue[0.9999999999998654, 1, 0.7037500000001975], 
     Hue[0.9999999999999801, 1, 0.7037500000000293], 
     Hue[0.999999999999997, 1, 0.7037500000000044], 
     Hue[0.9999999999999996, 1, 0.7037500000000007], 
     Hue[0.9999999999999999, 1, 0.7037500000000001], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.9836960385485061, 1, 0.21], 
     Hue[0.9836960385485061, 1, 0.21], 
     Hue[0.9836960385485061, 1, 0.21], 
     Hue[0.9836960385485061, 1, 0.21], 
     Hue[0.9836960385485061, 1, 0.21], 
     Hue[0.9836960385485061, 1, 0.21000000000000002`], 
     Hue[0.9836960385485061, 1, 0.21000000000000021`], 
     Hue[0.9836960385485062, 1, 0.2100000000000015], 
     Hue[0.9836960385485064, 1, 0.21000000000001012`], 
     Hue[0.9836960385485083, 1, 0.21000000000006835`], 
     Hue[0.9836960385485213, 1, 0.21000000000046176`], 
     Hue[0.9836960385486089, 1, 0.21000000000311908`], 
     Hue[0.9836960385492005, 1, 0.21000000002106775`], 
     Hue[0.9836960385531968, 1, 0.21000000014230152`], 
     Hue[0.9836960385801892, 1, 0.21000000096117097`], 
     Hue[0.9836960387625081, 1, 0.21000000649219758`], 
     Hue[0.9836960399939757, 1, 0.21000004385133186`], 
     Hue[0.9836960483118781, 1, 0.2100002961922288], 
     Hue[0.9836961044946546, 1, 0.21000200061380092`], 
     Hue[0.9836964839692665, 1, 0.21001351276672212`], 
     Hue[0.9836990466571348, 1, 0.21009125724211097`], 
     Hue[0.9837163352454732, 1, 0.21061574258542817`], 
     Hue[0.9838321601672548, 1, 0.21412953238674573`], 
     Hue[0.9845734515831168, 1, 0.23661801750842903`], 
     Hue[0.9882237119773193, 1, 0.34733787971795493`], 
     Hue[0.9954723265711868, 1, 0.5669323277515016], 
     Hue[0.9991225869653892, 1, 0.6772640235716105], 
     Hue[0.9998638783812512, 1, 0.6996419359859148], 
     Hue[0.9999797033030329, 1, 0.7031374814133594], 
     Hue[0.9999969918913714, 1, 0.7036592210833152], 
     Hue[0.9999995545792396, 1, 0.7037365580716574], 
     Hue[0.9999999340538516, 1, 0.7037480098743203], 
     Hue[0.999999990236628, 1, 0.7037497053605499], 
     Hue[0.9999999985545304, 1, 0.7037499563785575], 
     Hue[0.999999999785998, 1, 0.7037499935418376], 
     Hue[0.999999999968317, 1, 0.703749999043868], 
     Hue[0.9999999999953093, 1, 0.7037499998584446], 
     Hue[0.9999999999993056, 1, 0.7037499999790428], 
     Hue[0.9999999999998972, 1, 0.7037499999968972], 
     Hue[0.9999999999999848, 1, 0.7037499999995407], 
     Hue[0.9999999999999978, 1, 0.703749999999932], 
     Hue[0.9999999999999997, 1, 0.7037499999999899], 
     Hue[1., 1, 0.7037499999999984], 
     Hue[1., 1, 0.7037499999999998], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.2877144604546573`, 1, 0.21], 
     Hue[1.2877144604546573`, 1, 0.21], 
     Hue[1.287714460454657, 1, 0.21], 
     Hue[1.287714460454657, 1, 0.21], 
     Hue[1.287714460454657, 1, 0.21], 
     Hue[1.287714460454657, 1, 0.21000000000000002`], 
     Hue[1.287714460454657, 1, 0.21000000000000021`], 
     Hue[1.2877144604546567`, 1, 0.2100000000000015], 
     Hue[1.287714460454654, 1, 0.21000000000001012`], 
     Hue[1.2877144604546358`, 1, 0.21000000000006835`], 
     Hue[1.2877144604545125`, 1, 0.21000000000046176`], 
     Hue[1.2877144604536799`, 1, 0.21000000000311908`], 
     Hue[1.287714460448056, 1, 0.21000000002106775`], 
     Hue[1.2877144604100697`, 1, 0.21000000014230152`], 
     Hue[1.2877144601534924`, 1, 0.21000000096117097`], 
     Hue[1.2877144584204492`, 1, 0.2100000064921977], 
     Hue[1.2877144467146657`, 1, 0.21000004385133667`], 
     Hue[1.2877143676483258`, 1, 0.21000029619244726`], 
     Hue[1.2877138335968354`, 1, 0.2100020006237677], 
     Hue[1.2877102263409352`, 1, 0.2100135132214218], 
     Hue[1.2876858602156318`, 1, 0.21009127798307128`], 
     Hue[1.2875212329176489`, 1, 0.2106166876996471], 
     Hue[1.2864071343370378`, 1, 0.21417229904457424`], 
     Hue[1.2787913612224089`, 1, 0.2384632541817815], 
     Hue[1.2256298365481029`, 1, 0.40315662710154493`], 
     Hue[1.0620846239065544`, 1, 0.7120016667912038], 
     Hue[1.0089230992322482`, 1, 0.7096560945498317], 
     Hue[1.0013073261176195`, 1, 0.7047128125825017], 
     Hue[1.0001932275370082`, 1, 0.7038944068828532], 
     Hue[1.0000286002390255`, 1, 0.7037714200286252], 
     Hue[1.0000042341137219`, 1, 0.7037531721271738], 
     Hue[1.0000006268578219`, 1, 0.7037504696534328], 
     Hue[1.0000000928063313`, 1, 0.7037500695326969], 
     Hue[1.0000000137399914`, 1, 0.7037500102943369], 
     Hue[1.000000002034208, 1, 0.7037500015240785], 
     Hue[1.0000000003011649`, 1, 0.7037500002256402], 
     Hue[1.0000000000445874`, 1, 0.703750000033406], 
     Hue[1.0000000000066012`, 1, 0.7037500000049458], 
     Hue[1.0000000000009772`, 1, 0.7037500000007323], 
     Hue[1.0000000000001448`, 1, 0.7037500000001085], 
     Hue[1.0000000000000213`, 1, 0.7037500000000161], 
     Hue[1.000000000000003, 1, 0.7037500000000024], 
     Hue[1.0000000000000004`, 1, 0.7037500000000003], 
     Hue[1., 1, 0.7037500000000001], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.5917328823608088, 1, 0.21], 
     Hue[0.5917328823608088, 1, 0.21], 
     Hue[0.5917328823608088, 1, 0.21], 
     Hue[0.5917328823608088, 1, 0.21], 
     Hue[0.5917328823608088, 1, 0.21], 
     Hue[0.5917328823608088, 1, 0.21000000000000002`], 
     Hue[0.5917328823608088, 1, 0.21000000000000021`], 
     Hue[0.591732882360809, 1, 0.2100000000000015], 
     Hue[0.5917328823608106, 1, 0.21000000000001012`], 
     Hue[0.5917328823608208, 1, 0.21000000000006835`], 
     Hue[0.5917328823608898, 1, 0.21000000000046176`], 
     Hue[0.5917328823613568, 1, 0.21000000000311908`], 
     Hue[0.5917328823645098, 1, 0.21000000002106775`], 
     Hue[0.591732882385807, 1, 0.21000000014230152`], 
     Hue[0.5917328825296585, 1, 0.21000000096117097`], 
     Hue[0.5917328835012992, 1, 0.21000000649219774`], 
     Hue[0.5917328900642141, 1, 0.21000004385133902`], 
     Hue[0.5917329343932294, 1, 0.21000029619255453`], 
     Hue[0.5917332338131005, 1, 0.2100020006286614], 
     Hue[0.5917352562801672, 1, 0.21001351344469527`], 
     Hue[0.5917489190386513, 1, 0.21009128817202075`], 
     Hue[0.5918412982694484, 1, 0.21061715334473516`], 
     Hue[0.5924696119029143, 1, 0.21419378962157004`], 
     Hue[0.5969199426265429, 1, 0.23952191421125885`], 
     Hue[0.6395126934075479, 1, 0.4779176399748636], 
     Hue[0.9522201889532607, 1, 0.9063007371185954], 
     Hue[0.9948129397342658, 1, 0.7282402638934493], 
     Hue[0.9992632704578945, 1, 0.7072609673710332], 
     Hue[0.9998915840913604, 1, 0.7042673339004032], 
     Hue[0.9999839633221574, 1, 0.7038265375045542], 
     Hue[0.9999976260806415, 1, 0.7037613302103582], 
     Hue[0.9999996485477082, 1, 0.703751677413695], 
     Hue[0.9999999479675793, 1, 0.7037502483408143], 
     Hue[0.9999999922965946, 1, 0.7037500367668872], 
     Hue[0.9999999988595096, 1, 0.7037500054433435], 
     Hue[0.9999999998311502, 1, 0.703750000805888], 
     Hue[0.9999999999750018, 1, 0.7037500001193119], 
     Hue[0.999999999996299, 1, 0.7037500000176642], 
     Hue[0.9999999999994521, 1, 0.7037500000026152], 
     Hue[0.9999999999999188, 1, 0.7037500000003872], 
     Hue[0.999999999999988, 1, 0.7037500000000574], 
     Hue[0.9999999999999982, 1, 0.7037500000000085], 
     Hue[0.9999999999999998, 1, 0.7037500000000013], 
     Hue[1., 1, 0.7037500000000002], 
     Hue[1., 1, 0.7037500000000001], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.8957513042669598, 1, 0.21], 
     Hue[0.8957513042669598, 1, 0.21], 
     Hue[0.8957513042669598, 1, 0.21], 
     Hue[0.8957513042669598, 1, 0.21], 
     Hue[0.8957513042669598, 1, 0.21], 
     Hue[0.8957513042669598, 1, 0.21000000000000002`], 
     Hue[0.8957513042669598, 1, 0.21000000000000021`], 
     Hue[0.8957513042669601, 1, 0.2100000000000015], 
     Hue[0.8957513042669618, 1, 0.21000000000001012`], 
     Hue[0.8957513042669732, 1, 0.21000000000006835`], 
     Hue[0.8957513042670505, 1, 0.21000000000046176`], 
     Hue[0.8957513042675723, 1, 0.21000000000311908`], 
     Hue[0.8957513042710967, 1, 0.21000000002106775`], 
     Hue[0.8957513042949021, 1, 0.21000000014230152`], 
     Hue[0.8957513044556948, 1, 0.21000000096117097`], 
     Hue[0.8957513055417639, 1, 0.2100000064921976], 
     Hue[0.8957513128775814, 1, 0.21000004385133267`], 
     Hue[0.8957513624270964, 1, 0.21000029619226465`], 
     Hue[0.8957516971066146, 1, 0.21000200061543609`], 
     Hue[0.8957539576404283, 1, 0.21001351284131856`], 
     Hue[0.8957692241526621, 1, 0.21009126064397352`], 
     Hue[0.895872241514441, 1, 0.21061589734611488`], 
     Hue[0.896563540359057, 1, 0.21413645870553033`], 
     Hue[0.9010336062170398, 1, 0.2368962530104724], 
     Hue[0.9240327115143248, 1, 0.3532720015542732], 
     Hue[0.971718592752635, 1, 0.5823547292371507], 
     Hue[0.99471769804992, 1, 0.6821482881545785], 
     Hue[0.9991877639079029, 1, 0.7004631951071234], 
     Hue[0.9998790627525188, 1, 0.7032614265441332], 
     Hue[0.9999820801142977, 1, 0.7036776235769028], 
     Hue[0.9999973466265315, 1, 0.7037392837147712], 
     Hue[0.9999996071603452, 1, 0.7037484134314769], 
     Hue[0.9999999418398634, 1, 0.7037497651078085], 
     Hue[0.9999999913893785, 1, 0.7037499652241614], 
     Hue[0.999999998725196, 1, 0.7037499948514311], 
     Hue[0.9999999998112651, 1, 0.7037499992377535], 
     Hue[0.9999999999720578, 1, 0.7037499998871493], 
     Hue[0.9999999999958632, 1, 0.7037499999832925], 
     Hue[0.9999999999993875, 1, 0.7037499999975264], 
     Hue[0.9999999999999093, 1, 0.7037499999996338], 
     Hue[0.9999999999999866, 1, 0.7037499999999457], 
     Hue[0.999999999999998, 1, 0.703749999999992], 
     Hue[0.9999999999999997, 1, 0.7037499999999988], 
     Hue[1., 1, 0.7037499999999998], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.1997697261731115`, 1, 0.21], 
     Hue[1.1997697261731115`, 1, 0.21], 
     Hue[1.1997697261731115`, 1, 0.21], 
     Hue[1.1997697261731115`, 1, 0.21], 
     Hue[1.1997697261731115`, 1, 0.21], 
     Hue[1.1997697261731115`, 1, 0.21000000000000002`], 
     Hue[1.1997697261731113`, 1, 0.21000000000000021`], 
     Hue[1.199769726173111, 1, 0.2100000000000015], 
     Hue[1.1997697261731084`, 1, 0.21000000000001012`], 
     Hue[1.1997697261730906`, 1, 0.21000000000006835`], 
     Hue[1.19976972617297, 1, 0.21000000000046176`], 
     Hue[1.1997697261721558`, 1, 0.21000000000311908`], 
     Hue[1.199769726166656, 1, 0.21000000002106775`], 
     Hue[1.1997697261295077`, 1, 0.21000000014230152`], 
     Hue[1.199769725878591, 1, 0.21000000096117097`], 
     Hue[1.1997697241837835`, 1, 0.21000000649219763`], 
     Hue[1.1997697127362608`, 1, 0.21000004385133453`], 
     Hue[1.1997696354143592`, 1, 0.2100002961923504], 
     Hue[1.1997691131467594`, 1, 0.21000200061934854`], 
     Hue[1.1997655855367402`, 1, 0.21001351301980892`], 
     Hue[1.199741759748261, 1, 0.21009126878508677`], 
     Hue[1.1995808903097773`, 1, 0.21061626811307946`], 
     Hue[1.1984971042565267`, 1, 0.2141531736603784], 
     Hue[1.19130888036918, 1, 0.23759907470129388`], 
     Hue[1.1495071076905798`, 1, 0.3713196154954278], 
     Hue[1.0502626184825319`, 1, 0.6292593186163224], 
     Hue[1.0084608458039315`, 1, 0.6944859196480835], 
     Hue[1.0012726219165848`, 1, 0.7024451005833942], 
     Hue[1.0001888358633342`, 1, 0.7035583673298097], 
     Hue[1.0000279664248506`, 1, 0.7037216632117665], 
     Hue[1.0000041406363713`, 1, 0.7037458054900695], 
     Hue[1.0000006130263521`, 1, 0.703749379018677], 
     Hue[1.0000000907587523`, 1, 0.7037499080639734], 
     Hue[1.0000000134368507`, 1, 0.7037499863888638], 
     Hue[1.000000001989328, 1, 0.7037499979848691], 
     Hue[1.0000000002945204`, 1, 0.7037499997016596], 
     Hue[1.0000000000436038`, 1, 0.7037499999558307], 
     Hue[1.0000000000064555`, 1, 0.7037499999934608], 
     Hue[1.0000000000009557`, 1, 0.7037499999990319], 
     Hue[1.0000000000001414`, 1, 0.7037499999998568], 
     Hue[1.0000000000000209`, 1, 0.7037499999999788], 
     Hue[1.000000000000003, 1, 0.7037499999999969], 
     Hue[1.0000000000000004`, 1, 0.7037499999999995], 
     Hue[1., 1, 0.7037499999999999], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.5037881480792625, 1, 0.21], 
     Hue[0.5037881480792625, 1, 0.21], 
     Hue[0.5037881480792625, 1, 0.21], 
     Hue[0.5037881480792625, 1, 0.21], 
     Hue[0.5037881480792625, 1, 0.21], 
     Hue[0.5037881480792625, 1, 0.21000000000000002`], 
     Hue[0.5037881480792625, 1, 0.21000000000000021`], 
     Hue[0.5037881480792625, 1, 0.2100000000000015], 
     Hue[0.5037881480792625, 1, 0.21000000000001012`], 
     Hue[0.503788148079263, 1, 0.21000000000006835`], 
     Hue[0.5037881480792661, 1, 0.21000000000046176`], 
     Hue[0.5037881480792864, 1, 0.21000000000311908`], 
     Hue[0.5037881480794241, 1, 0.21000000002106775`], 
     Hue[0.5037881480803541, 1, 0.21000000014230152`], 
     Hue[0.5037881480866361, 1, 0.21000000096117097`], 
     Hue[0.5037881481290672, 1, 0.21000000649219774`], 
     Hue[0.5037881484156669, 1, 0.21000004385133964`], 
     Hue[0.5037881503514963, 1, 0.21000029619258317`], 
     Hue[0.5037881634270438, 1, 0.21000200062996874`], 
     Hue[0.5037882517477632, 1, 0.21001351350434372`], 
     Hue[0.5037888484150097, 1, 0.21009129089453352`], 
     Hue[0.5037928835109237, 1, 0.21061727791850748`], 
     Hue[0.503820365104358, 1, 0.21419958717208432`], 
     Hue[0.5040169523249636, 1, 0.23982531900119158`], 
     Hue[0.5061564983761928, 1, 0.518710270271964], 
     Hue[0.9976316497030696, 1, 1.012318163024342], 
     Hue[0.999771195754299, 1, 0.7335663608828281], 
     Hue[0.9999677829749045, 1, 0.7079483875416301], 
     Hue[0.9999952645683389, 1, 0.7043671028587165], 
     Hue[0.9999992996642528, 1, 0.7038412650320116], 
     Hue[0.9999998963314993, 1, 0.7037635096765986], 
     Hue[0.9999999846522187, 1, 0.703752000063297], 
     Hue[0.9999999977277663, 1, 0.703750296108688], 
     Hue[0.9999999996635955, 1, 0.703750043838919], 
     Hue[0.9999999999501953, 1, 0.7037500064903589], 
     Hue[0.9999999999926265, 1, 0.7037500009608988], 
     Hue[0.9999999999989083, 1, 0.7037500001422612], 
     Hue[0.9999999999998384, 1, 0.7037500000210618], 
     Hue[0.999999999999976, 1, 0.7037500000031183], 
     Hue[0.9999999999999964, 1, 0.7037500000004617], 
     Hue[0.9999999999999994, 1, 0.7037500000000684], 
     Hue[0.9999999999999999, 1, 0.7037500000000102], 
     Hue[1., 1, 0.7037500000000015], 
     Hue[1., 1, 0.7037500000000002], 
     Hue[1., 1, 0.7037500000000001], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.8078065699854136, 1, 0.21], 
     Hue[0.8078065699854136, 1, 0.21], 
     Hue[0.8078065699854136, 1, 0.21], 
     Hue[0.8078065699854136, 1, 0.21], 
     Hue[0.8078065699854136, 1, 0.21], 
     Hue[0.8078065699854136, 1, 0.21000000000000002`], 
     Hue[0.8078065699854137, 1, 0.21000000000000021`], 
     Hue[0.807806569985414, 1, 0.2100000000000015], 
     Hue[0.8078065699854167, 1, 0.21000000000001012`], 
     Hue[0.8078065699854342, 1, 0.21000000000006835`], 
     Hue[0.8078065699855528, 1, 0.21000000000046176`], 
     Hue[0.8078065699863534, 1, 0.21000000000311908`], 
     Hue[0.8078065699917615, 1, 0.21000000002106775`], 
     Hue[0.8078065700282905, 1, 0.21000000014230152`], 
     Hue[0.8078065702750241, 1, 0.21000000096117097`], 
     Hue[0.8078065719415788, 1, 0.21000000649219763`], 
     Hue[0.8078065831982669, 1, 0.21000004385133436`], 
     Hue[0.8078066592311811, 1, 0.21000029619234242`], 
     Hue[0.8078071727922768, 1, 0.21000200061898472`], 
     Hue[0.8078106415908218, 1, 0.21001351300321006`], 
     Hue[0.8078340699713237, 1, 0.21009126802791833`], 
     Hue[0.8079922474851812, 1, 0.21061623360564982`], 
     Hue[0.8090575054302487, 1, 0.21415161071438632`], 
     Hue[0.8161058163047328, 1, 0.2375313820864738], 
     Hue[0.8565794353990173, 1, 0.3693476122855477], 
     Hue[0.9512271345863962, 1, 0.6241342089416906], 
     Hue[0.9917007536806808, 1, 0.6932976146378813], 
     Hue[0.9987490645551648, 1, 0.7022597808353611], 
     Hue[0.9998143225002324, 1, 0.703530730932156], 
     Hue[0.9999725000140899, 1, 0.7037175672828782], 
     Hue[0.9999959283945917, 1, 0.7037451989917136], 
     Hue[0.9999993971931368, 1, 0.7037492892244022], 
     Hue[0.9999999107542324, 1, 0.7037498947698702], 
     Hue[0.9999999867871466, 1, 0.7037499844206685], 
     Hue[0.9999999980438348, 1, 0.7037499976934775], 
     Hue[0.9999999997103894, 1, 0.7037499996585189], 
     Hue[0.9999999999571231, 1, 0.7037499999494436], 
     Hue[0.9999999999936521, 1, 0.7037499999925152], 
     Hue[0.9999999999990602, 1, 0.7037499999988919], 
     Hue[0.9999999999998609, 1, 0.703749999999836], 
     Hue[0.9999999999999793, 1, 0.7037499999999757], 
     Hue[0.999999999999997, 1, 0.7037499999999964], 
     Hue[0.9999999999999996, 1, 0.7037499999999994], 
     Hue[0.9999999999999999, 1, 0.7037499999999999], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.1118249918915646`, 1, 0.21], 
     Hue[1.1118249918915646`, 1, 0.21], 
     Hue[1.1118249918915646`, 1, 0.21], 
     Hue[1.1118249918915646`, 1, 0.21], 
     Hue[1.1118249918915646`, 1, 0.21], 
     Hue[1.1118249918915646`, 1, 0.21000000000000002`], 
     Hue[1.1118249918915646`, 1, 0.21000000000000021`], 
     Hue[1.1118249918915644`, 1, 0.2100000000000015], 
     Hue[1.1118249918915626`, 1, 0.21000000000001012`], 
     Hue[1.1118249918915504`, 1, 0.21000000000006835`], 
     Hue[1.1118249918914684`, 1, 0.21000000000046176`], 
     Hue[1.1118249918909149`, 1, 0.21000000000311908`], 
     Hue[1.111824991887176, 1, 0.21000000002106775`], 
     Hue[1.1118249918619232`, 1, 0.21000000014230152`], 
     Hue[1.1118249916913516`, 1, 0.21000000096117097`], 
     Hue[1.1118249905392328`, 1, 0.2100000064921976], 
     Hue[1.1118249827572846`, 1, 0.21000004385133278`], 
     Hue[1.1118249301943945`, 1, 0.21000029619226995`], 
     Hue[1.1118245751611555`, 1, 0.21000200061567836`], 
     Hue[1.1118221771498045`, 1, 0.21001351285237063`], 
     Hue[1.1118059820957082`, 1, 0.21009126114801524`], 
     Hue[1.1116966950163367`, 1, 0.21061592028490345`], 
     Hue[1.1109631444855423`, 1, 0.2141374878545395], 
     Hue[1.1062125679492532`, 1, 0.23693822214072813`], 
     Hue[1.0816028675487899`, 1, 0.3542182780227652], 
     Hue[1.030222124342775, 1, 0.5848140409965061], 
     Hue[1.0056124239423117`, 1, 0.6828850321537472], 
     Hue[1.0008618474060222`, 1, 0.7005852221227934], 
     Hue[1.0001282968752279`, 1, 0.703279797819218], 
     Hue[1.0000190097958563`, 1, 0.7036803502081588], 
     Hue[1.0000028147417603`, 1, 0.7037396875414165], 
     Hue[1.000000416730409, 1, 0.7037484732213342], 
     Hue[1.00000006169717, 1, 0.7037497739597782], 
     Hue[1.00000000913428, 1, 0.7037499665346986], 
     Hue[1.0000000013523318`, 1, 0.7037499950454563], 
     Hue[1.000000000200213, 1, 0.703749999266479], 
     Hue[1.0000000000296416`, 1, 0.7037499998914021], 
     Hue[1.0000000000043885`, 1, 0.7037499999839221], 
     Hue[1.0000000000006497`, 1, 0.7037499999976197], 
     Hue[1.0000000000000961`, 1, 0.7037499999996476], 
     Hue[1.0000000000000142`, 1, 0.7037499999999478], 
     Hue[1.000000000000002, 1, 0.7037499999999923], 
     Hue[1.0000000000000002`, 1, 0.7037499999999989], 
     Hue[1., 1, 0.7037499999999998], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.4158434137977158`, 1, 0.21], 
     Hue[1.4158434137977158`, 1, 0.21], 
     Hue[1.4158434137977158`, 1, 0.21], 
     Hue[1.4158434137977156`, 1, 0.21], 
     Hue[1.4158434137977158`, 1, 0.21], 
     Hue[1.4158434137977156`, 1, 0.21000000000000002`], 
     Hue[1.4158434137977156`, 1, 0.21000000000000021`], 
     Hue[1.4158434137977154`, 1, 0.2100000000000015], 
     Hue[1.415843413797714, 1, 0.21000000000001012`], 
     Hue[1.4158434137977045`, 1, 0.21000000000006835`], 
     Hue[1.4158434137976406`, 1, 0.21000000000046176`], 
     Hue[1.4158434137972087`, 1, 0.21000000000311908`], 
     Hue[1.41584341379429, 1, 0.21000000002106775`], 
     Hue[1.415843413774576, 1, 0.21000000014230152`], 
     Hue[1.4158434136414184`, 1, 0.21000000096117097`], 
     Hue[1.4158434127420105`, 1, 0.21000000649219774`], 
     Hue[1.4158434066669896`, 1, 0.2100000438513391], 
     Hue[1.4158433656334393`, 1, 0.21000029619255897`], 
     Hue[1.4158430884727244`, 1, 0.21000200062886393`], 
     Hue[1.4158412163565197`, 1, 0.21001351345393568`], 
     Hue[1.4158285692348167`, 1, 0.2100912885937632], 
     Hue[1.4157430545056848`, 1, 0.21061717263815927`], 
     Hue[1.4151613080626744`, 1, 0.2141946861782777], 
     Hue[1.4110345387666154`, 1, 0.23956831057075728`], 
     Hue[1.3708213276823011`, 1, 0.4831913739513881], 
     Hue[1.045022086115415, 1, 0.9200068329753893], 
     Hue[1.0048088750311004`, 1, 0.7290547253615675], 
     Hue[1.0006821057350415`, 1, 0.707367272812167], 
     Hue[1.000100359292031, 1, 0.7042827856667754], 
     Hue[1.000014844562899, 1, 0.7038288189349987], 
     Hue[1.000002197441196, 1, 0.7037616678407448], 
     Hue[1.0000003253249912`, 1, 0.7037517273969557], 
     Hue[1.0000000481642763`, 1, 0.7037502557407793], 
     Hue[1.0000000071307262`, 1, 0.7037500378624518], 
     Hue[1.000000001055705, 1, 0.7037500056055421], 
     Hue[1.0000000001562974`, 1, 0.7037500008299015], 
     Hue[1.00000000002314, 1, 0.7037500001228671], 
     Hue[1.000000000003426, 1, 0.7037500000181905], 
     Hue[1.0000000000005071`, 1, 0.7037500000026932], 
     Hue[1.000000000000075, 1, 0.7037500000003988], 
     Hue[1.000000000000011, 1, 0.7037500000000592], 
     Hue[1.0000000000000016`, 1, 0.7037500000000088], 
     Hue[1.0000000000000002`, 1, 0.7037500000000013], 
     Hue[1., 1, 0.7037500000000002], 
     Hue[1., 1, 0.7037500000000001], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.7198618357038667, 1, 0.21], 
     Hue[0.7198618357038667, 1, 0.21], 
     Hue[0.7198618357038667, 1, 0.21], 
     Hue[0.7198618357038667, 1, 0.21], 
     Hue[0.7198618357038667, 1, 0.21], 
     Hue[0.7198618357038667, 1, 0.21000000000000002`], 
     Hue[0.7198618357038669, 1, 0.21000000000000021`], 
     Hue[0.7198618357038673, 1, 0.2100000000000015], 
     Hue[0.71986183570387, 1, 0.21000000000001012`], 
     Hue[0.7198618357038884, 1, 0.21000000000006835`], 
     Hue[0.719861835704013, 1, 0.21000000000046176`], 
     Hue[0.7198618357048542, 1, 0.21000000000311908`], 
     Hue[0.7198618357105363, 1, 0.21000000002106775`], 
     Hue[0.7198618357489162, 1, 0.21000000014230152`], 
     Hue[0.7198618360081515, 1, 0.21000000096117097`], 
     Hue[0.7198618377591476, 1, 0.2100000064921977], 
     Hue[0.7198618495861939, 1, 0.21000004385133647`], 
     Hue[0.7198619294715982, 1, 0.21000029619243898`], 
     Hue[0.7198624690553371, 1, 0.21000200062339056`], 
     Hue[0.7198661136743238, 1, 0.21001351320421638`], 
     Hue[0.7198907319709869, 1, 0.21009127719803217`], 
     Hue[0.7200570535854011, 1, 0.21061665185983597`], 
     Hue[0.7211821850572036, 1, 0.2141706566163158], 
     Hue[0.7288530755028233, 1, 0.23838632065950857`], 
     Hue[0.7814342511583192, 1, 0.3996787911150449], 
     Hue[0.9384275845455472, 1, 0.7029629944544187], 
     Hue[0.9910087602010433, 1, 0.7083055707118561], 
     Hue[0.9986796506466632, 1, 0.7045180685589963], 
     Hue[0.9998047821184657, 1, 0.703865703404144], 
     Hue[0.9999711037328799, 1, 0.703767173332137], 
     Hue[0.9999957220295429, 1, 0.7037525434658338], 
     Hue[0.9999993666485296, 1, 0.703750376581392], 
     Hue[0.9999999062322685, 1, 0.7037500557533958], 
     Hue[0.9999999861176728, 1, 0.7037500082543097], 
     Hue[0.9999999979447192, 1, 0.7037500012220521], 
     Hue[0.9999999996957153, 1, 0.703750000180925], 
     Hue[0.9999999999549506, 1, 0.703750000026786], 
     Hue[0.9999999999933304, 1, 0.7037500000039657], 
     Hue[0.9999999999990126, 1, 0.7037500000005871], 
     Hue[0.9999999999998538, 1, 0.7037500000000869], 
     Hue[0.9999999999999784, 1, 0.703750000000013], 
     Hue[0.9999999999999968, 1, 0.703750000000002], 
     Hue[0.9999999999999996, 1, 0.7037500000000003], 
     Hue[0.9999999999999999, 1, 0.7037500000000001], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.0238802576100174`, 1, 0.21], 
     Hue[1.0238802576100174`, 1, 0.21], 
     Hue[1.0238802576100174`, 1, 0.21], 
     Hue[1.0238802576100174`, 1, 0.21], 
     Hue[1.0238802576100174`, 1, 0.21], 
     Hue[1.0238802576100174`, 1, 0.21000000000000002`], 
     Hue[1.0238802576100174`, 1, 0.21000000000000021`], 
     Hue[1.0238802576100174`, 1, 0.2100000000000015], 
     Hue[1.023880257610017, 1, 0.21000000000001012`], 
     Hue[1.0238802576100143`, 1, 0.21000000000006835`], 
     Hue[1.0238802576099952`, 1, 0.21000000000046176`], 
     Hue[1.0238802576098673`, 1, 0.21000000000311908`], 
     Hue[1.0238802576090025`, 1, 0.21000000002106775`], 
     Hue[1.023880257603161, 1, 0.21000000014230152`], 
     Hue[1.0238802575637047`, 1, 0.21000000096117097`], 
     Hue[1.0238802572971988`, 1, 0.21000000649219758`], 
     Hue[1.0238802554970934`, 1, 0.2100000438513319], 
     Hue[1.0238802433383483`, 1, 0.21000029619222987`], 
     Hue[1.0238801612128254`, 1, 0.21000200061384952`], 
     Hue[1.0238796065133642`, 1, 0.21001351276893837`], 
     Hue[1.0238758604837872`, 1, 0.21009125734317474`], 
     Hue[1.0238505885663547`, 1, 0.21061574718168266`], 
     Hue[1.0236812710746463`, 1, 0.21412973766623156`], 
     Hue[1.0225972939655597`, 1, 0.23662615978411292`], 
     Hue[1.0172528916926682`, 1, 0.34750368000032306`], 
     Hue[1.0066273659173495`, 1, 0.5673632320355129], 
     Hue[1.0012829636444578`, 1, 0.67740695654909], 
     Hue[1.000198986535371, 1, 0.6996662761376425], 
     Hue[1.000029669043663, 1, 0.7031411624732942], 
     Hue[1.0000043971262305`, 1, 0.7036597677912511], 
     Hue[1.0000006510966535`, 1, 0.7037366390497916], 
     Hue[1.000000096397192, 1, 0.7037480218639786], 
     Hue[1.0000000142716694`, 1, 0.7037497071356392], 
     Hue[1.000000002112924, 1, 0.7037499566413601], 
     Hue[1.0000000003128189`, 1, 0.7037499935807456], 
     Hue[1.000000000046313, 1, 0.7037499990496283], 
     Hue[1.0000000000068567`, 1, 0.7037499998592973], 
     Hue[1.0000000000010152`, 1, 0.7037499999791689], 
     Hue[1.0000000000001503`, 1, 0.703749999996916], 
     Hue[1.0000000000000222`, 1, 0.7037499999995434], 
     Hue[1.0000000000000033`, 1, 0.7037499999999324], 
     Hue[1.0000000000000004`, 1, 0.70374999999999], 
     Hue[1., 1, 0.7037499999999984], 
     Hue[1., 1, 0.7037499999999998], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.3278986795161687`, 1, 0.21], 
     Hue[1.3278986795161687`, 1, 0.21], 
     Hue[1.3278986795161687`, 1, 0.21], 
     Hue[1.3278986795161687`, 1, 0.21], 
     Hue[1.3278986795161687`, 1, 0.21], 
     Hue[1.3278986795161687`, 1, 0.21000000000000002`], 
     Hue[1.3278986795161685`, 1, 0.21000000000000021`], 
     Hue[1.3278986795161682`, 1, 0.2100000000000015], 
     Hue[1.3278986795161658`, 1, 0.21000000000001012`], 
     Hue[1.3278986795161491`, 1, 0.21000000000006835`], 
     Hue[1.3278986795160372`, 1, 0.21000000000046176`], 
     Hue[1.3278986795152812`, 1, 0.21000000000311908`], 
     Hue[1.327898679510175, 1, 0.21000000002106775`], 
     Hue[1.3278986794756849`, 1, 0.21000000014230152`], 
     Hue[1.3278986792427216`, 1, 0.21000000096117097`], 
     Hue[1.3278986776691806`, 1, 0.21000000649219772`], 
     Hue[1.3278986670407473`, 1, 0.21000004385133758`], 
     Hue[1.327898595251326, 1, 0.21000029619248908`], 
     Hue[1.3278981103511363`, 1, 0.2100020006256758], 
     Hue[1.3278948350675293`, 1, 0.210013513308478], 
     Hue[1.3278727103916093`, 1, 0.21009128195548205`], 
     Hue[1.3277231842113424`, 1, 0.21061686913590866`], 
     Hue[1.3267093037106215`, 1, 0.21418063916773017`], 
     Hue[1.319683883428846, 1, 0.23886234162594963`], 
     Hue[1.2653466448089237`, 1, 0.4242545508428436], 
     Hue[1.0625520347072455`, 1, 0.7668338154101471], 
     Hue[1.008214796087323, 1, 0.7166618456302742], 
     Hue[1.0011893758055472`, 1, 0.7057017076112803], 
     Hue[1.000175495304826, 1, 0.7040397160155706], 
     Hue[1.0000259691245594`, 1, 0.7037929089225986], 
     Hue[1.0000038444486394`, 1, 0.7037563530319443], 
     Hue[1.0000005691650322`, 1, 0.7037509405753125], 
     Hue[1.0000000842648427`, 1, 0.7037501392525064], 
     Hue[1.0000000124754211`, 1, 0.7037500206163609], 
     Hue[1.0000000018469881`, 1, 0.7037500030522559], 
     Hue[1.0000000002734468`, 1, 0.703750000451887], 
     Hue[1.0000000000404838`, 1, 0.7037500000669019], 
     Hue[1.0000000000059937`, 1, 0.7037500000099048], 
     Hue[1.0000000000008873`, 1, 0.7037500000014665], 
     Hue[1.0000000000001315`, 1, 0.7037500000002171], 
     Hue[1.0000000000000195`, 1, 0.7037500000000322], 
     Hue[1.0000000000000029`, 1, 0.7037500000000049], 
     Hue[1.0000000000000004`, 1, 0.7037500000000008], 
     Hue[1., 1, 0.7037500000000001], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.6319171014223196, 1, 0.21], 
     Hue[0.6319171014223197, 1, 0.21], 
     Hue[0.6319171014223197, 1, 0.21], 
     Hue[0.6319171014223196, 1, 0.21], 
     Hue[0.6319171014223197, 1, 0.21], 
     Hue[0.6319171014223196, 1, 0.21000000000000002`], 
     Hue[0.6319171014223197, 1, 0.21000000000000021`], 
     Hue[0.63191710142232, 1, 0.2100000000000015], 
     Hue[0.6319171014223219, 1, 0.21000000000001012`], 
     Hue[0.6319171014223359, 1, 0.21000000000006835`], 
     Hue[0.6319171014224294, 1, 0.21000000000046176`], 
     Hue[0.6319171014230607, 1, 0.21000000000311908`], 
     Hue[0.6319171014273257, 1, 0.21000000002106775`], 
     Hue[0.6319171014561327, 1, 0.21000000014230152`], 
     Hue[0.6319171016507091, 1, 0.21000000096117097`], 
     Hue[0.6319171029649691, 1, 0.21000000649219772`], 
     Hue[0.6319171118420956, 1, 0.21000004385133839`], 
     Hue[0.6319171718023777, 1, 0.2100002961925256], 
     Hue[0.6319175768032167, 1, 0.21000200062734228`], 
     Hue[0.6319203124175488, 1, 0.2100135133845098], 
     Hue[0.6319387922922496, 1, 0.21009128542520614`], 
     Hue[0.6320637170504779, 1, 0.21061702772410454`], 
     Hue[0.6329122348206782, 1, 0.2141879640638791], 
     Hue[0.6388636247903751, 1, 0.23922497026247766`], 
     Hue[0.6901715631243883, 1, 0.4497246435918168], 
     Hue[0.9417455382979311, 1, 0.8330289504421404], 
     Hue[0.9930534766319445, 1, 0.723027583263166], 
     Hue[0.9990048666016415, 1, 0.7065702263672444], 
     Hue[0.9998533843718418, 1, 0.7041667265315851], 
     Hue[0.99997830913007, 1, 0.7038116785155994], 
     Hue[0.9999967890047708, 1, 0.7037591311212987], 
     Hue[0.9999995246191029, 1, 0.703751351855429], 
     Hue[0.9999999296199419, 1, 0.703750200142236], 
     Hue[0.9999999895802241, 1, 0.7037500296310877], 
     Hue[0.9999999984573505, 1, 0.7037500043868874], 
     Hue[0.9999999997716105, 1, 0.7037500006494795], 
     Hue[0.9999999999661869, 1, 0.7037500000961556], 
     Hue[0.999999999994994, 1, 0.7037500000142358], 
     Hue[0.9999999999992588, 1, 0.7037500000021076], 
     Hue[0.9999999999998903, 1, 0.7037500000003121], 
     Hue[0.9999999999999838, 1, 0.7037500000000463], 
     Hue[0.9999999999999976, 1, 0.7037500000000069], 
     Hue[0.9999999999999997, 1, 0.703750000000001], 
     Hue[1., 1, 0.7037500000000002], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.9359355233284709, 1, 0.21], 
     Hue[0.9359355233284709, 1, 0.21], 
     Hue[0.9359355233284709, 1, 0.21], 
     Hue[0.9359355233284709, 1, 0.21], 
     Hue[0.9359355233284709, 1, 0.21], 
     Hue[0.9359355233284709, 1, 0.21000000000000002`], 
     Hue[0.9359355233284709, 1, 0.21000000000000021`], 
     Hue[0.9359355233284711, 1, 0.2100000000000015], 
     Hue[0.9359355233284721, 1, 0.21000000000001012`], 
     Hue[0.9359355233284795, 1, 0.21000000000006835`], 
     Hue[0.9359355233285291, 1, 0.21000000000046176`], 
     Hue[0.9359355233288648, 1, 0.21000000000311908`], 
     Hue[0.9359355233311312, 1, 0.21000000002106775`], 
     Hue[0.93593552334644, 1, 0.21000000014230152`], 
     Hue[0.935935523449843, 1, 0.21000000096117097`], 
     Hue[0.9359355241482744, 1, 0.2100000064921976], 
     Hue[0.9359355288658068, 1, 0.21000004385133217`], 
     Hue[0.9359355607302067, 1, 0.21000029619224206`], 
     Hue[0.9359357759564635, 1, 0.21000200061440633`], 
     Hue[0.9359372296593348, 1, 0.21001351279434063`], 
     Hue[0.9359470470143973, 1, 0.21009125850157587`], 
     Hue[0.9360132835859358, 1, 0.21061579987058976`], 
     Hue[0.9364573051169964, 1, 0.21413209273627898`], 
     Hue[0.9393098523659438, 1, 0.23672002211095064`], 
     Hue[0.9535804692927871, 1, 0.34944797415019263`], 
     Hue[0.9823550540356838, 1, 0.5724163276430159], 
     Hue[0.9966256709625271, 1, 0.6790546558372168], 
     Hue[0.9994782182114744, 1, 0.6999455186642528], 
     Hue[0.9999222397425351, 1, 0.7031833600986681], 
     Hue[0.9999884763140735, 1, 0.7036660342024399], 
     Hue[0.9999982936691361, 1, 0.7037375672114365], 
     Hue[0.9999997473720075, 1, 0.7037481592876411], 
     Hue[0.9999999625982642, 1, 0.7037497274814367], 
     Hue[0.9999999944626641, 1, 0.7037499596535634], 
     Hue[0.9999999991801964, 1, 0.7037499940267028], 
     Hue[0.999999999878628, 1, 0.7037499991156523], 
     Hue[0.9999999999820308, 1, 0.7037499998690722], 
     Hue[0.9999999999973397, 1, 0.703749999980616], 
     Hue[0.9999999999996061, 1, 0.7037499999971302], 
     Hue[0.9999999999999417, 1, 0.7037499999995752], 
     Hue[0.9999999999999913, 1, 0.703749999999937], 
     Hue[0.9999999999999987, 1, 0.7037499999999907], 
     Hue[0.9999999999999998, 1, 0.7037499999999985], 
     Hue[1., 1, 0.7037499999999998], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.239953945234622, 1, 0.21], 
     Hue[1.239953945234622, 1, 0.21], 
     Hue[1.239953945234622, 1, 0.21], 
     Hue[1.239953945234622, 1, 0.21], 
     Hue[1.239953945234622, 1, 0.21], 
     Hue[1.239953945234622, 1, 0.21000000000000002`], 
     Hue[1.239953945234622, 1, 0.21000000000000021`], 
     Hue[1.2399539452346215`, 1, 0.2100000000000015], 
     Hue[1.2399539452346187`, 1, 0.21000000000001012`], 
     Hue[1.2399539452346, 1, 0.21000000000006835`], 
     Hue[1.2399539452344734`, 1, 0.21000000000046176`], 
     Hue[1.2399539452336186`, 1, 0.21000000000311908`], 
     Hue[1.2399539452278445`, 1, 0.21000000002106775`], 
     Hue[1.239953945188844, 1, 0.21000000014230152`], 
     Hue[1.239953944925416, 1, 0.21000000096117097`], 
     Hue[1.2399539431461002`, 1, 0.21000000649219766`], 
     Hue[1.2399539311277703`, 1, 0.2100000438513355], 
     Hue[1.2399538499503602`, 1, 0.21000029619239435`], 
     Hue[1.2399533016403497`, 1, 0.21000200062135335`], 
     Hue[1.2399495981046655`, 1, 0.21001351311127206`], 
     Hue[1.2399245829802836`, 1, 0.21009127295752505`], 
     Hue[1.2397556322604408`, 1, 0.21061645835770568`], 
     Hue[1.2386150844458181`, 1, 0.2141618174779988], 
     Hue[1.2309476527434813`, 1, 0.2379812406808026], 
     Hue[1.1828667741627785`, 1, 0.3836754401304232], 
     Hue[1.0570871710718437`, 1, 0.6613713131899632], 
     Hue[1.0090062924911407`, 1, 0.7011946241262014], 
     Hue[1.0013388607888039`, 1, 0.7034700049061082], 
     Hue[1.000198312974181, 1, 0.7037107309279332], 
     Hue[1.0000293622543384`, 1, 0.7037442341615853], 
     Hue[1.0000043471299565`, 1, 0.7037491474179972], 
     Hue[1.0000006435942723`, 1, 0.7037498737981354], 
     Hue[1.0000000952842616`, 1, 0.7037499813162977], 
     Hue[1.0000000141068515`, 1, 0.7037499972338859], 
     Hue[1.0000000020885218`, 1, 0.7037499995904766], 
     Hue[1.000000000309206, 1, 0.70374999993937], 
     Hue[1.000000000045778, 1, 0.7037499999910237], 
     Hue[1.0000000000067775`, 1, 0.703749999998671], 
     Hue[1.0000000000010034`, 1, 0.7037499999998033], 
     Hue[1.0000000000001485`, 1, 0.7037499999999709], 
     Hue[1.000000000000022, 1, 0.7037499999999958], 
     Hue[1.0000000000000033`, 1, 0.7037499999999993], 
     Hue[1.0000000000000004`, 1, 0.7037499999999999], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.543972367140773, 1, 0.21], 
     Hue[0.543972367140773, 1, 0.21], 
     Hue[0.543972367140773, 1, 0.21], 
     Hue[0.543972367140773, 1, 0.21], 
     Hue[0.543972367140773, 1, 0.21], 
     Hue[0.543972367140773, 1, 0.21000000000000002`], 
     Hue[0.543972367140773, 1, 0.21000000000000021`], 
     Hue[0.5439723671407732, 1, 0.2100000000000015], 
     Hue[0.5439723671407739, 1, 0.21000000000001012`], 
     Hue[0.543972367140779, 1, 0.21000000000006835`], 
     Hue[0.5439723671408137, 1, 0.21000000000046176`], 
     Hue[0.5439723671410472, 1, 0.21000000000311908`], 
     Hue[0.5439723671426255, 1, 0.21000000002106775`], 
     Hue[0.5439723671532855, 1, 0.21000000014230152`], 
     Hue[0.5439723672252881, 1, 0.21000000096117097`], 
     Hue[0.543972367711627, 1, 0.21000000649219774`], 
     Hue[0.5439723709965882, 1, 0.2100000438513395], 
     Hue[0.5439723931847631, 1, 0.21000029619257649`], 
     Hue[0.5439725430546322, 1, 0.2100020006296636], 
     Hue[0.5439735553718055, 1, 0.21001351349042147`], 
     Hue[0.5439803942244827, 1, 0.21009129025906673`], 
     Hue[0.5440266413669499, 1, 0.21061724883575927`], 
     Hue[0.5443415148356447, 1, 0.2141982318505346], 
     Hue[0.5465887024810882, 1, 0.23975366675624626`], 
     Hue[0.570254209768226, 1, 0.5075410252506691], 
     Hue[0.9737181573725469, 1, 0.9832900126490419], 
     Hue[0.9973836646596849, 1, 0.7323085468378683], 
     Hue[0.9996308523051284, 1, 0.7077876859886852], 
     Hue[0.9999457257738231, 1, 0.7043438109936738], 
     Hue[0.9999919729162903, 1, 0.703837827452352], 
     Hue[0.9999988117689675, 1, 0.7037630009781805], 
     Hue[0.9999998240861409, 1, 0.7037519247555774], 
     Hue[0.9999999739560099, 1, 0.7037502849594806], 
     Hue[0.9999999961441848, 1, 0.7037500421882795], 
     Hue[0.999999999429146, 1, 0.7037500062459815], 
     Hue[0.9999999999154849, 1, 0.7037500009247186], 
     Hue[0.9999999999874876, 1, 0.7037500001369048], 
     Hue[0.9999999999981475, 1, 0.7037500000202688], 
     Hue[0.9999999999997258, 1, 0.7037500000030008], 
     Hue[0.9999999999999594, 1, 0.7037500000004444], 
     Hue[0.999999999999994, 1, 0.7037500000000658], 
     Hue[0.9999999999999991, 1, 0.7037500000000098], 
     Hue[0.9999999999999999, 1, 0.7037500000000014], 
     Hue[1., 1, 0.7037500000000002], 
     Hue[1., 1, 0.7037500000000001], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.8479907890469242, 1, 0.21], 
     Hue[0.8479907890469242, 1, 0.21], 
     Hue[0.847990789046924, 1, 0.21], 
     Hue[0.8479907890469242, 1, 0.21], 
     Hue[0.8479907890469242, 1, 0.21], 
     Hue[0.8479907890469242, 1, 0.21000000000000002`], 
     Hue[0.8479907890469242, 1, 0.21000000000000021`], 
     Hue[0.8479907890469245, 1, 0.2100000000000015], 
     Hue[0.8479907890469268, 1, 0.21000000000001012`], 
     Hue[0.8479907890469421, 1, 0.21000000000006835`], 
     Hue[0.8479907890470456, 1, 0.21000000000046176`], 
     Hue[0.8479907890477449, 1, 0.21000000000311908`], 
     Hue[0.847990789052468, 1, 0.21000000002106775`], 
     Hue[0.8479907890843706, 1, 0.21000000014230152`], 
     Hue[0.8479907892998552, 1, 0.21000000096117097`], 
     Hue[0.8479907907553386, 1, 0.21000000649219763`], 
     Hue[0.8479908005863522, 1, 0.2100000438513335], 
     Hue[0.8479908669895893, 1, 0.21000029619230293`], 
     Hue[0.8479913155070435, 1, 0.2100020006171831], 
     Hue[0.8479943449566074, 1, 0.21001351292101816`], 
     Hue[0.8480148051374433, 1, 0.21009126427891778`], 
     Hue[0.8481529053002327, 1, 0.21061606282025236`], 
     Hue[0.8490812594256929, 1, 0.2141438973772201], 
     Hue[0.8551517422563184, 1, 0.23720337636051722`], 
     Hue[0.8880282058067158, 1, 0.3605477388706445], 
     Hue[0.9599625832402081, 1, 0.601263903179359], 
     Hue[0.9928390467906056, 1, 0.6875396623329634], 
     Hue[0.9989095296212313, 1, 0.7013452043193587], 
     Hue[0.9998378837466915, 1, 0.7033939518904772], 
     Hue[0.9999759839094808, 1, 0.7036972869342004], 
     Hue[0.9999964440903166, 1, 0.7037421958208702], 
     Hue[0.9999994735398805, 1, 0.7037488445899448], 
     Hue[0.9999999220573349, 1, 0.7037498289413455], 
     Hue[0.9999999884605718, 1, 0.7037499746747373], 
     Hue[0.9999999982915856, 1, 0.7037499962505906], 
     Hue[0.999999999747069, 1, 0.7037499994448992], 
     Hue[0.9999999999625535, 1, 0.7037499999178172], 
     Hue[0.999999999994456, 1, 0.7037499999878328], 
     Hue[0.9999999999991792, 1, 0.7037499999981986], 
     Hue[0.9999999999998784, 1, 0.7037499999997333], 
     Hue[0.999999999999982, 1, 0.7037499999999606], 
     Hue[0.9999999999999973, 1, 0.7037499999999942], 
     Hue[0.9999999999999996, 1, 0.7037499999999991], 
     Hue[0.9999999999999999, 1, 0.7037499999999999], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.1520092109530753`, 1, 0.21], 
     Hue[1.1520092109530753`, 1, 0.21], 
     Hue[1.1520092109530753`, 1, 0.21], 
     Hue[1.1520092109530753`, 1, 0.21], 
     Hue[1.1520092109530753`, 1, 0.21], 
     Hue[1.1520092109530753`, 1, 0.21000000000000002`], 
     Hue[1.152009210953075, 1, 0.21000000000000021`], 
     Hue[1.1520092109530748`, 1, 0.2100000000000015], 
     Hue[1.1520092109530726`, 1, 0.21000000000001012`], 
     Hue[1.1520092109530573`, 1, 0.21000000000006835`], 
     Hue[1.1520092109529536`, 1, 0.21000000000046176`], 
     Hue[1.1520092109522544`, 1, 0.21000000000311908`], 
     Hue[1.1520092109475313`, 1, 0.21000000002106775`], 
     Hue[1.1520092109156288`, 1, 0.21000000014230152`], 
     Hue[1.1520092107001443`, 1, 0.21000000096117097`], 
     Hue[1.1520092092446608`, 1, 0.21000000649219763`], 
     Hue[1.152009199413647, 1, 0.2100000438513335], 
     Hue[1.15200913301041, 1, 0.21000029619230293`], 
     Hue[1.1520086844929558`, 1, 0.2100020006171831], 
     Hue[1.152005655043392, 1, 0.21001351292101816`], 
     Hue[1.1519851948625561`, 1, 0.21009126427891778`], 
     Hue[1.1518470946997668`, 1, 0.21061606282025236`], 
     Hue[1.1509187405743064`, 1, 0.2141438973772201], 
     Hue[1.144848257743681, 1, 0.23720337636051722`], 
     Hue[1.1119717941932836`, 1, 0.3605477388706444], 
     Hue[1.0400374167597917`, 1, 0.6012639031793586], 
     Hue[1.0071609532093944`, 1, 0.6875396623329633], 
     Hue[1.0010904703787689`, 1, 0.7013452043193587], 
     Hue[1.0001621162533085`, 1, 0.7033939518904772], 
     Hue[1.0000240160905192`, 1, 0.7036972869342004], 
     Hue[1.0000035559096834`, 1, 0.7037421958208702], 
     Hue[1.0000005264601195`, 1, 0.7037488445899448], 
     Hue[1.0000000779426652`, 1, 0.7037498289413455], 
     Hue[1.000000011539428, 1, 0.7037499746747373], 
     Hue[1.0000000017084143`, 1, 0.7037499962505906], 
     Hue[1.000000000252931, 1, 0.7037499994448992], 
     Hue[1.0000000000374465`, 1, 0.7037499999178172], 
     Hue[1.000000000005544, 1, 0.7037499999878328], 
     Hue[1.0000000000008207`, 1, 0.7037499999981986], 
     Hue[1.0000000000001215`, 1, 0.7037499999997333], 
     Hue[1.000000000000018, 1, 0.7037499999999606], 
     Hue[1.0000000000000027`, 1, 0.7037499999999942], 
     Hue[1.0000000000000004`, 1, 0.7037499999999991], 
     Hue[1., 1, 0.7037499999999999], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.4560276328592263`, 1, 0.21], 
     Hue[1.4560276328592263`, 1, 0.21], 
     Hue[1.4560276328592263`, 1, 0.21], 
     Hue[1.4560276328592263`, 1, 0.21], 
     Hue[1.4560276328592263`, 1, 0.21], 
     Hue[1.4560276328592263`, 1, 0.21000000000000002`], 
     Hue[1.4560276328592263`, 1, 0.21000000000000021`], 
     Hue[1.456027632859226, 1, 0.2100000000000015], 
     Hue[1.4560276328592254`, 1, 0.21000000000001012`], 
     Hue[1.4560276328592203`, 1, 0.21000000000006835`], 
     Hue[1.4560276328591857`, 1, 0.21000000000046176`], 
     Hue[1.456027632858952, 1, 0.21000000000311908`], 
     Hue[1.4560276328573738`, 1, 0.21000000002106775`], 
     Hue[1.4560276328467139`, 1, 0.21000000014230152`], 
     Hue[1.4560276327747113`, 1, 0.21000000096117097`], 
     Hue[1.456027632288372, 1, 0.21000000649219774`], 
     Hue[1.4560276290034109`, 1, 0.2100000438513395], 
     Hue[1.4560276068152362`, 1, 0.21000029619257649`], 
     Hue[1.456027456945367, 1, 0.2100020006296636], 
     Hue[1.4560264446281939`, 1, 0.21001351349042147`], 
     Hue[1.4560196057755164`, 1, 0.21009129025906673`], 
     Hue[1.4559733586330494`, 1, 0.21061724883575927`], 
     Hue[1.4556584851643546`, 1, 0.2141982318505346], 
     Hue[1.453411297518911, 1, 0.23975366675624626`], 
     Hue[1.429745790231773, 1, 0.5075410252506688], 
     Hue[1.0262818426274536`, 1, 0.9832900126490409], 
     Hue[1.0026163353403152`, 1, 0.7323085468378683], 
     Hue[1.0003691476948717`, 1, 0.7077876859886852], 
     Hue[1.0000542742261769`, 1, 0.7043438109936738], 
     Hue[1.0000080270837097`, 1, 0.703837827452352], 
     Hue[1.0000011882310325`, 1, 0.7037630009781805], 
     Hue[1.0000001759138593`, 1, 0.7037519247555774], 
     Hue[1.00000002604399, 1, 0.7037502849594806], 
     Hue[1.0000000038558152`, 1, 0.7037500421882795], 
     Hue[1.000000000570854, 1, 0.7037500062459815], 
     Hue[1.000000000084515, 1, 0.7037500009247186], 
     Hue[1.0000000000125124`, 1, 0.7037500001369048], 
     Hue[1.0000000000018525`, 1, 0.7037500000202688], 
     Hue[1.0000000000002742`, 1, 0.7037500000030008], 
     Hue[1.0000000000000406`, 1, 0.7037500000004444], 
     Hue[1.000000000000006, 1, 0.7037500000000658], 
     Hue[1.0000000000000009`, 1, 0.7037500000000098], 
     Hue[1.0000000000000002`, 1, 0.7037500000000014], 
     Hue[1., 1, 0.7037500000000002], 
     Hue[1., 1, 0.7037500000000001], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.7600460547653773, 1, 0.21], 
     Hue[0.7600460547653773, 1, 0.21], 
     Hue[0.7600460547653773, 1, 0.21], 
     Hue[0.7600460547653773, 1, 0.21], 
     Hue[0.7600460547653773, 1, 0.21], 
     Hue[0.7600460547653773, 1, 0.21000000000000002`], 
     Hue[0.7600460547653775, 1, 0.21000000000000021`], 
     Hue[0.7600460547653778, 1, 0.2100000000000015], 
     Hue[0.7600460547653807, 1, 0.21000000000001012`], 
     Hue[0.7600460547653993, 1, 0.21000000000006835`], 
     Hue[0.7600460547655259, 1, 0.21000000000046176`], 
     Hue[0.7600460547663808, 1, 0.21000000000311908`], 
     Hue[0.7600460547721548, 1, 0.21000000002106775`], 
     Hue[0.7600460548111554, 1, 0.21000000014230152`], 
     Hue[0.7600460550745833, 1, 0.21000000096117097`], 
     Hue[0.7600460568538991, 1, 0.21000000649219766`], 
     Hue[0.7600460688722288, 1, 0.2100000438513355], 
     Hue[0.760046150049639, 1, 0.21000029619239435`], 
     Hue[0.7600466983596497, 1, 0.21000200062135335`], 
     Hue[0.7600504018953338, 1, 0.21001351311127206`], 
     Hue[0.7600754170197156, 1, 0.21009127295752505`], 
     Hue[0.7602443677395584, 1, 0.21061645835770568`], 
     Hue[0.7613849155541812, 1, 0.2141618174779988], 
     Hue[0.769052347256518, 1, 0.2379812406808026], 
     Hue[0.8171332258372208, 1, 0.38367544013042354`], 
     Hue[0.9429128289281563, 1, 0.661371313189964], 
     Hue[0.9909937075088593, 1, 0.7011946241262015], 
     Hue[0.9986611392111961, 1, 0.7034700049061082], 
     Hue[0.999801687025819, 1, 0.7037107309279332], 
     Hue[0.9999706377456618, 1, 0.7037442341615853], 
     Hue[0.9999956528700435, 1, 0.7037491474179972], 
     Hue[0.9999993564057277, 1, 0.7037498737981354], 
     Hue[0.9999999047157383, 1, 0.7037499813162977], 
     Hue[0.9999999858931485, 1, 0.7037499972338859], 
     Hue[0.9999999979114782, 1, 0.7037499995904766], 
     Hue[0.999999999690794, 1, 0.70374999993937], 
     Hue[0.999999999954222, 1, 0.7037499999910237], 
     Hue[0.9999999999932225, 1, 0.703749999998671], 
     Hue[0.9999999999989966, 1, 0.7037499999998033], 
     Hue[0.9999999999998515, 1, 0.7037499999999709], 
     Hue[0.999999999999978, 1, 0.7037499999999958], 
     Hue[0.9999999999999968, 1, 0.7037499999999993], 
     Hue[0.9999999999999996, 1, 0.7037499999999999], 
     Hue[0.9999999999999999, 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.0640644766715284`, 1, 0.21], 
     Hue[1.0640644766715284`, 1, 0.21], 
     Hue[1.0640644766715284`, 1, 0.21], 
     Hue[1.0640644766715284`, 1, 0.21], 
     Hue[1.0640644766715284`, 1, 0.21], 
     Hue[1.0640644766715284`, 1, 0.21000000000000002`], 
     Hue[1.0640644766715284`, 1, 0.21000000000000021`], 
     Hue[1.0640644766715281`, 1, 0.2100000000000015], 
     Hue[1.0640644766715273`, 1, 0.21000000000001012`], 
     Hue[1.0640644766715197`, 1, 0.21000000000006835`], 
     Hue[1.0640644766714702`, 1, 0.21000000000046176`], 
     Hue[1.0640644766711347`, 1, 0.21000000000311908`], 
     Hue[1.064064476668868, 1, 0.21000000002106775`], 
     Hue[1.0640644766535592`, 1, 0.21000000014230152`], 
     Hue[1.0640644765501563`, 1, 0.21000000096117097`], 
     Hue[1.0640644758517248`, 1, 0.2100000064921976], 
     Hue[1.0640644711341924`, 1, 0.21000004385133217`], 
     Hue[1.0640644392697927`, 1, 0.21000029619224206`], 
     Hue[1.0640642240435358`, 1, 0.21000200061440633`], 
     Hue[1.0640627703406644`, 1, 0.21001351279434063`], 
     Hue[1.064052952985602, 1, 0.21009125850157587`], 
     Hue[1.0639867164140635`, 1, 0.21061579987058976`], 
     Hue[1.063542694883003, 1, 0.21413209273627898`], 
     Hue[1.0606901476340556`, 1, 0.23672002211095064`], 
     Hue[1.0464195307072124`, 1, 0.3494479741501926], 
     Hue[1.017644945964316, 1, 0.5724163276430158], 
     Hue[1.0033743290374728`, 1, 0.6790546558372167], 
     Hue[1.0005217817885257`, 1, 0.6999455186642528], 
     Hue[1.0000777602574649`, 1, 0.7031833600986681], 
     Hue[1.0000115236859266`, 1, 0.7036660342024399], 
     Hue[1.000001706330864, 1, 0.7037375672114365], 
     Hue[1.0000002526279925`, 1, 0.7037481592876411], 
     Hue[1.000000037401736, 1, 0.7037497274814367], 
     Hue[1.000000005537336, 1, 0.7037499596535634], 
     Hue[1.0000000008198036`, 1, 0.7037499940267028], 
     Hue[1.000000000121372, 1, 0.7037499991156523], 
     Hue[1.0000000000179692`, 1, 0.7037499998690722], 
     Hue[1.0000000000026603`, 1, 0.703749999980616], 
     Hue[1.000000000000394, 1, 0.7037499999971302], 
     Hue[1.0000000000000584`, 1, 0.7037499999995752], 
     Hue[1.0000000000000087`, 1, 0.703749999999937], 
     Hue[1.0000000000000013`, 1, 0.7037499999999907], 
     Hue[1.0000000000000002`, 1, 0.7037499999999985], 
     Hue[1., 1, 0.7037499999999998], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.3680828985776796`, 1, 0.21], 
     Hue[1.3680828985776796`, 1, 0.21], 
     Hue[1.3680828985776796`, 1, 0.21], 
     Hue[1.3680828985776796`, 1, 0.21], 
     Hue[1.3680828985776796`, 1, 0.21], 
     Hue[1.3680828985776796`, 1, 0.21000000000000002`], 
     Hue[1.3680828985776796`, 1, 0.21000000000000021`], 
     Hue[1.3680828985776792`, 1, 0.2100000000000015], 
     Hue[1.368082898577677, 1, 0.21000000000001012`], 
     Hue[1.3680828985776632`, 1, 0.21000000000006835`], 
     Hue[1.3680828985775697`, 1, 0.21000000000046176`], 
     Hue[1.3680828985769384`, 1, 0.21000000000311908`], 
     Hue[1.3680828985726734`, 1, 0.21000000002106775`], 
     Hue[1.3680828985438664`, 1, 0.21000000014230152`], 
     Hue[1.3680828983492899`, 1, 0.21000000096117097`], 
     Hue[1.36808289703503, 1, 0.21000000649219772`], 
     Hue[1.3680828881579035`, 1, 0.21000004385133839`], 
     Hue[1.3680828281976214`, 1, 0.2100002961925256], 
     Hue[1.3680824231967823`, 1, 0.21000200062734228`], 
     Hue[1.3680796875824504`, 1, 0.2100135133845098], 
     Hue[1.3680612077077496`, 1, 0.21009128542520614`], 
     Hue[1.3679362829495214`, 1, 0.21061702772410454`], 
     Hue[1.367087765179321, 1, 0.2141879640638791], 
     Hue[1.3611363752096242`, 1, 0.23922497026247766`], 
     Hue[1.3098284368756108`, 1, 0.4497246435918162], 
     Hue[1.058254461702069, 1, 0.833028950442139], 
     Hue[1.0069465233680555`, 1, 0.7230275832631657], 
     Hue[1.0009951333983584`, 1, 0.7065702263672444], 
     Hue[1.0001466156281582`, 1, 0.7041667265315851], 
     Hue[1.00002169086993, 1, 0.7038116785155994], 
     Hue[1.000003210995229, 1, 0.7037591311212987], 
     Hue[1.000000475380897, 1, 0.703751351855429], 
     Hue[1.000000070380058, 1, 0.703750200142236], 
     Hue[1.000000010419776, 1, 0.7037500296310877], 
     Hue[1.0000000015426496`, 1, 0.7037500043868874], 
     Hue[1.0000000002283895`, 1, 0.7037500006494795], 
     Hue[1.0000000000338132`, 1, 0.7037500000961556], 
     Hue[1.000000000005006, 1, 0.7037500000142358], 
     Hue[1.0000000000007412`, 1, 0.7037500000021076], 
     Hue[1.0000000000001097`, 1, 0.7037500000003121], 
     Hue[1.0000000000000162`, 1, 0.7037500000000463], 
     Hue[1.0000000000000024`, 1, 0.7037500000000069], 
     Hue[1.0000000000000004`, 1, 0.703750000000001], 
     Hue[1., 1, 0.7037500000000002], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.6721013204838309, 1, 0.21], 
     Hue[0.6721013204838309, 1, 0.21], 
     Hue[0.6721013204838309, 1, 0.21], 
     Hue[0.6721013204838309, 1, 0.21], 
     Hue[0.6721013204838309, 1, 0.21], 
     Hue[0.6721013204838309, 1, 0.21000000000000002`], 
     Hue[0.6721013204838309, 1, 0.21000000000000021`], 
     Hue[0.6721013204838313, 1, 0.2100000000000015], 
     Hue[0.6721013204838338, 1, 0.21000000000001012`], 
     Hue[0.6721013204838502, 1, 0.21000000000006835`], 
     Hue[0.6721013204839622, 1, 0.21000000000046176`], 
     Hue[0.6721013204847182, 1, 0.21000000000311908`], 
     Hue[0.6721013204898245, 1, 0.21000000002106775`], 
     Hue[0.6721013205243147, 1, 0.21000000014230152`], 
     Hue[0.6721013207572777, 1, 0.21000000096117097`], 
     Hue[0.672101322330819, 1, 0.21000000649219772`], 
     Hue[0.672101332959252, 1, 0.21000004385133758`], 
     Hue[0.6721014047486734, 1, 0.21000029619248908`], 
     Hue[0.6721018896488631, 1, 0.2100020006256758], 
     Hue[0.6721051649324702, 1, 0.210013513308478], 
     Hue[0.6721272896083902, 1, 0.21009128195548205`], 
     Hue[0.672276815788657, 1, 0.21061686913590866`], 
     Hue[0.6732906962893779, 1, 0.21418063916773017`], 
     Hue[0.6803161165711535, 1, 0.23886234162594963`], 
     Hue[0.7346533551910759, 1, 0.4242545508428439], 
     Hue[0.9374479652927546, 1, 0.7668338154101478], 
     Hue[0.9917852039126772, 1, 0.7166618456302744], 
     Hue[0.9988106241944529, 1, 0.7057017076112803], 
     Hue[0.9998245046951738, 1, 0.7040397160155706], 
     Hue[0.9999740308754407, 1, 0.7037929089225986], 
     Hue[0.9999961555513607, 1, 0.7037563530319443], 
     Hue[0.9999994308349677, 1, 0.7037509405753125], 
     Hue[0.9999999157351575, 1, 0.7037501392525064], 
     Hue[0.9999999875245787, 1, 0.7037500206163609], 
     Hue[0.9999999981530119, 1, 0.7037500030522559], 
     Hue[0.9999999997265531, 1, 0.703750000451887], 
     Hue[0.9999999999595162, 1, 0.7037500000669019], 
     Hue[0.9999999999940063, 1, 0.7037500000099048], 
     Hue[0.9999999999991126, 1, 0.7037500000014665], 
     Hue[0.9999999999998687, 1, 0.7037500000002171], 
     Hue[0.9999999999999806, 1, 0.7037500000000322], 
     Hue[0.9999999999999971, 1, 0.7037500000000049], 
     Hue[0.9999999999999996, 1, 0.7037500000000008], 
     Hue[0.9999999999999999, 1, 0.7037500000000001], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.9761197423899816, 1, 0.21], 
     Hue[0.9761197423899817, 1, 0.21], 
     Hue[0.9761197423899816, 1, 0.21], 
     Hue[0.9761197423899816, 1, 0.21], 
     Hue[0.9761197423899816, 1, 0.21], 
     Hue[0.9761197423899817, 1, 0.21000000000000002`], 
     Hue[0.9761197423899817, 1, 0.21000000000000021`], 
     Hue[0.9761197423899817, 1, 0.2100000000000015], 
     Hue[0.9761197423899821, 1, 0.21000000000001012`], 
     Hue[0.9761197423899849, 1, 0.21000000000006835`], 
     Hue[0.9761197423900039, 1, 0.21000000000046176`], 
     Hue[0.9761197423901319, 1, 0.21000000000311908`], 
     Hue[0.9761197423909967, 1, 0.21000000002106775`], 
     Hue[0.9761197423968382, 1, 0.21000000014230152`], 
     Hue[0.9761197424362945, 1, 0.21000000096117097`], 
     Hue[0.9761197427028004, 1, 0.21000000649219758`], 
     Hue[0.9761197445029057, 1, 0.2100000438513319], 
     Hue[0.976119756661651, 1, 0.21000029619222987`], 
     Hue[0.9761198387871737, 1, 0.21000200061384952`], 
     Hue[0.976120393486635, 1, 0.21001351276893837`], 
     Hue[0.976124139516212, 1, 0.21009125734317474`], 
     Hue[0.9761494114336445, 1, 0.21061574718168266`], 
     Hue[0.9763187289253528, 1, 0.21412973766623156`], 
     Hue[0.9774027060344395, 1, 0.23662615978411292`], 
     Hue[0.9827471083073313, 1, 0.34750368000032306`], 
     Hue[0.9933726340826504, 1, 0.5673632320355129], 
     Hue[0.9987170363555421, 1, 0.67740695654909], 
     Hue[0.9998010134646289, 1, 0.6996662761376425], 
     Hue[0.9999703309563371, 1, 0.7031411624732942], 
     Hue[0.9999956028737695, 1, 0.7036597677912511], 
     Hue[0.9999993489033466, 1, 0.7037366390497916], 
     Hue[0.999999903602808, 1, 0.7037480218639786], 
     Hue[0.9999999857283307, 1, 0.7037497071356392], 
     Hue[0.9999999978870758, 1, 0.7037499566413601], 
     Hue[0.9999999996871812, 1, 0.7037499935807456], 
     Hue[0.9999999999536872, 1, 0.7037499990496283], 
     Hue[0.9999999999931434, 1, 0.7037499998592973], 
     Hue[0.9999999999989849, 1, 0.7037499999791689], 
     Hue[0.9999999999998497, 1, 0.703749999996916], 
     Hue[0.9999999999999778, 1, 0.7037499999995434], 
     Hue[0.9999999999999967, 1, 0.7037499999999324], 
     Hue[0.9999999999999996, 1, 0.70374999999999], 
     Hue[0.9999999999999999, 1, 0.7037499999999984], 
     Hue[1., 1, 0.7037499999999998], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.2801381642961327`, 1, 0.21], 
     Hue[1.2801381642961327`, 1, 0.21], 
     Hue[1.2801381642961327`, 1, 0.21], 
     Hue[1.2801381642961327`, 1, 0.21], 
     Hue[1.2801381642961327`, 1, 0.21], 
     Hue[1.2801381642961327`, 1, 0.21000000000000002`], 
     Hue[1.2801381642961327`, 1, 0.21000000000000021`], 
     Hue[1.2801381642961323`, 1, 0.2100000000000015], 
     Hue[1.2801381642961296`, 1, 0.21000000000001012`], 
     Hue[1.280138164296111, 1, 0.21000000000006835`], 
     Hue[1.2801381642959866`, 1, 0.21000000000046176`], 
     Hue[1.2801381642951453`, 1, 0.21000000000311908`], 
     Hue[1.2801381642894631`, 1, 0.21000000002106775`], 
     Hue[1.2801381642510834`, 1, 0.21000000014230152`], 
     Hue[1.280138163991848, 1, 0.21000000096117097`], 
     Hue[1.2801381622408519`, 1, 0.2100000064921977], 
     Hue[1.2801381504138054`, 1, 0.21000004385133647`], 
     Hue[1.2801380705284013`, 1, 0.21000029619243898`], 
     Hue[1.2801375309446623`, 1, 0.21000200062339056`], 
     Hue[1.2801338863256757`, 1, 0.21001351320421638`], 
     Hue[1.2801092680290125`, 1, 0.21009127719803217`], 
     Hue[1.2799429464145984`, 1, 0.21061665185983597`], 
     Hue[1.2788178149427958`, 1, 0.2141706566163158], 
     Hue[1.271146924497176, 1, 0.23838632065950857`], 
     Hue[1.2185657488416801`, 1, 0.3996787911150446], 
     Hue[1.0615724154544528`, 1, 0.702962994454418], 
     Hue[1.0089912397989567`, 1, 0.708305570711856], 
     Hue[1.001320349353337, 1, 0.7045180685589963], 
     Hue[1.0001952178815343`, 1, 0.703865703404144], 
     Hue[1.0000288962671202`, 1, 0.703767173332137], 
     Hue[1.000004277970457, 1, 0.7037525434658338], 
     Hue[1.0000006333514704`, 1, 0.703750376581392], 
     Hue[1.0000000937677314`, 1, 0.7037500557533958], 
     Hue[1.000000013882327, 1, 0.7037500082543097], 
     Hue[1.0000000020552808`, 1, 0.7037500012220521], 
     Hue[1.0000000003042846`, 1, 0.703750000180925], 
     Hue[1.0000000000450493`, 1, 0.703750000026786], 
     Hue[1.0000000000066696`, 1, 0.7037500000039657], 
     Hue[1.0000000000009874`, 1, 0.7037500000005871], 
     Hue[1.000000000000146, 1, 0.7037500000000869], 
     Hue[1.0000000000000215`, 1, 0.703750000000013], 
     Hue[1.000000000000003, 1, 0.703750000000002], 
     Hue[1.0000000000000004`, 1, 0.7037500000000003], 
     Hue[1., 1, 0.7037500000000001], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.5841565862022837, 1, 0.21], 
     Hue[0.5841565862022837, 1, 0.21], 
     Hue[0.5841565862022837, 1, 0.21], 
     Hue[0.5841565862022837, 1, 0.21], 
     Hue[0.5841565862022837, 1, 0.21], 
     Hue[0.5841565862022837, 1, 0.21000000000000002`], 
     Hue[0.5841565862022837, 1, 0.21000000000000021`], 
     Hue[0.584156586202284, 1, 0.2100000000000015], 
     Hue[0.5841565862022854, 1, 0.21000000000001012`], 
     Hue[0.5841565862022948, 1, 0.21000000000006835`], 
     Hue[0.5841565862023588, 1, 0.21000000000046176`], 
     Hue[0.5841565862027909, 1, 0.21000000000311908`], 
     Hue[0.5841565862057095, 1, 0.21000000002106775`], 
     Hue[0.5841565862254235, 1, 0.21000000014230152`], 
     Hue[0.584156586358581, 1, 0.21000000096117097`], 
     Hue[0.5841565872579888, 1, 0.21000000649219774`], 
     Hue[0.5841565933330097, 1, 0.2100000438513391], 
     Hue[0.5841566343665602, 1, 0.21000029619255897`], 
     Hue[0.5841569115272749, 1, 0.21000200062886393`], 
     Hue[0.5841587836434795, 1, 0.21001351345393568`], 
     Hue[0.5841714307651827, 1, 0.2100912885937632], 
     Hue[0.5842569454943147, 1, 0.21061717263815927`], 
     Hue[0.5848386919373251, 1, 0.2141946861782777], 
     Hue[0.5889654612333839, 1, 0.23956831057075728`], 
     Hue[0.6291786723176982, 1, 0.48319137395138856`], 
     Hue[0.9549779138845853, 1, 0.9200068329753903], 
     Hue[0.9951911249688997, 1, 0.7290547253615676], 
     Hue[0.9993178942649587, 1, 0.707367272812167], 
     Hue[0.999899640707969, 1, 0.7042827856667754], 
     Hue[0.999985155437101, 1, 0.7038288189349987], 
     Hue[0.9999978025588041, 1, 0.7037616678407448], 
     Hue[0.9999996746750087, 1, 0.7037517273969557], 
     Hue[0.9999999518357235, 1, 0.7037502557407793], 
     Hue[0.9999999928692739, 1, 0.7037500378624518], 
     Hue[0.9999999989442948, 1, 0.7037500056055421], 
     Hue[0.9999999998437027, 1, 0.7037500008299015], 
     Hue[0.9999999999768602, 1, 0.7037500001228671], 
     Hue[0.9999999999965742, 1, 0.7037500000181905], 
     Hue[0.9999999999994929, 1, 0.7037500000026932], 
     Hue[0.999999999999925, 1, 0.7037500000003988], 
     Hue[0.9999999999999889, 1, 0.7037500000000592], 
     Hue[0.9999999999999983, 1, 0.7037500000000088], 
     Hue[0.9999999999999998, 1, 0.7037500000000013], 
     Hue[1., 1, 0.7037500000000002], 
     Hue[1., 1, 0.7037500000000001], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.8881750081084343, 1, 0.21], 
     Hue[0.8881750081084342, 1, 0.21], 
     Hue[0.8881750081084343, 1, 0.21], 
     Hue[0.8881750081084342, 1, 0.21], 
     Hue[0.8881750081084342, 1, 0.21], 
     Hue[0.8881750081084343, 1, 0.21000000000000002`], 
     Hue[0.8881750081084343, 1, 0.21000000000000021`], 
     Hue[0.8881750081084345, 1, 0.2100000000000015], 
     Hue[0.8881750081084363, 1, 0.21000000000001012`], 
     Hue[0.8881750081084485, 1, 0.21000000000006835`], 
     Hue[0.8881750081085305, 1, 0.21000000000046176`], 
     Hue[0.888175008109084, 1, 0.21000000000311908`], 
     Hue[0.8881750081128227, 1, 0.21000000002106775`], 
     Hue[0.8881750081380758, 1, 0.21000000014230152`], 
     Hue[0.8881750083086472, 1, 0.21000000096117097`], 
     Hue[0.888175009460766, 1, 0.2100000064921976], 
     Hue[0.8881750172427143, 1, 0.21000004385133278`], 
     Hue[0.8881750698056043, 1, 0.21000029619226995`], 
     Hue[0.8881754248388433, 1, 0.21000200061567836`], 
     Hue[0.8881778228501944, 1, 0.21001351285237063`], 
     Hue[0.8881940179042906, 1, 0.21009126114801524`], 
     Hue[0.8883033049836622, 1, 0.21061592028490345`], 
     Hue[0.8890368555144564, 1, 0.2141374878545395], 
     Hue[0.8937874320507458, 1, 0.23693822214072813`], 
     Hue[0.9183971324512094, 1, 0.3542182780227653], 
     Hue[0.9697778756572247, 1, 0.5848140409965065], 
     Hue[0.9943875760576883, 1, 0.6828850321537473], 
     Hue[0.9991381525939778, 1, 0.7005852221227934], 
     Hue[0.999871703124772, 1, 0.703279797819218], 
     Hue[0.9999809902041435, 1, 0.7036803502081588], 
     Hue[0.9999971852582398, 1, 0.7037396875414165], 
     Hue[0.9999995832695909, 1, 0.7037484732213342], 
     Hue[0.9999999383028298, 1, 0.7037497739597782], 
     Hue[0.99999999086572, 1, 0.7037499665346986], 
     Hue[0.9999999986476682, 1, 0.7037499950454563], 
     Hue[0.999999999799787, 1, 0.703749999266479], 
     Hue[0.9999999999703585, 1, 0.7037499998914021], 
     Hue[0.9999999999956115, 1, 0.7037499999839221], 
     Hue[0.9999999999993503, 1, 0.7037499999976197], 
     Hue[0.9999999999999039, 1, 0.7037499999996476], 
     Hue[0.9999999999999858, 1, 0.7037499999999478], 
     Hue[0.9999999999999979, 1, 0.7037499999999923], 
     Hue[0.9999999999999997, 1, 0.7037499999999989], 
     Hue[1., 1, 0.7037499999999998], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.1921934300145853`, 1, 0.21], 
     Hue[1.1921934300145853`, 1, 0.21], 
     Hue[1.1921934300145853`, 1, 0.21], 
     Hue[1.1921934300145853`, 1, 0.21], 
     Hue[1.1921934300145853`, 1, 0.21], 
     Hue[1.1921934300145853`, 1, 0.21000000000000002`], 
     Hue[1.1921934300145853`, 1, 0.21000000000000021`], 
     Hue[1.1921934300145849`, 1, 0.2100000000000015], 
     Hue[1.1921934300145822`, 1, 0.21000000000001012`], 
     Hue[1.1921934300145647`, 1, 0.21000000000006835`], 
     Hue[1.192193430014446, 1, 0.21000000000046176`], 
     Hue[1.1921934300136454`, 1, 0.21000000000311908`], 
     Hue[1.1921934300082373`, 1, 0.21000000002106775`], 
     Hue[1.1921934299717083`, 1, 0.21000000014230152`], 
     Hue[1.1921934297249748`, 1, 0.21000000096117097`], 
     Hue[1.19219342805842, 1, 0.21000000649219763`], 
     Hue[1.1921934168017319`, 1, 0.21000004385133436`], 
     Hue[1.1921933407688177`, 1, 0.21000029619234242`], 
     Hue[1.1921928272077222`, 1, 0.21000200061898472`], 
     Hue[1.192189358409177, 1, 0.21001351300321006`], 
     Hue[1.192165930028675, 1, 0.21009126802791833`], 
     Hue[1.1920077525148176`, 1, 0.21061623360564982`], 
     Hue[1.1909424945697502`, 1, 0.21415161071438632`], 
     Hue[1.1838941836952661`, 1, 0.23753138208647379`], 
     Hue[1.1434205646009818`, 1, 0.36934761228554736`], 
     Hue[1.0487728654136035`, 1, 0.6241342089416898], 
     Hue[1.0082992463193192`, 1, 0.6932976146378811], 
     Hue[1.0012509354448351`, 1, 0.702259780835361], 
     Hue[1.0001856774997675`, 1, 0.7035307309321559], 
     Hue[1.0000274999859102`, 1, 0.7037175672828782], 
     Hue[1.0000040716054082`, 1, 0.7037451989917136], 
     Hue[1.000000602806863, 1, 0.7037492892244022], 
     Hue[1.0000000892457674`, 1, 0.7037498947698702], 
     Hue[1.0000000132128535`, 1, 0.7037499844206685], 
     Hue[1.0000000019561652`, 1, 0.7037499976934775], 
     Hue[1.0000000002896106`, 1, 0.7037499996585189], 
     Hue[1.0000000000428768`, 1, 0.7037499999494436], 
     Hue[1.000000000006348, 1, 0.7037499999925152], 
     Hue[1.00000000000094, 1, 0.7037499999988919], 
     Hue[1.0000000000001392`, 1, 0.703749999999836], 
     Hue[1.0000000000000207`, 1, 0.7037499999999757], 
     Hue[1.000000000000003, 1, 0.7037499999999964], 
     Hue[1.0000000000000004`, 1, 0.7037499999999994], 
     Hue[1., 1, 0.7037499999999999], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.4962118519207368`, 1, 0.21], 
     Hue[1.4962118519207368`, 1, 0.21], 
     Hue[1.4962118519207368`, 1, 0.21], 
     Hue[1.4962118519207368`, 1, 0.21], 
     Hue[1.4962118519207368`, 1, 0.21], 
     Hue[1.4962118519207368`, 1, 0.21000000000000002`], 
     Hue[1.4962118519207368`, 1, 0.21000000000000021`], 
     Hue[1.4962118519207368`, 1, 0.2100000000000015], 
     Hue[1.4962118519207368`, 1, 0.21000000000001012`], 
     Hue[1.4962118519207364`, 1, 0.21000000000006835`], 
     Hue[1.4962118519207332`, 1, 0.21000000000046176`], 
     Hue[1.496211851920713, 1, 0.21000000000311908`], 
     Hue[1.4962118519205754`, 1, 0.21000000002106775`], 
     Hue[1.4962118519196452`, 1, 0.21000000014230152`], 
     Hue[1.4962118519133634`, 1, 0.21000000096117097`], 
     Hue[1.4962118518709322`, 1, 0.21000000649219774`], 
     Hue[1.4962118515843326`, 1, 0.21000004385133964`], 
     Hue[1.496211849648503, 1, 0.21000029619258317`], 
     Hue[1.4962118365729555`, 1, 0.21000200062996874`], 
     Hue[1.4962117482522364`, 1, 0.21001351350434372`], 
     Hue[1.4962111515849896`, 1, 0.21009129089453352`], 
     Hue[1.4962071164890758`, 1, 0.21061727791850748`], 
     Hue[1.4961796348956415`, 1, 0.21419958717208432`], 
     Hue[1.4959830476750358`, 1, 0.23982531900119158`], 
     Hue[1.4938435016238063`, 1, 0.5187102702719639], 
     Hue[1.0023683502969307`, 1, 1.0123181630243419`], 
     Hue[1.000228804245701, 1, 0.7335663608828281], 
     Hue[1.0000322170250955`, 1, 0.7079483875416301], 
     Hue[1.0000047354316612`, 1, 0.7043671028587165], 
     Hue[1.0000007003357472`, 1, 0.7038412650320116], 
     Hue[1.0000001036685007`, 1, 0.7037635096765986], 
     Hue[1.0000000153477813`, 1, 0.703752000063297], 
     Hue[1.0000000022722337`, 1, 0.703750296108688], 
     Hue[1.0000000003364045`, 1, 0.703750043838919], 
     Hue[1.0000000000498048`, 1, 0.7037500064903589], 
     Hue[1.0000000000073737`, 1, 0.7037500009608988], 
     Hue[1.0000000000010916`, 1, 0.7037500001422612], 
     Hue[1.0000000000001616`, 1, 0.7037500000210618], 
     Hue[1.000000000000024, 1, 0.7037500000031183], 
     Hue[1.0000000000000036`, 1, 0.7037500000004617], 
     Hue[1.0000000000000004`, 1, 0.7037500000000684], 
     Hue[1., 1, 0.7037500000000102], 
     Hue[1., 1, 0.7037500000000015], 
     Hue[1., 1, 0.7037500000000002], 
     Hue[1., 1, 0.7037500000000001], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.8002302738268879, 1, 0.21], 
     Hue[0.8002302738268879, 1, 0.21], 
     Hue[0.8002302738268879, 1, 0.21], 
     Hue[0.8002302738268879, 1, 0.21], 
     Hue[0.8002302738268879, 1, 0.21], 
     Hue[0.8002302738268879, 1, 0.21000000000000002`], 
     Hue[0.800230273826888, 1, 0.21000000000000021`], 
     Hue[0.8002302738268885, 1, 0.2100000000000015], 
     Hue[0.800230273826891, 1, 0.21000000000001012`], 
     Hue[0.8002302738269089, 1, 0.21000000000006835`], 
     Hue[0.8002302738270295, 1, 0.21000000000046176`], 
     Hue[0.8002302738278437, 1, 0.21000000000311908`], 
     Hue[0.8002302738333436, 1, 0.21000000002106775`], 
     Hue[0.8002302738704917, 1, 0.21000000014230152`], 
     Hue[0.8002302741214083, 1, 0.21000000096117097`], 
     Hue[0.8002302758162161, 1, 0.21000000649219763`], 
     Hue[0.8002302872637388, 1, 0.21000004385133453`], 
     Hue[0.8002303645856403, 1, 0.2100002961923504], 
     Hue[0.80023088685324, 1, 0.21000200061934854`], 
     Hue[0.8002344144632592, 1, 0.21001351301980892`], 
     Hue[0.8002582402517386, 1, 0.21009126878508677`], 
     Hue[0.8004191096902221, 1, 0.21061626811307946`], 
     Hue[0.8015028957434728, 1, 0.2141531736603784], 
     Hue[0.8086911196308195, 1, 0.2375990747012939], 
     Hue[0.8504928923094197, 1, 0.3713196154954279], 
     Hue[0.949737381517468, 1, 0.6292593186163229], 
     Hue[0.9915391541960685, 1, 0.6944859196480835], 
     Hue[0.9987273780834152, 1, 0.7024451005833942], 
     Hue[0.9998111641366658, 1, 0.7035583673298097], 
     Hue[0.9999720335751494, 1, 0.7037216632117665], 
     Hue[0.9999958593636288, 1, 0.7037458054900695], 
     Hue[0.999999386973648, 1, 0.703749379018677], 
     Hue[0.9999999092412476, 1, 0.7037499080639734], 
     Hue[0.9999999865631493, 1, 0.7037499863888638], 
     Hue[0.999999998010672, 1, 0.7037499979848691], 
     Hue[0.9999999997054796, 1, 0.7037499997016596], 
     Hue[0.9999999999563962, 1, 0.7037499999558307], 
     Hue[0.9999999999935445, 1, 0.7037499999934608], 
     Hue[0.9999999999990442, 1, 0.7037499999990319], 
     Hue[0.9999999999998584, 1, 0.7037499999998568], 
     Hue[0.999999999999979, 1, 0.7037499999999788], 
     Hue[0.9999999999999969, 1, 0.7037499999999969], 
     Hue[0.9999999999999996, 1, 0.7037499999999995], 
     Hue[0.9999999999999999, 1, 0.7037499999999999], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.104248695733039, 1, 0.21], 
     Hue[1.104248695733039, 1, 0.21], 
     Hue[1.104248695733039, 1, 0.21], 
     Hue[1.104248695733039, 1, 0.21], 
     Hue[1.104248695733039, 1, 0.21], 
     Hue[1.104248695733039, 1, 0.21000000000000002`], 
     Hue[1.104248695733039, 1, 0.21000000000000021`], 
     Hue[1.1042486957330386`, 1, 0.2100000000000015], 
     Hue[1.104248695733037, 1, 0.21000000000001012`], 
     Hue[1.1042486957330255`, 1, 0.21000000000006835`], 
     Hue[1.1042486957329483`, 1, 0.21000000000046176`], 
     Hue[1.1042486957324265`, 1, 0.21000000000311908`], 
     Hue[1.1042486957289022`, 1, 0.21000000002106775`], 
     Hue[1.1042486957050968`, 1, 0.21000000014230152`], 
     Hue[1.104248695544304, 1, 0.21000000096117097`], 
     Hue[1.104248694458235, 1, 0.2100000064921976], 
     Hue[1.1042486871224175`, 1, 0.21000004385133267`], 
     Hue[1.1042486375729024`, 1, 0.21000029619226465`], 
     Hue[1.1042483028933843`, 1, 0.21000200061543609`], 
     Hue[1.1042460423595706`, 1, 0.21001351284131856`], 
     Hue[1.1042307758473369`, 1, 0.21009126064397352`], 
     Hue[1.1041277584855578`, 1, 0.21061589734611488`], 
     Hue[1.1034364596409418`, 1, 0.21413645870553033`], 
     Hue[1.0989663937829592`, 1, 0.23689625301047237`], 
     Hue[1.0759672884856744`, 1, 0.3532720015542731], 
     Hue[1.0282814072473647`, 1, 0.5823547292371504], 
     Hue[1.0052823019500798`, 1, 0.6821482881545784], 
     Hue[1.0008122360920972`, 1, 0.7004631951071234], 
     Hue[1.000120937247481, 1, 0.7032614265441332], 
     Hue[1.0000179198857022`, 1, 0.7036776235769028], 
     Hue[1.0000026533734685`, 1, 0.7037392837147712], 
     Hue[1.0000003928396548`, 1, 0.7037484134314769], 
     Hue[1.0000000581601365`, 1, 0.7037497651078085], 
     Hue[1.0000000086106215`, 1, 0.7037499652241614], 
     Hue[1.000000001274804, 1, 0.7037499948514311], 
     Hue[1.000000000188735, 1, 0.7037499992377535], 
     Hue[1.0000000000279423`, 1, 0.7037499998871493], 
     Hue[1.000000000004137, 1, 0.7037499999832925], 
     Hue[1.0000000000006124`, 1, 0.7037499999975264], 
     Hue[1.0000000000000906`, 1, 0.7037499999996338], 
     Hue[1.0000000000000133`, 1, 0.7037499999999457], 
     Hue[1.000000000000002, 1, 0.703749999999992], 
     Hue[1.0000000000000002`, 1, 0.7037499999999988], 
     Hue[1., 1, 0.7037499999999998], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.4082671176391908`, 1, 0.21], 
     Hue[1.4082671176391908`, 1, 0.21], 
     Hue[1.4082671176391908`, 1, 0.21], 
     Hue[1.4082671176391908`, 1, 0.21], 
     Hue[1.4082671176391908`, 1, 0.21], 
     Hue[1.4082671176391908`, 1, 0.21000000000000002`], 
     Hue[1.4082671176391908`, 1, 0.21000000000000021`], 
     Hue[1.4082671176391903`, 1, 0.2100000000000015], 
     Hue[1.408267117639189, 1, 0.21000000000001012`], 
     Hue[1.4082671176391788`, 1, 0.21000000000006835`], 
     Hue[1.4082671176391095`, 1, 0.21000000000046176`], 
     Hue[1.4082671176386428`, 1, 0.21000000000311908`], 
     Hue[1.4082671176354897`, 1, 0.21000000002106775`], 
     Hue[1.4082671176141925`, 1, 0.21000000014230152`], 
     Hue[1.408267117470341, 1, 0.21000000096117097`], 
     Hue[1.4082671164987004`, 1, 0.21000000649219774`], 
     Hue[1.4082671099357853`, 1, 0.21000004385133902`], 
     Hue[1.4082670656067702`, 1, 0.21000029619255453`], 
     Hue[1.4082667661868988`, 1, 0.2100020006286614], 
     Hue[1.4082647437198321`, 1, 0.21001351344469527`], 
     Hue[1.4082510809613482`, 1, 0.21009128817202075`], 
     Hue[1.408158701730551, 1, 0.21061715334473516`], 
     Hue[1.4075303880970853`, 1, 0.21419378962157004`], 
     Hue[1.4030800573734563`, 1, 0.23952191421125882`], 
     Hue[1.3604873065924514`, 1, 0.47791763997486314`], 
     Hue[1.0477798110467396`, 1, 0.9063007371185944], 
     Hue[1.0051870602657342`, 1, 0.7282402638934492], 
     Hue[1.0007367295421055`, 1, 0.7072609673710332], 
     Hue[1.0001084159086397`, 1, 0.7042673339004032], 
     Hue[1.0000160366778426`, 1, 0.7038265375045542], 
     Hue[1.0000023739193584`, 1, 0.7037613302103582], 
     Hue[1.0000003514522917`, 1, 0.703751677413695], 
     Hue[1.0000000520324206`, 1, 0.7037502483408143], 
     Hue[1.0000000077034055`, 1, 0.7037500367668872], 
     Hue[1.0000000011404904`, 1, 0.7037500054433435], 
     Hue[1.0000000001688498`, 1, 0.703750000805888], 
     Hue[1.0000000000249982`, 1, 0.7037500001193119], 
     Hue[1.000000000003701, 1, 0.7037500000176642], 
     Hue[1.000000000000548, 1, 0.7037500000026152], 
     Hue[1.000000000000081, 1, 0.7037500000003872], 
     Hue[1.000000000000012, 1, 0.7037500000000574], 
     Hue[1.0000000000000018`, 1, 0.7037500000000085], 
     Hue[1.0000000000000002`, 1, 0.7037500000000013], 
     Hue[1., 1, 0.7037500000000002], 
     Hue[1., 1, 0.7037500000000001], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.7122855395453418, 1, 0.21], 
     Hue[0.7122855395453417, 1, 0.21], 
     Hue[0.7122855395453417, 1, 0.21], 
     Hue[0.7122855395453417, 1, 0.21], 
     Hue[0.7122855395453417, 1, 0.21], 
     Hue[0.7122855395453418, 1, 0.21000000000000002`], 
     Hue[0.7122855395453418, 1, 0.21000000000000021`], 
     Hue[0.7122855395453422, 1, 0.2100000000000015], 
     Hue[0.7122855395453449, 1, 0.21000000000001012`], 
     Hue[0.7122855395453631, 1, 0.21000000000006835`], 
     Hue[0.7122855395454863, 1, 0.21000000000046176`], 
     Hue[0.712285539546319, 1, 0.21000000000311908`], 
     Hue[0.712285539551943, 1, 0.21000000002106775`], 
     Hue[0.7122855395899292, 1, 0.21000000014230152`], 
     Hue[0.7122855398465066, 1, 0.21000000096117097`], 
     Hue[0.7122855415795497, 1, 0.2100000064921977], 
     Hue[0.7122855532853332, 1, 0.21000004385133667`], 
     Hue[0.7122856323516731, 1, 0.21000029619244726`], 
     Hue[0.7122861664031634, 1, 0.2100020006237677], 
     Hue[0.7122897736590637, 1, 0.2100135132214218], 
     Hue[0.7123141397843671, 1, 0.21009127798307128`], 
     Hue[0.71247876708235, 1, 0.2106166876996471], 
     Hue[0.7135928656629611, 1, 0.21417229904457424`], 
     Hue[0.7212086387775898, 1, 0.2384632541817815], 
     Hue[0.774370163451896, 1, 0.4031566271015455], 
     Hue[0.9379153760934454, 1, 0.7120016667912051], 
     Hue[0.9910769007677518, 1, 0.7096560945498319], 
     Hue[0.9986926738823806, 1, 0.7047128125825017], 
     Hue[0.9998067724629917, 1, 0.7038944068828532], 
     Hue[0.9999713997609746, 1, 0.7037714200286252], 
     Hue[0.999995765886278, 1, 0.7037531721271738], 
     Hue[0.9999993731421781, 1, 0.7037504696534328], 
     Hue[0.9999999071936686, 1, 0.7037500695326969], 
     Hue[0.9999999862600086, 1, 0.7037500102943369], 
     Hue[0.999999997965792, 1, 0.7037500015240785], 
     Hue[0.9999999996988351, 1, 0.7037500002256402], 
     Hue[0.9999999999554124, 1, 0.703750000033406], 
     Hue[0.9999999999933988, 1, 0.7037500000049458], 
     Hue[0.9999999999990227, 1, 0.7037500000007323], 
     Hue[0.9999999999998553, 1, 0.7037500000001085], 
     Hue[0.9999999999999786, 1, 0.7037500000000161], 
     Hue[0.9999999999999968, 1, 0.7037500000000024], 
     Hue[0.9999999999999996, 1, 0.7037500000000003], 
     Hue[0.9999999999999999, 1, 0.7037500000000001], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.0163039614514933`, 1, 0.21], 
     Hue[1.0163039614514933`, 1, 0.21], 
     Hue[1.0163039614514933`, 1, 0.21], 
     Hue[1.0163039614514933`, 1, 0.21], 
     Hue[1.0163039614514933`, 1, 0.21], 
     Hue[1.0163039614514933`, 1, 0.21000000000000002`], 
     Hue[1.0163039614514933`, 1, 0.21000000000000021`], 
     Hue[1.0163039614514933`, 1, 0.2100000000000015], 
     Hue[1.016303961451493, 1, 0.21000000000001012`], 
     Hue[1.016303961451491, 1, 0.21000000000006835`], 
     Hue[1.0163039614514782`, 1, 0.21000000000046176`], 
     Hue[1.0163039614513905`, 1, 0.21000000000311908`], 
     Hue[1.016303961450799, 1, 0.21000000002106775`], 
     Hue[1.0163039614468026`, 1, 0.21000000014230152`], 
     Hue[1.0163039614198104`, 1, 0.21000000096117097`], 
     Hue[1.0163039612374913`, 1, 0.21000000649219758`], 
     Hue[1.0163039600060237`, 1, 0.21000004385133186`], 
     Hue[1.0163039516881214`, 1, 0.2100002961922288], 
     Hue[1.016303895505345, 1, 0.21000200061380092`], 
     Hue[1.016303516030733, 1, 0.21001351276672212`], 
     Hue[1.0163009533428646`, 1, 0.21009125724211097`], 
     Hue[1.0162836647545261`, 1, 0.21061574258542817`], 
     Hue[1.0161678398327445`, 1, 0.21412953238674573`], 
     Hue[1.0154265484168827`, 1, 0.23661801750842903`], 
     Hue[1.0117762880226804`, 1, 0.34733787971795493`], 
     Hue[1.004527673428813, 1, 0.5669323277515015], 
     Hue[1.0008774130346108`, 1, 0.6772640235716105], 
     Hue[1.0001361216187488`, 1, 0.6996419359859148], 
     Hue[1.0000202966969671`, 1, 0.7031374814133594], 
     Hue[1.0000030081086286`, 1, 0.7036592210833152], 
     Hue[1.0000004454207603`, 1, 0.7037365580716574], 
     Hue[1.0000000659461485`, 1, 0.7037480098743203], 
     Hue[1.0000000097633719`, 1, 0.7037497053605499], 
     Hue[1.0000000014454695`, 1, 0.7037499563785575], 
     Hue[1.000000000214002, 1, 0.7037499935418376], 
     Hue[1.000000000031683, 1, 0.703749999043868], 
     Hue[1.0000000000046907`, 1, 0.7037499998584446], 
     Hue[1.0000000000006946`, 1, 0.7037499999790428], 
     Hue[1.0000000000001028`, 1, 0.7037499999968972], 
     Hue[1.0000000000000153`, 1, 0.7037499999995407], 
     Hue[1.0000000000000022`, 1, 0.703749999999932], 
     Hue[1.0000000000000004`, 1, 0.7037499999999899], 
     Hue[1., 1, 0.7037499999999984], 
     Hue[1., 1, 0.7037499999999998], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.3203223833576443`, 1, 0.21], 
     Hue[1.3203223833576443`, 1, 0.21], 
     Hue[1.3203223833576443`, 1, 0.21], 
     Hue[1.3203223833576443`, 1, 0.21], 
     Hue[1.3203223833576443`, 1, 0.21], 
     Hue[1.3203223833576443`, 1, 0.21000000000000002`], 
     Hue[1.3203223833576443`, 1, 0.21000000000000021`], 
     Hue[1.3203223833576438`, 1, 0.2100000000000015], 
     Hue[1.3203223833576414`, 1, 0.21000000000001012`], 
     Hue[1.3203223833576245`, 1, 0.21000000000006835`], 
     Hue[1.32032238335751, 1, 0.21000000000046176`], 
     Hue[1.3203223833567357`, 1, 0.21000000000311908`], 
     Hue[1.3203223833515056`, 1, 0.21000000002106775`], 
     Hue[1.3203223833161803`, 1, 0.21000000014230152`], 
     Hue[1.3203223830775759`, 1, 0.21000000096117097`], 
     Hue[1.3203223814659313`, 1, 0.21000000649219772`], 
     Hue[1.3203223705801295`, 1, 0.21000004385133741`], 
     Hue[1.3203222970523212`, 1, 0.21000029619248153`], 
     Hue[1.3203218004103157`, 1, 0.21000200062533103`], 
     Hue[1.3203184458198214`, 1, 0.2100135132927481], 
     Hue[1.3202957855968873`, 1, 0.2100912812376874], 
     Hue[1.320142647967812, 1, 0.2106168363411872], 
     Hue[1.3191046463111047`, 1, 0.2141791285277435], 
     Hue[1.311929885126058, 1, 0.23878898929957154`], 
     Hue[1.2575366359613314`, 1, 0.4199297156228061], 
     Hue[1.0627857473963134`, 1, 0.7555938464707703], 
     Hue[1.0083924982315866`, 1, 0.7153741876312925], 
     Hue[1.0012177370465396`, 1, 0.7055225898278669], 
     Hue[1.0001797353898323`, 1, 0.7040134512959795], 
     Hue[1.0000265977607572`, 1, 0.7037890259873848], 
     Hue[1.000003937537823, 1, 0.7037557782846178], 
     Hue[1.0000005829473286`, 1, 0.7037508554865454], 
     Hue[1.0000000863053233`, 1, 0.7037501266551586], 
     Hue[1.0000000127775148`, 1, 0.7037500187513228], 
     Hue[1.0000000018917132`, 1, 0.7037500027761366], 
     Hue[1.0000000002800684`, 1, 0.7037500004110075], 
     Hue[1.0000000000414642`, 1, 0.7037500000608498], 
     Hue[1.0000000000061389`, 1, 0.7037500000090089], 
     Hue[1.0000000000009088`, 1, 0.7037500000013338], 
     Hue[1.0000000000001346`, 1, 0.7037500000001975], 
     Hue[1.00000000000002, 1, 0.7037500000000293], 
     Hue[1.0000000000000029`, 1, 0.7037500000000044], 
     Hue[1.0000000000000004`, 1, 0.7037500000000007], 
     Hue[1., 1, 0.7037500000000001], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.624340805263796, 1, 0.21], 
     Hue[0.624340805263796, 1, 0.21], 
     Hue[0.624340805263796, 1, 0.21], 
     Hue[0.624340805263796, 1, 0.21], 
     Hue[0.624340805263796, 1, 0.21], 
     Hue[0.624340805263796, 1, 0.21000000000000002`], 
     Hue[0.624340805263796, 1, 0.21000000000000021`], 
     Hue[0.6243408052637963, 1, 0.2100000000000015], 
     Hue[0.6243408052637983, 1, 0.21000000000001012`], 
     Hue[0.6243408052638115, 1, 0.21000000000006835`], 
     Hue[0.6243408052639008, 1, 0.21000000000046176`], 
     Hue[0.624340805264504, 1, 0.21000000000311908`], 
     Hue[0.624340805268578, 1, 0.21000000002106775`], 
     Hue[0.6243408052960959, 1, 0.21000000014230152`], 
     Hue[0.6243408054819647, 1, 0.21000000096117097`], 
     Hue[0.6243408067374092, 1, 0.21000000649219774`], 
     Hue[0.6243408152172687, 1, 0.21000004385133852`], 
     Hue[0.6243408724942244, 1, 0.21000029619253172`], 
     Hue[0.6243412593706272, 1, 0.21000200062762042`], 
     Hue[0.6243438725642371, 1, 0.21001351339720042`], 
     Hue[0.6243615255607068, 1, 0.21009128600437793`], 
     Hue[0.6244808655946283, 1, 0.21061705420604734`], 
     Hue[0.6252916825209105, 1, 0.2141891904192185], 
     Hue[0.6309903301992615, 1, 0.2392868381477764], 
     Hue[0.6811328276598678, 1, 0.454928651487954], 
     Hue[0.9432079776039278, 1, 0.8465538326947286], 
     Hue[0.9933504750645344, 1, 0.7241136384889318], 
     Hue[0.9990491227428855, 1, 0.7067156362941702], 
     Hue[0.9998599396691676, 1, 0.7041879354570145], 
     Hue[0.9999792797030892, 1, 0.703814811565545], 
     Hue[0.9999969326995589, 1, 0.7037595948180524], 
     Hue[0.9999995458931688, 1, 0.7037514205024846], 
     Hue[0.9999999327695716, 1, 0.7037502103053712], 
     Hue[0.9999999900465273, 1, 0.7037500311357401], 
     Hue[0.9999999985263868, 1, 0.7037500046096514], 
     Hue[0.9999999997818313, 1, 0.7037500006824596], 
     Hue[0.9999999999677001, 1, 0.7037500001010383], 
     Hue[0.999999999995218, 1, 0.7037500000149588], 
     Hue[0.999999999999292, 1, 0.7037500000022147], 
     Hue[0.9999999999998952, 1, 0.703750000000328], 
     Hue[0.9999999999999845, 1, 0.7037500000000486], 
     Hue[0.9999999999999977, 1, 0.7037500000000072], 
     Hue[0.9999999999999997, 1, 0.7037500000000011], 
     Hue[1., 1, 0.7037500000000002], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.9283592271699466, 1, 0.21], 
     Hue[0.9283592271699466, 1, 0.21], 
     Hue[0.9283592271699466, 1, 0.21], 
     Hue[0.9283592271699466, 1, 0.21], 
     Hue[0.9283592271699466, 1, 0.21], 
     Hue[0.9283592271699466, 1, 0.21000000000000002`], 
     Hue[0.9283592271699466, 1, 0.21000000000000021`], 
     Hue[0.9283592271699468, 1, 0.2100000000000015], 
     Hue[0.9283592271699479, 1, 0.21000000000001012`], 
     Hue[0.9283592271699561, 1, 0.21000000000006835`], 
     Hue[0.9283592271700113, 1, 0.21000000000046176`], 
     Hue[0.928359227170384, 1, 0.21000000000311908`], 
     Hue[0.9283592271729012, 1, 0.21000000002106775`], 
     Hue[0.9283592271899036, 1, 0.21000000014230152`], 
     Hue[0.9283592273047457, 1, 0.21000000096117097`], 
     Hue[0.9283592280804435, 1, 0.2100000064921976], 
     Hue[0.9283592333198676, 1, 0.21000004385133225`], 
     Hue[0.9283592687093671, 1, 0.21000029619224556`], 
     Hue[0.928359507745725, 1, 0.2100020006145659], 
     Hue[0.9283611222700313, 1, 0.21001351280161976`], 
     Hue[0.9283720257463043, 1, 0.21009125883352664`], 
     Hue[0.9284455920182038, 1, 0.21061581497121662`], 
     Hue[0.9289388276958152, 1, 0.21413276833031902`], 
     Hue[0.932110716385017, 1, 0.23674710208883298`], 
     Hue[0.948046541810677, 1, 0.35002049560314763`], 
     Hue[0.9803126853592694, 1, 0.5739042741244277], 
     Hue[0.9962485107849296, 1, 0.6795300293100732], 
     Hue[0.9994203994741314, 1, 0.700025624386338], 
     Hue[0.9999136351517427, 1, 0.7031954539269637], 
     Hue[0.9999872014236423, 1, 0.7036678299016774], 
     Hue[0.9999981048999153, 1, 0.7037378331793609], 
     Hue[0.9999997194242216, 1, 0.7037481986667444], 
     Hue[0.9999999584605794, 1, 0.7037497333115746], 
     Hue[0.9999999938500789, 1, 0.7037499605167175], 
     Hue[0.9999999990895031, 1, 0.7037499941544929], 
     Hue[0.9999999998652008, 1, 0.7037499991345717], 
     Hue[0.999999999980043, 1, 0.7037499998718733], 
     Hue[0.9999999999970454, 1, 0.7037499999810308], 
     Hue[0.9999999999995626, 1, 0.7037499999971916], 
     Hue[0.9999999999999353, 1, 0.7037499999995843], 
     Hue[0.9999999999999905, 1, 0.7037499999999385], 
     Hue[0.9999999999999986, 1, 0.7037499999999909], 
     Hue[0.9999999999999998, 1, 0.7037499999999987], 
     Hue[1., 1, 0.7037499999999998], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.2323776490760983`, 1, 0.21], 
     Hue[1.2323776490760983`, 1, 0.21], 
     Hue[1.2323776490760983`, 1, 0.21], 
     Hue[1.2323776490760983`, 1, 0.21], 
     Hue[1.2323776490760983`, 1, 0.21], 
     Hue[1.2323776490760983`, 1, 0.21000000000000002`], 
     Hue[1.232377649076098, 1, 0.21000000000000021`], 
     Hue[1.2323776490760978`, 1, 0.2100000000000015], 
     Hue[1.232377649076095, 1, 0.21000000000001012`], 
     Hue[1.2323776490760763`, 1, 0.21000000000006835`], 
     Hue[1.2323776490759502`, 1, 0.21000000000046176`], 
     Hue[1.2323776490750988`, 1, 0.21000000000311908`], 
     Hue[1.2323776490693488`, 1, 0.21000000002106775`], 
     Hue[1.2323776490305096`, 1, 0.21000000014230152`], 
     Hue[1.2323776487681724`, 1, 0.21000000096117097`], 
     Hue[1.2323776469962238`, 1, 0.21000000649219766`], 
     Hue[1.2323776350276556`, 1, 0.2100000438513353], 
     Hue[1.23237755418636, 1, 0.21000029619238592`], 
     Hue[1.232377008146725, 1, 0.21000200062096896`], 
     Hue[1.2323733199508753`, 1, 0.21001351309373506`], 
     Hue[1.2323484086512941`, 1, 0.21009127215747084`], 
     Hue[1.2321801688994771`, 1, 0.21061642186716176`], 
     Hue[1.2310448642278875`, 1, 0.2141601559581766], 
     Hue[1.2234325932431838`, 1, 0.23790673505113533`], 
     Hue[1.1764218760674858`, 1, 0.38108631720156544`], 
     Hue[1.0559557730086127`, 1, 0.6546423490052103], 
     Hue[1.0089450558329143`, 1, 0.6998867205497596], 
     Hue[1.0013327848482105`, 1, 0.7032729971807228], 
     Hue[1.000197480176621, 1, 0.703681506288683], 
     Hue[1.000029240424804, 1, 0.7037399062405317], 
     Hue[1.000004329125223, 1, 0.7037485066422466], 
     Hue[1.0000006409293731`, 1, 0.7037497789306011], 
     Hue[1.0000000948897383`, 1, 0.7037499672711307], 
     Hue[1.0000000140484426`, 1, 0.7037499951544961], 
     Hue[1.0000000020798743`, 1, 0.7037499992826226], 
     Hue[1.0000000003079257`, 1, 0.7037499998937922], 
     Hue[1.0000000000455884`, 1, 0.7037499999842759], 
     Hue[1.0000000000067495`, 1, 0.7037499999976721], 
     Hue[1.0000000000009992`, 1, 0.7037499999996554], 
     Hue[1.0000000000001479`, 1, 0.703749999999949], 
     Hue[1.000000000000022, 1, 0.7037499999999924], 
     Hue[1.0000000000000033`, 1, 0.7037499999999989], 
     Hue[1.0000000000000004`, 1, 0.7037499999999998], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.5363960709822486, 1, 0.21], 
     Hue[0.5363960709822486, 1, 0.21], 
     Hue[0.5363960709822486, 1, 0.21], 
     Hue[0.5363960709822486, 1, 0.21], 
     Hue[0.5363960709822486, 1, 0.21], 
     Hue[0.5363960709822486, 1, 0.21000000000000002`], 
     Hue[0.5363960709822486, 1, 0.21000000000000021`], 
     Hue[0.5363960709822487, 1, 0.2100000000000015], 
     Hue[0.5363960709822494, 1, 0.21000000000001012`], 
     Hue[0.5363960709822536, 1, 0.21000000000006835`], 
     Hue[0.5363960709822824, 1, 0.21000000000046176`], 
     Hue[0.5363960709824765, 1, 0.21000000000311908`], 
     Hue[0.536396070983788, 1, 0.21000000002106775`], 
     Hue[0.536396070992647, 1, 0.21000000014230152`], 
     Hue[0.536396071052484, 1, 0.21000000096117097`], 
     Hue[0.5363960714566514, 1, 0.21000000649219774`], 
     Hue[0.5363960741865867, 1, 0.21000004385133955`], 
     Hue[0.5363960926258553, 1, 0.2100002961925786], 
     Hue[0.5363962171737701, 1, 0.21000200062976], 
     Hue[0.5363970584504985, 1, 0.2100135134948194], 
     Hue[0.5364027418273403, 1, 0.2100912904598038], 
     Hue[0.5364411757249692, 1, 0.21061725802230455`], 
     Hue[0.5367028787999056, 1, 0.21419865984313397`], 
     Hue[0.5385719709376315, 1, 0.23977624525759672`], 
     Hue[0.5584569716893997, 1, 0.5109374027265038], 
     Hue[0.9779390992928488, 1, 0.9921169795489388], 
     Hue[0.997824100044617, 1, 0.7327048994732172], 
     Hue[0.9996931921823429, 1, 0.7078384334112299], 
     Hue[0.9999548952572793, 1, 0.704351168337323], 
     Hue[0.9999933291549084, 1, 0.7038389133463756], 
     Hue[0.9999990125317503, 1, 0.7037631616714557], 
     Hue[0.9999998538084786, 1, 0.703751948544633], 
     Hue[0.9999999783563933, 1, 0.703750288481419], 
     Hue[0.999999996795662, 1, 0.7037500427097022], 
     Hue[0.9999999995255973, 1, 0.7037500063231782], 
     Hue[0.9999999999297646, 1, 0.7037500009361476], 
     Hue[0.9999999999896017, 1, 0.7037500001385968], 
     Hue[0.9999999999984606, 1, 0.7037500000205194], 
     Hue[0.9999999999997721, 1, 0.7037500000030379], 
     Hue[0.9999999999999662, 1, 0.7037500000004498], 
     Hue[0.999999999999995, 1, 0.7037500000000667], 
     Hue[0.9999999999999992, 1, 0.7037500000000099], 
     Hue[0.9999999999999999, 1, 0.7037500000000015], 
     Hue[1., 1, 0.7037500000000002], 
     Hue[1., 1, 0.7037500000000001], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.8404144928883992, 1, 0.21], 
     Hue[0.8404144928883991, 1, 0.21], 
     Hue[0.8404144928883991, 1, 0.21], 
     Hue[0.8404144928883991, 1, 0.21], 
     Hue[0.8404144928883991, 1, 0.21], 
     Hue[0.8404144928883992, 1, 0.21000000000000002`], 
     Hue[0.8404144928883992, 1, 0.21000000000000021`], 
     Hue[0.8404144928883995, 1, 0.2100000000000015], 
     Hue[0.8404144928884019, 1, 0.21000000000001012`], 
     Hue[0.8404144928884177, 1, 0.21000000000006835`], 
     Hue[0.8404144928885247, 1, 0.21000000000046176`], 
     Hue[0.8404144928892466, 1, 0.21000000000311908`], 
     Hue[0.8404144928941235, 1, 0.21000000002106775`], 
     Hue[0.8404144929270637, 1, 0.21000000014230152`], 
     Hue[0.8404144931495581, 1, 0.21000000096117097`], 
     Hue[0.8404144946523888, 1, 0.21000000649219763`], 
     Hue[0.8404145048032093, 1, 0.21000004385133364`], 
     Hue[0.8404145733665709, 1, 0.21000029619230995`], 
     Hue[0.8404150364745544, 1, 0.21000200061750332`], 
     Hue[0.8404181644771522, 1, 0.21001351293562645`], 
     Hue[0.8404392904125635, 1, 0.2100912649452139], 
     Hue[0.840581891092089, 1, 0.21061609316447627`], 
     Hue[0.8415408089184516, 1, 0.21414526516845003`], 
     Hue[0.8478241841304515, 1, 0.23726081829683066`], 
     Hue[0.8821939787974259, 1, 0.3620055155826972], 
     Hue[0.9582205140909731, 1, 0.6050525712164909], 
     Hue[0.9925903087579476, 1, 0.6885480225639636], 
     Hue[0.9988736839699476, 1, 0.7015073844121977], 
     Hue[0.9998326017963101, 1, 0.7034182540493776], 
     Hue[0.9999752024758356, 1, 0.7037008912861513], 
     Hue[0.9999963284112469, 1, 0.7037427295864425], 
     Hue[0.9999994564138447, 1, 0.7037489236171113], 
     Hue[0.9999999195218283, 1, 0.7037498406413983], 
     Hue[0.9999999880851898, 1, 0.7037499764069336], 
     Hue[0.9999999982360103, 1, 0.7037499965070425], 
     Hue[0.999999999738841, 1, 0.7037499994828671], 
     Hue[0.9999999999613354, 1, 0.7037499999234383], 
     Hue[0.9999999999942757, 1, 0.703749999988665], 
     Hue[0.9999999999991526, 1, 0.7037499999983219], 
     Hue[0.9999999999998745, 1, 0.7037499999997516], 
     Hue[0.9999999999999815, 1, 0.7037499999999631], 
     Hue[0.9999999999999972, 1, 0.7037499999999945], 
     Hue[0.9999999999999996, 1, 0.7037499999999992], 
     Hue[0.9999999999999999, 1, 0.7037499999999999], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.1444329147945496`, 1, 0.21], 
     Hue[1.1444329147945496`, 1, 0.21], 
     Hue[1.1444329147945496`, 1, 0.21], 
     Hue[1.1444329147945496`, 1, 0.21], 
     Hue[1.1444329147945496`, 1, 0.21], 
     Hue[1.1444329147945496`, 1, 0.21000000000000002`], 
     Hue[1.1444329147945496`, 1, 0.21000000000000021`], 
     Hue[1.1444329147945493`, 1, 0.2100000000000015], 
     Hue[1.1444329147945471`, 1, 0.21000000000001012`], 
     Hue[1.1444329147945322`, 1, 0.21000000000006835`], 
     Hue[1.1444329147944323`, 1, 0.21000000000046176`], 
     Hue[1.1444329147937573`, 1, 0.21000000000311908`], 
     Hue[1.1444329147891985`, 1, 0.21000000002106775`], 
     Hue[1.144432914758406, 1, 0.21000000014230152`], 
     Hue[1.1444329145504195`, 1, 0.21000000096117097`], 
     Hue[1.1444329131455813`, 1, 0.2100000064921976], 
     Hue[1.1444329036566478`, 1, 0.21000004385133336`], 
     Hue[1.1444328395639811`, 1, 0.21000029619229615`], 
     Hue[1.1444324066532288`, 1, 0.2100020006168735], 
     Hue[1.1444294826199788`, 1, 0.2100135129068938], 
     Hue[1.1444097345321653`, 1, 0.21009126363470623`], 
     Hue[1.144276446995239, 1, 0.21061603348542643`], 
     Hue[1.1433807245955963`, 1, 0.21414257617990481`], 
     Hue[1.1375353262826324`, 1, 0.23714818101596824`], 
     Hue[1.1061756372199933`, 1, 0.359177401085757], 
     Hue[1.0382572775745564`, 1, 0.5977024832974575], 
     Hue[1.0068975885119171`, 1, 0.6865707397312631], 
     Hue[1.0010521901989535`, 1, 0.7011885489040031], 
     Hue[1.0001564677993107`, 1, 0.7033704581407715], 
     Hue[1.0000231802623845`, 1, 0.7036938020494113], 
     Hue[1.000003432174571, 1, 0.7037416797376235], 
     Hue[1.000000508141321, 1, 0.703748768180544], 
     Hue[1.0000000752305684`, 1, 0.7037498176288509], 
     Hue[1.000000011137902, 1, 0.703749972999919], 
     Hue[1.0000000016489683`, 1, 0.7037499960026335], 
     Hue[1.00000000024413, 1, 0.7037499994081893], 
     Hue[1.0000000000361435`, 1, 0.7037499999123823], 
     Hue[1.000000000005351, 1, 0.7037499999870281], 
     Hue[1.0000000000007923`, 1, 0.7037499999980795], 
     Hue[1.0000000000001172`, 1, 0.7037499999997158], 
     Hue[1.0000000000000173`, 1, 0.7037499999999579], 
     Hue[1.0000000000000027`, 1, 0.7037499999999938], 
     Hue[1.0000000000000004`, 1, 0.7037499999999991], 
     Hue[1., 1, 0.7037499999999999], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1.4484513367007013`, 1, 0.21], 
     Hue[1.4484513367007013`, 1, 0.21], 
     Hue[1.4484513367007013`, 1, 0.21], 
     Hue[1.4484513367007013`, 1, 0.21], 
     Hue[1.4484513367007013`, 1, 0.21], 
     Hue[1.4484513367007013`, 1, 0.21000000000000002`], 
     Hue[1.4484513367007013`, 1, 0.21000000000000021`], 
     Hue[1.448451336700701, 1, 0.2100000000000015], 
     Hue[1.4484513367007001`, 1, 0.21000000000001012`], 
     Hue[1.4484513367006944`, 1, 0.21000000000006835`], 
     Hue[1.448451336700654, 1, 0.21000000000046176`], 
     Hue[1.4484513367003813`, 1, 0.21000000000311908`], 
     Hue[1.44845133669854, 1, 0.21000000002106775`], 
     Hue[1.4484513366861032`, 1, 0.21000000014230152`], 
     Hue[1.4484513366020981`, 1, 0.21000000096117097`], 
     Hue[1.4484513360346893`, 1, 0.21000000649219774`], 
     Hue[1.4484513322021448`, 1, 0.21000004385133944`], 
     Hue[1.4484513063153344`, 1, 0.210000296192574], 
     Hue[1.4484511314630673`, 1, 0.21000200062954955`], 
     Hue[1.448449950399207, 1, 0.21001351348521738`], 
     Hue[1.4484419715745838`, 1, 0.21009129002153368`], 
     Hue[1.4483880164007856`, 1, 0.21061723796572981`], 
     Hue[1.4480207060944459`, 1, 0.2141977255703204], 
     Hue[1.4454015588247007`, 1, 0.23972701555217074`], 
     Hue[1.4181422073592784`, 1, 0.5036668310905273], 
     Hue[1.030309129341423, 1, 0.9732212308782693], 
     Hue[1.0030497778760006`, 1, 0.7318407002431545], 
     Hue[1.0004306306062554`, 1, 0.7077276559414497], 
     Hue[1.0000633202999158`, 1, 0.7043351053769494], 
     Hue[1.0000093651261177`, 1, 0.7038365425089924], 
     Hue[1.0000013863014945`, 1, 0.7037628108279274], 
     Hue[1.000000205237634, 1, 0.7037518966056808], 
     Hue[1.0000000303853671`, 1, 0.7037502807919248], 
     Hue[1.0000000044985566`, 1, 0.703750041571273], 
     Hue[1.000000000666012, 1, 0.7037500061546337], 
     Hue[1.0000000000986031`, 1, 0.7037500009111946], 
     Hue[1.0000000000145983`, 1, 0.7037500001349025], 
     Hue[1.0000000000021612`, 1, 0.7037500000199723], 
     Hue[1.00000000000032, 1, 0.703750000002957], 
     Hue[1.0000000000000473`, 1, 0.7037500000004377], 
     Hue[1.000000000000007, 1, 0.7037500000000648], 
     Hue[1.000000000000001, 1, 0.7037500000000096], 
     Hue[1.0000000000000002`, 1, 0.7037500000000014], 
     Hue[1., 1, 0.7037500000000002], 
     Hue[1., 1, 0.7037500000000001], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[1., 1, 0.70375], 
     Hue[0.5531625976657465, 1, 0.22573215097703814`], 
     Hue[0.8595633441466374, 1, 0.22573212541677937`], 
     Hue[0.5547766748514241, 1, 0.24146407608429782`], 
     Hue[0.5563910067458637, 1, 0.2571952468275457], 
     Hue[0.5580058844632816, 1, 0.27292687823676265`], 
     Hue[0.5596212847893909, 1, 0.2886571189602078], 
     Hue[0.5612378857705536, 1, 0.30439093867300565`], 
     Hue[0.5628552652203427, 1, 0.32012258915824193`], 
     Hue[0.5644738709778321, 1, 0.3358547816277183], 
     Hue[0.5660937947272937, 1, 0.3515867511909315], 
     Hue[0.5677152445694718, 1, 0.3673188523393502], 
     Hue[0.5693383122074895, 1, 0.38305029674110747`], 
     Hue[0.5709631902509084, 1, 0.39878126055131546`], 
     Hue[0.5725900325523692, 1, 0.4145115277291091], 
     Hue[0.574219352516381, 1, 0.4302443342132921], 
     Hue[0.5758510177880461, 1, 0.445976654467778], 
     Hue[0.5774851966278081, 1, 0.461708350029595], 
     Hue[0.5791220709890587, 1, 0.47743939081813214`], 
     Hue[0.5807620082831364, 1, 0.49317149853642095`], 
     Hue[0.8631528899949032, 1, 0.3673161807532376], 
     Hue[0.8186732280853918, 1, 0.3830481130703415], 
     Hue[0.7832911010446961, 1, 0.39878060717494423`], 
     Hue[0.7524501518529099, 1, 0.41451142181944856`], 
     Hue[0.7240180374239289, 1, 0.43024505395921014`], 
     Hue[0.6966590562904462, 1, 0.4459753917898177], 
     Hue[0.6692327694968473, 1, 0.46170712042802586`], 
     Hue[0.6404287840357412, 1, 0.47743942721593713`], 
     Hue[0.6080411994397382, 1, 0.4931707813959906], 
     Hue[0.8635620578025692, 1, 0.24146398499912314`], 
     Hue[0.8675657357059643, 1, 0.2571954734122295], 
     Hue[0.8715768824654407, 1, 0.27292635456423975`], 
     Hue[0.8755988109141953, 1, 0.2886593815436512], 
     Hue[0.8796332553843177, 1, 0.30439089453731294`], 
     Hue[0.8836832186322567, 1, 0.32012190606771107`], 
     Hue[0.8877517573357462, 1, 0.3358532583869755], 
     Hue[0.8918420735190306, 1, 0.35158589637023246`], 
     Hue[0.5824058500431584, 1, 0.5089108885521197], 
     Hue[0.5840520999624484, 1, 0.5246413778980564], 
     Hue[0.5857016575534331, 1, 0.5403697067341252], 
     Hue[0.5873536176983867, 1, 0.5560853764584334], 
     Hue[0.5890112458111992, 1, 0.5718174881225198], 
     Hue[0.5906756719255466, 1, 0.5875746255329627], 
     Hue[0.5923414705649619, 1, 0.6033034110219374], 
     Hue[0.5940106276276278, 1, 0.6190206905971871], 
     Hue[0.5956860732811939, 1, 0.6347519408071247], 
     Hue[0.5973675411909252, 1, 0.6504924087343993], 
     Hue[0.5990508105431445, 1, 0.6662004938355318], 
     Hue[0.6007449350797325, 1, 0.6819583506514004], 
     Hue[0.6024420370934734, 1, 0.6976902853924419], 
     Hue[0.6041430490115769, 1, 0.7134028195344386], 
     Hue[0.6058543654391657, 1, 0.7291525085556494], 
     Hue[0.6075680610886531, 1, 0.7448639460052803], 
     Hue[0.6092913631715038, 1, 0.7606009203215365], 
     Hue[0.6110217059527425, 1, 0.7763372379072342], 
     Hue[0.6127620521038437, 1, 0.7920970028614094], 
     Hue[0.6145042485535002, 1, 0.8078038095007406], 
     Hue[0.6162573544260014, 1, 0.823536659867315], 
     Hue[0.6180193346741625, 1, 0.8392741408820162], 
     Hue[0.6197880495695345, 1, 0.8549942031743055], 
     Hue[0.621567787658502, 1, 0.870731830100644], 
     Hue[0.6233567401396259, 1, 0.8864676692295587], 
     Hue[0.625153009362218, 1, 0.9021818722533816], 
     Hue[0.6269616725398827, 1, 0.9179154119038231], 
     Hue[0.6287812007183673, 1, 0.9336512143109302], 
     Hue[0.6306099893049762, 1, 0.9493717960593197], 
     Hue[0.6324539602345995, 1, 0.9651240416755157], 
     Hue[0.9590106907675658, 1, 0.6032947980968156], 
     Hue[0.9528567843767118, 1, 0.6190241278369851], 
     Hue[0.948282129888421, 1, 0.6347594405901441], 
     Hue[0.9448131654231546, 1, 0.6504866637531719], 
     Hue[0.9421782328213311, 1, 0.666221510315446], 
     Hue[0.9402104621218804, 1, 0.6819520778617205], 
     Hue[0.9387941596794636, 1, 0.6976842166879285], 
     Hue[0.9378480143554684, 1, 0.7134122194054138], 
     Hue[0.93731143055291, 1, 0.7291466230018732], 
     Hue[0.9371398880027492, 1, 0.7448767689770998], 
     Hue[0.9372994059341587, 1, 0.7606130547915442], 
     Hue[0.9377643573078838, 1, 0.7763406939638285], 
     Hue[0.9385164589995886, 1, 0.7920722457784025], 
     Hue[0.9395430717744775, 1, 0.8078048170236186], 
     Hue[0.9408366572291791, 1, 0.8235351122242603], 
     Hue[0.9423956790603852, 1, 0.839269325634045], 
     Hue[0.9442229372107045, 1, 0.8550012080039799], 
     Hue[0.946328392691045, 1, 0.8707342059334644], 
     Hue[0.9487286790178219, 1, 0.8864642681528256], 
     Hue[0.951451587604287, 1, 0.902194701003975], 
     Hue[0.9545394460471937, 1, 0.9179274886014195], 
     Hue[0.9580559922175853, 1, 0.9336586668650163], 
     Hue[0.9621048245140056, 1, 0.9493907119525122], 
     Hue[0.9668632202877504, 1, 0.9651226240666128], 
     Hue[0.8959570526171798, 1, 0.3673190147272106], 
     Hue[0.9000998276806128, 1, 0.38305215548892657`], 
     Hue[0.9042724523209487, 1, 0.3987801157744297], 
     Hue[0.9084803757400153, 1, 0.41450969597956755`], 
     Hue[0.912728547377309, 1, 0.4302446847413152], 
     Hue[0.917018237314592, 1, 0.4459742030136439], 
     Hue[0.9213567018443342, 1, 0.4617081752217437], 
     Hue[0.9257468752383171, 1, 0.4774392460198338], 
     Hue[0.9301947488817466, 1, 0.49316950944470705`], 
     Hue[0.9347071695512186, 1, 0.5089020034309508], 
     Hue[0.9392903262896989, 1, 0.5246351135688676], 
     Hue[0.9439508011160894, 1, 0.5403660333318379], 
     Hue[0.948698079246375, 1, 0.5560986408242706], 
     Hue[0.9535406202240346, 1, 0.571829621868798], 
     Hue[0.9584899071149076, 1, 0.5875611538106223], 
     Hue[0.9955277533136418, 1, 0.7448777829478599], 
     Hue[0.9938047485758259, 1, 0.7606119916348704], 
     Hue[0.9920751803496081, 1, 0.7763412336686986], 
     Hue[0.9903379775424621, 1, 0.7920725788002096], 
     Hue[0.9885930475860569, 1, 0.8078040834841059], 
     Hue[0.9868400247336535, 1, 0.8235361892764299], 
     Hue[0.9850784462714643, 1, 0.8392700926487076], 
     Hue[0.9833084206268616, 1, 0.8550017956056518], 
     Hue[0.9815293533417923, 1, 0.8707334670098001], 
     Hue[0.9797409244100281, 1, 0.8864647045806655], 
     Hue[0.9779426845235722, 1, 0.9021961158201318], 
     Hue[0.9761342122971626, 1, 0.9179279175724309], 
     Hue[0.9743150931009589, 1, 0.9336601194191605], 
     Hue[0.9724850058484841, 1, 0.9493917756970375], 
     Hue[0.9706435115423684, 1, 0.9651228054417973], 
     Hue[0.9912058186043662, 1, 0.6976836669243704], 
     Hue[0.9913798911131959, 1, 0.7134153180554915], 
     Hue[0.9952367418450064, 1, 0.7291471839862073], 
     Hue[0.9635587123970113, 1, 0.6032940368700567], 
     Hue[0.9687598687267679, 1, 0.6190229304165441], 
     Hue[0.9741137376406883, 1, 0.6347572652224333], 
     Hue[0.9796378495131782, 1, 0.6504879496764518], 
     Hue[0.9853591264143271, 1, 0.6662205025145573], 
     Hue[0.9913073252665899, 1, 0.6819517548183189], 
     Hue[0.9989529293116501, 1, 0.7134152512110717], 
     Hue[0.9972435879261903, 1, 0.7291467511351064], 
     Hue[0.9975220977044679, 1, 0.697683565132366], 
     Hue[1.1553105572376363`, 1, 0.22573165741825427`], 
     Hue[1.1510323144656638`, 1, 0.24146406721836128`], 
     Hue[1.1467482550756432`, 1, 0.25719508078392594`], 
     Hue[1.1424547351121355`, 1, 0.27292651839121673`], 
     Hue[1.1381482592987648`, 1, 0.2886594146807236], 
     Hue[1.1338265087922714`, 1, 0.30439020630760294`], 
     Hue[1.1294853872566202`, 1, 0.32012142556310796`], 
     Hue[1.1251211767524538`, 1, 0.3358537148105041], 
     Hue[1.12073067691521, 1, 0.3515852664716431], 
     Hue[1.040987584900557, 1, 0.6032910350210424], 
     Hue[1.1163095620599384`, 1, 0.3673176166589594], 
     Hue[1.1118542319188855`, 1, 0.3830488890609538], 
     Hue[1.1073596429740766`, 1, 0.398781345811419], 
     Hue[1.1028219087992803`, 1, 0.4145120629269272], 
     Hue[1.0982355060079858`, 1, 0.43024252996679124`], 
     Hue[1.0935945227027088`, 1, 0.4459739838625505], 
     Hue[1.088891779361473, 1, 0.4617100639252585], 
     Hue[1.0841239639164428`, 1, 0.47743948762173805`], 
     Hue[1.0792815102830937`, 1, 0.49316942045189716`], 
     Hue[1.0743555090970671`, 1, 0.5089017145470709], 
     Hue[1.0693374040317842`, 1, 0.5246336738424863], 
     Hue[1.0642163821132915`, 1, 0.5403657276103625], 
     Hue[1.0589798146097786`, 1, 0.5560989535365023], 
     Hue[1.0536145303457158`, 1, 0.5718301993533257], 
     Hue[1.0481032173649134`, 1, 0.5875613457753045], 
     Hue[1.0424257442374094`, 1, 0.6032931931771582], 
     Hue[1.036559059064327, 1, 0.6190233839734524], 
     Hue[1.0304725134016135`, 1, 0.6347554726840253], 
     Hue[1.0241298795580902`, 1, 0.6504882595792842], 
     Hue[1.0174850706443983`, 1, 0.6662199133209705], 
     Hue[1.010475961880576, 1, 0.6819518188484712], 
     Hue[1.0030189704221346`, 1, 0.6976835296672571], 
     Hue[1.462454383405611, 1, 0.22573138539891288`], 
     Hue[1.1368485135109887`, 1, 0.3673166035995372], 
     Hue[1.1813272717663836`, 1, 0.38304831580822774`], 
     Hue[1.2167069158806862`, 1, 0.3987796515669192], 
     Hue[1.247549671748641, 1, 0.41451132734178825`], 
     Hue[1.2759817769563337`, 1, 0.43024494854476064`], 
     Hue[1.3033435969978693`, 1, 0.445976926130782], 
     Hue[1.3307690746766345`, 1, 0.4617081618783714], 
     Hue[1.3595721421015008`, 1, 0.47743991150072673`], 
     Hue[1.3919589253661862`, 1, 0.4931708366816989], 
     Hue[1.4342458768091635`, 1, 0.508902928171312], 
     Hue[1.4613047701494133`, 1, 0.24146287572322106`], 
     Hue[1.460154966983574, 1, 0.2571953227777727], 
     Hue[1.4590050426326182`, 1, 0.2729269643339153], 
     Hue[1.457854833359443, 1, 0.2886592175214403], 
     Hue[1.4567044972184349`, 1, 0.3043890969721298], 
     Hue[1.4555535772553274`, 1, 0.32012202487135155`], 
     Hue[1.4544022781271446`, 1, 0.3358543743008151], 
     Hue[1.4532504959636579`, 1, 0.35158673437449806`], 
     Hue[1.4520983206242284`, 1, 0.3673170458346014], 
     Hue[1.4509454213905948`, 1, 0.38304898784283514`], 
     Hue[1.4497918971585444`, 1, 0.3987803702659097], 
     Hue[1.4486376534848144`, 1, 0.41451163802427204`], 
     Hue[1.447482515114754, 1, 0.43024433044057464`], 
     Hue[1.4463266824924865`, 1, 0.4459748658295116], 
     Hue[1.4451697408842104`, 1, 0.4617080304703588], 
     Hue[1.444011967022608, 1, 0.4774391975082427], 
     Hue[1.442853130096361, 1, 0.49317063669693195`], 
     Hue[1.4416931290727995`, 1, 0.508902843408386], 
     Hue[1.047142766963779, 1, 0.6190227852890988], 
     Hue[1.0517167003289065`, 1, 0.6347547995685805], 
     Hue[1.0551873076736136`, 1, 0.6504891299293036], 
     Hue[1.057821521988632, 1, 0.6662198173781875], 
     Hue[1.0597898764724147`, 1, 0.681955255752121], 
     Hue[1.0612057310013219`, 1, 0.697682746505322], 
     Hue[1.0621520268859246`, 1, 0.7134131046828384], 
     Hue[1.0626886360457495`, 1, 0.72914963803235], 
     Hue[1.0628601119834435`, 1, 0.744876588062146], 
     Hue[1.0627005774770442`, 1, 0.7606138808040023], 
     Hue[1.0622356519130784`, 1, 0.7763404566021029], 
     Hue[1.0614833191504889`, 1, 0.7920761627603621], 
     Hue[1.060456848594697, 1, 0.8078058960961907], 
     Hue[1.0591633136040044`, 1, 0.8235354339643366], 
     Hue[1.0576043764821428`, 1, 0.8392688092055125], 
     Hue[1.0557770889946474`, 1, 0.8550009981067901], 
     Hue[1.0536717436656367`, 1, 0.8707332522511437], 
     Hue[1.0512715977530904`, 1, 0.8864625648341559], 
     Hue[1.0485483201763899`, 1, 0.902195201809062], 
     Hue[1.0454607569827923`, 1, 0.9179265174598791], 
     Hue[1.041944037686065, 1, 0.9336585417839297], 
     Hue[1.037895108533064, 1, 0.9493909532710776], 
     Hue[1.03313654372191, 1, 0.9651233372057187], 
     Hue[1.027319205910602, 1, 0.980854787903392], 
     Hue[1.4405329739190993`, 1, 0.5246212589452323], 
     Hue[1.439368578187319, 1, 0.5403803175981114], 
     Hue[1.4382049832501766`, 1, 0.5561108729389963], 
     Hue[1.437040083945077, 1, 0.5718405302904128], 
     Hue[1.4358733371706969`, 1, 0.587575703096016], 
     Hue[1.4347062933206707`, 1, 0.603294583007994], 
     Hue[1.433537447493475, 1, 0.619016537194177], 
     Hue[1.4323645866053938`, 1, 0.6347703221484172], 
     Hue[1.4311940316469633`, 1, 0.6504701348263334], 
     Hue[1.430016721677747, 1, 0.6662365129541592], 
     Hue[1.4288418502971718`, 1, 0.6819453470556203], 
     Hue[1.4276624565802551`, 1, 0.6976887805236519], 
     Hue[1.42648100896412, 1, 0.7134327800155176], 
     Hue[1.4253001261096863`, 1, 0.729141532118545], 
     Hue[1.424114866597446, 1, 0.7448797651058774], 
     Hue[1.4229273449849877`, 1, 0.7606182846503526], 
     Hue[1.4217397984347018`, 1, 0.7763264794308724], 
     Hue[1.4205460774601368`, 1, 0.7920845680149263], 
     Hue[1.4193522262253269`, 1, 0.8078116254131819], 
     Hue[1.4181558840777693`, 1, 0.8235377531858652], 
     Hue[1.416954236894053, 1, 0.8392987178602515], 
     Hue[1.4157536154861021`, 1, 0.8550104014353436], 
     Hue[1.4145511046392532`, 1, 0.8707100176417524], 
     Hue[1.4133433051094975`, 1, 0.8864407129552062], 
     Hue[1.412131555006999, 1, 0.9021837129783448], 
     Hue[1.4109172630883424`, 1, 0.9179194850954614], 
     Hue[1.4097019075125554`, 1, 0.9336277779245469], 
     Hue[1.408481354388638, 1, 0.9493607791132567], 
     Hue[1.407256765036749, 1, 0.9651021067722039], 
     Hue[1.4060293586061876`, 1, 0.9808347873405603], 
     Hue[1.0087942058363375`, 1, 0.6976839630983598], 
     Hue[1.008620167097673, 1, 0.7134147559461698], 
     Hue[1.0047632430747566`, 1, 0.7291472143527621], 
     Hue[1.0030929823673218`, 1, 0.7448796447743524], 
     Hue[1.0042798832255695`, 1, 0.7606099454709568], 
     Hue[1.0054693160223849`, 1, 0.7763430821227159], 
     Hue[1.006661073426407, 1, 0.7920752426788942], 
     Hue[1.007855064551106, 1, 0.8078041606108659], 
     Hue[1.009051903244472, 1, 0.8235368246633737], 
     Hue[1.0102513458396374`, 1, 0.8392689083133965], 
     Hue[1.011453519126336, 1, 0.8550009454712225], 
     Hue[1.0126584637758644`, 1, 0.870732321188564], 
     Hue[1.013866426948157, 1, 0.886465090672141], 
     Hue[1.0150773198712548`, 1, 0.9021969070295431], 
     Hue[1.0162912875684615`, 1, 0.9179284489675904], 
     Hue[1.0175084152770504`, 1, 0.9336595919450296], 
     Hue[1.0187289154091237`, 1, 0.9493918241282673], 
     Hue[1.0199527056771929`, 1, 0.9651228074715554], 
     Hue[1.0211800644878615`, 1, 0.9808548189195179], 
     Hue[1.000725545528221, 1, 0.7134154240957249], 
     Hue[1.0019081476444316`, 1, 0.729147057254172], 
     Hue[0.7726630029179348, 1, 0.2257314497928806], 
     Hue[0.8186723762676704, 1, 0.3830484585645543], 
     Hue[0.7832934044371742, 1, 0.3987794972122281], 
     Hue[0.7524490235593977, 1, 0.4145120261259023], 
     Hue[0.7240199193067367, 1, 0.43024398522905916`], 
     Hue[0.6966547308279047, 1, 0.4459778931139048], 
     Hue[0.6692298928500168, 1, 0.4617087449401678], 
     Hue[0.6404267966224045, 1, 0.4774404664486863], 
     Hue[0.6080416072315632, 1, 0.4931706007547244], 
     Hue[0.5657565660663127, 1, 0.5089022107982438], 
     Hue[0.777708619907745, 1, 0.24146258791732886`], 
     Hue[0.782764551098174, 1, 0.2571941567988042], 
     Hue[0.7878365947407202, 1, 0.2729279922293072], 
     Hue[0.7929287261120648, 1, 0.28865983520318444`], 
     Hue[0.7980465584542296, 1, 0.3043899273949874], 
     Hue[0.8031970701497173, 1, 0.3201218974990948], 
     Hue[0.8083856916334841, 1, 0.3358536302746912], 
     Hue[0.8136190307067387, 1, 0.3515854138274121], 
     Hue[0.8189041954055865, 1, 0.36731757856017433`], 
     Hue[0.942178065785581, 1, 0.6662226636595316], 
     Hue[0.9402107398191051, 1, 0.6819494716801551], 
     Hue[0.9387941259276519, 1, 0.6976846706112514], 
     Hue[0.9378480793073725, 1, 0.7134108252204159], 
     Hue[0.9373113264862714, 1, 0.7291513345353], 
     Hue[0.9371398876938318, 1, 0.7448809782212039], 
     Hue[0.9372992604160472, 1, 0.7606058071557777], 
     Hue[0.9377642679532843, 1, 0.7763383937685138], 
     Hue[0.9385164654608149, 1, 0.7920723598620465], 
     Hue[0.9395433162911679, 1, 0.8078081304006621], 
     Hue[0.9408369581494707, 1, 0.8235384316268449], 
     Hue[0.9423960130195689, 1, 0.839272430694506], 
     Hue[0.944222736219847, 1, 0.8549995981159936], 
     Hue[0.9463287706734222, 1, 0.8707368495128753], 
     Hue[0.9487280452426261, 1, 0.88646036770464], 
     Hue[0.9514523883718026, 1, 0.9021990495753137], 
     Hue[0.9545389106465547, 1, 0.9179249276338781], 
     Hue[0.958055596860404, 1, 0.9336570131524493], 
     Hue[0.9621055304038577, 1, 0.9493932561628082], 
     Hue[0.9668627380493602, 1, 0.9651211667708449], 
     Hue[0.9726811409013711, 1, 0.9808556200748656], 
     Hue[0.8242473385439191, 1, 0.3830459309936592], 
     Hue[0.829661488531418, 1, 0.3987843011317772], 
     Hue[0.8351483537612217, 1, 0.4145110979895794], 
     Hue[0.8407240419624382, 1, 0.43024340669423045`], 
     Hue[0.8463966863120104, 1, 0.44597180099897893`], 
     Hue[0.8521844549616916, 1, 0.46171033355706015`], 
     Hue[0.8580961976645021, 1, 0.4774422243366594], 
     Hue[0.8641503951215951, 1, 0.4931706317542951], 
     Hue[0.8703698041721801, 1, 0.508901411111555], 
     Hue[0.8767784923210018, 1, 0.5246332558270264], 
     Hue[0.8834058461801718, 1, 0.5403650865925307], 
     Hue[0.8902900838425548, 1, 0.5560998483728944], 
     Hue[0.8974736438565227, 1, 0.5718280207200811], 
     Hue[0.9050219392783609, 1, 0.5875601254413031], 
     Hue[0.9130145946293136, 1, 0.6032920793456621], 
     Hue[0.9215657883884045, 1, 0.6190243941541023], 
     Hue[0.9308432230476016, 1, 0.6347563421751976], 
     Hue[0.9411143507625621, 1, 0.6504882667814286], 
     Hue[0.9913798523675704, 1, 0.7134149439152638], 
     Hue[0.9952367332569806, 1, 0.729147166692736], 
     Hue[0.9528541908688627, 1, 0.666220265752443], 
     Hue[0.9670802210098206, 1, 0.681951797481528], 
     Hue[0.9870984325447092, 1, 0.6976835662460891], 
     Hue[1.0694344318288729`, 1, 0.2257315666718128], 
     Hue[0.9353329649507757, 1, 0.3515855109761129], 
     Hue[0.8631483289589361, 1, 0.3673175549127835], 
     Hue[1.0672276564586032`, 1, 0.2414632061519939], 
     Hue[1.0650200527205642`, 1, 0.2571946982688814], 
     Hue[1.0628112058488992`, 1, 0.2729259607274967], 
     Hue[1.0606004170383874`, 1, 0.28865891635707064`], 
     Hue[1.0583877727655824`, 1, 0.3043898789940413], 
     Hue[1.0561724690797754`, 1, 0.32012147159261134`], 
     Hue[1.0539540611062652`, 1, 0.33585372752537623`], 
     Hue[0.9677986769433771, 1, 0.58756205910285], 
     Hue[0.9590113397357174, 1, 0.6032933817920996], 
     Hue[0.9528563074506866, 1, 0.6190255550051463], 
     Hue[0.9482827400740453, 1, 0.6347570196793683], 
     Hue[0.9448128581008668, 1, 0.6504882657619596], 
     Hue[1.0517320540062634`, 1, 0.35158699486525136`], 
     Hue[1.0495063874043447`, 1, 0.3673185066575807], 
     Hue[1.0472761061683196`, 1, 0.3830517731445917], 
     Hue[1.0450413007266264`, 1, 0.39878286764351256`], 
     Hue[1.0428010214741807`, 1, 0.41451513206289037`], 
     Hue[1.0405556975888128`, 1, 0.4302421616831746], 
     Hue[1.038302869191213, 1, 0.44597769802874654`], 
     Hue[1.0360440356105587`, 1, 0.4617077070644452], 
     Hue[1.0337778792124475`, 1, 0.4774377592007786], 
     Hue[1.03150335292024, 1, 0.4931713850986602], 
     Hue[1.0292208606980786`, 1, 0.5089019718901595], 
     Hue[1.0269290407286842`, 1, 0.5246349871483811], 
     Hue[1.0246278290762045`, 1, 0.5403668279728167], 
     Hue[1.0223164918735204`, 1, 0.5560983634513803], 
     Hue[1.019994408075734, 1, 0.5718295354035726], 
     Hue[0.9948115087750939, 1, 0.6819515376191922], 
     Hue[0.9912058233801287, 1, 0.6976836090529968], 
     Hue[1.0176610734862364`, 1, 0.5875593393135341], 
     Hue[1.0153147858638085`, 1, 0.6032946302614824], 
     Hue[1.0129566490879685`, 1, 0.6190232590885965], 
     Hue[1.01058428140828, 1, 0.6347561937203038], 
     Hue[1.0081975939418106`, 1, 0.6504888555829836], 
     Hue[1.0057959890802708`, 1, 0.6662198572267815], 
     Hue[1.0033782722566045`, 1, 0.6819514605113698], 
     Hue[1.0009435797197233`, 1, 0.6976834551878905], 
     Hue[1.3720879966322184`, 1, 0.225732064682602], 
     Hue[1.0646691300620132`, 1, 0.35158579773996806`], 
     Hue[1.136848092513763, 1, 0.36731647676159185`], 
     Hue[1.1813273188008995`, 1, 0.38304833488526907`], 
     Hue[1.2167086116300132`, 1, 0.39878046871756745`], 
     Hue[1.2475516308133654`, 1, 0.4145123766044282], 
     Hue[1.2759813055465248`, 1, 0.43024468082870904`], 
     Hue[1.303342432671212, 1, 0.44597625282514014`], 
     Hue[1.3685151433480562`, 1, 0.24146349359060554`], 
     Hue[1.3649389288950462`, 1, 0.2571938415442809], 
     Hue[1.3613569992618848`, 1, 0.2729254396735556], 
     Hue[1.3577672035961248`, 1, 0.2886596025458853], 
     Hue[1.3541691687470143`, 1, 0.30438971806356363`], 
     Hue[1.3505595087167932`, 1, 0.32012217574202056`], 
     Hue[1.346937143713602, 1, 0.3358530549639116], 
     Hue[1.3432990913930178`, 1, 0.3515864325215464], 
     Hue[1.3396443528002973`, 1, 0.3673174727423712], 
     Hue[1.3359700842189133`, 1, 0.38304894203568013`], 
     Hue[1.3322738162365253`, 1, 0.39878153000253014`], 
     Hue[1.3285538713340554`, 1, 0.41451207799260503`], 
     Hue[1.3248069559005935`, 1, 0.43024371730937405`], 
     Hue[1.3210304001724045`, 1, 0.44597626279281627`], 
     Hue[1.0322020367084757`, 1, 0.5875630959189976], 
     Hue[1.040988342502912, 1, 0.6032926883274313], 
     Hue[1.0471429452731846`, 1, 0.6190233188498608], 
     Hue[1.0517175561117957`, 1, 0.6347581947835905], 
     Hue[1.0551867855716064`, 1, 0.6504864083029323], 
     Hue[1.0578217373655718`, 1, 0.6662213044653349], 
     Hue[1.0597894418793612`, 1, 0.6819511768997608], 
     Hue[1.061205875802242, 1, 0.697684693876491], 
     Hue[1.062152190731311, 1, 0.7134166220213526], 
     Hue[1.0626886041071644`, 1, 0.7291481920447151], 
     Hue[1.0628601120697312`, 1, 0.7448777282312861], 
     Hue[1.0627006556090413`, 1, 0.7606099899810185], 
     Hue[1.0622356141883378`, 1, 0.7763414276842305], 
     Hue[1.061483449046759, 1, 0.7920738693483678], 
     Hue[1.0604568079889278`, 1, 0.8078064463360006], 
     Hue[1.0591631632322434`, 1, 0.8235370927006198], 
     Hue[1.0576043416633223`, 1, 0.8392691329475249], 
     Hue[1.3172219344586522`, 1, 0.4617071649592961], 
     Hue[1.3133757031208937`, 1, 0.47744775407485485`], 
     Hue[1.3094927846829871`, 1, 0.4931800245985357], 
     Hue[1.305569820662184, 1, 0.5089033519143358], 
     Hue[1.3016009453456177`, 1, 0.5246258626807011], 
     Hue[1.2975778986811979`, 1, 0.5403632579236697], 
     Hue[1.293501074489837, 1, 0.5560956484283929], 
     Hue[1.2893644328673166`, 1, 0.5718267215505198], 
     Hue[1.2851605802726456`, 1, 0.5875629241133988], 
     Hue[1.2808868181112187`, 1, 0.6032907474828584], 
     Hue[1.2765339544461511`, 1, 0.6190181039085424], 
     Hue[1.2720919739843173`, 1, 0.634751975679395], 
     Hue[1.2675502938442218`, 1, 0.6504968352875171], 
     Hue[1.2629107043406895`, 1, 0.6662106673660915], 
     Hue[1.2581436687234782`, 1, 0.681952240156652], 
     Hue[1.2532449964872645`, 1, 0.6976872972148417], 
     Hue[1.2481985730760292`, 1, 0.7134137018737227], 
     Hue[1.2429763041716213`, 1, 0.729155078378985], 
     Hue[1.2375649414012233`, 1, 0.7448766012423665], 
     Hue[1.2319211394247525`, 1, 0.7606144699915287], 
     Hue[1.2260122586999425`, 1, 0.7763493393634655], 
     Hue[1.2197922159044938`, 1, 0.7920691165851544], 
     Hue[1.2131790879642321`, 1, 0.8078068314720354], 
     Hue[1.2060876723102691`, 1, 0.8235354330500785], 
     Hue[1.1983703352870205`, 1, 0.8392675002406184], 
     Hue[1.0051886182366083`, 1, 0.6819518003899551], 
     Hue[1.0087941446274207`, 1, 0.6976832213909533], 
     Hue[1.0086200762721558`, 1, 0.7134156329798078], 
     Hue[1.008339398836489, 1, 0.7291471228808487], 
     Hue[1.0137540433885408`, 1, 0.7448782971196152], 
     Hue[1.019396105517417, 1, 0.7606113479737013], 
     Hue[1.0253035109333943`, 1, 0.7763425343439496], 
     Hue[1.0315280426113993`, 1, 0.7920737077506259], 
     Hue[1.0381386120441147`, 1, 0.8078052440402745], 
     Hue[1.0452319028509558`, 1, 0.8235379618885212], 
     Hue[1.0529488147315114`, 1, 0.8392689783221837], 
     Hue[1.0031203016346748`, 1, 0.7134151899606106], 
     Hue[0.6842621876192545, 1, 0.2257316793266786], 
     Hue[0.7240243948598629, 1, 0.4302414435523261], 
     Hue[0.6966589937229659, 1, 0.4459754279712822], 
     Hue[0.6888505313347189, 1, 0.24146323212384582`], 
     Hue[0.6934465584234724, 1, 0.2571949066537327], 
     Hue[0.6980538532943386, 1, 0.27292563984236146`], 
     Hue[0.7026769774730202, 1, 0.28865740306229754`], 
     Hue[0.7073203858942387, 1, 0.30439136834696573`], 
     Hue[0.7119864499318405, 1, 0.320121149712357], 
     Hue[0.7166818088951512, 1, 0.3358541199918976], 
     Hue[0.7214097940248854, 1, 0.3515857061786528], 
     Hue[0.7261758672092691, 1, 0.36731753334280076`], 
     Hue[0.7309854031049456, 1, 0.383049776175371], 
     Hue[0.735843747771427, 1, 0.3987811954264439], 
     Hue[0.7407572570783715, 1, 0.4145122775296606], 
     Hue[0.937299428662636, 1, 0.7606141865088848], 
     Hue[0.9377646371722685, 1, 0.776347897303972], 
     Hue[0.9385166512535329, 1, 0.7920756402311444], 
     Hue[0.9395432566746177, 1, 0.807807322568302], 
     Hue[0.9408368498184996, 1, 0.8235372366605684], 
     Hue[0.9423955976256293, 1, 0.8392685684614065], 
     Hue[0.7457322170905005, 1, 0.4302414580125071], 
     Hue[0.7507779699049819, 1, 0.4459745931392674], 
     Hue[0.755903677159198, 1, 0.461714122933796], 
     Hue[0.7611114905398721, 1, 0.4774383238188784], 
     Hue[0.7664190899141763, 1, 0.4931690999094652], 
     Hue[0.7718365471404971, 1, 0.5089006164396626], 
     Hue[0.7773787634426897, 1, 0.524635932644339], 
     Hue[0.783059840347166, 1, 0.5403693814975385], 
     Hue[0.7888965684430213, 1, 0.5560953598452824], 
     Hue[0.7949164552137836, 1, 0.5718270410589911], 
     Hue[0.8011461044094581, 1, 0.587561665959223], 
     Hue[0.8076177419065085, 1, 0.6032946495037226], 
     Hue[0.8143741242683636, 1, 0.6190257321314535], 
     Hue[0.8214706388545613, 1, 0.6347546620287511], 
     Hue[0.8289858416554292, 1, 0.6504904122004492], 
     Hue[0.8370186016576013, 1, 0.6662232695716513], 
     Hue[0.8457181681891817, 1, 0.6819503492936071], 
     Hue[0.8553285905544156, 1, 0.6976834154039385], 
     Hue[0.8662598166400657, 1, 0.7134149095303677], 
     Hue[0.8793707409297522, 1, 0.7291464962156196], 
     Hue[0.897208026720813, 1, 0.7448786664646305], 
     Hue[0.9799843390344377, 1, 0.7291466597794402], 
     Hue[0.9621468514471128, 1, 0.7448789133783094], 
     Hue[0.9930950128507149, 1, 0.7134154472204199], 
     Hue[0.9842146107275936, 1, 0.2257319395704006], 
     Hue[0.9353333598684047, 1, 0.35158545692114085`], 
     Hue[0.863149235590196, 1, 0.36731728175689715`], 
     Hue[0.818669941472107, 1, 0.3830494461180539], 
     Hue[0.7832896696252987, 1, 0.39878129695506714`], 
     Hue[0.7524483717427928, 1, 0.41451237523536244`], 
     Hue[0.9847331562445001, 1, 0.24146290328840372`], 
     Hue[0.9852517661769129, 1, 0.25719548710283174`], 
     Hue[0.9857703725215541, 1, 0.27292746096426096`], 
     Hue[0.9862889880281888, 1, 0.2886590445850599], 
     Hue[0.9868076228678473, 1, 0.30439037938492286`], 
     Hue[0.987326299806246, 1, 0.32012198867617664`], 
     Hue[0.9878450316265874, 1, 0.33585409278695944`], 
     Hue[0.9832378408353697, 1, 0.5718296079167685], 
     Hue[0.9677991804203423, 1, 0.5875613276559355], 
     Hue[0.9590113745641654, 1, 0.6032933057839237], 
     Hue[0.9528564068749272, 1, 0.6190252574818447], 
     Hue[0.948282763246552, 1, 0.6347569277444891], 
     Hue[0.9448126917856638, 1, 0.6504891327480621], 
     Hue[0.9421785090536519, 1, 0.666219603047646], 
     Hue[0.9402105233656705, 1, 0.6819515030781151], 
     Hue[0.938794223894033, 1, 0.6976833530897775], 
     Hue[0.9378478934228979, 1, 0.7134148153924224], 
     Hue[0.9373114339556974, 1, 0.7291464689683632], 
     Hue[0.9371398878557691, 1, 0.7448787316049604], 
     Hue[0.9883638034902127, 1, 0.3515860742300443], 
     Hue[0.9888826728208459, 1, 0.3673195066739361], 
     Hue[0.9894014729643453, 1, 0.3830491694471493], 
     Hue[0.989920438884842, 1, 0.3987820187884848], 
     Hue[0.9904393995131981, 1, 0.4145127004934006], 
     Hue[0.990958441745928, 1, 0.4302436808149558], 
     Hue[0.9914776040899285, 1, 0.44597595816922064`], 
     Hue[0.9919968467603156, 1, 0.46170815815468425`], 
     Hue[0.9925161264435236, 1, 0.4774388001251296], 
     Hue[0.9930356016892217, 1, 0.49317251768599213`], 
     Hue[0.9935550578637258, 1, 0.5089026410362882], 
     Hue[0.9940746524947811, 1, 0.5246337717251973], 
     Hue[0.9945944174799041, 1, 0.5403667048813083], 
     Hue[0.995114247722631, 1, 0.5560980892076032], 
     Hue[0.9948115327174478, 1, 0.6819514880866502], 
     Hue[0.9912057930681278, 1, 0.6976839763744437], 
     Hue[0.9913799148783159, 1, 0.7134155475306977], 
     Hue[0.9956342702707485, 1, 0.5718315989444457], 
     Hue[0.9961543288425683, 1, 0.5875623353180061], 
     Hue[0.9966745572539545, 1, 0.6032941756381511], 
     Hue[0.9971949059008064, 1, 0.6190254483531115], 
     Hue[0.9977153936647469, 1, 0.6347565529269928], 
     Hue[0.9982360402868533, 1, 0.6504879139298623], 
     Hue[0.9987568709027017, 1, 0.6662201179028229], 
     Hue[0.9992778335757224, 1, 0.6819514232207925], 
     Hue[0.9997989887895848, 1, 0.6976834830633654], 
     Hue[1.282784288560904, 1, 0.22573218253896685`], 
     Hue[1.0646695249802556`, 1, 0.3515858517971663], 
     Hue[1.1368527963899384`, 1, 0.3673178939680618], 
     Hue[1.1813281167337986`, 1, 0.3830486585249401], 
     Hue[1.2167094349909866`, 1, 0.39878086548224406`], 
     Hue[1.2778498467603459`, 1, 0.24146287120354476`], 
     Hue[1.272905017565201, 1, 0.25719632681538496`], 
     Hue[1.2679462913186772`, 1, 0.27292823862777715`], 
     Hue[1.2629685128271597`, 1, 0.2886591413424329], 
     Hue[1.2579657903310546`, 1, 0.30439132898103455`], 
     Hue[1.2529338572857442`, 1, 0.32012127272964896`], 
     Hue[1.2478652551999847`, 1, 0.335854531428844], 
     Hue[1.2427557996504845`, 1, 0.3515853768841566], 
     Hue[1.237597958561921, 1, 0.36731714793850934`], 
     Hue[1.2323851550309755`, 1, 0.383048639965308], 
     Hue[1.227109595630475, 1, 0.39878046336679174`], 
     Hue[1.0167632214740656`, 1, 0.571830293876135], 
     Hue[1.032200159601637, 1, 0.5875603688712994], 
     Hue[1.0409887252882313`, 1, 0.6032935236980378], 
     Hue[1.0471438353669777`, 1, 0.6190259823845262], 
     Hue[1.0517172008684035`, 1, 0.6347567853740272], 
     Hue[1.0551872662236534`, 1, 0.6504889138531955], 
     Hue[1.057821605699659, 1, 0.6662203953627529], 
     Hue[1.0597894541622526`, 1, 0.6819512921754958], 
     Hue[1.0612058190047815`, 1, 0.6976839300180679], 
     Hue[1.2217629703064323`, 1, 0.4145125161985462], 
     Hue[1.216335636915165, 1, 0.4302459243913806], 
     Hue[1.2108171924136977`, 1, 0.44598077445113327`], 
     Hue[1.2052010272718843`, 1, 0.4617028863100935], 
     Hue[1.1994638627276477`, 1, 0.47743999686141514`], 
     Hue[1.1935996429201667`, 1, 0.49316635674544707`], 
     Hue[1.1875813277733753`, 1, 0.5089060962762377], 
     Hue[1.1813956205157563`, 1, 0.524638050746382], 
     Hue[1.175014015808284, 1, 0.5403699358243832], 
     Hue[1.1684057168702964`, 1, 0.5561006423175227], 
     Hue[1.1615328713260447`, 1, 0.5718278180529798], 
     Hue[1.1543430026764643`, 1, 0.5875579443991324], 
     Hue[1.1467695492052845`, 1, 0.6032935510963341], 
     Hue[1.1387281151435251`, 1, 0.6190261036694696], 
     Hue[1.1300926062043526`, 1, 0.6347573810451116], 
     Hue[1.1206742731696617`, 1, 0.6504879236590148], 
     Hue[1.1101639851937797`, 1, 0.6662192723173085], 
     Hue[1.0979894914164825`, 1, 0.6819512861400264], 
     Hue[1.0828187241545526`, 1, 0.6976832288709504], 
     Hue[1.0051886421786391`, 1, 0.6819518499240035], 
     Hue[1.0087941604927522`, 1, 0.6976834136329291], 
     Hue[0.5944965557147753, 1, 0.2257313137231234], 
     Hue[1.2475513176048938`, 1, 0.4145122088515803], 
     Hue[1.2759795333483441`, 1, 0.4302436743898067], 
     Hue[1.3033425963140053`, 1, 0.4459763474563325], 
     Hue[1.3307720588407486`, 1, 0.4617098471027037], 
     Hue[1.359569464717562, 1, 0.477438511470066], 
     Hue[0.5972610410819134, 1, 0.24146250363973104`], 
     Hue[0.6000275710573149, 1, 0.25719582432788546`], 
     Hue[0.6027960993197661, 1, 0.27292623260353593`], 
     Hue[0.6055684768157643, 1, 0.28865942927016874`], 
     Hue[0.6083447412436152, 1, 0.3043907644064994], 
     Hue[0.6111263428115614, 1, 0.3201235347736318], 
     Hue[0.6139135048037729, 1, 0.3358540137197734], 
     Hue[0.6167075914148834, 1, 0.3515848307962811], 
     Hue[0.6195099555079749, 1, 0.36731841551205957`], 
     Hue[0.622320686564509, 1, 0.3830499794254394], 
     Hue[0.6251410836145004, 1, 0.39878138843821387`], 
     Hue[0.6279720444040061, 1, 0.4145120967474273], 
     Hue[0.6308148320773272, 1, 0.4302434055522356], 
     Hue[0.6336706049546896, 1, 0.4459758163984294], 
     Hue[0.6365402504225605, 1, 0.4617081147880029], 
     Hue[0.6394247469424333, 1, 0.47743935819158745`], 
     Hue[1.0621521147819644`, 1, 0.7134149915299353], 
     Hue[1.0626885990044708`, 1, 0.7291479610382449], 
     Hue[1.0628601123809724`, 1, 0.7448820488905381], 
     Hue[1.0627006301070467`, 1, 0.7606112600333745], 
     Hue[1.062235691248539, 1, 0.776339444028089], 
     Hue[1.061483333286323, 1, 0.7920759131870422], 
     Hue[1.0604568786971142`, 1, 0.8078054881821259], 
     Hue[1.0591633086211907`, 1, 0.8235354889297904], 
     Hue[1.0576046969766704`, 1, 0.8392658292289595], 
     Hue[1.0557776669407757`, 1, 0.8549963688271067], 
     Hue[1.0536719131454664`, 1, 0.8707320668940801], 
     Hue[1.0512718114059734`, 1, 0.8864612499440501], 
     Hue[1.048547525201844, 1, 0.9021995189049897], 
     Hue[0.6423236417025908, 1, 0.49316061393307487`], 
     Hue[0.6452419358530327, 1, 0.5088921805838965], 
     Hue[0.6481817623006801, 1, 0.5246382033878486], 
     Hue[0.6511366027472261, 1, 0.5403564597801763], 
     Hue[0.654119971907918, 1, 0.556110935467231], 
     Hue[0.6571181040841056, 1, 0.5718208458994323], 
     Hue[0.6601479505700014, 1, 0.5875664786661989], 
     Hue[0.6632024285281481, 1, 0.6033015986713545], 
     Hue[0.6662854980082513, 1, 0.6190370899802284], 
     Hue[0.6693964457864404, 1, 0.634759273240921], 
     Hue[0.6725410626313566, 1, 0.6504866647095047], 
     Hue[0.6757200972651243, 1, 0.6662113817029767], 
     Hue[0.6789411506534586, 1, 0.6819582742063192], 
     Hue[0.6821998218099172, 1, 0.6976923397901454], 
     Hue[0.6854981929367681, 1, 0.713409870550878], 
     Hue[0.6888456749721936, 1, 0.7291403353564164], 
     Hue[0.6922456623334547, 1, 0.744882415429669], 
     Hue[0.6956946790183943, 1, 0.7606020696532181], 
     Hue[0.6992037013714671, 1, 0.7763298168091126], 
     Hue[0.7027770740937304, 1, 0.7920630359682703], 
     Hue[0.7064193614915617, 1, 0.8077976803865011], 
     Hue[0.7101352870850719, 1, 0.8235277549621468], 
     Hue[0.7139375849451417, 1, 0.8392772058420715], 
     Hue[0.7178233961518452, 1, 0.8550014425069687], 
     Hue[0.72180559081901, 1, 0.8707167307715362], 
     Hue[0.7259055186325796, 1, 0.8864644009565359], 
     Hue[0.7301198618933971, 1, 0.9021835895029203], 
     Hue[1.0086200865156283`, 1, 0.7134155340709957], 
     Hue[0.9946186749034877, 1, 0.7291469359252067], 
     Hue[0.9912208828916352, 1, 0.7448788294047272], 
     Hue[0.9877693269537415, 1, 0.7606100202055803], 
     Hue[0.984259490686938, 1, 0.7763412476504303], 
     Hue[0.9806862518119248, 1, 0.7920736745435716], 
     Hue[0.9770443709263871, 1, 0.8078063732847199], 
     Hue[0.9733284291162333, 1, 0.8235363352037599], 
     Hue[0.96952990961628, 1, 0.8392701216794389], 
     Hue[0.9656426482581008, 1, 0.8550003244508224], 
     Hue[0.9616560969838249, 1, 0.8707326095906485], 
     Hue[0.9575602899037592, 1, 0.8864642350459871], 
     Hue[0.953342549421454, 1, 0.9021959056656297], 
     Hue[0.9979664548463236, 1, 0.7134151567902175], 
     Hue[0.8988406588644463, 1, 0.22573217545402283`], 
     Hue[0.8631468150975963, 1, 0.36731801102330186`], 
     Hue[0.8186688919290743, 1, 0.38304987181707084`], 
     Hue[0.783288879233774, 1, 0.3987816778349484], 
     Hue[0.7524496380451466, 1, 0.41451169701121676`], 
     Hue[0.7240208300913026, 1, 0.43024346799118374`], 
     Hue[0.6966587927491071, 1, 0.44597554419025764`], 
     Hue[0.6692312042362174, 1, 0.46170800436959936`], 
     Hue[0.6404287378652058, 1, 0.47743945135892973`], 
     Hue[0.9019310945276612, 1, 0.24146392482085086`], 
     Hue[0.9050236789607649, 1, 0.25719473556538036`], 
     Hue[0.9081198763173208, 1, 0.27292607135941904`], 
     Hue[0.9112210805206704, 1, 0.2886589711300121], 
     Hue[0.9143279109960709, 1, 0.3043904644497988], 
     Hue[0.9174417743482409, 1, 0.3201214747078949], 
     Hue[0.9205643007811766, 1, 0.3358539166664678], 
     Hue[0.9236962792607532, 1, 0.3515853129228309], 
     Hue[0.9677989459966023, 1, 0.5875616682225807], 
     Hue[0.9590117370052957, 1, 0.603292514814814], 
     Hue[0.952857028145891, 1, 0.6190233983892395], 
     Hue[0.9482829572413679, 1, 0.6347561580929285], 
     Hue[0.9448128787350547, 1, 0.6504881581987186], 
     Hue[0.9421781740076758, 1, 0.6662219164076342], 
     Hue[0.9402105293661305, 1, 0.6819514467631261], 
     Hue[0.9387941587189017, 1, 0.6976842296063162], 
     Hue[0.9378478007206903, 1, 0.7134168055369088], 
     Hue[0.9373114401654684, 1, 0.7291461878755777], 
     Hue[0.9371398879447583, 1, 0.7448775351611454], 
     Hue[0.9372993486038828, 1, 0.7606101998002222], 
     Hue[0.9377644405867738, 1, 0.7763428376142539], 
     Hue[0.9385166286087951, 1, 0.792075240425341], 
     Hue[0.9395431883612655, 1, 0.8078063968784586], 
     Hue[0.9408368520110855, 1, 0.8235372608464891], 
     Hue[0.9423956547082017, 1, 0.8392690992103565], 
     Hue[0.944222879463634, 1, 0.8550007454663436], 
     Hue[0.9463281935697636, 1, 0.8707328132712904], 
     Hue[0.9487286416957554, 1, 0.8864640384646776], 
     Hue[0.9514518936178739, 1, 0.9021963628298048], 
     Hue[0.9268399001843906, 1, 0.36732004565210874`], 
     Hue[0.9299944597303534, 1, 0.38304782671211146`], 
     Hue[0.9331632016064003, 1, 0.39877786736236304`], 
     Hue[0.9363477849367432, 1, 0.4145111454732999], 
     Hue[0.939548874277863, 1, 0.43024344408000487`], 
     Hue[0.9427681913597453, 1, 0.4459754584527329], 
     Hue[0.9460078333980328, 1, 0.4617093189494387], 
     Hue[0.9492681289401015, 1, 0.4774381843858915], 
     Hue[0.952552451123479, 1, 0.4931694802844738], 
     Hue[0.9558626283912482, 1, 0.5089025900107904], 
     Hue[0.9591998656189482, 1, 0.5246334126286996], 
     Hue[0.9625674182848118, 1, 0.5403668901606958], 
     Hue[0.9659665367745083, 1, 0.556097837360736], 
     Hue[0.9694005831084211, 1, 0.5718301016227891], 
     Hue[0.9912058407909362, 1, 0.6976833980781179], 
     Hue[0.9913799394901567, 1, 0.7134157851750472], 
     Hue[0.9728722515279251, 1, 0.5875634715972726], 
     Hue[0.9763833256020674, 1, 0.603292684206453], 
     Hue[0.979938375553262, 1, 0.6190238623429805], 
     Hue[0.9835408270726536, 1, 0.634756587422271], 
     Hue[0.9871941045283629, 1, 0.65048900629648], 
     Hue[0.9909021240660479, 1, 0.6662197995361325], 
     Hue[0.9946702676952708, 1, 0.6819519322742547], 
     Hue[0.9985032931281191, 1, 0.6976834853926043], 
     Hue[1.1949483918770138`, 1, 0.22573207976005963`], 
     Hue[1.1368497875237713`, 1, 0.36731698743635643`], 
     Hue[1.1901230682999664`, 1, 0.2414627186828279], 
     Hue[1.1852883600296966`, 1, 0.25719493957137707`], 
     Hue[1.1804401480655375`, 1, 0.27292735813276714`], 
     Hue[1.175574467193787, 1, 0.28865774095183927`], 
     Hue[1.17068530423304, 1, 0.30438997146987057`], 
     Hue[1.165768064703187, 1, 0.3201226811126132], 
     Hue[1.1608182082104124`, 1, 0.3358535570752613], 
     Hue[1.1558293723478752`, 1, 0.3515851057291406], 
     Hue[1.150795583761059, 1, 0.36731736938064224`], 
     Hue[1.0321999777849677`, 1, 0.5875601047418115], 
     Hue[1.0409885439225925`, 1, 0.6032931278932653], 
     Hue[1.0471434847126477`, 1, 0.6190249330636214], 
     Hue[1.1457116458265113`, 1, 0.3830465959483885], 
     Hue[1.140568936150798, 1, 0.39877796341699967`], 
     Hue[1.1353591957435343`, 1, 0.41451334675190116`], 
     Hue[1.130076649894416, 1, 0.43024481972723316`], 
     Hue[1.1247115815508395`, 1, 0.44597362765098414`], 
     Hue[1.119250477080369, 1, 0.4617085129958438], 
     Hue[1.1136847420899731`, 1, 0.47743984567472], 
     Hue[1.1080002827454798`, 1, 0.4931690414889699], 
     Hue[1.1021782925347068`, 1, 0.5089042221075274], 
     Hue[1.0962050305975781`, 1, 0.524632407016172], 
     Hue[1.0900534973228027`, 1, 0.5403666028297539], 
     Hue[1.0837001678215263`, 1, 0.5560986565078903], 
     Hue[1.0771115381167429`, 1, 0.5718305787243317], 
     Hue[1.0702469879940566`, 1, 0.5875614455359922], 
     Hue[1.0630526678518057`, 1, 0.603293844884743], 
     Hue[1.0554603437135452`, 1, 0.6190245742321016], 
     Hue[1.047372059077191, 1, 0.6347582756131874], 
     Hue[1.0386542849696632`, 1, 0.6504872265340264], 
     Hue[1.0290915534133174`, 1, 0.6662194594203676], 
     Hue[1.0183302699965597`, 1, 0.6819518936301445], 
     Hue[1.005679608066532, 1, 0.6976835850065342], 
     Hue[0.5039088315490748, 1, 0.22573145580936332`], 
     Hue[1.1813309661648235`, 1, 0.3830498142592187], 
     Hue[1.216709084689595, 1, 0.3987806966773604], 
     Hue[1.2475547339195336`, 1, 0.4145140386199029], 
     Hue[1.2759790775187438`, 1, 0.43024341552262824`], 
     Hue[1.3033393681082681`, 1, 0.4459744806525158], 
     Hue[1.330770368137547, 1, 0.4617088923257744], 
     Hue[1.3595732651054597`, 1, 0.4774404987265084], 
     Hue[1.3919582663656194`, 1, 0.4931705447614346], 
     Hue[1.434246518769604, 1, 0.508903116684973], 
     Hue[0.5040295170583657, 1, 0.24146316842531948`], 
     Hue[0.504150216118114, 1, 0.25719662928862064`], 
     Hue[0.5042708944191726, 1, 0.2729273570617793], 
     Hue[0.5043915866607804, 1, 0.2886598658357532], 
     Hue[0.5045122596536589, 1, 0.3043898202705886], 
     Hue[0.5046329587752274, 1, 0.32012312634851736`], 
     Hue[0.5047536257446273, 1, 0.33585217803521106`], 
     Hue[0.5048743209111735, 1, 0.351584832876949], 
     Hue[0.50499501797249, 1, 0.36731765327597765`], 
     Hue[0.5051156982566607, 1, 0.3830481963236537], 
     Hue[0.5052364064896818, 1, 0.3987822829435937], 
     Hue[0.5053570858351439, 1, 0.41451249557409875`], 
     Hue[0.5054777723382224, 1, 0.4302435235858295], 
     Hue[0.5055984672616339, 1, 0.4459755224998586], 
     Hue[0.5057191708384603, 1, 0.4617085136220366], 
     Hue[0.5058398546329418, 1, 0.4774387814932384], 
     Hue[0.5059605580918546, 1, 0.4931714586703866], 
     Hue[0.5060812511552767, 1, 0.5089026180315388], 
     Hue[1.0517177680691907`, 1, 0.6347590357299648], 
     Hue[1.0551876507488414`, 1, 0.6504909183907422], 
     Hue[1.0578217932745728`, 1, 0.6662216905001415], 
     Hue[1.0597896780582887`, 1, 0.6819533935028408], 
     Hue[1.0612059117153465`, 1, 0.6976851768727734], 
     Hue[1.0621519648790152`, 1, 0.7134117736685507], 
     Hue[1.0626885816239826`, 1, 0.7291471742245502], 
     Hue[1.0628601121556933`, 1, 0.7448788876087634], 
     Hue[1.0627006287565937`, 1, 0.7606113272859866], 
     Hue[1.0622355628372175`, 1, 0.7763427494812883], 
     Hue[1.0614832617355785`, 1, 0.7920771764291006], 
     Hue[1.0604571051205516`, 1, 0.8078024198687733], 
     Hue[1.0591633919779464`, 1, 0.8235345694161333], 
     Hue[1.0576043949394989`, 1, 0.83926863759038], 
     Hue[1.0557768934132699`, 1, 0.8550025646467698], 
     Hue[1.0536719397462788`, 1, 0.8707318808445607], 
     Hue[1.0512710377534475`, 1, 0.8864660111905438], 
     Hue[1.0485478096944836`, 1, 0.9021979739895288], 
     Hue[1.0454600989180018`, 1, 0.9179296651147699], 
     Hue[1.0419437145810417`, 1, 0.9336598932613129], 
     Hue[1.0378945104452424`, 1, 0.9493931089338375], 
     Hue[1.0331370891599372`, 1, 0.9651216889371377], 
     Hue[1.0273195256184484`, 1, 0.9808540207572245], 
     Hue[1.0195421361084822`, 1, 0.9965867172152854], 
     Hue[0.506201846112137, 1, 0.5246208184833306], 
     Hue[0.5063227624809818, 1, 0.5403807300161284], 
     Hue[0.5064432808111842, 1, 0.5560885725251256], 
     Hue[0.5065641324053924, 1, 0.5718396519528065], 
     Hue[0.5066848506187516, 1, 0.5875731390290506], 
     Hue[0.5068055270105561, 1, 0.603300958294904], 
     Hue[0.5069263264162395, 1, 0.6190445835620412], 
     Hue[0.5070468455884883, 1, 0.6347514515601951], 
     Hue[0.5071676640954517, 1, 0.6504970863926713], 
     Hue[0.5072884501374497, 1, 0.666238236496041], 
     Hue[0.5074088491613914, 1, 0.6819286878987528], 
     Hue[0.5075296214372748, 1, 0.6976675103113502], 
     Hue[0.5076504992301252, 1, 0.7134198023180753], 
     Hue[0.5077711967498102, 1, 0.7291483121373281], 
     Hue[0.5078918337289857, 1, 0.7448686343690972], 
     Hue[0.5080125731351731, 1, 0.7606019962668092], 
     Hue[0.5081331696058147, 1, 0.77631641614411], 
     Hue[0.5082543020270405, 1, 0.7921003461549141], 
     Hue[0.5083748203202763, 1, 0.8078039187671925], 
     Hue[0.5084954393835623, 1, 0.8235202785300139], 
     Hue[0.5086164724120925, 1, 0.8392902227061005], 
     Hue[0.5087372188723405, 1, 0.8550224659644851], 
     Hue[0.5088580025727205, 1, 0.8707591898601789], 
     Hue[0.5089786359392259, 1, 0.8864759471419371], 
     Hue[0.5090995060340984, 1, 0.9022231568656018], 
     Hue[0.5092198552259635, 1, 0.9179021055932752], 
     Hue[0.5093407056688982, 1, 0.9336459493854851], 
     Hue[0.5094612999268906, 1, 0.9493560026689972], 
     Hue[0.5095821118853843, 1, 0.9650939905840707], 
     Hue[0.5097030063309045, 1, 0.9808422884179105], 
     Hue[0.5098238408837872, 1, 0.9965823399052618], 
     Hue[1.0087942280210953`, 1, 0.6976842319466591], 
     Hue[1.008620157910782, 1, 0.7134148446613207], 
     Hue[1.0047632764605645`, 1, 0.7291471471247319], 
     Hue[0.9996843761323329, 1, 0.744879879733201], 
     Hue[0.9995636507462042, 1, 0.760611414494113], 
     Hue[0.9994429273909942, 1, 0.7763423678048943], 
     Hue[0.9993221897090557, 1, 0.7920748620603906], 
     Hue[0.9992014507007445, 1, 0.8078071941566893], 
     Hue[0.9990807389920445, 1, 0.8235356251764693], 
     Hue[0.9989599862950928, 1, 0.8392690437433142], 
     Hue[0.9988392423627722, 1, 0.8550009581316595], 
     Hue[0.9987184910344061, 1, 0.8707334648914363], 
     Hue[0.998597743934619, 1, 0.8864650403980527], 
     Hue[0.9984769910649325, 1, 0.9021969782434333], 
     Hue[0.998356251166335, 1, 0.9179268277929518], 
     Hue[0.998235483600679, 1, 0.9336598742060936], 
     Hue[0.998114717579753, 1, 0.9493923027144375], 
     Hue[0.9979939646155797, 1, 0.9651226046430293], 
     Hue[0.9978731964251834, 1, 0.9808544553024058], 
     Hue[0.9977524202834008, 1, 0.9965868978528917], 
     Hue[0.9999258320176629, 1, 0.7134152296727005], 
     Hue[0.9998051098502718, 1, 0.7291469514748413], 
     Hue[0.8125473585201255, 1, 0.22573158770474386`], 
     Hue[0.8186737489363801, 1, 0.3830479018158663], 
     Hue[0.7832934433254771, 1, 0.39877947847275613`], 
     Hue[0.7524465553284178, 1, 0.41451334810039137`], 
     Hue[0.724018219869003, 1, 0.43024495034766874`], 
     Hue[0.6966604392755372, 1, 0.445974592038442], 
     Hue[0.6692300077112597, 1, 0.4617086800753937], 
     Hue[0.6404289237161178, 1, 0.47743935417577354`], 
     Hue[0.6080385457224458, 1, 0.4931719569122729], 
     Hue[0.5657543239321245, 1, 0.508902869222674], 
     Hue[0.8172926800342131, 1, 0.2414642356389907], 
     Hue[0.8220463086437018, 1, 0.2571963743331152], 
     Hue[0.8268125607198621, 1, 0.27292800967182507`], 
     Hue[0.8315954162339971, 1, 0.2886577031962379], 
     Hue[0.8364008383725555, 1, 0.30439005698432403`], 
     Hue[0.8412326240450212, 1, 0.3201219428862618], 
     Hue[0.846096001755884, 1, 0.33585417231089865`], 
     Hue[0.8509957780803501, 1, 0.351585277370205], 
     Hue[0.8559381597210726, 1, 0.36731718876892755`], 
     Hue[0.9482832526746559, 1, 0.6347549860160391], 
     Hue[0.9448133662550341, 1, 0.6504856168814753], 
     Hue[0.9421780508152432, 1, 0.6662227670275299], 
     Hue[0.9402108585940756, 1, 0.6819483570231771], 
     Hue[0.938794439127118, 1, 0.6976804586374673], 
     Hue[0.9378477312733213, 1, 0.7134182965351309], 
     Hue[0.9373114445568641, 1, 0.7291459890969272], 
     Hue[0.9371398878100002, 1, 0.7448793571847416], 
     Hue[0.9372993142991779, 1, 0.7606084912203924], 
     Hue[0.9377643839063061, 1, 0.7763413786386507], 
     Hue[0.9385165315207407, 1, 0.79207352624477], 
     Hue[0.9395432502313524, 1, 0.8078072352584499], 
     Hue[0.9408368588250443, 1, 0.8235373360096886], 
     Hue[0.9423954357521028, 1, 0.8392670633595714], 
     Hue[0.9442232695852246, 1, 0.8550038701921606], 
     Hue[0.9463280250585043, 1, 0.8707316346842233], 
     Hue[0.9487288635153679, 1, 0.8864654035848203], 
     Hue[0.9514517935695456, 1, 0.9021958195135491], 
     Hue[0.9545395976439345, 1, 0.9179282137202419], 
     Hue[0.9580560595731638, 1, 0.9336589485996423], 
     Hue[0.9621048436501372, 1, 0.9493907809249653], 
     Hue[0.9668637402909082, 1, 0.9651241954554959], 
     Hue[0.9726806542271348, 1, 0.9808544523020143], 
     Hue[0.9804574639047713, 1, 0.9965860534251414], 
     Hue[0.8609283528854608, 1, 0.383047333866793], 
     Hue[0.8659735143585275, 1, 0.3987777648348805], 
     Hue[0.8710814977542262, 1, 0.41451076478394566`], 
     Hue[0.8762587280861796, 1, 0.43024203580287906`], 
     Hue[0.8815163287962664, 1, 0.44597894204139676`], 
     Hue[0.8868601763897573, 1, 0.4617100394476559], 
     Hue[0.8923028863762106, 1, 0.4774403876646346], 
     Hue[0.8978577550410296, 1, 0.4931722979919516], 
     Hue[0.9035387878676717, 1, 0.5089046132031275], 
     Hue[0.9093612267817837, 1, 0.524633211456117], 
     Hue[0.9153484890919611, 1, 0.5403677672399778], 
     Hue[0.9215209918346721, 1, 0.5560995022641579], 
     Hue[0.927908193430449, 1, 0.5718301723466838], 
     Hue[0.9345461686829059, 1, 0.5875606758565005], 
     Hue[0.9414812810780304, 1, 0.6032934728431047], 
     Hue[0.9487708905049447, 1, 0.6190250726252375], 
     Hue[0.9912058481866511, 1, 0.6976833084629167], 
     Hue[0.9913798378632781, 1, 0.7134148038527607], 
     Hue[0.9952365795649851, 1, 0.7291468572002163], 
     Hue[0.9564939141014278, 1, 0.6347553933962151], 
     Hue[0.9647628072887166, 1, 0.6504881368972748], 
     Hue[0.973739379168406, 1, 0.6662203372202271], 
     Hue[0.9836833346963603, 1, 0.6819521341039008], 
     Hue[0.9950562438708717, 1, 0.6976835482692553], 
     Hue[1.1085478544511007`, 1, 0.225731583579329], 
     Hue[0.8631472397708161, 1, 0.3673178830731765], 
     Hue[1.1052692790767147`, 1, 0.24146339475842915`], 
     Hue[1.1019877486640954`, 1, 0.2571960140352772], 
     Hue[1.098702233472852, 1, 0.2729276349327464], 
     Hue[1.0954110456148751`, 1, 0.28865952827826996`], 
     Hue[1.0921131498320904`, 1, 0.3043897423202357], 
     Hue[1.0888061746408824`, 1, 0.3201225625016787], 
     Hue[1.0854895278759273`, 1, 0.33585363692699804`], 
     Hue[1.0821611523843229`, 1, 0.3515853908851102], 
     Hue[0.9677990805234225, 1, 0.5875614727839575], 
     Hue[0.9590115170926896, 1, 0.6032929947368443], 
     Hue[0.9528564806684431, 1, 0.6190250366585908], 
     Hue[1.07881937162887, 1, 0.367318202296958], 
     Hue[1.0754634940100822`, 1, 0.38304757611816076`], 
     Hue[1.072090553512611, 1, 0.3987793913627923], 
     Hue[1.0686995662142234`, 1, 0.4145099005226631], 
     Hue[1.0652873737792248`, 1, 0.4302450563638114], 
     Hue[1.0618538746253847`, 1, 0.4459762701574649], 
     Hue[1.0583957461610023`, 1, 0.46170930469460514`], 
     Hue[1.0549118183984727`, 1, 0.47743953408183204`], 
     Hue[1.051399022891174, 1, 0.49317033934696464`], 
     Hue[1.047854919643394, 1, 0.5089015309787008], 
     Hue[1.0442766423690173`, 1, 0.5246340230702109], 
     Hue[1.040661685040689, 1, 0.5403662681561605], 
     Hue[1.0370069509322735`, 1, 0.5560983391218297], 
     Hue[1.0333092805567146`, 1, 0.5718294757403019], 
     Hue[1.029564170008368, 1, 0.5875633284163521], 
     Hue[1.0257697798319612`, 1, 0.6032909762237382], 
     Hue[1.0219190503527265`, 1, 0.6190235704085908], 
     Hue[1.0180078916987363`, 1, 0.6347579138027147], 
     Hue[1.0140323788433725`, 1, 0.6504882301890472], 
     Hue[1.0099852402516118`, 1, 0.6662195978826574], 
     Hue[1.0058597497548416`, 1, 0.6819518444233769], 
     Hue[1.0016485711765315`, 1, 0.6976837428190237], 
     Hue[1.4132851126341013`, 1, 0.22573193232017727`], 
     Hue[1.1368502121952089`, 1, 0.3673171153829672], 
     Hue[1.1813270345402678`, 1, 0.38304821959019014`], 
     Hue[1.216709193528078, 1, 0.39878074912493494`], 
     Hue[1.2475532475454658`, 1, 0.4145132425201164], 
     Hue[1.2759813215952693`, 1, 0.4302446899428707], 
     Hue[1.3033423882056043`, 1, 0.4459762271116125], 
     Hue[1.3307689307105939`, 1, 0.46170808057730717`], 
     Hue[1.3595705279061252`, 1, 0.4774390674235951], 
     Hue[1.4107262694727347`, 1, 0.24146313123616372`], 
     Hue[1.408165762556235, 1, 0.2571964169415143], 
     Hue[1.405603515127376, 1, 0.2729281685128104], 
     Hue[1.403038775181518, 1, 0.28865888918910504`], 
     Hue[1.4004706209050273`, 1, 0.30439008282207947`], 
     Hue[1.397898440106011, 1, 0.3201213044552088], 
     Hue[1.39532158101394, 1, 0.335852294720996], 
     Hue[1.392738953127913, 1, 0.35158539708861314`], 
     Hue[1.390150446816778, 1, 0.36731689827220193`], 
     Hue[1.3875548525675137`, 1, 0.383049688602732], 
     Hue[1.3849518381208632`, 1, 0.39878122867915344`], 
     Hue[1.382340581232995, 1, 0.41451184151515863`], 
     Hue[1.3797199229040067`, 1, 0.43024373600943056`], 
     Hue[1.377089320685588, 1, 0.4459752645329421], 
     Hue[1.3744477854378285`, 1, 0.46170730094532864`], 
     Hue[1.3717944963374018`, 1, 0.4774395332346171], 
     Hue[1.0322001123127553`, 1, 0.5875603001733809], 
     Hue[1.0409893987400753`, 1, 0.6032949934412883], 
     Hue[1.0471429979273263`, 1, 0.6190234764094965], 
     Hue[1.0517174387350399`, 1, 0.6347577290936225], 
     Hue[1.0551873073141838`, 1, 0.6504891280556142], 
     Hue[1.057821176350783, 1, 0.6662174309796483], 
     Hue[1.0597894171488538`, 1, 0.6819509448031807], 
     Hue[1.0612056877258407`, 1, 0.6976821645289566], 
     Hue[1.0621522501628442`, 1, 0.7134178979717216], 
     Hue[1.0626885320263915`, 1, 0.7291449291710633], 
     Hue[1.0628601121072216`, 1, 0.7448782308981291], 
     Hue[1.062700669719493, 1, 0.7606092872086262], 
     Hue[1.0622355267964556`, 1, 0.7763436771528902], 
     Hue[1.0614835405546754`, 1, 0.7920722536486159], 
     Hue[1.0604568146594573`, 1, 0.8078063559454336], 
     Hue[1.0591630686451357`, 1, 0.82353813606519], 
     Hue[1.0576043122909329`, 1, 0.8392694060483304], 
     Hue[1.0557771442251584`, 1, 0.855000555725286], 
     Hue[1.0536718736160395`, 1, 0.8707323433674669], 
     Hue[1.0512712400082627`, 1, 0.8864647664825348], 
     Hue[1.0485482028875652`, 1, 0.9021958387533842], 
     Hue[1.0454604703699064`, 1, 0.917927888396394], 
     Hue[1.369127532269958, 1, 0.4931779391712746], 
     Hue[1.3664495096511873`, 1, 0.5089015890073074], 
     Hue[1.3637550823210973`, 1, 0.5246361421199377], 
     Hue[1.361046139978617, 1, 0.5403645439417194], 
     Hue[1.3583188293474366`, 1, 0.5561029013123052], 
     Hue[1.3555772100985217`, 1, 0.5718213890385334], 
     Hue[1.3528148169790337`, 1, 0.5875503803835163], 
     Hue[1.3500285221866863`, 1, 0.6033002378809891], 
     Hue[1.3472249169285602`, 1, 0.6190262703112943], 
     Hue[1.344399606676914, 1, 0.6347456394256591], 
     Hue[1.3415469687157053`, 1, 0.6504812419687296], 
     Hue[1.3386661587756443`, 1, 0.6662286216994387], 
     Hue[1.3357620312497356`, 1, 0.6819521568463816], 
     Hue[1.3328269145522658`, 1, 0.697683794300288], 
     Hue[1.329858456491143, 1, 0.7134254195232527], 
     Hue[1.3268605333564167`, 1, 0.7291455392951748], 
     Hue[1.3238234118138337`, 1, 0.7448833550506629], 
     Hue[1.320750323928043, 1, 0.7606092720495601], 
     Hue[1.317637460623014, 1, 0.7763294270059077], 
     Hue[1.3144731280824278`, 1, 0.792087430393048], 
     Hue[1.3112672666828353`, 1, 0.8078175756616587], 
     Hue[1.3080152228440745`, 1, 0.8235264751651079], 
     Hue[1.3047040449144531`, 1, 0.8392578030040528], 
     Hue[1.3013278531484531`, 1, 0.8550175343291185], 
     Hue[1.2978968532125674`, 1, 0.8707357121144539], 
     Hue[1.2943971512258625`, 1, 0.8864522435947231], 
     Hue[1.2908140759952624`, 1, 0.9022042766694404], 
     Hue[1.287158087021363, 1, 0.9179151968592586], 
     Hue[1.008794235415823, 1, 0.6976843215629754], 
     Hue[1.0086201597532727`, 1, 0.7134148268689994], 
     Hue[1.004826440520964, 1, 0.7291463019004929], 
     Hue[1.0078627573075252`, 1, 0.7448799638607446], 
     Hue[1.0109368742151859`, 1, 0.7606111559939378], 
     Hue[1.0140517136525118`, 1, 0.7763411969183895], 
     Hue[1.0172111729168745`, 1, 0.7920749392045767], 
     Hue[1.0204169724728462`, 1, 0.8078049719961918], 
     Hue[1.0236740687081514`, 1, 0.8235382809449215], 
     Hue[1.026985171738243, 1, 0.8392690558449979], 
     Hue[1.0303552002090972`, 1, 0.8550000773008508], 
     Hue[1.0337892036023275`, 1, 0.8707322152078132], 
     Hue[1.0372924169590558`, 1, 0.886464423906706], 
     Hue[1.0408708405956897`, 1, 0.9021959682512368], 
     Hue[1.0445317457308132`, 1, 0.9179279584277077], 
     Hue[1.0018264753756128`, 1, 0.7134154218466219], 
     Hue[0.7248429685810877, 1, 0.22573177706494815`], 
     Hue[0.7524449532967843, 1, 0.4145142061467993], 
     Hue[0.7240152791389021, 1, 0.43024662040730444`], 
     Hue[0.6966578248274071, 1, 0.44597610391909176`], 
     Hue[0.6692330896187164, 1, 0.46170693964696263`], 
     Hue[0.6404314588790758, 1, 0.4774380285089783], 
     Hue[0.7298288007191664, 1, 0.24146296058942415`], 
     Hue[0.7348251616142192, 1, 0.25719638101250736`], 
     Hue[0.7398357925507953, 1, 0.2729280138578488], 
     Hue[0.744866388930741, 1, 0.2886595705058157], 
     Hue[0.7499218204022948, 1, 0.30438960164154255`], 
     Hue[0.7550088171164501, 1, 0.32012169363489523`], 
     Hue[0.7601323260423246, 1, 0.3358529597445782], 
     Hue[0.765299043073275, 1, 0.3515847789830703], 
     Hue[0.7705159100730578, 1, 0.3673178638855956], 
     Hue[0.7757890583391818, 1, 0.38304886395036075`], 
     Hue[0.7811274062413608, 1, 0.3987808147546177], 
     Hue[0.9378476706172986, 1, 0.7134195988522859], 
     Hue[0.937311386166019, 1, 0.7291486324019102], 
     Hue[0.9371398875614092, 1, 0.7448828889065898], 
     Hue[0.9372994336627158, 1, 0.7606144354669313], 
     Hue[0.9377645070778033, 1, 0.7763445490363841], 
     Hue[0.938516865393007, 1, 0.7920794208316262], 
     Hue[0.9395427975717829, 1, 0.8078011011891436], 
     Hue[0.940836888665059, 1, 0.8235376651671876], 
     Hue[0.9423959680427599, 1, 0.8392720125181857], 
     Hue[0.9442226195050991, 1, 0.8549986632485116], 
     Hue[0.9463274805405484, 1, 0.8707278261841901], 
     Hue[0.948728358344852, 1, 0.8864622946475842], 
     Hue[0.9514515425694892, 1, 0.9021944564378465], 
     Hue[0.9545391495315554, 1, 0.9179260702927774], 
     Hue[0.7865374218100372, 1, 0.4145072235368297], 
     Hue[0.7920327196734442, 1, 0.43023954882917215`], 
     Hue[0.7976227547932919, 1, 0.4459736179108721], 
     Hue[0.8033186217607379, 1, 0.4617060487302902], 
     Hue[0.8091349513605072, 1, 0.4774384149593577], 
     Hue[0.8150878655663485, 1, 0.493170242210912], 
     Hue[0.8211964276961796, 1, 0.508901425308839], 
     Hue[0.8274833735986193, 1, 0.5246320278502276], 
     Hue[0.8339783108254247, 1, 0.5403672485115492], 
     Hue[0.8407114624673856, 1, 0.5560985193405025], 
     Hue[0.8477261194673106, 1, 0.5718283659744369], 
     Hue[0.85507996023602, 1, 0.5875637468079411], 
     Hue[0.8628394690892128, 1, 0.60329266058333], 
     Hue[0.8711094499974067, 1, 0.6190265401667329], 
     Hue[0.8800276977767324, 1, 0.6347552348227886], 
     Hue[0.8898193302930119, 1, 0.6504869318670865], 
     Hue[0.9008575381005278, 1, 0.6662201276157149], 
     Hue[0.9138766984606514, 1, 0.6819522493998736], 
     Hue[0.9308164543258256, 1, 0.6976835601677404], 
     Hue[0.9913798135957356, 1, 0.7134145695048711], 
     Hue[1.0231222610001893`, 1, 0.22573129622144877`], 
     Hue[0.9353345446207114, 1, 0.35158529475834244`], 
     Hue[0.8631473905519333, 1, 0.36731783764431847`], 
     Hue[0.8186700061650427, 1, 0.3830494198784127], 
     Hue[0.7832906461785293, 1, 0.39878082636787393`], 
     Hue[1.0223641865732018`, 1, 0.2414638505488775], 
     Hue[1.0216061330446244`, 1, 0.2571952573684181], 
     Hue[1.0208480554929522`, 1, 0.27292609199600926`], 
     Hue[1.0200898293412182`, 1, 0.28865858213974127`], 
     Hue[1.019331525184081, 1, 0.3043909052711437], 
     Hue[1.01857314158422, 1, 0.32012273345730685`], 
     Hue[1.017814662507985, 1, 0.3358540412833491], 
     Hue[0.983238277107123, 1, 0.571829326219287], 
     Hue[0.9677983858056644, 1, 0.5875624820728869], 
     Hue[0.9590110564678163, 1, 0.6032939999890656], 
     Hue[0.9528562102605252, 1, 0.6190258458446454], 
     Hue[0.9482826336372551, 1, 0.6347574419598523], 
     Hue[0.9448129921589583, 1, 0.6504875669388007], 
     Hue[0.9421784508288591, 1, 0.6662200050597212], 
     Hue[0.9402105291683646, 1, 0.6819514486191808], 
     Hue[0.9387941889776745, 1, 0.697683822664701], 
     Hue[1.0170561528579727`, 1, 0.3515831247140401], 
     Hue[1.0162973369472579`, 1, 0.3673153411972897], 
     Hue[1.0155382686689085`, 1, 0.3830492120465476], 
     Hue[1.014779115917012, 1, 0.3987808968639358], 
     Hue[1.014019751025262, 1, 0.4145126808352455], 
     Hue[1.0132601950447537`, 1, 0.4302437661617453], 
     Hue[1.0125004511122344`, 1, 0.44597372596731555`], 
     Hue[1.0117403419996271`, 1, 0.4617058654222935], 
     Hue[1.010979851155617, 1, 0.47744016004815093`], 
     Hue[1.0102192683772784`, 1, 0.4931702494069554], 
     Hue[1.009458206479082, 1, 0.5089037746064624], 
     Hue[1.0086969635187952`, 1, 0.5246342055866089], 
     Hue[1.0079352690513683`, 1, 0.5403667621040413], 
     Hue[1.0071732542908383`, 1, 0.5560983624692727], 
     Hue[0.9948111902285806, 1, 0.6819521966690296], 
     Hue[0.9912058297784863, 1, 0.697683531520296], 
     Hue[1.0064108652476698`, 1, 0.5718297500261619], 
     Hue[1.0056479770845421`, 1, 0.5875631257103116], 
     Hue[1.004884841601899, 1, 0.6032929226998532], 
     Hue[1.0041212263009098`, 1, 0.6190235588421225], 
     Hue[1.0033570448653544`, 1, 0.6347564311288892], 
     Hue[1.0025924518674294`, 1, 0.6504879761725361], 
     Hue[1.0018273373963695`, 1, 0.6662200739891251], 
     Hue[1.0010617453519997`, 1, 0.681951438070574], 
     Hue[1.0002955767037918`, 1, 0.6976837170457088], 
     Hue[1.3234224611432774`, 1, 0.22573191663441128`], 
     Hue[1.0646707097355546`, 1, 0.3515860139708778], 
     Hue[1.1368506790859454`, 1, 0.36731725605005827`], 
     Hue[1.181328327645929, 1, 0.38304874407063794`], 
     Hue[1.2167086290034779`, 1, 0.39878047708955244`], 
     Hue[1.247551743902801, 1, 0.414512437174584], 
     Hue[1.3189425642656492`, 1, 0.24146429953130538`], 
     Hue[1.3144556649801542`, 1, 0.25719628044965803`], 
     Hue[1.3099587132655461`, 1, 0.2729258630834511], 
     Hue[1.30544668155004, 1, 0.2886576921423165], 
     Hue[1.3009159490929776`, 1, 0.3043910984636651], 
     Hue[1.2963634846964576`, 1, 0.32012291050419905`], 
     Hue[1.2917853144060834`, 1, 0.33585266970857375`], 
     Hue[1.2871754530222619`, 1, 0.3515860697731926], 
     Hue[1.282530787642089, 1, 0.36731809838279317`], 
     Hue[1.2778462110312245`, 1, 0.38304956788529787`], 
     Hue[1.2731163475558596`, 1, 0.3987809788568333], 
     Hue[1.2683355396610676`, 1, 0.41451235795608043`], 
     Hue[1.0167611411963149`, 1, 0.57182895063469], 
     Hue[1.03220166348054, 1, 0.5875625536773197], 
     Hue[1.0409887823658412`, 1, 0.6032936482625355], 
     Hue[1.047143922130512, 1, 0.6190262420245591], 
     Hue[1.0517169110643405`, 1, 0.6347556356172411], 
     Hue[1.0551870667177996`, 1, 0.6504878738527721], 
     Hue[1.0578213981130016`, 1, 0.6662189620875839], 
     Hue[1.0597893773511344`, 1, 0.6819505713027005], 
     Hue[1.061205805069938, 1, 0.6976837426132327], 
     Hue[1.0621521001063077`, 1, 0.7134146764817045], 
     Hue[1.0626885880475276`, 1, 0.7291474650132532], 
     Hue[1.0628601121555374`, 1, 0.7448788854837481], 
     Hue[1.0627006454763568`, 1, 0.7606104946216323], 
     Hue[1.2634989996682613`, 1, 0.43023930782529446`], 
     Hue[1.2585946862678823`, 1, 0.4459789010350421], 
     Hue[1.2536208486321527`, 1, 0.4617127075225054], 
     Hue[1.2485695322787203`, 1, 0.477439931725556], 
     Hue[1.2434300700810856`, 1, 0.49316503598099215`], 
     Hue[1.2381850693467336`, 1, 0.5089085285661764], 
     Hue[1.23283525059851, 1, 0.5246321331205795], 
     Hue[1.2273573476962512`, 1, 0.540363708959363], 
     Hue[1.2217384104886864`, 1, 0.5560935799755915], 
     Hue[1.2159575861339116`, 1, 0.5718262950192383], 
     Hue[1.209992341193981, 1, 0.5875603075484885], 
     Hue[1.2038154088457864`, 1, 0.6032935005084914], 
     Hue[1.1973925489059274`, 1, 0.6190245891566649], 
     Hue[1.1906769723064097`, 1, 0.6347599324480149], 
     Hue[1.1836157523809123`, 1, 0.6504891329175005], 
     Hue[1.1761274919551448`, 1, 0.6662217756821004], 
     Hue[1.1681077216356006`, 1, 0.6819504284950887], 
     Hue[1.1593934047793182`, 1, 0.6976818014208864], 
     Hue[1.149731800532226, 1, 0.7134127331898876], 
     Hue[1.1386663596787907`, 1, 0.7291478654223748], 
     Hue[1.1252277569699807`, 1, 0.7448781072885402], 
     Hue[1.10620017707439, 1, 0.7606108989297643], 
     Hue[1.0051887140044238`, 1, 0.6819519985275815], 
     Hue[1.0087941381662648`, 1, 0.6976831431020899], 
     Hue[1.0086200933418439`, 1, 0.7134154681578347], 
     Hue[1.0171300770300225`, 1, 0.7291466574340547], 
     Hue[1.030570682339973, 1, 0.7448792199066189], 
     Hue[1.0495964480870656`, 1, 0.7606104426293084], 
     Hue[1.0060672588650814`, 1, 0.7134153400831104], 
     Hue[0.6356554651891411, 1, 0.22573135374160824`], 
     Hue[1.2759815305341353`, 1, 0.430244808600307], 
     Hue[1.3033412689030488`, 1, 0.4459755798424086], 
     Hue[0.6393962859431819, 1, 0.24146435724847656`], 
     Hue[0.6431408362371329, 1, 0.257195635714989], 
     Hue[0.6468913407470283, 1, 0.27292573747842075`], 
     Hue[0.6506506515941402, 1, 0.28865770218108694`], 
     Hue[0.6544205010863168, 1, 0.30438969298882024`], 
     Hue[0.6582029232470956, 1, 0.3201209202432073], 
     Hue[0.6620006790549349, 1, 0.335853335835336], 
     Hue[0.6658157592408303, 1, 0.35158535701085014`], 
     Hue[0.669650494649314, 1, 0.3673164326007927], 
     Hue[0.6735079920250299, 1, 0.3830487270657327], 
     Hue[0.6773907587085766, 1, 0.3987814052430242], 
     Hue[0.6813013196729745, 1, 0.4145131202369292], 
     Hue[0.685242791279032, 1, 0.4302442290283892], 
     Hue[0.6892187145485713, 1, 0.4459759661052004], 
     Hue[1.0622354763705397`, 1, 0.7763449750482793], 
     Hue[1.0614831785018088`, 1, 0.7920786458979603], 
     Hue[1.0604573723443693`, 1, 0.8077987984836682], 
     Hue[1.0591636287812818`, 1, 0.8235319571691222], 
     Hue[0.6932338124184281, 1, 0.4617132325833426], 
     Hue[0.697286826112312, 1, 0.4774366131686085], 
     Hue[0.7013873388861307, 1, 0.49316773666592684`], 
     Hue[0.7055390888564199, 1, 0.5089038882203513], 
     Hue[0.7097429592509249, 1, 0.524630308003195], 
     Hue[0.7140119863152831, 1, 0.5403757884230269], 
     Hue[0.7183399348107506, 1, 0.5560959092277413], 
     Hue[0.722743008687168, 1, 0.5718262192039784], 
     Hue[0.7272280499627365, 1, 0.5875645941186424], 
     Hue[0.7317967998578936, 1, 0.6032883685012439], 
     Hue[0.7364688798668073, 1, 0.6190325189201679], 
     Hue[0.7412407843384652, 1, 0.6347491293950924], 
     Hue[0.7461386996581956, 1, 0.6504835757517106], 
     Hue[0.7511706399046598, 1, 0.6662140217705366], 
     Hue[0.7563559567082829, 1, 0.6819467190532261], 
     Hue[0.7617189261911721, 1, 0.6976912814776952], 
     Hue[0.7672754286602277, 1, 0.7134197634967079], 
     Hue[0.7730630512517866, 1, 0.7291498304541532], 
     Hue[0.7791207212984611, 1, 0.7448782843912841], 
     Hue[0.7855047049316536, 1, 0.7606150717284027], 
     Hue[0.7922780697701375, 1, 0.7763426774173908], 
     Hue[0.7995460726869776, 1, 0.7920773983662159], 
     Hue[0.8074476686622152, 1, 0.8078058184659769], 
     Hue[0.8162155482053767, 1, 0.823532753144051], 
     Hue[0.9907724054249754, 1, 0.7291464962929802], 
     Hue[0.9847131943907905, 1, 0.7448790117879439], 
     Hue[0.9783314020423235, 1, 0.7606105088083799], 
     Hue[0.9715561820804719, 1, 0.7763425673035281], 
     Hue[0.964289637661223, 1, 0.7920742594748664], 
     Hue[0.9563865852453746, 1, 0.8078057215435948], 
     Hue[0.9476156830684744, 1, 0.8235377702217223], 
     Hue[0.9965603242034492, 1, 0.7134154606227091], 
     Hue[0.9379221087749621, 1, 0.22573178102966543`], 
     Hue[0.9353349395379527, 1, 0.3515852407047825], 
     Hue[0.8631523240795964, 1, 0.3673163512508537], 
     Hue[0.8186693826482795, 1, 0.3830496727790077], 
     Hue[0.7832905204999172, 1, 0.3987808869305143], 
     Hue[0.7524486722297711, 1, 0.4145122142960793], 
     Hue[0.7240199862156265, 1, 0.43024394723123477`], 
     Hue[0.6966578192186931, 1, 0.4459761071624935], 
     Hue[0.9399090626136052, 1, 0.24146402750750884`], 
     Hue[0.9418966087775136, 1, 0.25719605751805136`], 
     Hue[0.9438848325265223, 1, 0.2729260864980343], 
     Hue[0.9458746299341918, 1, 0.2886587332375356], 
     Hue[0.9478658454089229, 1, 0.30439028369399457`], 
     Hue[0.9498588846139775, 1, 0.3201214467589566], 
     Hue[0.9518542586998313, 1, 0.3358537392179738], 
     Hue[0.9677993495774768, 1, 0.5875610819097347], 
     Hue[0.9590116024398677, 1, 0.6032928084804762], 
     Hue[0.9528567715818173, 1, 0.6190241661243269], 
     Hue[0.9482823178682849, 1, 0.6347586947693502], 
     Hue[0.9448131892393326, 1, 0.6504865396061326], 
     Hue[0.9421781611463884, 1, 0.666222005211709], 
     Hue[0.9402104945765718, 1, 0.6819517732679495], 
     Hue[0.9387940905075881, 1, 0.6976851469762965], 
     Hue[0.9378479434169064, 1, 0.7134137421720415], 
     Hue[0.9373114333261054, 1, 0.7291464974678995], 
     Hue[0.9371398878077773, 1, 0.7448793877510592], 
     Hue[0.937299344879062, 1, 0.7606100142905018], 
     Hue[0.9377643775858147, 1, 0.7763412159429978], 
     Hue[0.9385165623909666, 1, 0.7920740712937618], 
     Hue[0.9395431320101971, 1, 0.8078056332758329], 
     Hue[0.9408368657749706, 1, 0.8235374126726455], 
     Hue[0.9538518766610974, 1, 0.35158390700290765`], 
     Hue[0.9558526476116996, 1, 0.3673165442280054], 
     Hue[0.95785691168822, 1, 0.38305172105056284`], 
     Hue[0.9598640037131235, 1, 0.3987815968678511], 
     Hue[0.9618748131630324, 1, 0.414510499091547], 
     Hue[0.9638907115476588, 1, 0.43024643709401356`], 
     Hue[0.9659105087481603, 1, 0.4459773701382266], 
     Hue[0.9679349175426305, 1, 0.4617060828871139], 
     Hue[0.9699651076360576, 1, 0.4774388131940873], 
     Hue[0.9720009543490034, 1, 0.49317167814384266`], 
     Hue[0.9740426536527734, 1, 0.5089032356415687], 
     Hue[0.9760907484161168, 1, 0.5246346479156182], 
     Hue[0.9781457292069752, 1, 0.5403665830480952], 
     Hue[0.9802078500260514, 1, 0.5560978119727199], 
     Hue[0.9822777396688103, 1, 0.5718298739655625], 
     Hue[0.9948112141702525, 1, 0.6819521471333093], 
     Hue[0.9912058385840039, 1, 0.6976834248201569], 
     Hue[0.9913798984107192, 1, 0.7134153885208154], 
     Hue[0.984355937276344, 1, 0.5875635074406078], 
     Hue[0.9864424245974834, 1, 0.6032951364696523], 
     Hue[0.9885375368468385, 1, 0.6190237787295607], 
     Hue[0.9906426238991243, 1, 0.6347559146893728], 
     Hue[0.9927578391341095, 1, 0.6504888933897864], 
     Hue[0.9948833731253902, 1, 0.6662202450537476], 
     Hue[0.9970200586467354, 1, 0.6819521142995517], 
     Hue[0.9991683200622067, 1, 0.6976834548827148], 
     Hue[1.234892349376511, 1, 0.22573138585760047`], 
     Hue[1.0646642706278544`, 1, 0.35158513259872143`], 
     Hue[1.1368501287391322`, 1, 0.3673170902389723], 
     Hue[1.1813289572625842`, 1, 0.38304899944297566`], 
     Hue[1.229825133991567, 1, 0.24146429493342925`], 
     Hue[1.2247482682424295`, 1, 0.25719517371950845`], 
     Hue[1.2196551759824812`, 1, 0.27292806460308705`], 
     Hue[1.2145421536042016`, 1, 0.2886576848839495], 
     Hue[1.2094014182616448`, 1, 0.304390695908481], 
     Hue[1.2042284474514033`, 1, 0.3201229301839765], 
     Hue[1.1990171491553385`, 1, 0.3358540634841936], 
     Hue[1.1937606274451287`, 1, 0.3515849792560406], 
     Hue[1.1884511533370254`, 1, 0.3673175324950102], 
     Hue[1.1830819574350633`, 1, 0.3830489518205912], 
     Hue[1.0322003813679155`, 1, 0.5875606910395422], 
     Hue[1.0409886287209051`, 1, 0.6032933129531213], 
     Hue[1.0471435280188277`, 1, 0.6190250626547495], 
     Hue[1.05171712420555, 1, 0.6347564812227148], 
     Hue[1.0551871088829252`, 1, 0.650488093653014], 
     Hue[1.177643905637824, 1, 0.398781305769118], 
     Hue[1.1721297528529107`, 1, 0.4145087113369341], 
     Hue[1.1665240516817328`, 1, 0.430245514798576], 
     Hue[1.1608201360187889`, 1, 0.44597749634119654`], 
     Hue[1.155002474686939, 1, 0.46171087712389924`], 
     Hue[1.149056791772667, 1, 0.4774428559659608], 
     Hue[1.1429652570877606`, 1, 0.49317352198340325`], 
     Hue[1.1367069073996496`, 1, 0.5089027847414704], 
     Hue[1.1302554252842512`, 1, 0.5246334658320461], 
     Hue[1.1235797291864456`, 1, 0.540366360905464], 
     Hue[1.1166429857441886`, 1, 0.5560984279526133], 
     Hue[1.1093968433506802`, 1, 0.5718297396539973], 
     Hue[1.1017769462969627`, 1, 0.5875629707035132], 
     Hue[1.0937009415953756`, 1, 0.603292663325885], 
     Hue[1.0850466187564702`, 1, 0.6190239278063258], 
     Hue[1.0756355502002863`, 1, 0.6347569801714176], 
     Hue[1.0651833708767606`, 1, 0.6504881101397564], 
     Hue[1.0051887379462496`, 1, 0.6819520480625851], 
     Hue[1.0087941620911751`, 1, 0.6976834330015197], 
     Hue[1.0531700823035812`, 1, 0.6662192537717724], 
     Hue[1.0384419996306964`, 1, 0.6819522866027885], 
     Hue[1.0168572806573386`, 1, 0.6976837736473047], 
     Hue[0.5453556750533841, 1, 0.2257318588374817], 
     Hue[1.2167110512272439`, 1, 0.398781644324925], 
     Hue[1.2475529077151122`, 1, 0.4145130605079278], 
     Hue[1.2759788788822188`, 1, 0.4302433027163215], 
     Hue[1.3033384360453988`, 1, 0.4459739416599858], 
     Hue[1.3307679072346406`, 1, 0.4617075025954014], 
     Hue[1.359573712700594, 1, 0.47744073277611576`], 
     Hue[1.391958517900705, 1, 0.4931706561851461], 
     Hue[0.5467390135353587, 1, 0.24146287684791773`], 
     Hue[0.5481225844481267, 1, 0.25719416043618076`], 
     Hue[0.5495065405669899, 1, 0.2729262556923761], 
     Hue[0.5508910039101044, 1, 0.28865935594963954`], 
     Hue[0.5522758933969332, 1, 0.30439134395039985`], 
     Hue[0.5536611589192332, 1, 0.32012045367039704`], 
     Hue[0.5550473837491673, 1, 0.33585210458317905`], 
     Hue[0.5564347382458601, 1, 0.3515870161914263], 
     Hue[0.5578225922097413, 1, 0.3673168280469646], 
     Hue[0.5592116479713058, 1, 0.38304828264293933`], 
     Hue[0.5606020036808006, 1, 0.3987812591745188], 
     Hue[0.561993479619328, 1, 0.41451248744046415`], 
     Hue[0.5633864643624295, 1, 0.4302451150231973], 
     Hue[0.5647808058141783, 1, 0.4459761688884445], 
     Hue[0.566176815757713, 1, 0.4617079019118241], 
     Hue[0.5675745478826911, 1, 0.47743964037506437`], 
     Hue[0.568974068807434, 1, 0.4931708452438338], 
     Hue[1.0578214226083174`, 1, 0.6662191312127033], 
     Hue[1.0597891966480768`, 1, 0.6819488754461087], 
     Hue[1.061205923802366, 1, 0.6976853394327516], 
     Hue[1.062152049788774, 1, 0.7134135963216709], 
     Hue[1.0626886592640523`, 1, 0.7291506893053042], 
     Hue[1.0628601117575633`, 1, 0.7448737056165434], 
     Hue[1.062700587546005, 1, 0.7606133794413037], 
     Hue[1.062235469756298, 1, 0.7763451452862582], 
     Hue[1.0614832432688626`, 1, 0.7920775024574369], 
     Hue[1.060456827493129, 1, 0.8078061820394312], 
     Hue[1.0591628393919634`, 1, 0.8235406648410903], 
     Hue[1.057604441404475, 1, 0.8392682055611534], 
     Hue[1.055777440079102, 1, 0.8549981859850448], 
     Hue[1.053671901608968, 1, 0.8707321475817498], 
     Hue[1.0512717227617936`, 1, 0.8864617954911628], 
     Hue[1.0485482970711784`, 1, 0.902195327283619], 
     Hue[1.045460958217864, 1, 0.9179255548961862], 
     Hue[1.0419437501476883`, 1, 0.9336597444946341], 
     Hue[1.0378953741327077`, 1, 0.9493899959663328], 
     Hue[1.0331369008544382`, 1, 0.9651222579846138], 
     Hue[1.027320040826544, 1, 0.9808527844821231], 
     Hue[0.5703752066643546, 1, 0.5088982907080472], 
     Hue[0.5717779158427223, 1, 0.5246201689270943], 
     Hue[0.5731859158919638, 1, 0.5403767696863198], 
     Hue[0.5745931823738206, 1, 0.5560993250612466], 
     Hue[0.5760021967387473, 1, 0.5718142986434905], 
     Hue[0.5774166836622102, 1, 0.5875617837013234], 
     Hue[0.5788319515909781, 1, 0.6032881163464572], 
     Hue[0.5802497661812287, 1, 0.619011563632584], 
     Hue[0.5816727258063282, 1, 0.6347594318059071], 
     Hue[0.5830969841397529, 1, 0.6504876723427702], 
     Hue[0.5845260660437408, 1, 0.6662337241769032], 
     Hue[0.5859565369943229, 1, 0.6819582429263336], 
     Hue[0.5873888550852214, 1, 0.6976648662698717], 
     Hue[0.5888281146138514, 1, 0.7134078225418425], 
     Hue[0.5902716494516191, 1, 0.7291561907060204], 
     Hue[0.5917166379060337, 1, 0.7448776442510345], 
     Hue[0.5931647971340054, 1, 0.7605893596045473], 
     Hue[0.5946231542033835, 1, 0.776365645604495], 
     Hue[0.596079852520868, 1, 0.7920765157039724], 
     Hue[0.5975422846475502, 1, 0.8078001750326552], 
     Hue[0.5990083564810651, 1, 0.8235123041936065], 
     Hue[0.6004813359063262, 1, 0.8392460341771186], 
     Hue[0.601959398812721, 1, 0.8549798850894972], 
     Hue[0.6034464182773867, 1, 0.8707529409980928], 
     Hue[0.6049349206125159, 1, 0.8864839586919767], 
     Hue[0.6064289291251335, 1, 0.9022136656067381], 
     Hue[0.6079267594169755, 1, 0.9179223785791955], 
     Hue[0.6094330996126027, 1, 0.9336571024214134], 
     Hue[0.610946617033642, 1, 0.9494015069243678], 
     Hue[0.6124659124694325, 1, 0.9651387651953204], 
     Hue[0.6139895217229697, 1, 0.980851599851554], 
     Hue[1.008620047739536, 1, 0.7134159084784883], 
     Hue[1.0047632631995784`, 1, 0.7291471738280708], 
     Hue[0.996228058175765, 1, 0.7448780592866395], 
     Hue[0.9947779870210496, 1, 0.760610486940754], 
     Hue[0.9933236480155901, 1, 0.7763433083252054], 
     Hue[0.9918651889566634, 1, 0.7920732076096518], 
     Hue[0.9904018495518334, 1, 0.8078066166784045], 
     Hue[0.9889339296402181, 1, 0.8235384983557656], 
     Hue[0.9874611409173993, 1, 0.8392701063455495], 
     Hue[0.9859833002823262, 1, 0.85500151143321], 
     Hue[0.9845001977590895, 1, 0.8707330170792251], 
     Hue[0.9830116234949591, 1, 0.8864648674636368], 
     Hue[0.9815175784598613, 1, 0.9021950312188178], 
     Hue[0.9800175529054087, 1, 0.9179267951682496], 
     Hue[0.9785114545172, 1, 0.933658980377271], 
     Hue[0.9769991699514414, 1, 0.9493905792215883], 
     Hue[0.9754803176378339, 1, 0.9651233046490982], 
     Hue[0.9739549193923204, 1, 0.9808546164950328], 
     Hue[0.9991159305040043, 1, 0.713415351016678], 
     Hue[0.9976739422116868, 1, 0.7291468495730752], 
     Hue[0.8521311189311996, 1, 0.2257320194923159], 
     Hue[0.8631485137889499, 1, 0.36731749922581225`], 
     Hue[0.8186693324997915, 1, 0.3830496931194497], 
     Hue[0.7832901988070763, 1, 0.398781041949617], 
     Hue[0.7524469634145725, 1, 0.41451312953048897`], 
     Hue[0.7240184535243325, 1, 0.43024481765358497`], 
     Hue[0.6966572938302935, 1, 0.445976410983578], 
     Hue[0.6692301953093072, 1, 0.4617085741344533], 
     Hue[0.6404275738522327, 1, 0.4774400600305244], 
     Hue[0.6080414714879805, 1, 0.4931706608856872], 
     Hue[0.8562741494537696, 1, 0.24146364179342414`], 
     Hue[0.86042267557085, 1, 0.257194764750808], 
     Hue[0.8645798514586942, 1, 0.272926515742983], 
     Hue[0.8687487518233603, 1, 0.28865951261117906`], 
     Hue[0.8729317048377689, 1, 0.3043912902692226], 
     Hue[0.8771319114940925, 1, 0.32012234091894903`], 
     Hue[0.881352911720886, 1, 0.3358539889975027], 
     Hue[0.885597843597639, 1, 0.3515855369104409], 
     Hue[0.9590115529286517, 1, 0.6032929165305786], 
     Hue[0.952856512892074, 1, 0.6190249402313387], 
     Hue[0.9482827891674475, 1, 0.6347568249057945], 
     Hue[0.9448124518056034, 1, 0.650490383765505], 
     Hue[0.9421786472657058, 1, 0.666218648776864], 
     Hue[0.940210739885132, 1, 0.6819494710605105], 
     Hue[0.9387941824380083, 1, 0.6976839106144527], 
     Hue[0.937847733953368, 1, 0.713418238994488], 
     Hue[0.9373114254334164, 1, 0.7291468547482647], 
     Hue[0.9371398879061889, 1, 0.7448780505713963], 
     Hue[0.9372993774292855, 1, 0.7606116353394441], 
     Hue[0.9377645148985541, 1, 0.7763447503300672], 
     Hue[0.9385167227708543, 1, 0.7920769028898599], 
     Hue[0.939543206673523, 1, 0.8078066450225492], 
     Hue[0.9408368344515996, 1, 0.8235370671515642], 
     Hue[0.942395707353439, 1, 0.8392695886988248], 
     Hue[0.9442229857063096, 1, 0.8550015964385216], 
     Hue[0.9463278906680617, 1, 0.870730694733774], 
     Hue[0.9487286372048075, 1, 0.886464010826375], 
     Hue[0.9514516942433006, 1, 0.9021952801162703], 
     Hue[0.9545393421115158, 1, 0.9179269914528981], 
     Hue[0.958056197530972, 1, 0.9336595256467688], 
     Hue[0.9621050545868681, 1, 0.949391541202062], 
     Hue[0.9668633587752037, 1, 0.9651230425625594], 
     Hue[0.9726807988499617, 1, 0.9808547993263939], 
     Hue[0.8898706135629972, 1, 0.3673185191461902], 
     Hue[0.8941742722175704, 1, 0.3830505993162978], 
     Hue[0.8985132809154813, 1, 0.3987837804897132], 
     Hue[0.9028904449673744, 1, 0.41451311504467175`], 
     Hue[0.9073111309985463, 1, 0.4302418096364349], 
     Hue[0.9117815037871713, 1, 0.44597446053259615`], 
     Hue[0.9163054426831635, 1, 0.461706059250943], 
     Hue[0.9208901410942075, 1, 0.47744141487916303`], 
     Hue[0.9255395959731179, 1, 0.49317232679234446`], 
     Hue[0.9302623575676225, 1, 0.5089037990619766], 
     Hue[0.9350662424395686, 1, 0.5246354129507899], 
     Hue[0.9399599157070168, 1, 0.5403662578940204], 
     Hue[0.9449541250015294, 1, 0.5560981711885526], 
     Hue[0.9500600018063913, 1, 0.5718294425017452], 
     Hue[0.9552915203171113, 1, 0.5875614617501602], 
     Hue[0.9912058703743707, 1, 0.697683039617963], 
     Hue[0.9913799065659613, 1, 0.7134154672676087], 
     Hue[0.9952366540032018, 1, 0.7291470070995802], 
     Hue[0.9606638266663023, 1, 0.6032921737506577], 
     Hue[0.9661963081843169, 1, 0.619023396167435], 
     Hue[0.9719115919335465, 1, 0.6347552240921078], 
     Hue[0.9778377330138384, 1, 0.6504888368652372], 
     Hue[0.9840076094536002, 1, 0.6662204129856625], 
     Hue[0.990465520133104, 1, 0.6819517273558712], 
     Hue[0.9972687871905175, 1, 0.6976834770720028], 
     Hue[1.1478688810687996`, 1, 0.2257320194923159], 
     Hue[1.1437258505462298`, 1, 0.24146364179342414`], 
     Hue[1.1395773244291494`, 1, 0.257194764750808], 
     Hue[1.1354201485413054`, 1, 0.27292651574298293`], 
     Hue[1.131251248176639, 1, 0.28865951261117906`], 
     Hue[1.1270682951622304`, 1, 0.3043912902692226], 
     Hue[1.122868088505907, 1, 0.320122340918949], 
     Hue[1.1186470882791135`, 1, 0.33585398899750263`], 
     Hue[1.1144021564023605`, 1, 0.35158553691044087`], 
     Hue[1.1101293864370023`, 1, 0.36731851914619007`], 
     Hue[1.1058257277824293`, 1, 0.3830505993162977], 
     Hue[1.1014867190845181`, 1, 0.398783780489713], 
     Hue[1.0971095550326253`, 1, 0.4145131150446716], 
     Hue[1.0926888690014533`, 1, 0.43024180963643466`], 
     Hue[1.0882184962128283`, 1, 0.44597446053259593`], 
     Hue[1.0836945573168362`, 1, 0.46170605925094266`], 
     Hue[1.0791098589057921`, 1, 0.4774414148791628], 
     Hue[1.074460404026882, 1, 0.49317232679234413`], 
     Hue[1.0697376424323772`, 1, 0.5089037990619762], 
     Hue[1.0649337575604312`, 1, 0.5246354129507895], 
     Hue[1.060040084292983, 1, 0.5403662578940202], 
     Hue[1.0550458749984704`, 1, 0.5560981711885523], 
     Hue[1.0499399981936086`, 1, 0.5718294425017448], 
     Hue[1.0447084796828885`, 1, 0.5875614617501599], 
     Hue[1.0393361733336974`, 1, 0.6032921737506575], 
     Hue[1.033803691815683, 1, 0.6190233961674347], 
     Hue[1.0280884080664534`, 1, 0.6347552240921075], 
     Hue[1.0221622669861616`, 1, 0.6504888368652368], 
     Hue[1.0159923905463997`, 1, 0.6662204129856623], 
     Hue[1.009534479866896, 1, 0.6819517273558711], 
     Hue[1.0027312128094825`, 1, 0.6976834770720028], 
     Hue[1.454644324946615, 1, 0.2257318588374817], 
     Hue[1.1368514862110495`, 1, 0.36731749922581214`], 
     Hue[1.181330667500208, 1, 0.3830496931194495], 
     Hue[1.2167098011929232`, 1, 0.3987810419496167], 
     Hue[1.2475530365854268`, 1, 0.4145131295304886], 
     Hue[1.2759815464756668`, 1, 0.43024481765358447`], 
     Hue[1.3033427061697056`, 1, 0.4459764109835775], 
     Hue[1.330769804690692, 1, 0.4617085741344529], 
     Hue[1.3595724261477664`, 1, 0.47744006003052386`], 
     Hue[1.3919585285120184`, 1, 0.49317066088568673`], 
     Hue[1.4532609864646404`, 1, 0.24146287684791773`], 
     Hue[1.4518774155518726`, 1, 0.25719416043618076`], 
     Hue[1.4504934594330092`, 1, 0.2729262556923761], 
     Hue[1.4491089960898949`, 1, 0.28865935594963954`], 
     Hue[1.447724106603066, 1, 0.3043913439503998], 
     Hue[1.4463388410807658`, 1, 0.32012045367039704`], 
     Hue[1.444952616250832, 1, 0.33585210458317905`], 
     Hue[1.443565261754139, 1, 0.3515870161914263], 
     Hue[1.4421774077902576`, 1, 0.36731682804696447`], 
     Hue[1.4407883520286933`, 1, 0.3830482826429392], 
     Hue[1.4393979963191985`, 1, 0.3987812591745187], 
     Hue[1.4380065203806711`, 1, 0.414512487440464], 
     Hue[1.4366135356375695`, 1, 0.4302451150231971], 
     Hue[1.4352191941858208`, 1, 0.44597616888844427`], 
     Hue[1.4338231842422862`, 1, 0.46170790191182387`], 
     Hue[1.4324254521173079`, 1, 0.47743964037506403`], 
     Hue[1.4310259311925648`, 1, 0.4931708452438336], 
     Hue[1.0409884470713482`, 1, 0.6032929165305784], 
     Hue[1.047143487107926, 1, 0.6190249402313384], 
     Hue[1.0517172108325523`, 1, 0.6347568249057941], 
     Hue[1.0551875481943966`, 1, 0.6504903837655046], 
     Hue[1.0578213527342941`, 1, 0.6662186487768633], 
     Hue[1.059789260114868, 1, 0.6819494710605098], 
     Hue[1.0612058175619916`, 1, 0.6976839106144518], 
     Hue[1.062152266046632, 1, 0.7134182389944872], 
     Hue[1.0626885745665835`, 1, 0.7291468547482638], 
     Hue[1.062860112093811, 1, 0.7448780505713952], 
     Hue[1.0627006225707145`, 1, 0.7606116353394432], 
     Hue[1.062235485101446, 1, 0.7763447503300662], 
     Hue[1.0614832772291458`, 1, 0.7920769028898588], 
     Hue[1.060456793326477, 1, 0.807806645022548], 
     Hue[1.0591631655484004`, 1, 0.8235370671515629], 
     Hue[1.0576042926465612`, 1, 0.8392695886988236], 
     Hue[1.0557770142936906`, 1, 0.8550015964385204], 
     Hue[1.0536721093319386`, 1, 0.870730694733773], 
     Hue[1.0512713627951926`, 1, 0.8864640108263739], 
     Hue[1.0485483057566998`, 1, 0.9021952801162688], 
     Hue[1.0454606578884844`, 1, 0.9179269914528968], 
     Hue[1.0419438024690282`, 1, 0.9336595256467677], 
     Hue[1.037894945413132, 1, 0.9493915412020609], 
     Hue[1.0331366412247966`, 1, 0.9651230425625583], 
     Hue[1.0273192011500387`, 1, 0.980854799326393], 
     Hue[1.4296247933356443`, 1, 0.5088982907080469], 
     Hue[1.4282220841572766`, 1, 0.5246201689270938], 
     Hue[1.426814084108035, 1, 0.5403767696863193], 
     Hue[1.4254068176261783`, 1, 0.5560993250612462], 
     Hue[1.4239978032612515`, 1, 0.5718142986434901], 
     Hue[1.4225833163377886`, 1, 0.5875617837013227], 
     Hue[1.4211680484090206`, 1, 0.6032881163464565], 
     Hue[1.4197502338187702`, 1, 0.6190115636325833], 
     Hue[1.4183272741936706`, 1, 0.6347594318059062], 
     Hue[1.416903015860246, 1, 0.6504876723427693], 
     Hue[1.4154739339562579`, 1, 0.6662337241769022], 
     Hue[1.4140434630056757`, 1, 0.6819582429263324], 
     Hue[1.4126111449147774`, 1, 0.6976648662698705], 
     Hue[1.4111718853861472`, 1, 0.7134078225418415], 
     Hue[1.4097283505483795`, 1, 0.7291561907060191], 
     Hue[1.408283362093965, 1, 0.744877644251033], 
     Hue[1.4068352028659934`, 1, 0.7605893596045458], 
     Hue[1.4053768457966151`, 1, 0.7763656456044933], 
     Hue[1.4039201474791305`, 1, 0.7920765157039709], 
     Hue[1.4024577153524482`, 1, 0.8078001750326536], 
     Hue[1.4009916435189336`, 1, 0.8235123041936045], 
     Hue[1.3995186640936723`, 1, 0.8392460341771164], 
     Hue[1.3980406011872775`, 1, 0.8549798850894951], 
     Hue[1.3965535817226118`, 1, 0.8707529409980903], 
     Hue[1.3950650793874826`, 1, 0.8864839586919739], 
     Hue[1.3935710708748652`, 1, 0.9022136656067355], 
     Hue[1.3920732405830232`, 1, 0.9179223785791927], 
     Hue[1.390566900387396, 1, 0.9336571024214106], 
     Hue[1.3890533829663567`, 1, 0.9494015069243646], 
     Hue[1.3875340875305662`, 1, 0.9651387651953169], 
     Hue[1.3860104782770288`, 1, 0.9808515998515507], 
     Hue[1.0087941296256293`, 1, 0.6976830396179629], 
     Hue[1.0086200934340388`, 1, 0.7134154672676086], 
     Hue[1.0047633459967982`, 1, 0.7291470070995802], 
     Hue[1.003771941824235, 1, 0.7448780592866394], 
     Hue[1.0052220129789504`, 1, 0.7606104869407538], 
     Hue[1.00667635198441, 1, 0.7763433083252053], 
     Hue[1.0081348110433366`, 1, 0.7920732076096516], 
     Hue[1.0095981504481668`, 1, 0.8078066166784041], 
     Hue[1.011066070359782, 1, 0.8235384983557653], 
     Hue[1.0125388590826008`, 1, 0.8392701063455491], 
     Hue[1.014016699717674, 1, 0.8550015114332098], 
     Hue[1.0154998022409107`, 1, 0.8707330170792247], 
     Hue[1.0169883765050411`, 1, 0.8864648674636363], 
     Hue[1.018482421540139, 1, 0.9021950312188175], 
     Hue[1.0199824470945915`, 1, 0.9179267951682492], 
     Hue[1.0214885454828002`, 1, 0.9336589803772702], 
     Hue[1.023000830048559, 1, 0.9493905792215876], 
     Hue[1.0245196823621665`, 1, 0.9651233046490975], 
     Hue[1.02604508060768, 1, 0.9808546164950318], 
     Hue[1.0008840694959957`, 1, 0.713415351016678], 
     Hue[1.0023260577883133`, 1, 0.7291468495730752], 
     Hue[0.7651076506234883, 1, 0.22573138585760047`], 
     Hue[0.7832889487727555, 1, 0.39878164432492536`], 
     Hue[0.752447092284887, 1, 0.41451306050792824`], 
     Hue[0.7240211211177804, 1, 0.43024330271632194`], 
     Hue[0.6966615639546004, 1, 0.4459739416599863], 
     Hue[0.6692320927653586, 1, 0.46170750259540183`], 
     Hue[0.6404262872994051, 1, 0.4774407327761163], 
     Hue[0.6080414820992939, 1, 0.49317065618514644`], 
     Hue[0.7701748660084324, 1, 0.24146429493342925`], 
     Hue[0.7752517317575699, 1, 0.25719517371950845`], 
     Hue[0.7803448240175181, 1, 0.2729280646030871], 
     Hue[0.7854578463957979, 1, 0.28865768488394955`], 
     Hue[0.7905985817383546, 1, 0.30439069590848106`], 
     Hue[0.795771552548596, 1, 0.3201229301839766], 
     Hue[0.8009828508446608, 1, 0.3358540634841938], 
     Hue[0.8062393725548707, 1, 0.35158497925604076`], 
     Hue[0.8115488466629741, 1, 0.3673175324950104], 
     Hue[0.816918042564936, 1, 0.3830489518205914], 
     Hue[0.9421785773916824, 1, 0.6662191312127039], 
     Hue[0.9402108033519232, 1, 0.6819488754461095], 
     Hue[0.938794076197634, 1, 0.6976853394327522], 
     Hue[0.9378479502112259, 1, 0.7134135963216719], 
     Hue[0.9373113407359476, 1, 0.7291506893053052], 
     Hue[0.9371398882424367, 1, 0.7448737056165444], 
     Hue[0.9372994124539952, 1, 0.7606133794413048], 
     Hue[0.937764530243702, 1, 0.7763451452862593], 
     Hue[0.9385167567311375, 1, 0.7920775024574381], 
     Hue[0.9395431725068711, 1, 0.8078061820394324], 
     Hue[0.9408371606080367, 1, 0.8235406648410916], 
     Hue[0.9423955585955253, 1, 0.8392682055611548], 
     Hue[0.9442225599208981, 1, 0.8549981859850463], 
     Hue[0.9463280983910322, 1, 0.8707321475817511], 
     Hue[0.9487282772382066, 1, 0.886461795491164], 
     Hue[0.9514517029288219, 1, 0.9021953272836202], 
     Hue[0.9545390417821363, 1, 0.9179255548961874], 
     Hue[0.958056249852312, 1, 0.9336597444946353], 
     Hue[0.9621046258672925, 1, 0.9493899959663339], 
     Hue[0.9668630991455621, 1, 0.9651222579846148], 
     Hue[0.9726799591734563, 1, 0.9808527844821241], 
     Hue[0.8223560943621754, 1, 0.3987813057691183], 
     Hue[0.8278702471470889, 1, 0.4145087113369344], 
     Hue[0.8334759483182667, 1, 0.4302455147985763], 
     Hue[0.8391798639812105, 1, 0.4459774963411969], 
     Hue[0.8449975253130605, 1, 0.4617108771238997], 
     Hue[0.8509432082273326, 1, 0.47744285596596125`], 
     Hue[0.8570347429122389, 1, 0.4931735219834039], 
     Hue[0.8632930926003499, 1, 0.508902784741471], 
     Hue[0.8697445747157485, 1, 0.5246334658320467], 
     Hue[0.8764202708135541, 1, 0.5403663609054646], 
     Hue[0.883357014255811, 1, 0.5560984279526141], 
     Hue[0.8906031566493194, 1, 0.5718297396539981], 
     Hue[0.898223053703037, 1, 0.587562970703514], 
     Hue[0.9062990584046242, 1, 0.6032926633258858], 
     Hue[0.9149533812435295, 1, 0.6190239278063265], 
     Hue[0.9243644497997136, 1, 0.6347569801714184], 
     Hue[0.9348166291232392, 1, 0.6504881101397572], 
     Hue[0.9913799522604642, 1, 0.7134159084784885], 
     Hue[0.9952367368004216, 1, 0.7291471738280709], 
     Hue[0.9468299176964188, 1, 0.666219253771773], 
     Hue[0.9615580003693036, 1, 0.6819522866027888], 
     Hue[0.9831427193426615, 1, 0.6976837736473049], 
     Hue[1.0620778912250373`, 1, 0.22573178102966543`], 
     Hue[0.9353357293721453, 1, 0.3515851325987215], 
     Hue[0.8631498712608673, 1, 0.36731709023897247`], 
     Hue[0.8186710427374151, 1, 0.3830489994429758], 
     Hue[1.0600909373863943`, 1, 0.24146402750750884`], 
     Hue[1.0581033912224858`, 1, 0.25719605751805136`], 
     Hue[1.056115167473477, 1, 0.2729260864980343], 
     Hue[1.0541253700658075`, 1, 0.2886587332375356], 
     Hue[1.0521341545910765`, 1, 0.3043902836939945], 
     Hue[1.050141115386022, 1, 0.32012144675895654`], 
     Hue[1.048145741300168, 1, 0.3358537392179738], 
     Hue[0.9677996186320843, 1, 0.5875606910395423], 
     Hue[0.9590113712790947, 1, 0.6032933129531216], 
     Hue[0.9528564719811721, 1, 0.6190250626547499], 
     Hue[0.9482828757944498, 1, 0.6347564812227152], 
     Hue[0.9448128911170747, 1, 0.6504880936530146], 
     Hue[1.046148123338902, 1, 0.35158390700290754`], 
     Hue[1.0441473523882998`, 1, 0.3673165442280054], 
     Hue[1.0421430883117795`, 1, 0.38305172105056273`], 
     Hue[1.040135996286876, 1, 0.398781596867851], 
     Hue[1.0381251868369672`, 1, 0.4145104990915469], 
     Hue[1.0361092884523408`, 1, 0.43024643709401345`], 
     Hue[1.0340894912518392`, 1, 0.44597737013822647`], 
     Hue[1.0320650824573692`, 1, 0.4617060828871138], 
     Hue[1.0300348923639422`, 1, 0.4774388131940872], 
     Hue[1.0279990456509962`, 1, 0.49317167814384266`], 
     Hue[1.0259573463472262`, 1, 0.5089032356415685], 
     Hue[1.023909251583883, 1, 0.5246346479156181], 
     Hue[1.0218542707930245`, 1, 0.540366583048095], 
     Hue[1.0197921499739484`, 1, 0.5560978119727198], 
     Hue[1.0177222603311895`, 1, 0.5718298739655624], 
     Hue[0.9948112620537504, 1, 0.6819520480625852], 
     Hue[0.9912058379088249, 1, 0.6976834330015198], 
     Hue[1.0156440627236558`, 1, 0.5875635074406076], 
     Hue[1.0135575754025163`, 1, 0.603295136469652], 
     Hue[1.0114624631531612`, 1, 0.6190237787295605], 
     Hue[1.0093573761008756`, 1, 0.6347559146893728], 
     Hue[1.0072421608658904`, 1, 0.6504888933897863], 
     Hue[1.0051166268746097`, 1, 0.6662202450537474], 
     Hue[1.0029799413532645`, 1, 0.6819521142995517], 
     Hue[1.0008316799377934`, 1, 0.6976834548827147], 
     Hue[1.364344534810858, 1, 0.22573135374160821`], 
     Hue[1.064665060462047, 1, 0.3515852407047825], 
     Hue[1.136847675920403, 1, 0.36731635125085355`], 
     Hue[1.18133061735172, 1, 0.3830496727790075], 
     Hue[1.2167094795000823`, 1, 0.398780886930514], 
     Hue[1.2475513277702281`, 1, 0.4145122142960789], 
     Hue[1.2759800137843724`, 1, 0.43024394723123427`], 
     Hue[1.3033421807813061`, 1, 0.44597610716249303`], 
     Hue[1.3606037140568172`, 1, 0.24146435724847654`], 
     Hue[1.3568591637628662`, 1, 0.257195635714989], 
     Hue[1.3531086592529709`, 1, 0.27292573747842075`], 
     Hue[1.349349348405859, 1, 0.2886577021810869], 
     Hue[1.3455794989136822`, 1, 0.3043896929888201], 
     Hue[1.3417970767529033`, 1, 0.32012092024320726`], 
     Hue[1.3379993209450642`, 1, 0.33585333583533583`], 
     Hue[1.3341842407591686`, 1, 0.3515853570108499], 
     Hue[1.330349505350685, 1, 0.3673164326007925], 
     Hue[1.3264920079749691`, 1, 0.38304872706573234`], 
     Hue[1.3226092412914223`, 1, 0.39878140524302386`], 
     Hue[1.3186986803270244`, 1, 0.41451312023692877`], 
     Hue[1.314757208720967, 1, 0.43024422902838877`], 
     Hue[1.3107812854514278`, 1, 0.44597596610519985`], 
     Hue[1.032200650422523, 1, 0.5875610819097346], 
     Hue[1.0409883975601322`, 1, 0.6032928084804757], 
     Hue[1.0471432284181827`, 1, 0.6190241661243264], 
     Hue[1.0517176821317151`, 1, 0.6347586947693497], 
     Hue[1.0551868107606672`, 1, 0.650486539606132], 
     Hue[1.0578218388536116`, 1, 0.6662220052117085], 
     Hue[1.059789505423428, 1, 0.6819517732679488], 
     Hue[1.0612059094924118`, 1, 0.6976851469762955], 
     Hue[1.0621520565830935`, 1, 0.7134137421720408], 
     Hue[1.0626885666738946`, 1, 0.7291464974678985], 
     Hue[1.0628601121922225`, 1, 0.7448793877510583], 
     Hue[1.0627006551209381`, 1, 0.7606100142905009], 
     Hue[1.0622356224141853`, 1, 0.7763412159429969], 
     Hue[1.0614834376090334`, 1, 0.7920740712937605], 
     Hue[1.060456867989803, 1, 0.8078056332758319], 
     Hue[1.0591631342250296`, 1, 0.8235374126726446], 
     Hue[1.306766187581571, 1, 0.46171323258334196`], 
     Hue[1.302713173887687, 1, 0.47743661316860775`], 
     Hue[1.2986126611138684`, 1, 0.49316773666592606`], 
     Hue[1.2944609111435792`, 1, 0.5089038882203503], 
     Hue[1.290257040749074, 1, 0.524630308003194], 
     Hue[1.285988013684716, 1, 0.5403757884230258], 
     Hue[1.2816600651892482`, 1, 0.5560959092277401], 
     Hue[1.2772569913128309`, 1, 0.571826219203977], 
     Hue[1.2727719500372625`, 1, 0.5875645941186408], 
     Hue[1.2682032001421055`, 1, 0.6032883685012421], 
     Hue[1.2635311201331918`, 1, 0.619032518920166], 
     Hue[1.258759215661534, 1, 0.6347491293950904], 
     Hue[1.2538613003418035`, 1, 0.6504835757517083], 
     Hue[1.2488293600953393`, 1, 0.6662140217705343], 
     Hue[1.2436440432917162`, 1, 0.6819467190532237], 
     Hue[1.2382810738088272`, 1, 0.6976912814776925], 
     Hue[1.2327245713397716`, 1, 0.713419763496705], 
     Hue[1.2269369487482127`, 1, 0.7291498304541503], 
     Hue[1.2208792787015381`, 1, 0.744878284391281], 
     Hue[1.2144952950683459`, 1, 0.7606150717283996], 
     Hue[1.2077219302298619`, 1, 0.7763426774173874], 
     Hue[1.2004539273130217`, 1, 0.7920773983662124], 
     Hue[1.1925523313377844`, 1, 0.8078058184659732], 
     Hue[1.183784451794623, 1, 0.8235327531440473], 
     Hue[1.0051887858297475`, 1, 0.6819521471333093], 
     Hue[1.008794161415996, 1, 0.6976834248201568], 
     Hue[1.0086201015892808`, 1, 0.7134153885208153], 
     Hue[1.0092275945750246`, 1, 0.7291464962929801], 
     Hue[1.0152868056092095`, 1, 0.7448790117879436], 
     Hue[1.0216685979576765`, 1, 0.7606105088083793], 
     Hue[1.028443817919528, 1, 0.7763425673035275], 
     Hue[1.0357103623387771`, 1, 0.7920742594748656], 
     Hue[1.0436134147546257`, 1, 0.8078057215435936], 
     Hue[1.0523843169315257`, 1, 0.8235377702217208], 
     Hue[1.003439675796551, 1, 0.7134154606227091], 
     Hue[0.6765775388567221, 1, 0.22573191663441128`], 
     Hue[0.7240184694658638, 1, 0.4302448086003075], 
     Hue[0.6966587310969501, 1, 0.4459755798424091], 
     Hue[0.6810574357343502, 1, 0.2414642995313054], 
     Hue[0.6855443350198454, 1, 0.25719628044965803`], 
     Hue[0.6900412867344532, 1, 0.2729258630834512], 
     Hue[0.6945533184499594, 1, 0.2886576921423165], 
     Hue[0.699084050907022, 1, 0.3043910984636652], 
     Hue[0.703636515303542, 1, 0.3201229105041991], 
     Hue[0.7082146855939162, 1, 0.33585266970857386`], 
     Hue[0.7128245469777376, 1, 0.35158606977319273`], 
     Hue[0.7174692123579103, 1, 0.3673180983827933], 
     Hue[0.7221537889687748, 1, 0.3830495678852981], 
     Hue[0.72688365244414, 1, 0.39878097885683356`], 
     Hue[0.7316644603389318, 1, 0.41451235795608077`], 
     Hue[0.9377645236294603, 1, 0.77634497504828], 
     Hue[0.9385168214981912, 1, 0.7920786458979612], 
     Hue[0.9395426276556308, 1, 0.8077987984836692], 
     Hue[0.9408363712187183, 1, 0.8235319571691236], 
     Hue[0.736501000331738, 1, 0.43023930782529485`], 
     Hue[0.741405313732117, 1, 0.44597890103504245`], 
     Hue[0.7463791513678468, 1, 0.4617127075225057], 
     Hue[0.7514304677212793, 1, 0.47743993172555665`], 
     Hue[0.7565699299189138, 1, 0.4931650359809928], 
     Hue[0.7618149306532659, 1, 0.5089085285661771], 
     Hue[0.7671647494014895, 1, 0.5246321331205802], 
     Hue[0.7726426523037484, 1, 0.5403637089593638], 
     Hue[0.7782615895113131, 1, 0.5560935799755923], 
     Hue[0.7840424138660879, 1, 0.5718262950192392], 
     Hue[0.7900076588060186, 1, 0.5875603075484895], 
     Hue[0.7961845911542133, 1, 0.6032935005084925], 
     Hue[0.8026074510940722, 1, 0.619024589156666], 
     Hue[0.8093230276935899, 1, 0.634759932448016], 
     Hue[0.8163842476190872, 1, 0.6504891329175019], 
     Hue[0.8238725080448548, 1, 0.6662217756821018], 
     Hue[0.831892278364399, 1, 0.68195042849509], 
     Hue[0.8406065952206816, 1, 0.6976818014208879], 
     Hue[0.850268199467774, 1, 0.7134127331898891], 
     Hue[0.8613336403212092, 1, 0.7291478654223763], 
     Hue[0.8747722430300193, 1, 0.7448781072885418], 
     Hue[0.89379982292561, 1, 0.7606108989297655], 
     Hue[0.9828699229699775, 1, 0.7291466574340547], 
     Hue[0.969429317660027, 1, 0.7448792199066193], 
     Hue[0.9504035519129345, 1, 0.760610442629309], 
     Hue[0.9939327411349186, 1, 0.7134153400831104], 
     Hue[0.9768777389998099, 1, 0.22573129622144877`], 
     Hue[0.9353292902644448, 1, 0.35158601397087785`], 
     Hue[0.8631493209140542, 1, 0.36731725605005844`], 
     Hue[0.8186716723540705, 1, 0.38304874407063816`], 
     Hue[0.7832913709965214, 1, 0.3987804770895528], 
     Hue[0.7524482560971986, 1, 0.4145124371745843], 
     Hue[0.9776358134267975, 1, 0.2414638505488775], 
     Hue[0.9783938669553748, 1, 0.2571952573684181], 
     Hue[0.979151944507047, 1, 0.27292609199600926`], 
     Hue[0.9799101706587812, 1, 0.28865858213974127`], 
     Hue[0.9806684748159181, 1, 0.30439090527114365`], 
     Hue[0.9814268584157794, 1, 0.32012273345730685`], 
     Hue[0.9821853374920144, 1, 0.3358540412833491], 
     Hue[0.9832388588036851, 1, 0.57182895063469], 
     Hue[0.9677983365194598, 1, 0.5875625536773199], 
     Hue[0.9590112176341585, 1, 0.603293648262536], 
     Hue[0.9528560778694878, 1, 0.6190262420245595], 
     Hue[0.9482830889356594, 1, 0.6347556356172418], 
     Hue[0.9448129332822004, 1, 0.6504878738527727], 
     Hue[0.9421786018869984, 1, 0.6662189620875845], 
     Hue[0.9402106226488656, 1, 0.6819505713027009], 
     Hue[0.938794194930062, 1, 0.6976837426132335], 
     Hue[0.9378478998936923, 1, 0.7134146764817054], 
     Hue[0.9373114119524725, 1, 0.729147465013254], 
     Hue[0.9371398878444626, 1, 0.7448788854837494], 
     Hue[0.9372993545236433, 1, 0.7606104946216335], 
     Hue[0.9829438471420266, 1, 0.3515831247140401], 
     Hue[0.9837026630527417, 1, 0.3673153411972898], 
     Hue[0.9844617313310909, 1, 0.3830492120465476], 
     Hue[0.9852208840829874, 1, 0.39878089686393586`], 
     Hue[0.9859802489747376, 1, 0.4145126808352455], 
     Hue[0.9867398049552458, 1, 0.4302437661617454], 
     Hue[0.987499548887765, 1, 0.44597372596731555`], 
     Hue[0.9882596580003725, 1, 0.4617058654222935], 
     Hue[0.9890201488443826, 1, 0.47744016004815104`], 
     Hue[0.9897807316227212, 1, 0.4931702494069554], 
     Hue[0.9905417935209178, 1, 0.5089037746064625], 
     Hue[0.9913030364812044, 1, 0.5246342055866089], 
     Hue[0.9920647309486315, 1, 0.5403667621040414], 
     Hue[0.9928267457091615, 1, 0.5560983624692727], 
     Hue[0.9948112859955761, 1, 0.6819519985275814], 
     Hue[0.991205861833735, 1, 0.69768314310209], 
     Hue[0.9913799066581561, 1, 0.713415468157835], 
     Hue[0.9935891347523301, 1, 0.5718297500261619], 
     Hue[0.9943520229154578, 1, 0.5875631257103117], 
     Hue[0.9951151583981009, 1, 0.6032929226998532], 
     Hue[0.99587877369909, 1, 0.6190235588421225], 
     Hue[0.9966429551346454, 1, 0.6347564311288894], 
     Hue[0.9974075481325705, 1, 0.6504879761725361], 
     Hue[0.9981726626036305, 1, 0.6662200739891252], 
     Hue[0.9989382546480002, 1, 0.681951438070574], 
     Hue[0.9997044232962083, 1, 0.6976837170457088], 
     Hue[1.2751570314189118`, 1, 0.22573177706494815`], 
     Hue[1.064665455379288, 1, 0.35158529475834244`], 
     Hue[1.1368526094480662`, 1, 0.36731783764431836`], 
     Hue[1.1813299938349568`, 1, 0.38304941987841246`], 
     Hue[1.21670935382147, 1, 0.3987808263678736], 
     Hue[1.270171199280833, 1, 0.24146296058942415`], 
     Hue[1.2651748383857802`, 1, 0.2571963810125073], 
     Hue[1.260164207449204, 1, 0.27292801385784876`], 
     Hue[1.2551336110692586`, 1, 0.2886595705058157], 
     Hue[1.2500781795977045`, 1, 0.3043896016415425], 
     Hue[1.2449911828835494`, 1, 0.3201216936348951], 
     Hue[1.2398676739576748`, 1, 0.335852959744578], 
     Hue[1.2347009569267244`, 1, 0.3515847789830701], 
     Hue[1.2294840899269417`, 1, 0.36731786388559545`], 
     Hue[1.2242109416608178`, 1, 0.38304886395036053`], 
     Hue[1.2188725937586387`, 1, 0.3987808147546174], 
     Hue[1.016761722892877, 1, 0.5718293262192868], 
     Hue[1.0322016141943355`, 1, 0.5875624820728867], 
     Hue[1.0409889435321835`, 1, 0.6032939999890652], 
     Hue[1.0471437897394746`, 1, 0.619025845844645], 
     Hue[1.0517173663627448`, 1, 0.6347574419598518], 
     Hue[1.0551870078410417`, 1, 0.6504875669388003], 
     Hue[1.057821549171141, 1, 0.6662200050597203], 
     Hue[1.0597894708316353`, 1, 0.68195144861918], 
     Hue[1.0612058110223255`, 1, 0.6976838226647004], 
     Hue[1.2134625781899624`, 1, 0.41450722353682945`], 
     Hue[1.2079672803265553`, 1, 0.4302395488291718], 
     Hue[1.2023772452067076`, 1, 0.4459736179108717], 
     Hue[1.1966813782392616`, 1, 0.46170604873028975`], 
     Hue[1.1908650486394925`, 1, 0.47743841495935724`], 
     Hue[1.184912134433651, 1, 0.49317024221091155`], 
     Hue[1.17880357230382, 1, 0.5089014253088384], 
     Hue[1.1725166264013802`, 1, 0.5246320278502269], 
     Hue[1.166021689174575, 1, 0.5403672485115485], 
     Hue[1.159288537532614, 1, 0.5560985193405018], 
     Hue[1.152273880532689, 1, 0.571828365974436], 
     Hue[1.1449200397639798`, 1, 0.5875637468079403], 
     Hue[1.137160530910787, 1, 0.6032926605833292], 
     Hue[1.128890550002593, 1, 0.619026540166732], 
     Hue[1.1199723022232673`, 1, 0.6347552348227877], 
     Hue[1.110180669706988, 1, 0.6504869318670856], 
     Hue[1.099142461899472, 1, 0.666220127615714], 
     Hue[1.0861233015393486`, 1, 0.6819522493998729], 
     Hue[1.0691835456741743`, 1, 0.6976835601677397], 
     Hue[1.0051888097714194`, 1, 0.6819521966690296], 
     Hue[1.0087941702215137`, 1, 0.6976835315202959], 
     Hue[0.586714887365898, 1, 0.22573193232017727`], 
     Hue[1.247555046703215, 1, 0.41451420614679907`], 
     Hue[1.275984720861097, 1, 0.4302466204073039], 
     Hue[1.3033421751725922`, 1, 0.44597610391909137`], 
     Hue[1.3307669103812827`, 1, 0.46170693964696197`], 
     Hue[1.359568541120923, 1, 0.47743802850897765`], 
     Hue[0.5892737305272646, 1, 0.24146313123616372`], 
     Hue[0.5918342374437644, 1, 0.2571964169415143], 
     Hue[0.5943964848726233, 1, 0.27292816851281043`], 
     Hue[0.5969612248184812, 1, 0.2886588891891051], 
     Hue[0.5995293790949718, 1, 0.3043900828220795], 
     Hue[0.6021015598939883, 1, 0.3201213044552088], 
     Hue[0.6046784189860595, 1, 0.3358522947209961], 
     Hue[0.6072610468720863, 1, 0.35158539708861325`], 
     Hue[0.6098495531832213, 1, 0.36731689827220204`], 
     Hue[0.6124451474324857, 1, 0.38304968860273214`], 
     Hue[0.6150481618791359, 1, 0.3987812286791536], 
     Hue[0.6176594187670044, 1, 0.41451184151515885`], 
     Hue[0.6202800770959924, 1, 0.4302437360094308], 
     Hue[0.622910679314411, 1, 0.44597526453294245`], 
     Hue[0.6255522145621706, 1, 0.46170730094532897`], 
     Hue[0.6282055036625974, 1, 0.4774395332346175], 
     Hue[1.0621523293827013`, 1, 0.7134195988522849], 
     Hue[1.062688613833981, 1, 0.729148632401909], 
     Hue[1.0628601124385908`, 1, 0.7448828889065889], 
     Hue[1.0627005663372842`, 1, 0.7606144354669301], 
     Hue[1.0622354929221967`, 1, 0.7763445490363826], 
     Hue[1.061483134606993, 1, 0.7920794208316251], 
     Hue[1.060457202428217, 1, 0.8078011011891427], 
     Hue[1.0591631113349411`, 1, 0.8235376651671866], 
     Hue[1.0576040319572402`, 1, 0.8392720125181843], 
     Hue[1.055777380494901, 1, 0.8549986632485105], 
     Hue[1.0536725194594518`, 1, 0.8707278261841885], 
     Hue[1.0512716416551482`, 1, 0.8864622946475825], 
     Hue[1.048548457430511, 1, 0.9021944564378453], 
     Hue[1.0454608504684448`, 1, 0.9179260702927765], 
     Hue[0.6308724677300412, 1, 0.49317793917127517`], 
     Hue[0.633550490348812, 1, 0.508901589007308], 
     Hue[0.6362449176789018, 1, 0.5246361421199383], 
     Hue[0.6389538600213822, 1, 0.5403645439417201], 
     Hue[0.6416811706525625, 1, 0.5561029013123059], 
     Hue[0.6444227899014774, 1, 0.5718213890385342], 
     Hue[0.6471851830209656, 1, 0.5875503803835171], 
     Hue[0.649971477813313, 1, 0.6033002378809901], 
     Hue[0.6527750830714389, 1, 0.6190262703112953], 
     Hue[0.6556003933230853, 1, 0.6347456394256602], 
     Hue[0.6584530312842938, 1, 0.6504812419687307], 
     Hue[0.6613338412243548, 1, 0.6662286216994402], 
     Hue[0.6642379687502638, 1, 0.6819521568463831], 
     Hue[0.6671730854477333, 1, 0.6976837943002895], 
     Hue[0.670141543508856, 1, 0.7134254195232544], 
     Hue[0.6731394666435824, 1, 0.7291455392951764], 
     Hue[0.6761765881861656, 1, 0.7448833550506648], 
     Hue[0.6792496760719562, 1, 0.7606092720495621], 
     Hue[0.6823625393769852, 1, 0.7763294270059099], 
     Hue[0.6855268719175713, 1, 0.7920874303930502], 
     Hue[0.6887327333171638, 1, 0.8078175756616611], 
     Hue[0.6919847771559247, 1, 0.8235264751651106], 
     Hue[0.6952959550855462, 1, 0.8392578030040555], 
     Hue[0.6986721468515461, 1, 0.8550175343291215], 
     Hue[0.7021031467874318, 1, 0.8707357121144569], 
     Hue[0.7056028487741368, 1, 0.8864522435947263], 
     Hue[0.7091859240047367, 1, 0.9022042766694439], 
     Hue[0.7128419129786361, 1, 0.9179151968592622], 
     Hue[1.0086201864042645`, 1, 0.7134145695048711], 
     Hue[0.9951735594790361, 1, 0.7291463019004929], 
     Hue[0.9921372426924748, 1, 0.7448799638607447], 
     Hue[0.9890631257848141, 1, 0.7606111559939379], 
     Hue[0.9859482863474883, 1, 0.7763411969183898], 
     Hue[0.9827888270831256, 1, 0.7920749392045769], 
     Hue[0.9795830275271538, 1, 0.8078049719961921], 
     Hue[0.9763259312918489, 1, 0.8235382809449221], 
     Hue[0.9730148282617572, 1, 0.8392690558449983], 
     Hue[0.9696447997909029, 1, 0.8550000773008514], 
     Hue[0.9662107963976725, 1, 0.8707322152078139], 
     Hue[0.9627075830409443, 1, 0.8864644239067067], 
     Hue[0.9591291594043105, 1, 0.9021959682512377], 
     Hue[0.9554682542691871, 1, 0.9179279584277088], 
     Hue[0.9981735246243872, 1, 0.7134154218466219], 
     Hue[0.8914521455488982, 1, 0.225731583579329], 
     Hue[0.8631497878047906, 1, 0.3673171153829673], 
     Hue[0.8186729654597312, 1, 0.3830482195901906], 
     Hue[0.7832908064719215, 1, 0.39878074912493516`], 
     Hue[0.7524467524545335, 1, 0.4145132425201167], 
     Hue[0.72401867840473, 1, 0.4302446899428711], 
     Hue[0.696657611794395, 1, 0.4459762271116129], 
     Hue[0.6692310692894056, 1, 0.4617080805773076], 
     Hue[0.6404294720938739, 1, 0.47743906742359554`], 
     Hue[0.8947307209232843, 1, 0.24146339475842915`], 
     Hue[0.8980122513359036, 1, 0.2571960140352772], 
     Hue[0.901297766527147, 1, 0.2729276349327464], 
     Hue[0.9045889543851239, 1, 0.28865952827827], 
     Hue[0.9078868501679087, 1, 0.30438974232023575`], 
     Hue[0.9111938253591167, 1, 0.32012256250167875`], 
     Hue[0.9145104721240718, 1, 0.3358536369269981], 
     Hue[0.9178388476156764, 1, 0.35158539088511037`], 
     Hue[0.9677998876872445, 1, 0.5875603001733811], 
     Hue[0.9590106012599247, 1, 0.6032949934412887], 
     Hue[0.9528570020726737, 1, 0.619023476409497], 
     Hue[0.94828256126496, 1, 0.6347577290936229], 
     Hue[0.9448126926858161, 1, 0.6504891280556147], 
     Hue[0.9421788236492169, 1, 0.6662174309796488], 
     Hue[0.9402105828511461, 1, 0.6819509448031814], 
     Hue[0.9387943122741593, 1, 0.6976821645289573], 
     Hue[0.9378477498371557, 1, 0.7134178979717224], 
     Hue[0.9373114679736085, 1, 0.729144929171064], 
     Hue[0.9371398878927782, 1, 0.7448782308981307], 
     Hue[0.937299330280507, 1, 0.7606092872086269], 
     Hue[0.9377644732035444, 1, 0.7763436771528919], 
     Hue[0.9385164594453246, 1, 0.7920722536486167], 
     Hue[0.9395431853405428, 1, 0.8078063559454354], 
     Hue[0.9408369313548645, 1, 0.8235381360651909], 
     Hue[0.9423956877090673, 1, 0.8392694060483314], 
     Hue[0.9442228557748416, 1, 0.8550005557252871], 
     Hue[0.9463281263839607, 1, 0.8707323433674677], 
     Hue[0.9487287599917376, 1, 0.886464766482536], 
     Hue[0.951451797112435, 1, 0.9021958387533852], 
     Hue[0.9545395296300938, 1, 0.9179278883963949], 
     Hue[0.9211806283711292, 1, 0.36731820229695816`], 
     Hue[0.924536505989917, 1, 0.383047576118161], 
     Hue[0.9279094464873883, 1, 0.39877939136279256`], 
     Hue[0.9313004337857759, 1, 0.41450990052266334`], 
     Hue[0.9347126262207744, 1, 0.43024505636381166`], 
     Hue[0.9381461253746146, 1, 0.44597627015746516`], 
     Hue[0.941604253838997, 1, 0.4617093046946056], 
     Hue[0.9450881816015266, 1, 0.4774395340818324], 
     Hue[0.9486009771088255, 1, 0.49317033934696497`], 
     Hue[0.9521450803566055, 1, 0.5089015309787013], 
     Hue[0.9557233576309824, 1, 0.5246340230702113], 
     Hue[0.9593383149593107, 1, 0.5403662681561608], 
     Hue[0.9629930490677261, 1, 0.55609833912183], 
     Hue[0.9666907194432852, 1, 0.5718294757403022], 
     Hue[0.991205764584177, 1, 0.6976843215629757], 
     Hue[0.9913798402467274, 1, 0.7134148268689995], 
     Hue[0.9704358299916317, 1, 0.5875633284163525], 
     Hue[0.9742302201680386, 1, 0.6032909762237386], 
     Hue[0.9780809496472732, 1, 0.6190235704085911], 
     Hue[0.9819921083012635, 1, 0.6347579138027151], 
     Hue[0.9859676211566275, 1, 0.6504882301890473], 
     Hue[0.990014759748388, 1, 0.6662195978826575], 
     Hue[0.9941402502451584, 1, 0.681951844423377], 
     Hue[0.9983514288234685, 1, 0.6976837428190237], 
     Hue[1.1874526414798734`, 1, 0.22573158770474386`], 
     Hue[1.136852760229183, 1, 0.3673178830731762], 
     Hue[1.1827073199657858`, 1, 0.2414642356389907], 
     Hue[1.1779536913562971`, 1, 0.25719637433311515`], 
     Hue[1.173187439280137, 1, 0.272928009671825], 
     Hue[1.1684045837660018`, 1, 0.28865770319623785`], 
     Hue[1.1635991616274435`, 1, 0.3043900569843239], 
     Hue[1.158767375954978, 1, 0.32012194288626167`], 
     Hue[1.153903998244115, 1, 0.33585417231089854`], 
     Hue[1.1490042219196488`, 1, 0.3515852773702048], 
     Hue[1.1440618402789264`, 1, 0.36731718876892727`], 
     Hue[1.032200919476577, 1, 0.5875614727839569], 
     Hue[1.0409884829073102`, 1, 0.6032929947368436], 
     Hue[1.0471435193315568`, 1, 0.6190250366585904], 
     Hue[1.1390716471145383`, 1, 0.38304733386679274`], 
     Hue[1.1340264856414715`, 1, 0.39877776483488003`], 
     Hue[1.128918502245773, 1, 0.4145107647839452], 
     Hue[1.1237412719138196`, 1, 0.43024203580287856`], 
     Hue[1.118483671203733, 1, 0.4459789420413963], 
     Hue[1.113139823610242, 1, 0.4617100394476552], 
     Hue[1.1076971136237888`, 1, 0.4774403876646339], 
     Hue[1.1021422449589697`, 1, 0.49317229799195095`], 
     Hue[1.0964612121323276`, 1, 0.5089046132031267], 
     Hue[1.090638773218216, 1, 0.5246332114561162], 
     Hue[1.0846515109080384`, 1, 0.5403677672399769], 
     Hue[1.0784790081653275`, 1, 0.5560995022641572], 
     Hue[1.0720918065695506`, 1, 0.571830172346683], 
     Hue[1.0654538313170938`, 1, 0.5875606758564997], 
     Hue[1.0585187189219691`, 1, 0.603293472843104], 
     Hue[1.051229109495055, 1, 0.6190250726252369], 
     Hue[1.043506085898572, 1, 0.6347553933962145], 
     Hue[1.0352371927112833`, 1, 0.6504881368972742], 
     Hue[1.0262606208315939`, 1, 0.6662203372202266], 
     Hue[1.0163166653036397`, 1, 0.6819521341039004], 
     Hue[1.0049437561291283`, 1, 0.6976835482692552], 
     Hue[1.4960911684509246`, 1, 0.22573145580936332`], 
     Hue[1.1813262510636189`, 1, 0.3830479018158659], 
     Hue[1.2167065566745219`, 1, 0.39877947847275563`], 
     Hue[1.2475534446715806`, 1, 0.4145133481003904], 
     Hue[1.2759817801309958`, 1, 0.430244950347668], 
     Hue[1.3033395607244616`, 1, 0.44597459203844114`], 
     Hue[1.3307699922887382`, 1, 0.46170868007539256`], 
     Hue[1.3595710762838822`, 1, 0.47743935417577354`], 
     Hue[1.3919614542775542`, 1, 0.4931719569122729], 
     Hue[1.4342456760678755`, 1, 0.508902869222674], 
     Hue[1.4959704829416336`, 1, 0.24146316842531948`], 
     Hue[1.4958497838818854`, 1, 0.25719662928862064`], 
     Hue[1.4957291055808268`, 1, 0.2729273570617793], 
     Hue[1.495608413339219, 1, 0.2886598658357532], 
     Hue[1.4954877403463405`, 1, 0.30438982027058853`], 
     Hue[1.495367041224772, 1, 0.32012312634851736`], 
     Hue[1.4952463742553719`, 1, 0.33585217803521106`], 
     Hue[1.4951256790888259`, 1, 0.35158483287694897`], 
     Hue[1.495004982027509, 1, 0.3673176532759776], 
     Hue[1.4948843017433386`, 1, 0.3830481963236537], 
     Hue[1.4947635935103174`, 1, 0.3987822829435937], 
     Hue[1.4946429141648552`, 1, 0.41451249557409875`], 
     Hue[1.494522227661777, 1, 0.4302435235858294], 
     Hue[1.4944015327383653`, 1, 0.44597552249985856`], 
     Hue[1.4942808291615388`, 1, 0.4617085136220366], 
     Hue[1.4941601453670574`, 1, 0.47743878149323826`], 
     Hue[1.4940394419081446`, 1, 0.4931714586703866], 
     Hue[1.4939187488447223`, 1, 0.5089026180315388], 
     Hue[1.051716747325344, 1, 0.6347549860160383], 
     Hue[1.0551866337449656`, 1, 0.6504856168814739], 
     Hue[1.0578219491847567`, 1, 0.6662227670275283], 
     Hue[1.0597891414059244`, 1, 0.6819483570231759], 
     Hue[1.0612055608728819`, 1, 0.697680458637466], 
     Hue[1.0621522687266787`, 1, 0.7134182965351309], 
     Hue[1.0626885554431358`, 1, 0.7291459890969256], 
     Hue[1.0628601121899997`, 1, 0.7448793571847402], 
     Hue[1.062700685700822, 1, 0.7606084912203909], 
     Hue[1.062235616093694, 1, 0.776341378638648], 
     Hue[1.0614834684792596`, 1, 0.7920735262447671], 
     Hue[1.0604567497686477`, 1, 0.807807235258448], 
     Hue[1.059163141174956, 1, 0.8235373360096857], 
     Hue[1.0576045642478973`, 1, 0.8392670633595694], 
     Hue[1.0557767304147756`, 1, 0.8550038701921586], 
     Hue[1.053671974941496, 1, 0.8707316346842203], 
     Hue[1.0512711364846326`, 1, 0.8864654035848183], 
     Hue[1.0485482064304548`, 1, 0.9021958195135471], 
     Hue[1.045460402356066, 1, 0.9179282137202388], 
     Hue[1.0419439404268367`, 1, 0.9336589485996404], 
     Hue[1.0378951563498628`, 1, 0.9493907809249653], 
     Hue[1.0331362597090918`, 1, 0.9651241954554959], 
     Hue[1.027319345772865, 1, 0.9808544523020143], 
     Hue[1.0195425360952286`, 1, 0.9965860534251414], 
     Hue[1.493798153887862, 1, 0.5246208184833306], 
     Hue[1.4936772375190173`, 1, 0.5403807300161284], 
     Hue[1.493556719188815, 1, 0.5560885725251254], 
     Hue[1.4934358675946064`, 1, 0.5718396519528064], 
     Hue[1.4933151493812473`, 1, 0.5875731390290505], 
     Hue[1.4931944729894429`, 1, 0.6033009582949039], 
     Hue[1.4930736735837595`, 1, 0.6190445835620411], 
     Hue[1.4929531544115107`, 1, 0.634751451560195], 
     Hue[1.4928323359045472`, 1, 0.6504970863926712], 
     Hue[1.4927115498625492`, 1, 0.6662382364960409], 
     Hue[1.4925911508386074`, 1, 0.6819286878987526], 
     Hue[1.492470378562724, 1, 0.69766751031135], 
     Hue[1.4923495007698735`, 1, 0.713419802318075], 
     Hue[1.4922288032501887`, 1, 0.729148312137328], 
     Hue[1.4921081662710132`, 1, 0.7448686343690969], 
     Hue[1.4919874268648257`, 1, 0.7606019962668091], 
     Hue[1.491866830394184, 1, 0.7763164161441098], 
     Hue[1.4917456979729584`, 1, 0.7921003461549139], 
     Hue[1.4916251796797226`, 1, 0.8078039187671923], 
     Hue[1.4915045606164363`, 1, 0.8235202785300137], 
     Hue[1.4913835275879062`, 1, 0.8392902227061003], 
     Hue[1.4912627811276582`, 1, 0.8550224659644847], 
     Hue[1.4911419974272782`, 1, 0.8707591898601784], 
     Hue[1.4910213640607728`, 1, 0.8864759471419368], 
     Hue[1.4909004939659003`, 1, 0.9022231568656015], 
     Hue[1.4907801447740352`, 1, 0.917902105593275], 
     Hue[1.4906592943311003`, 1, 0.9336459493854847], 
     Hue[1.4905387000731078`, 1, 0.9493560026689967], 
     Hue[1.4904178881146144`, 1, 0.9650939905840703], 
     Hue[1.4902969936690942`, 1, 0.9808422884179102], 
     Hue[1.4901761591162113`, 1, 0.9965823399052612], 
     Hue[1.0087941518133487`, 1, 0.6976833084629165], 
     Hue[1.008620162136722, 1, 0.7134148038527605], 
     Hue[1.004763420435015, 1, 0.7291468572002161], 
     Hue[1.0003156238676671`, 1, 0.744879879733201], 
     Hue[1.0004363492537958`, 1, 0.760611414494113], 
     Hue[1.0005570726090058`, 1, 0.7763423678048943], 
     Hue[1.0006778102909444`, 1, 0.7920748620603906], 
     Hue[1.0007985492992557`, 1, 0.8078071941566893], 
     Hue[1.0009192610079556`, 1, 0.8235356251764693], 
     Hue[1.0010400137049074`, 1, 0.8392690437433141], 
     Hue[1.001160757637228, 1, 0.8550009581316595], 
     Hue[1.0012815089655942`, 1, 0.8707334648914363], 
     Hue[1.0014022560653812`, 1, 0.8864650403980527], 
     Hue[1.0015230089350677`, 1, 0.9021969782434333], 
     Hue[1.0016437488336654`, 1, 0.9179268277929518], 
     Hue[1.0017645163993212`, 1, 0.9336598742060934], 
     Hue[1.0018852824202473`, 1, 0.9493923027144376], 
     Hue[1.0020060353844207`, 1, 0.9651226046430293], 
     Hue[1.002126803574817, 1, 0.9808544553024058], 
     Hue[1.0022475797165995`, 1, 0.9965868978528917], 
     Hue[1.000074167982337, 1, 0.7134152296727005], 
     Hue[1.0001948901497282`, 1, 0.7291469514748413], 
     Hue[0.8050516081229855, 1, 0.22573207976005963`], 
     Hue[0.8186690338351764, 1, 0.3830498142592187], 
     Hue[0.783290915310404, 1, 0.3987806966773608], 
     Hue[0.7524452660804647, 1, 0.41451403861990366`], 
     Hue[0.7240209224812544, 1, 0.4302434155226293], 
     Hue[0.6966606318917319, 1, 0.4459744806525158], 
     Hue[0.6692296318624532, 1, 0.4617088923257744], 
     Hue[0.6404267348945379, 1, 0.4774404987265096], 
     Hue[0.6080417336343782, 1, 0.4931705447614356], 
     Hue[0.5657534812303933, 1, 0.5089031166849738], 
     Hue[0.809876931700033, 1, 0.2414627186828279], 
     Hue[0.8147116399703029, 1, 0.25719493957137707`], 
     Hue[0.819559851934462, 1, 0.27292735813276714`], 
     Hue[0.8244255328062122, 1, 0.28865774095183927`], 
     Hue[0.8293146957669595, 1, 0.3043899714698707], 
     Hue[0.8342319352968125, 1, 0.32012268111261327`], 
     Hue[0.8391817917895871, 1, 0.33585355707526143`], 
     Hue[0.8441706276521244, 1, 0.3515851057291407], 
     Hue[0.8492044162389405, 1, 0.3673173693806424], 
     Hue[0.948282231930809, 1, 0.6347590357299662], 
     Hue[0.9448123492511584, 1, 0.6504909183907432], 
     Hue[0.9421782067254273, 1, 0.6662216905001415], 
     Hue[0.9402103219417113, 1, 0.6819533935028408], 
     Hue[0.9387940882846536, 1, 0.6976851768727734], 
     Hue[0.9378480351209847, 1, 0.7134117736685507], 
     Hue[0.9373114183760173, 1, 0.7291471742245502], 
     Hue[0.9371398878443067, 1, 0.7448788876087634], 
     Hue[0.9372993712434063, 1, 0.7606113272859866], 
     Hue[0.9377644371627825, 1, 0.7763427494812883], 
     Hue[0.9385167382644214, 1, 0.7920771764291006], 
     Hue[0.9395428948794485, 1, 0.8078024198687733], 
     Hue[0.9408366080220536, 1, 0.8235345694161333], 
     Hue[0.9423956050605012, 1, 0.83926863759038], 
     Hue[0.9442231065867301, 1, 0.8550025646467698], 
     Hue[0.9463280602537213, 1, 0.8707318808445607], 
     Hue[0.9487289622465525, 1, 0.8864660111905438], 
     Hue[0.9514521903055164, 1, 0.9021979739895288], 
     Hue[0.9545399010819982, 1, 0.9179296651147699], 
     Hue[0.9580562854189583, 1, 0.9336598932613129], 
     Hue[0.9621054895547576, 1, 0.9493931089338375], 
     Hue[0.9668629108400628, 1, 0.9651216889371377], 
     Hue[0.9726804743815516, 1, 0.9808540207572245], 
     Hue[0.9804578638915189, 1, 0.996586717215287], 
     Hue[0.8542883541734884, 1, 0.38304659594838875`], 
     Hue[0.8594310638492015, 1, 0.3987779634169999], 
     Hue[0.8646408042564654, 1, 0.41451334675190143`], 
     Hue[0.8699233501055836, 1, 0.4302448197272334], 
     Hue[0.87528841844916, 1, 0.4459736276509844], 
     Hue[0.8807495229196305, 1, 0.46170851299584414`], 
     Hue[0.8863152579100265, 1, 0.4774398456747202], 
     Hue[0.8919997172545199, 1, 0.49316904148897023`], 
     Hue[0.8978217074652929, 1, 0.5089042221075278], 
     Hue[0.9037949694024217, 1, 0.5246324070161724], 
     Hue[0.9099465026771971, 1, 0.5403666028297543], 
     Hue[0.9162998321784736, 1, 0.5560986565078906], 
     Hue[0.9228884618832569, 1, 0.5718305787243322], 
     Hue[0.9297530120059432, 1, 0.5875614455359927], 
     Hue[0.936947332148194, 1, 0.6032938448847435], 
     Hue[0.9445396562864546, 1, 0.6190245742321021], 
     Hue[0.9912057719789047, 1, 0.6976842319466594], 
     Hue[0.9913798420892179, 1, 0.713414844661321], 
     Hue[0.9952367235394356, 1, 0.7291471471247322], 
     Hue[0.9526279409228088, 1, 0.6347582756131878], 
     Hue[0.9613457150303368, 1, 0.6504872265340268], 
     Hue[0.9709084465866826, 1, 0.666219459420368], 
     Hue[0.9816697300034402, 1, 0.6819518936301447], 
     Hue[0.9943203919334679, 1, 0.6976835850065342], 
     Hue[1.1011593411355527`, 1, 0.2257321754540228], 
     Hue[0.8631502124762287, 1, 0.36731698743635643`], 
     Hue[1.0980689054723378`, 1, 0.24146392482085083`], 
     Hue[1.094976321039234, 1, 0.25719473556538036`], 
     Hue[1.091880123682678, 1, 0.272926071359419], 
     Hue[1.0887789194793287`, 1, 0.28865897113001204`], 
     Hue[1.0856720890039282`, 1, 0.3043904644497987], 
     Hue[1.082558225651758, 1, 0.32012147470789487`], 
     Hue[1.0794356992188225`, 1, 0.3358539166664677], 
     Hue[1.076303720739246, 1, 0.3515853129228308], 
     Hue[0.9678000222150323, 1, 0.5875601047418115], 
     Hue[0.9590114560774072, 1, 0.6032931278932658], 
     Hue[0.952856515287352, 1, 0.619024933063622], 
     Hue[1.0731600998156086`, 1, 0.36732004565210863`], 
     Hue[1.0700055402696458`, 1, 0.3830478267121113], 
     Hue[1.066836798393599, 1, 0.3987778673623628], 
     Hue[1.0636522150632561`, 1, 0.41451114547329965`], 
     Hue[1.0604511257221363`, 1, 0.4302434440800046], 
     Hue[1.0572318086402541`, 1, 0.44597545845273256`], 
     Hue[1.0539921666019665`, 1, 0.46170931894943834`], 
     Hue[1.050731871059898, 1, 0.47743818438589114`], 
     Hue[1.0474475488765205`, 1, 0.4931694802844736], 
     Hue[1.0441373716087514`, 1, 0.50890259001079], 
     Hue[1.0408001343810513`, 1, 0.5246334126286992], 
     Hue[1.0374325817151877`, 1, 0.5403668901606956], 
     Hue[1.0340334632254913`, 1, 0.5560978373607357], 
     Hue[1.0305994168915786`, 1, 0.5718301016227888], 
     Hue[1.0271277484720747`, 1, 0.5875634715972722], 
     Hue[1.0236166743979322`, 1, 0.6032926842064525], 
     Hue[1.0200616244467378`, 1, 0.6190238623429801], 
     Hue[1.0164591729273464`, 1, 0.6347565874222707], 
     Hue[1.012805895471637, 1, 0.6504890062964798], 
     Hue[1.009097875933952, 1, 0.6662197995361323], 
     Hue[1.0053297323047292`, 1, 0.6819519322742545], 
     Hue[1.0014967068718807`, 1, 0.6976834853926043], 
     Hue[1.4055034442852241`, 1, 0.2257313137231234], 
     Hue[1.1368531849024037`, 1, 0.36731801102330186`], 
     Hue[1.1813311080709257`, 1, 0.38304987181707084`], 
     Hue[1.216711120766226, 1, 0.3987816778349484], 
     Hue[1.2475503619548534`, 1, 0.41451169701121676`], 
     Hue[1.2759791699086973`, 1, 0.43024346799118374`], 
     Hue[1.3033412072508916`, 1, 0.44597554419025687`], 
     Hue[1.3307687957637804`, 1, 0.46170800436959814`], 
     Hue[1.3595712621347926`, 1, 0.47743945135892896`], 
     Hue[1.402738958918086, 1, 0.24146250363973104`], 
     Hue[1.3999724289426845`, 1, 0.2571958243278854], 
     Hue[1.3972039006802335`, 1, 0.27292623260353593`], 
     Hue[1.394431523184235, 1, 0.28865942927016874`], 
     Hue[1.3916552587563842`, 1, 0.30439076440649937`], 
     Hue[1.388873657188438, 1, 0.32012353477363176`], 
     Hue[1.3860864951962264`, 1, 0.33585401371977336`], 
     Hue[1.383292408585116, 1, 0.351584830796281], 
     Hue[1.3804900444920243`, 1, 0.36731841551205946`], 
     Hue[1.37767931343549, 1, 0.3830499794254393], 
     Hue[1.374858916385499, 1, 0.39878138843821376`], 
     Hue[1.372027955595993, 1, 0.41451209674742706`], 
     Hue[1.369185167922672, 1, 0.43024340555223545`], 
     Hue[1.3663293950453097`, 1, 0.4459758163984292], 
     Hue[1.3634597495774388`, 1, 0.46170811478800255`], 
     Hue[1.3605752530575659`, 1, 0.4774393581915871], 
     Hue[1.0322010540033975`, 1, 0.5875616682225804], 
     Hue[1.0409882629947043`, 1, 0.603292514814814], 
     Hue[1.047142971854109, 1, 0.6190233983892395], 
     Hue[1.051717042758632, 1, 0.6347561580929285], 
     Hue[1.0551871212649453`, 1, 0.6504881581987186], 
     Hue[1.0578218259923242`, 1, 0.6662219164076342], 
     Hue[1.0597894706338695`, 1, 0.6819514467631261], 
     Hue[1.0612058412810983`, 1, 0.6976842296063162], 
     Hue[1.0621521992793097`, 1, 0.7134168055369088], 
     Hue[1.0626885598345315`, 1, 0.7291461878755777], 
     Hue[1.0628601120552417`, 1, 0.7448775351611454], 
     Hue[1.0627006513961172`, 1, 0.7606101998002222], 
     Hue[1.0622355594132262`, 1, 0.7763428376142539], 
     Hue[1.0614833713912049`, 1, 0.792075240425341], 
     Hue[1.0604568116387345`, 1, 0.8078063968784569], 
     Hue[1.0591631479889148`, 1, 0.8235372608464862], 
     Hue[1.0576043452917987`, 1, 0.8392690992103535], 
     Hue[1.0557771205363662`, 1, 0.8550007454663416], 
     Hue[1.0536718064302366`, 1, 0.8707328132712883], 
     Hue[1.051271358304245, 1, 0.8864640384646755], 
     Hue[1.048548106382126, 1, 0.9021963628298048], 
     Hue[1.3576763582974083`, 1, 0.4931606139330744], 
     Hue[1.3547580641469665`, 1, 0.5088921805838962], 
     Hue[1.351818237699319, 1, 0.5246382033878481], 
     Hue[1.348863397252773, 1, 0.5403564597801757], 
     Hue[1.345880028092081, 1, 0.5561109354672303], 
     Hue[1.3428818959158935`, 1, 0.5718208458994315], 
     Hue[1.3398520494299977`, 1, 0.587566478666198], 
     Hue[1.336797571471851, 1, 0.6033015986713537], 
     Hue[1.3337145019917478`, 1, 0.6190370899802274], 
     Hue[1.3306035542135588`, 1, 0.63475927324092], 
     Hue[1.3274589373686425`, 1, 0.6504866647095037], 
     Hue[1.3242799027348748`, 1, 0.6662113817029754], 
     Hue[1.3210588493465405`, 1, 0.6819582742063178], 
     Hue[1.3178001781900819`, 1, 0.6976923397901439], 
     Hue[1.3145018070632313`, 1, 0.7134098705508763], 
     Hue[1.3111543250278057`, 1, 0.7291403353564148], 
     Hue[1.3077543376665446`, 1, 0.7448824154296672], 
     Hue[1.304305320981605, 1, 0.7606020696532161], 
     Hue[1.3007962986285322`, 1, 0.7763298168091106], 
     Hue[1.2972229259062689`, 1, 0.792063035968268], 
     Hue[1.2935806385084376`, 1, 0.8077976803864987], 
     Hue[1.2898647129149272`, 1, 0.8235277549621443], 
     Hue[1.2860624150548576`, 1, 0.8392772058420689], 
     Hue[1.282176603848154, 1, 0.8550014425069657], 
     Hue[1.2781944091809891`, 1, 0.8707167307715333], 
     Hue[1.2740944813674198`, 1, 0.8864644009565326], 
     Hue[1.2698801381066023`, 1, 0.9021835895029171], 
     Hue[1.008794159209064, 1, 0.6976833980781176], 
     Hue[1.0086200605098434`, 1, 0.7134157851750469], 
     Hue[1.0053813250965122`, 1, 0.7291469359252066], 
     Hue[1.0087791171083649`, 1, 0.7448788294047269], 
     Hue[1.0122306730462585`, 1, 0.7606100202055801], 
     Hue[1.015740509313062, 1, 0.7763412476504301], 
     Hue[1.0193137481880752`, 1, 0.7920736745435714], 
     Hue[1.022955629073613, 1, 0.8078063732847197], 
     Hue[1.0266715708837668`, 1, 0.8235363352037594], 
     Hue[1.03047009038372, 1, 0.8392701216794384], 
     Hue[1.0343573517418994`, 1, 0.8550003244508216], 
     Hue[1.0383439030161752`, 1, 0.8707326095906477], 
     Hue[1.042439710096241, 1, 0.8864642350459861], 
     Hue[1.0466574505785462`, 1, 0.9021959056656285], 
     Hue[1.0020335451536764`, 1, 0.7134151567902175], 
     Hue[0.7172157114390949, 1, 0.22573218253896685`], 
     Hue[0.7524486823951045, 1, 0.41451220885158124`], 
     Hue[0.7240204666516548, 1, 0.4302436743898074], 
     Hue[0.6966574036859934, 1, 0.4459763474563334], 
     Hue[0.6692279411592494, 1, 0.4617098471027049], 
     Hue[0.6404305352824364, 1, 0.4774385114700669], 
     Hue[0.722150153239653, 1, 0.24146287120354476`], 
     Hue[0.7270949824347979, 1, 0.25719632681538496`], 
     Hue[0.7320537086813217, 1, 0.2729282386277772], 
     Hue[0.7370314871728392, 1, 0.28865914134243303`], 
     Hue[0.7420342096689443, 1, 0.30439132898103466`], 
     Hue[0.7470661427142546, 1, 0.32012127272964913`], 
     Hue[0.7521347448000142, 1, 0.33585453142884425`], 
     Hue[0.7572442003495143, 1, 0.3515853768841569], 
     Hue[0.7624020414380779, 1, 0.3673171479385097], 
     Hue[0.7676148449690234, 1, 0.38304863996530847`], 
     Hue[0.7728904043695239, 1, 0.39878046336679224`], 
     Hue[0.9378478852180356, 1, 0.7134149915299353], 
     Hue[0.9373114009955292, 1, 0.7291479610382449], 
     Hue[0.9371398876190274, 1, 0.7448820488905381], 
     Hue[0.9372993698929533, 1, 0.7606112600333745], 
     Hue[0.9377643087514612, 1, 0.776339444028089], 
     Hue[0.9385166667136772, 1, 0.7920759131870422], 
     Hue[0.9395431213028858, 1, 0.8078054881821259], 
     Hue[0.9408366913788093, 1, 0.8235354889297904], 
     Hue[0.9423953030233297, 1, 0.8392658292289595], 
     Hue[0.9442223330592243, 1, 0.8549963688271067], 
     Hue[0.9463280868545337, 1, 0.8707320668940801], 
     Hue[0.9487281885940266, 1, 0.8864612499440501], 
     Hue[0.9514524747981562, 1, 0.9021995189049897], 
     Hue[0.7782370296935667, 1, 0.41451251619854673`], 
     Hue[0.7836643630848341, 1, 0.4302459243913813], 
     Hue[0.7891828075863013, 1, 0.44598077445113404`], 
     Hue[0.7947989727281148, 1, 0.4617028863100944], 
     Hue[0.8005361372723513, 1, 0.47743999686141625`], 
     Hue[0.8064003570798324, 1, 0.4931663567454482], 
     Hue[0.8124186722266238, 1, 0.5089060962762388], 
     Hue[0.8186043794842429, 1, 0.5246380507463833], 
     Hue[0.8249859841917153, 1, 0.5403699358243846], 
     Hue[0.831594283129703, 1, 0.5561006423175242], 
     Hue[0.8384671286739547, 1, 0.5718278180529814], 
     Hue[0.845656997323535, 1, 0.5875579443991341], 
     Hue[0.8532304507947148, 1, 0.6032935510963359], 
     Hue[0.8612718848564742, 1, 0.6190261036694714], 
     Hue[0.869907393795647, 1, 0.6347573810451134], 
     Hue[0.8793257268303379, 1, 0.6504879236590168], 
     Hue[0.8898360148062199, 1, 0.6662192723173104], 
     Hue[0.9020105085835173, 1, 0.6819512861400283], 
     Hue[0.9171812758454472, 1, 0.6976832288709521], 
     Hue[0.9913799134843716, 1, 0.7134155340709957], 
     Hue[1.0157853892724058`, 1, 0.2257319395704006], 
     Hue[0.9353304750197445, 1, 0.3515858517971663], 
     Hue[0.8631472036100616, 1, 0.3673178939680618], 
     Hue[0.8186718832662013, 1, 0.3830486585249401], 
     Hue[0.7832905650090133, 1, 0.39878086548224406`], 
     Hue[1.0152668437554995`, 1, 0.24146290328840372`], 
     Hue[1.0147482338230864`, 1, 0.25719548710283174`], 
     Hue[1.0142296274784455`, 1, 0.27292746096426096`], 
     Hue[1.0137110119718107`, 1, 0.28865904458505987`], 
     Hue[1.0131923771321523`, 1, 0.3043903793849228], 
     Hue[1.0126737001937536`, 1, 0.32012198867617664`], 
     Hue[1.0121549683734121`, 1, 0.3358540927869595], 
     Hue[0.9832367785259345, 1, 0.571830293876135], 
     Hue[0.9677998403983625, 1, 0.5875603688713], 
     Hue[0.9590112747117684, 1, 0.6032935236980383], 
     Hue[0.9528561646330221, 1, 0.6190259823845262], 
     Hue[0.9482827991315965, 1, 0.6347567853740272], 
     Hue[0.9448127337763467, 1, 0.6504889138531955], 
     Hue[0.942178394300341, 1, 0.6662203953627529], 
     Hue[0.9402105458377474, 1, 0.6819512921754958], 
     Hue[0.9387941809952185, 1, 0.6976839300180679], 
     Hue[1.0116361965097869`, 1, 0.3515860742300443], 
     Hue[1.0111173271791538`, 1, 0.3673195066739361], 
     Hue[1.0105985270356543`, 1, 0.3830491694471493], 
     Hue[1.0100795611151576`, 1, 0.3987820187884848], 
     Hue[1.0095606004868016`, 1, 0.4145127004934006], 
     Hue[1.0090415582540717`, 1, 0.4302436808149557], 
     Hue[1.008522395910071, 1, 0.44597595816922064`], 
     Hue[1.008003153239684, 1, 0.46170815815468425`], 
     Hue[1.0074838735564762`, 1, 0.4774388001251295], 
     Hue[1.006964398310778, 1, 0.49317251768599213`], 
     Hue[1.006444942136274, 1, 0.5089026410362882], 
     Hue[1.0059253475052188`, 1, 0.5246337717251973], 
     Hue[1.0054055825200958`, 1, 0.5403667048813083], 
     Hue[1.0048857522773689`, 1, 0.5560980892076031], 
     Hue[0.994811357821361, 1, 0.6819518499240035], 
     Hue[0.9912058395072478, 1, 0.6976834136329291], 
     Hue[1.0043657297292514`, 1, 0.5718315989444457], 
     Hue[1.0038456711574315`, 1, 0.5875623353180062], 
     Hue[1.0033254427460454`, 1, 0.6032941756381511], 
     Hue[1.0028050940991935`, 1, 0.6190254483531115], 
     Hue[1.002284606335253, 1, 0.6347565529269928], 
     Hue[1.0017639597131467`, 1, 0.6504879139298623], 
     Hue[1.0012431290972983`, 1, 0.6662201179028229], 
     Hue[1.0007221664242776`, 1, 0.6819514232207925], 
     Hue[1.0002010112104152`, 1, 0.6976834830633654], 
     Hue[1.3157378123807444`, 1, 0.2257316793266786], 
     Hue[1.0646666401315952`, 1, 0.35158545692114085`], 
     Hue[1.136850764409804, 1, 0.36731728175689715`], 
     Hue[1.181330058527892, 1, 0.38304944611805347`], 
     Hue[1.2167103303747002`, 1, 0.3987812969550666], 
     Hue[1.2475516282572061`, 1, 0.4145123752353619], 
     Hue[1.31114946866528, 1, 0.2414632321238458], 
     Hue[1.3065534415765265`, 1, 0.2571949066537327], 
     Hue[1.3019461467056603`, 1, 0.2729256398423614], 
     Hue[1.2973230225269787`, 1, 0.2886574030622974], 
     Hue[1.2926796141057602`, 1, 0.3043913683469656], 
     Hue[1.2880135500681584`, 1, 0.32012114971235683`], 
     Hue[1.2833181911048475`, 1, 0.3358541199918974], 
     Hue[1.2785902059751133`, 1, 0.3515857061786525], 
     Hue[1.2738241327907298`, 1, 0.3673175333428004], 
     Hue[1.2690145968950532`, 1, 0.3830497761753705], 
     Hue[1.2641562522285719`, 1, 0.3987811954264434], 
     Hue[1.2592427429216273`, 1, 0.41451227752966], 
     Hue[1.0167621591646299`, 1, 0.5718296079167684], 
     Hue[1.0322008195796577`, 1, 0.5875613276559355], 
     Hue[1.0409886254358347`, 1, 0.6032933057839237], 
     Hue[1.0471435931250728`, 1, 0.6190252574818447], 
     Hue[1.051717236753448, 1, 0.6347569277444891], 
     Hue[1.0551873082143362`, 1, 0.6504891327480621], 
     Hue[1.0578214909463481`, 1, 0.666219603047646], 
     Hue[1.0597894766343294`, 1, 0.6819515030781151], 
     Hue[1.061205776105967, 1, 0.6976833530897775], 
     Hue[1.0621521065771022`, 1, 0.7134148153924224], 
     Hue[1.0626885660443026`, 1, 0.7291464689683617], 
     Hue[1.062860112144231, 1, 0.7448787316049588], 
     Hue[1.2542677829094984`, 1, 0.43024145801250646`], 
     Hue[1.249222030095017, 1, 0.4459745931392666], 
     Hue[1.2440963228408009`, 1, 0.4617141229337951], 
     Hue[1.2388885094601267`, 1, 0.4774383238188774], 
     Hue[1.2335809100858226`, 1, 0.4931690999094641], 
     Hue[1.228163452859502, 1, 0.5089006164396613], 
     Hue[1.2226212365573093`, 1, 0.5246359326443376], 
     Hue[1.216940159652833, 1, 0.540369381497537], 
     Hue[1.2111034315569777`, 1, 0.5560953598452808], 
     Hue[1.2050835447862154`, 1, 0.5718270410589893], 
     Hue[1.198853895590541, 1, 0.5875616659592211], 
     Hue[1.1923822580934909`, 1, 0.6032946495037205], 
     Hue[1.1856258757316356`, 1, 0.6190257321314513], 
     Hue[1.178529361145438, 1, 0.6347546620287488], 
     Hue[1.1710141583445701`, 1, 0.6504904122004468], 
     Hue[1.1629813983423982`, 1, 0.6662232695716488], 
     Hue[1.154281831810818, 1, 0.6819503492936044], 
     Hue[1.1446714094455839`, 1, 0.6976834154039359], 
     Hue[1.1337401833599339`, 1, 0.7134149095303649], 
     Hue[1.1206292590702476`, 1, 0.7291464962156171], 
     Hue[1.1027919732791869`, 1, 0.7448786664646281], 
     Hue[1.0051884672825522`, 1, 0.6819514880866501], 
     Hue[1.008794206931872, 1, 0.6976839763744435], 
     Hue[1.0086200851216842`, 1, 0.7134155475306975], 
     Hue[1.0200156609655624`, 1, 0.7291466597794397], 
     Hue[1.0378531485528872`, 1, 0.7448789133783084], 
     Hue[1.0069049871492852`, 1, 0.7134154472204197], 
     Hue[0.6279120033677816, 1, 0.225732064682602], 
     Hue[1.2759756051401359`, 1, 0.43024144355232535`], 
     Hue[1.3033410062770328`, 1, 0.4459754279712814], 
     Hue[0.6314848566519438, 1, 0.24146349359060554`], 
     Hue[0.6350610711049537, 1, 0.2571938415442809], 
     Hue[0.6386430007381152, 1, 0.2729254396735556], 
     Hue[0.6422327964038752, 1, 0.2886596025458853], 
     Hue[0.6458308312529857, 1, 0.30438971806356363`], 
     Hue[0.6494404912832068, 1, 0.32012217574202056`], 
     Hue[0.6530628562863982, 1, 0.3358530549639116], 
     Hue[0.6567009086069822, 1, 0.3515864325215464], 
     Hue[0.6603556471997026, 1, 0.3673174727423712], 
     Hue[0.6640299157810867, 1, 0.38304894203568013`], 
     Hue[0.6677261837634746, 1, 0.39878153000253014`], 
     Hue[0.6714461286659447, 1, 0.41451207799260503`], 
     Hue[0.6751930440994064, 1, 0.43024371730937405`], 
     Hue[0.6789695998275955, 1, 0.44597626279281627`], 
     Hue[1.062700571337364, 1, 0.7606141865088832], 
     Hue[1.0622353628277317`, 1, 0.7763478973039685], 
     Hue[1.0614833487464672`, 1, 0.7920756402311425], 
     Hue[1.0604567433253826`, 1, 0.8078073225682981], 
     Hue[1.0591631501815006`, 1, 0.8235372366605644], 
     Hue[1.0576044023743711`, 1, 0.8392685684614024], 
     Hue[0.6827780655413478, 1, 0.4617071649592961], 
     Hue[0.6866242968791063, 1, 0.47744775407485485`], 
     Hue[0.690507215317013, 1, 0.4931800245985357], 
     Hue[0.694430179337816, 1, 0.5089033519143358], 
     Hue[0.6983990546543823, 1, 0.5246258626807011], 
     Hue[0.7024221013188021, 1, 0.5403632579236697], 
     Hue[0.706498925510163, 1, 0.5560956484283929], 
     Hue[0.7106355671326834, 1, 0.5718267215505198], 
     Hue[0.7148394197273544, 1, 0.5875629241133988], 
     Hue[0.7191131818887813, 1, 0.6032907474828584], 
     Hue[0.723466045553849, 1, 0.6190181039085424], 
     Hue[0.7279080260156827, 1, 0.634751975679395], 
     Hue[0.7324497061557783, 1, 0.6504968352875171], 
     Hue[0.7370892956593105, 1, 0.6662106673660915], 
     Hue[0.7418563312765218, 1, 0.681952240156652], 
     Hue[0.7467550035127355, 1, 0.6976872972148417], 
     Hue[0.7518014269239708, 1, 0.7134137018737227], 
     Hue[0.7570236958283787, 1, 0.729155078378985], 
     Hue[0.7624350585987767, 1, 0.7448766012423665], 
     Hue[0.7680788605752475, 1, 0.7606144699915287], 
     Hue[0.7739877413000574, 1, 0.7763493393634655], 
     Hue[0.7802077840955061, 1, 0.7920691165851544], 
     Hue[0.786820912035768, 1, 0.8078068314720354], 
     Hue[0.793912327689731, 1, 0.8235354330500785], 
     Hue[0.8016296647129795, 1, 0.8392675002406184], 
     Hue[0.991660601163511, 1, 0.7291471228808487], 
     Hue[0.9862459566114592, 1, 0.7448782971196152], 
     Hue[0.980603894482583, 1, 0.7606113479737013], 
     Hue[0.9746964890666058, 1, 0.7763425343439496], 
     Hue[0.9684719573886007, 1, 0.7920737077506259], 
     Hue[0.9618613879558853, 1, 0.8078052440402745], 
     Hue[0.9547680971490442, 1, 0.8235379618885212], 
     Hue[0.9470511852684887, 1, 0.8392689783221837], 
     Hue[0.9968796983653252, 1, 0.7134151899606106], 
     Hue[0.9305655681711261, 1, 0.2257315666718128], 
     Hue[0.9353308699379851, 1, 0.3515857977399683], 
     Hue[0.8631519074862353, 1, 0.3673164767615924], 
     Hue[0.8186726811990985, 1, 0.3830483348852699], 
     Hue[0.7832913883699857, 1, 0.398780468717568], 
     Hue[0.7524483691866335, 1, 0.41451237660442874`], 
     Hue[0.7240186944534752, 1, 0.43024468082870904`], 
     Hue[0.6966575673287869, 1, 0.44597625282514086`], 
     Hue[0.9327723435413958, 1, 0.2414632061519939], 
     Hue[0.9349799472794348, 1, 0.25719469826888147`], 
     Hue[0.9371887941510998, 1, 0.27292596072749675`], 
     Hue[0.9393995829616117, 1, 0.2886589163570707], 
     Hue[0.9416122272344166, 1, 0.30438987899404135`], 
     Hue[0.9438275309202238, 1, 0.3201214715926114], 
     Hue[0.946045938893734, 1, 0.33585372752537634`], 
     Hue[0.9677979632915238, 1, 0.5875630959189984], 
     Hue[0.9590116574970877, 1, 0.6032926883274319], 
     Hue[0.9528570547268149, 1, 0.6190233188498623], 
     Hue[0.9482824438882037, 1, 0.6347581947835923], 
     Hue[0.9448132144283933, 1, 0.6504864083029341], 
     Hue[0.9421782626344283, 1, 0.6662213044653349], 
     Hue[0.9402105581206388, 1, 0.6819511768997608], 
     Hue[0.9387941241977579, 1, 0.697684693876491], 
     Hue[0.9378478092686889, 1, 0.7134166220213526], 
     Hue[0.9373113958928356, 1, 0.7291481920447151], 
     Hue[0.9371398879302688, 1, 0.7448777282312875], 
     Hue[0.9372993443909589, 1, 0.7606099899810203], 
     Hue[0.9377643858116622, 1, 0.7763414276842323], 
     Hue[0.938516550953241, 1, 0.7920738693483697], 
     Hue[0.9395431920110724, 1, 0.8078064463360044], 
     Hue[0.9408368367677565, 1, 0.8235370927006198], 
     Hue[0.9423956583366779, 1, 0.839269132947527], 
     Hue[0.9482679459937359, 1, 0.35158699486525147`], 
     Hue[0.9504936125956547, 1, 0.3673185066575808], 
     Hue[0.9527238938316797, 1, 0.3830517731445918], 
     Hue[0.954958699273373, 1, 0.3987828676435127], 
     Hue[0.9571989785258185, 1, 0.4145151320628906], 
     Hue[0.9594443024111866, 1, 0.43024216168317475`], 
     Hue[0.9616971308087864, 1, 0.44597769802874676`], 
     Hue[0.9639559643894408, 1, 0.4617077070644454], 
     Hue[0.966222120787552, 1, 0.4774377592007788], 
     Hue[0.9684966470797596, 1, 0.4931713850986603], 
     Hue[0.970779139301921, 1, 0.5089019718901597], 
     Hue[0.9730709592713153, 1, 0.5246349871483813], 
     Hue[0.9753721709237951, 1, 0.5403668279728169], 
     Hue[0.9776835081264793, 1, 0.5560983634513805], 
     Hue[0.9800055919242656, 1, 0.571829535403573], 
     Hue[0.9948113817633917, 1, 0.6819518003899552], 
     Hue[0.9912058553725794, 1, 0.6976832213909535], 
     Hue[0.9913799237278441, 1, 0.7134156329798078], 
     Hue[0.9823389265137634, 1, 0.5875593393135343], 
     Hue[0.9846852141361913, 1, 0.6032946302614826], 
     Hue[0.9870433509120314, 1, 0.6190232590885967], 
     Hue[0.9894157185917198, 1, 0.634756193720304], 
     Hue[0.9918024060581893, 1, 0.6504888555829836], 
     Hue[0.994204010919729, 1, 0.6662198572267816], 
     Hue[0.9966217277433955, 1, 0.6819514605113699], 
     Hue[0.9990564202802766, 1, 0.6976834551878905], 
     Hue[1.227336997082064, 1, 0.2257314497928806], 
     Hue[1.0646670350492242`, 1, 0.3515855109761129], 
     Hue[1.136851671041063, 1, 0.3673175549127832], 
     Hue[1.222291380092254, 1, 0.24146258791732883`], 
     Hue[1.217235448901825, 1, 0.25719415679880414`], 
     Hue[1.2121634052592787`, 1, 0.2729279922293072], 
     Hue[1.2070712738879341`, 1, 0.2886598352031844], 
     Hue[1.2019534415457693`, 1, 0.30438992739498727`], 
     Hue[1.1968029298502816`, 1, 0.3201218974990947], 
     Hue[1.191614308366515, 1, 0.335853630274691], 
     Hue[1.1863809692932603`, 1, 0.3515854138274118], 
     Hue[1.1810958045944124`, 1, 0.367317578560174], 
     Hue[1.0322013230566227`, 1, 0.5875620591028494], 
     Hue[1.0409886602642822`, 1, 0.6032933817920986], 
     Hue[1.0471436925493132`, 1, 0.6190255550051457], 
     Hue[1.051717259925954, 1, 0.6347570196793666], 
     Hue[1.0551871418991332`, 1, 0.6504882657619596], 
     Hue[1.17575266145608, 1, 0.3830459309936588], 
     Hue[1.1703385114685811`, 1, 0.39878430113177676`], 
     Hue[1.1648516462387775`, 1, 0.41451109798957886`], 
     Hue[1.159275958037561, 1, 0.43024340669422984`], 
     Hue[1.1536033136879889`, 1, 0.44597180099897826`], 
     Hue[1.1478155450383076`, 1, 0.46171033355705937`], 
     Hue[1.1419038023354973`, 1, 0.4774422243366586], 
     Hue[1.1358496048784041`, 1, 0.4931706317542943], 
     Hue[1.1296301958278192`, 1, 0.508901411111554], 
     Hue[1.1232215076789975`, 1, 0.5246332558270254], 
     Hue[1.1165941538198276`, 1, 0.5403650865925296], 
     Hue[1.1097099161574446`, 1, 0.5560998483728933], 
     Hue[1.1025263561434768`, 1, 0.5718280207200799], 
     Hue[1.0949780607216386`, 1, 0.5875601254413019], 
     Hue[1.086985405370686, 1, 0.6032920793456609], 
     Hue[1.0784342116115953`, 1, 0.619024394154101], 
     Hue[1.0691567769523982`, 1, 0.6347563421751965], 
     Hue[1.0588856492374377`, 1, 0.6504882667814276], 
     Hue[1.005188491224906, 1, 0.6819515376191922], 
     Hue[1.0087941766198711`, 1, 0.6976836090529964], 
     Hue[1.0471458091311372`, 1, 0.666220265752442], 
     Hue[1.0329197789901794`, 1, 0.6819517974815272], 
     Hue[1.0129015674552908`, 1, 0.6976835662460887], 
     Hue[0.5375456165943878, 1, 0.22573138539891288`], 
     Hue[1.1813276237323278`, 1, 0.38304845856455344`], 
     Hue[1.2167065955628238`, 1, 0.3987794972122271], 
     Hue[1.2475509764406, 1, 0.4145120261259011], 
     Hue[1.2759800806932597`, 1, 0.43024398522905716`], 
     Hue[1.3033452691720926`, 1, 0.44597789311390323`], 
     Hue[1.330770107149979, 1, 0.46170874494016545`], 
     Hue[1.3595732033775925`, 1, 0.47744046644868476`], 
     Hue[1.3919583927684336`, 1, 0.49317060075472297`], 
     Hue[1.4342434339336836`, 1, 0.5089022107982427], 
     Hue[0.5386952298505856, 1, 0.2414628757232211], 
     Hue[0.5398450330164247, 1, 0.2571953227777727], 
     Hue[0.5409949573673806, 1, 0.2729269643339153], 
     Hue[0.5421451666405557, 1, 0.28865921752144036`], 
     Hue[0.5432955027815638, 1, 0.3043890969721298], 
     Hue[0.5444464227446713, 1, 0.3201220248713516], 
     Hue[0.545597721872854, 1, 0.3358543743008152], 
     Hue[0.5467495040363407, 1, 0.35158673437449817`], 
     Hue[0.5479016793757701, 1, 0.3673170458346015], 
     Hue[0.5490545786094037, 1, 0.38304898784283525`], 
     Hue[0.550208102841454, 1, 0.39878037026590984`], 
     Hue[0.551362346515184, 1, 0.41451163802427227`], 
     Hue[0.5525174848852445, 1, 0.430244330440575], 
     Hue[0.5536733175075119, 1, 0.44597486582951196`], 
     Hue[0.554830259115788, 1, 0.46170803047035924`], 
     Hue[0.5559880329773903, 1, 0.47743919750824304`], 
     Hue[0.5571468699036373, 1, 0.4931706366969324], 
     Hue[0.5583068709271988, 1, 0.5089028434083864], 
     Hue[1.0578219342144186`, 1, 0.6662226636595296], 
     Hue[1.0597892601808947`, 1, 0.6819494716801527], 
     Hue[1.061205874072348, 1, 0.6976846706112488], 
     Hue[1.0621519206926275`, 1, 0.7134108252204131], 
     Hue[1.0626886735137286`, 1, 0.7291513345352956], 
     Hue[1.0628601123061683`, 1, 0.7448809782212008], 
     Hue[1.062700739583953, 1, 0.7606058071557744], 
     Hue[1.062235732046716, 1, 0.7763383937685101], 
     Hue[1.0614835345391853`, 1, 0.7920723598620428], 
     Hue[1.0604566837088325`, 1, 0.8078081304006564], 
     Hue[1.0591630418505296`, 1, 0.823538431626841], 
     Hue[1.057603986980432, 1, 0.8392724306945], 
     Hue[1.055777263780154, 1, 0.8549995981159874], 
     Hue[1.0536712293265784`, 1, 0.8707368495128711], 
     Hue[1.0512719547573746`, 1, 0.8864603677046358], 
     Hue[1.0485476116281987`, 1, 0.9021990495753076], 
     Hue[1.0454610893534466`, 1, 0.917924927633872], 
     Hue[1.0419444031395975`, 1, 0.9336570131524435], 
     Hue[1.0378944695961432`, 1, 0.9493932561628047], 
     Hue[1.033137261950641, 1, 0.9651211667708415], 
     Hue[1.0273188590986302`, 1, 0.9808556200748626], 
     Hue[0.559467026080899, 1, 0.5246212589452327], 
     Hue[0.5606314218126791, 1, 0.540380317598112], 
     Hue[0.5617950167498216, 1, 0.556110872938997], 
     Hue[0.5629599160549212, 1, 0.5718405302904136], 
     Hue[0.5641266628293014, 1, 0.5875757030960169], 
     Hue[0.5652937066793273, 1, 0.6032945830079949], 
     Hue[0.5664625525065232, 1, 0.6190165371941782], 
     Hue[0.5676354133946043, 1, 0.6347703221484186], 
     Hue[0.5688059683530347, 1, 0.6504701348263348], 
     Hue[0.5699832783222509, 1, 0.6662365129541605], 
     Hue[0.5711581497028261, 1, 0.6819453470556216], 
     Hue[0.5723375434197427, 1, 0.6976887805236535], 
     Hue[0.573518991035878, 1, 0.7134327800155195], 
     Hue[0.5746998738903115, 1, 0.7291415321185468], 
     Hue[0.5758851334025519, 1, 0.7448797651058794], 
     Hue[0.5770726550150099, 1, 0.7606182846503547], 
     Hue[0.578260201565296, 1, 0.7763264794308746], 
     Hue[0.5794539225398608, 1, 0.7920845680149288], 
     Hue[0.5806477737746708, 1, 0.8078116254131844], 
     Hue[0.5818441159222283, 1, 0.823537753185868], 
     Hue[0.5830457631059445, 1, 0.8392987178602545], 
     Hue[0.5842463845138954, 1, 0.8550104014353467], 
     Hue[0.5854488953607444, 1, 0.8707100176417557], 
     Hue[0.5866566948905002, 1, 0.8864407129552097], 
     Hue[0.5878684449929985, 1, 0.9021837129783485], 
     Hue[0.5890827369116551, 1, 0.9179194850954653], 
     Hue[0.5902980924874421, 1, 0.9336277779245508], 
     Hue[0.5915186456113594, 1, 0.9493607791132612], 
     Hue[0.5927432349632484, 1, 0.9651021067722084], 
     Hue[0.59397064139381, 1, 0.980834787340565], 
     Hue[1.0086201476324297`, 1, 0.7134149439152632], 
     Hue[1.0047632667430195`, 1, 0.7291471666927357], 
     Hue[0.9969070176326783, 1, 0.7448796447743525], 
     Hue[0.9957201167744306, 1, 0.760609945470957], 
     Hue[0.9945306839776152, 1, 0.776343082122716], 
     Hue[0.9933389265735934, 1, 0.7920752426788943], 
     Hue[0.9921449354488943, 1, 0.8078041606108662], 
     Hue[0.9909480967555283, 1, 0.823536824663374], 
     Hue[0.9897486541603631, 1, 0.8392689083133968], 
     Hue[0.9885464808736644, 1, 0.855000945471223], 
     Hue[0.987341536224136, 1, 0.8707323211885646], 
     Hue[0.9861335730518433, 1, 0.8864650906721414], 
     Hue[0.9849226801287456, 1, 0.9021969070295437], 
     Hue[0.9837087124315389, 1, 0.9179284489675913], 
     Hue[0.9824915847229501, 1, 0.9336595919450303], 
     Hue[0.9812710845908769, 1, 0.9493918241282683], 
     Hue[0.9800472943228077, 1, 0.9651228074715565], 
     Hue[0.9788199355121392, 1, 0.9808548189195189], 
     Hue[0.9992744544717791, 1, 0.7134154240957249], 
     Hue[0.9980918523555684, 1, 0.7291470572541721], 
     Hue[0.8446894427623625, 1, 0.22573165741825427`], 
     Hue[0.8631514864890113, 1, 0.3673166035995372], 
     Hue[0.8186727282336163, 1, 0.38304831580822774`], 
     Hue[0.7832930841193139, 1, 0.3987796515669192], 
     Hue[0.7524503282513589, 1, 0.41451132734178825`], 
     Hue[0.7240182230436663, 1, 0.43024494854476064`], 
     Hue[0.6966564030021307, 1, 0.445976926130782], 
     Hue[0.6692309253233655, 1, 0.4617081618783714], 
     Hue[0.6404278578984992, 1, 0.47743991150072673`], 
     Hue[0.6080410746338137, 1, 0.4931708366816989], 
     Hue[0.5657541231908312, 1, 0.5089029281713137], 
     Hue[0.8489676855343351, 1, 0.24146406721836128`], 
     Hue[0.8532517449243557, 1, 0.25719508078392594`], 
     Hue[0.8575452648878635, 1, 0.2729265183912168], 
     Hue[0.861851740701234, 1, 0.28865941468072365`], 
     Hue[0.8661734912077276, 1, 0.30439020630760305`], 
     Hue[0.8705146127433789, 1, 0.32012142556310813`], 
     Hue[0.8748788232475452, 1, 0.3358537148105043], 
     Hue[0.8792693230847893, 1, 0.35158526647164334`], 
     Hue[0.9528572330362212, 1, 0.6190227852890988], 
     Hue[0.9482832996710935, 1, 0.6347547995685805], 
     Hue[0.9448126923263863, 1, 0.6504891299293036], 
     Hue[0.9421784780113679, 1, 0.6662198173781875], 
     Hue[0.9402101235275853, 1, 0.681955255752121], 
     Hue[0.9387942689986781, 1, 0.697682746505322], 
     Hue[0.9378479731140753, 1, 0.7134131046828384], 
     Hue[0.9373113639542505, 1, 0.72914963803235], 
     Hue[0.9371398880165565, 1, 0.744876588062146], 
     Hue[0.9372994225229557, 1, 0.7606138808040023], 
     Hue[0.9377643480869217, 1, 0.7763404566021029], 
     Hue[0.938516680849511, 1, 0.7920761627603621], 
     Hue[0.9395431514053031, 1, 0.8078058960961907], 
     Hue[0.9408366863959956, 1, 0.8235354339643366], 
     Hue[0.9423956235178572, 1, 0.8392688092055125], 
     Hue[0.9442229110053526, 1, 0.8550009981067901], 
     Hue[0.9463282563343635, 1, 0.8707332522511437], 
     Hue[0.9487284022469096, 1, 0.8864625648341559], 
     Hue[0.9514516798236101, 1, 0.902195201809062], 
     Hue[0.9545392430172077, 1, 0.9179265174598791], 
     Hue[0.9580559623139351, 1, 0.9336585417839297], 
     Hue[0.962104891466937, 1, 0.9493909532710811], 
     Hue[0.9668634562780912, 1, 0.9651233372057224], 
     Hue[0.9726807940893979, 1, 0.980854787903392], 
     Hue[0.8836904379400609, 1, 0.3673176166589596], 
     Hue[0.8881457680811136, 1, 0.3830488890609541], 
     Hue[0.8926403570259225, 1, 0.39878134581141933`], 
     Hue[0.8971780912007189, 1, 0.41451206292692766`], 
     Hue[0.9017644939920134, 1, 0.43024252996679163`], 
     Hue[0.9064054772972906, 1, 0.44597398386255094`], 
     Hue[0.9111082206385264, 1, 0.46171006392525893`], 
     Hue[0.9158760360835566, 1, 0.4774394876217385], 
     Hue[0.9207184897169056, 1, 0.4931694204518977], 
     Hue[0.9256444909029323, 1, 0.5089017145470714], 
     Hue[0.9306625959682152, 1, 0.5246336738424869], 
     Hue[0.9357836178867082, 1, 0.5403657276103631], 
     Hue[0.9410201853902209, 1, 0.556098953536503], 
     Hue[0.9463854696542837, 1, 0.5718301993533264], 
     Hue[0.9518967826350864, 1, 0.587561345775305], 
     Hue[0.9575742557625904, 1, 0.6032931931771588], 
     Hue[0.9912057941636626, 1, 0.6976839630983598], 
     Hue[0.9913798329023269, 1, 0.7134147559461698], 
     Hue[0.9952367569252433, 1, 0.7291472143527621], 
     Hue[0.9634409409356728, 1, 0.6190233839734529], 
     Hue[0.9695274865983863, 1, 0.6347554726840258], 
     Hue[0.9758701204419096, 1, 0.6504882595792847], 
     Hue[0.9825149293556017, 1, 0.6662199133209709], 
     Hue[0.9895240381194238, 1, 0.6819518188484714], 
     Hue[0.9969810295778654, 1, 0.6976835296672572], 
     Hue[1.1404366558533616`, 1, 0.22573212541677937`], 
     Hue[1.1364379421974298`, 1, 0.24146398499912314`], 
     Hue[1.1324342642940346`, 1, 0.2571954734122295], 
     Hue[1.1284231175345583`, 1, 0.2729263545642397], 
     Hue[1.1244011890858037`, 1, 0.2886593815436511], 
     Hue[1.1203667446156813`, 1, 0.30439089453731283`], 
     Hue[1.1163167813677424`, 1, 0.3201219060677109], 
     Hue[1.1122482426642528`, 1, 0.33585325838697533`], 
     Hue[1.1081579264809687`, 1, 0.3515858963702323], 
     Hue[0.959012415099443, 1, 0.6032910350210424], 
     Hue[1.1040429473828193`, 1, 0.3673190147272104], 
     Hue[1.0999001723193864`, 1, 0.38305215548892635`], 
     Hue[1.0957275476790505`, 1, 0.39878011577442934`], 
     Hue[1.091519624259984, 1, 0.4145096959795672], 
     Hue[1.0872714526226903`, 1, 0.4302446847413149], 
     Hue[1.0829817626854075`, 1, 0.44597420301364343`], 
     Hue[1.0786432981556653`, 1, 0.46170817522174323`], 
     Hue[1.0742531247616824`, 1, 0.47743924601983323`], 
     Hue[1.069805251118253, 1, 0.4931695094447066], 
     Hue[1.065292830448781, 1, 0.5089020034309503], 
     Hue[1.0607096737103006`, 1, 0.524635113568867], 
     Hue[1.0560491988839102`, 1, 0.5403660333318373], 
     Hue[1.0513019207536247`, 1, 0.5560986408242701], 
     Hue[1.046459379775965, 1, 0.5718296218687976], 
     Hue[1.0415100928850922`, 1, 0.5875611538106218], 
     Hue[1.0364412876029885`, 1, 0.6032940368700561], 
     Hue[1.0312401312732318`, 1, 0.6190229304165438], 
     Hue[1.0258862623593115`, 1, 0.6347572652224329], 
     Hue[1.0203621504868217`, 1, 0.6504879496764515], 
     Hue[1.0146408735856727`, 1, 0.6662205025145571], 
     Hue[1.00869267473341, 1, 0.6819517548183187], 
     Hue[1.0024779022955321`, 1, 0.6976835651323658], 
     Hue[1.4468374023342534`, 1, 0.22573215097703814`], 
     Hue[1.1368471100050968`, 1, 0.3673161807532376], 
     Hue[1.181326771914608, 1, 0.3830481130703415], 
     Hue[1.2167088989553039`, 1, 0.39878060717494423`], 
     Hue[1.2475498481470901`, 1, 0.41451142181944856`], 
     Hue[1.275981962576071, 1, 0.43024505395921014`], 
     Hue[1.3033409437095538`, 1, 0.4459753917898177], 
     Hue[1.3307672305031528`, 1, 0.46170712042802586`], 
     Hue[1.3595712159642588`, 1, 0.47743942721593713`], 
     Hue[1.3919588005602619`, 1, 0.4931707813959906], 
     Hue[1.445223325148576, 1, 0.24146407608429782`], 
     Hue[1.4436089932541363`, 1, 0.2571952468275457], 
     Hue[1.4419941155367184`, 1, 0.27292687823676265`], 
     Hue[1.4403787152106091`, 1, 0.2886571189602078], 
     Hue[1.4387621142294464`, 1, 0.30439093867300565`], 
     Hue[1.4371447347796573`, 1, 0.32012258915824193`], 
     Hue[1.435526129022168, 1, 0.3358547816277183], 
     Hue[1.4339062052727063`, 1, 0.3515867511909315], 
     Hue[1.4322847554305282`, 1, 0.3673188523393502], 
     Hue[1.4306616877925105`, 1, 0.38305029674110747`], 
     Hue[1.4290368097490918`, 1, 0.39878126055131546`], 
     Hue[1.4274099674476308`, 1, 0.4145115277291091], 
     Hue[1.425780647483619, 1, 0.4302443342132921], 
     Hue[1.4241489822119537`, 1, 0.445976654467778], 
     Hue[1.422514803372192, 1, 0.461708350029595], 
     Hue[1.4208779290109415`, 1, 0.47743939081813214`], 
     Hue[1.4192379917168636`, 1, 0.49317149853642095`], 
     Hue[1.0409893092324336`, 1, 0.6032947980968145], 
     Hue[1.0471432156232874`, 1, 0.619024127836983], 
     Hue[1.0517178701115788`, 1, 0.6347594405901434], 
     Hue[1.055186834576845, 1, 0.6504866637531691], 
     Hue[1.0578217671786685`, 1, 0.6662215103154427], 
     Hue[1.0597895378781192`, 1, 0.681952077861717], 
     Hue[1.0612058403205362`, 1, 0.6976842166879258], 
     Hue[1.0621519856445314`, 1, 0.713412219405411], 
     Hue[1.06268856944709, 1, 0.7291466230018702], 
     Hue[1.062860111997251, 1, 0.7448767689770964], 
     Hue[1.0627005940658414`, 1, 0.7606130547915392], 
     Hue[1.0622356426921165`, 1, 0.7763406939638231], 
     Hue[1.0614835410004113`, 1, 0.7920722457784025], 
     Hue[1.0604569282255225`, 1, 0.8078048170236186], 
     Hue[1.059163342770821, 1, 0.8235351122242603], 
     Hue[1.0576043209396147`, 1, 0.839269325634045], 
     Hue[1.0557770627892955`, 1, 0.8550012080039799], 
     Hue[1.053671607308955, 1, 0.8707342059334644], 
     Hue[1.051271320982178, 1, 0.8864642681528256], 
     Hue[1.048548412395713, 1, 0.902194701003975], 
     Hue[1.0454605539528063`, 1, 0.9179274886014195], 
     Hue[1.0419440077824147`, 1, 0.9336586668650163], 
     Hue[1.0378951754859944`, 1, 0.9493907119525122], 
     Hue[1.0331367797122495`, 1, 0.9651226240666128], 
     Hue[1.4175941499568416`, 1, 0.5089108885521197], 
     Hue[1.4159479000375517`, 1, 0.5246413778980564], 
     Hue[1.414298342446567, 1, 0.5403697067341252], 
     Hue[1.4126463823016133`, 1, 0.5560853764584334], 
     Hue[1.4109887541888009`, 1, 0.5718174881225198], 
     Hue[1.4093243280744534`, 1, 0.5875746255329627], 
     Hue[1.407658529435038, 1, 0.6033034110219374], 
     Hue[1.4059893723723722`, 1, 0.6190206905971871], 
     Hue[1.404313926718806, 1, 0.6347519408071247], 
     Hue[1.4026324588090748`, 1, 0.6504924087343993], 
     Hue[1.4009491894568555`, 1, 0.6662004938355318], 
     Hue[1.3992550649202675`, 1, 0.6819583506514004], 
     Hue[1.3975579629065265`, 1, 0.6976902853924419], 
     Hue[1.395856950988423, 1, 0.7134028195344386], 
     Hue[1.3941456345608343`, 1, 0.7291525085556494], 
     Hue[1.3924319389113469`, 1, 0.7448639460052803], 
     Hue[1.3907086368284962`, 1, 0.7606009203215365], 
     Hue[1.3889782940472575`, 1, 0.7763372379072342], 
     Hue[1.3872379478961563`, 1, 0.7920970028614094], 
     Hue[1.3854957514464998`, 1, 0.8078038095007406], 
     Hue[1.3837426455739985`, 1, 0.823536659867315], 
     Hue[1.3819806653258375`, 1, 0.8392741408820162], 
     Hue[1.3802119504304655`, 1, 0.8549942031743055], 
     Hue[1.378432212341498, 1, 0.870731830100644], 
     Hue[1.3766432598603742`, 1, 0.8864676692295587], 
     Hue[1.374846990637782, 1, 0.9021818722533816], 
     Hue[1.3730383274601174`, 1, 0.9179154119038231], 
     Hue[1.3712187992816327`, 1, 0.9336512143109302], 
     Hue[1.3693900106950236`, 1, 0.9493717960593197], 
     Hue[1.3675460397654005`, 1, 0.9651240416755157], 
     Hue[1.0087941813956338`, 1, 0.6976836669243698], 
     Hue[1.008620108886804, 1, 0.7134153180554911], 
     Hue[1.0047632581549935`, 1, 0.7291471839862073], 
     Hue[1.004472246686358, 1, 0.7448777829478599], 
     Hue[1.006195251424174, 1, 0.7606119916348704], 
     Hue[1.007924819650392, 1, 0.7763412336686986], 
     Hue[1.0096620224575379`, 1, 0.7920725788002096], 
     Hue[1.011406952413943, 1, 0.8078040834841059], 
     Hue[1.0131599752663465`, 1, 0.8235361892764299], 
     Hue[1.0149215537285357`, 1, 0.8392700926487076], 
     Hue[1.0166915793731384`, 1, 0.8550017956056518], 
     Hue[1.0184706466582076`, 1, 0.8707334670098001], 
     Hue[1.0202590755899719`, 1, 0.8864647045806655], 
     Hue[1.0220573154764276`, 1, 0.9021961158201318], 
     Hue[1.0238657877028374`, 1, 0.9179279175724309], 
     Hue[1.0256849068990412`, 1, 0.9336601194191605], 
     Hue[1.0275149941515158`, 1, 0.9493917756970375], 
     Hue[1.0293564884576316`, 1, 0.9651228054417973], 
     Hue[1.0010470706883499`, 1, 0.7134152512110717], 
     Hue[1.0027564120738097`, 1, 0.7291467511351064]}],
  Axes->True,
  BaseStyle->{FontSize -> 10},
  Frame->True,
  FrameTicksStyle->(FontOpacity -> 0.5),
  ImageSize->Medium,
  Method->{"TransparentPolygonMesh" -> True, "AxesInFront" -> True},
  PlotRange->{All, All},
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.618630920027968*^9, 3.618630966113879*^9, 3.618631321272731*^9, 
   3.618631445997841*^9, 3.6186317896780767`*^9, {3.618632722586097*^9, 
   3.61863276878189*^9}, 3.618633879058587*^9, 3.618634041729107*^9, 
   3.6186342730593767`*^9, 3.618634922679408*^9, 3.621832360602593*^9, 
   3.627285722651084*^9, 3.627286092847149*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"fun", " ", "=", " ", 
     RowBox[{
      RowBox[{"funk", "[", 
       RowBox[{"19.5", ",", "#"}], "]"}], "&"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"Abs", "[", 
      RowBox[{"fun", "[", 
       RowBox[{"x", "+", 
        RowBox[{"I", " ", "y"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"color", " ", "and", " ", "mesh", " ", "functions", " ", 
        RowBox[{"don", "'"}], "t", " ", "trigger", " ", "refinement"}], ",", 
       RowBox[{
       "so", " ", "just", " ", "use", " ", "a", " ", "big", " ", "grid"}]}], 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"PlotPoints", "\[Rule]", "100"}], ",", 
     RowBox[{"MaxRecursion", "\[Rule]", "0"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "100"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
      "turn", " ", "off", " ", "scaling", " ", "so", " ", "we", " ", "can", 
       " ", "do", " ", "computations", " ", "with", " ", "the", " ", "actual",
        " ", "complex", " ", "values"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Hue", "[", "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"hue", " ", "according", " ", "to", " ", "argument"}], ",", 
           RowBox[{
            RowBox[{"with", " ", "shift", " ", "so", " ", "arg", 
             RowBox[{"(", "z", ")"}]}], "\[Equal]", 
            RowBox[{"0", " ", "is", " ", "red"}]}]}], "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Rescale", "[", 
           RowBox[{
            RowBox[{"Arg", "[", 
             RowBox[{"fun", "[", 
              RowBox[{"#", "+", 
               RowBox[{"I", " ", "#2"}]}], "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "\[Pi]"}], ",", "\[Pi]"}], "}"}], ",", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}], "+", "0.5"}]}], "]"}], ",", "1",
           ",", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"fudge", " ", "brightness", " ", "a", " ", 
             RowBox[{"bit", ":", 
              RowBox[{
              "0.1", " ", "keeps", " ", "things", " ", "from", " ", "getting",
                " ", "too", " ", "dark"}]}]}], ",", 
            RowBox[{
            "2", " ", "forces", " ", "some", " ", "actual", " ", "bright", 
             " ", "areas"}]}], "*)"}], 
          RowBox[{"Rescale", "[", 
           RowBox[{
            RowBox[{"Log", "[", 
             RowBox[{"Abs", "[", 
              RowBox[{"fun", "[", 
               RowBox[{"#", "+", 
                RowBox[{"I", " ", "#2"}]}], "]"}], "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1", ",", "2"}], "}"}]}], "]"}]}], "]"}], "&"}], 
       ")"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
       "mesh", " ", "lines", " ", "according", " ", "to", " ", "magnitude"}], 
       ",", 
       RowBox[{
        RowBox[{
        "scaled", " ", "to", " ", "avoid", " ", "the", " ", "pole", " ", "at",
          " ", "z"}], "=", "1"}]}], "*)"}], 
     RowBox[{"MeshFunctions", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Log", "[", 
         RowBox[{"Abs", "[", 
          RowBox[{"fun", "[", 
           RowBox[{"#1", "+", 
            RowBox[{"I", " ", "#2"}]}], "]"}], "]"}], "]"}], "&"}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Re", ",", " ", "Im", ",", " ", "Abs"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotLabel", "\[Rule]", " ", "\"\<Abs value from function\>\""}],
      ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"0", ",", "4"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"FontSize", "\[Rule]", "10"}], "}"}]}]}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{"for", " ", "export"}], " ", "*)"}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.618630764060663*^9, 3.618630821272451*^9}, {
  3.6186308643082533`*^9, 3.618630874856839*^9}, {3.618633973300705*^9, 
  3.6186339893353252`*^9}, {3.618634293158869*^9, 3.6186343295886173`*^9}, {
  3.618634955357542*^9, 3.618634963912648*^9}, {3.621833630001718*^9, 
  3.621833656466135*^9}, {3.627286098255782*^9, 3.627286100295871*^9}}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx03XVUlWu3xmFKBRUBCzuwuxUVwU7sbuwuROxuMRC7CxXsxBZFxRY7ULFF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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJws3XtgzfUfx/Gzs9vZEnMJibOd5baZkSRJkmbmNpfkbiQkobUkSdISkpAk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         "]], Polygon3DBox[CompressedData["
1:eJws3X2cTtXXx/FJkiRJYwzXjCRJkiRJGsN4SpIkSUKSJEmSJEklSaWSJEmS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         "]], Polygon3DBox[CompressedData["
1:eJwtmHdYkEcSh0dFrEAssUtR8ABpomJEFATxUEFQsZ4VKYIFg+Yud4ldCdi7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         
         "]]}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl1nt4FmIYB+AHpU1FsakoGtGiCKXIoRxLS+faVNoqKi2F0qiIQihKpSGE
EEWLsBRCsSgVciznKEJRhML98sfd79fVdXXt/d7nfb7l9BvW5fK9IqLz3hE1
G0akfgkraeIvU9lJgX9/iZx9Im5iCx0qRSwku3LENWykzb4Rj5JZJWIo62ie
EXEPeyjKjFhBo/0iJrOd7lUjFlOvWsQNbKJd9YinqLl/xEg+5vQDIh6ico2I
wazmhJoRM/iDPgdGvMpRB0Xcyo90zop4jjrZEWP5knMPjniC6rUirmA9p9SO
uJ+96jg/K2lyiPOzk4JDnZ+cus7PFjrUc36yD3N+NtLmcOcns77zs47mOc7P
HoqOcH4aHen8bKd7A+en3lHOzybaHe38tL8w4mmZJzuwQL9QdqRM7yQ7s1Dv
IrvyjN5NdudZvYfsySI9XxbwnH6R7MXzem/Zhxf0i2VfyvVCWcRivZ/sz4v6
AHkJS/RL5UCW6oPkYF7SL5NDeFkvlkN5Rb9cDmOZPlxewav6lfIqXtNHyJG8
rl8tR7FcL5HXsEK/Vo7mDX2MHMub+nXyeir0cfIGVuo3yvG8pU+QN/G2frO8
hVX6RHkrq/Xb5O28o0+Sk1mj3yHvZK0+RU5lnX6XnMa7+nQ5g/f0u+VM3tdL
5T2s1++V9/GBPkvez4f6A/JBPtJny4f4WH9YPsIn+hz5KJ/qj8nH2aDPlU+w
UX9Sfibnyc/lfPmF/JKv+Jpv2MS3fMdmtvA9P7CVH/mJn9nGdn7hV3awk9/4
nV38wZ/8xW728Df/EGnHsDf7UInK7EsVMshkP6pSjerszwHUYL7/p2362b2T
cdSl3PvpxjbvaRK5LPfOCtnt3ZXSjLXeYzEZzPFOW7PBuy0hizLvOY/N3vcE
6rPUu89nhz0whcZU2A8DCGbZGy153x4ZTjXm2i/n8IV9M4baLLKHOrHVXppI
A5bZV73ZZX9Npymr7LVBVGK2fXcaH9l/I6jBfHuxLd/Yk+OoS7n92Y1t9ukk
clluzxay294tpRlr7eNiMphjT7dmg71dQhZl9nkem+33CdRnqb2fzw7fA1No
TIWjD6A//SiikL5cTB9604uLKCCfnvSgO93oSpf0/UMnOmJMowN5tOcC2tGW
8zmPczmHszmLNrTmTM7gdE6jFadyCi1pwck0pxnvmaeT5Dp5olwjT5Cr5Ns0
1SvkmxyvL5evc5y+TL5CE32pXEJjvVy+wLH6Ivksx+hlcgGN9PlyHrn6XPl4
w/+eRszxxyOkpzJbPojxjlnyPox4lMqZGPGYLqdhzGOKvBNjHpPk7RjzmChv
wajHBDkeox7j5PUY9xgjR2Pco0SOwsjHCHkVRj6Gy2EN/xv5KJZDMPYxSA6k
VpoJ2Z+D0zzIvmSnWZC9yEpzIHtyUJoB2ZUD0/3LjtRMdy/bp/ee7l2en95/
unN5dtoH6b7lmWk/pLuWrdK+SPcsW6T9ke443W/aJ3rTdIdpv+iN0/2kfaPn
ps8+7R+9Qfpc0z7S66fPLO0nvW76PNK+0muns6b9pWelc6R9Fv///vQvIUtj
dQ==
       "],
       VertexColors->None]}, {Line3DBox[CompressedData["
1:eJwN0z9IlHEcx/H34WDiEAYRERIScpnZVZeZlZnVZXZZeVZmZpZmZZea/SEi
IuSGiIaQaLghRBrEIUQaJOIGh0McjoPC6QaHo0HEQKLhCKn38PCCB36f58P3
+3sqeodjQwFg3qcsCJ/PwybdeAEWdUTrdsIPTWrdRVjXCY1XwYY2+K6D2rAL
MjqhoRgUVcOY9utvndeOdqjeDXOa1OAl+KdvdaAGVjSjrZfN2APTOqZlV8zQ
p9oRgiVNa6TDvL0wpR+05CoUNK5d+8zSlIY6Yft+eK8JXdc17btmXthuOqfB
Lqg8AG/0ta7osrZeh2gtzOi0buuG8oMwqgn9qasauQFtdTCpX7SkBzYfso8+
06zmtP4mtNTDuE5r0S3Yetg++lLTuqTBXmg6Yh/9pKtafNTOfc5CU5rTitt+
u8E+OqV5LT3mu353o5Oa1dI7EG70rE5oTouPQ+Ndd63juqiBe+66yT6a1LT+
1aoB6DnhHDWjBQ2fhO778FFTGjjlrOOe1VFNa16DEWh+4K51Rgu6ZdC80/BC
FzSnNc3epSF4p+O6poFhaD/jXdJZzWplC9Q+NE+T+kcL2nnW3Y/AN01pedQ+
j+CVJjSvvzR2zszH8FVndUerfZ64d32uy5rTqP/Ef58vobw=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN00FI02EcxvFvw4OJhyiKiJCKsGVmq8yWlZmVma1VamVmZmZWtmZZRERE
iIeIDiHRYYcYo4N4iCEdJGIHDys6yKDwtIOH0UHEQKLDCOl7+POBP7zP+/D+
3ndz31BbfAXw1W/NNvgYhbW66izM6rCGg/BTExo+B8ua0th2WHkefmhcG6pg
RlMaaoOSHTCmA/pHv2lnO1RXw7QmNNjhxjvhtQ7qgs5o9IIZNZDWMV190Qx9
rJ27YE6z2nzJvBBM6Dst64SixrR7t1ma0dBl2LQH3uqoLuuS9neZt9duOq3B
K1BZC6/0pS7ovEa7IbIPJjWtG69CRR2M6Kj+0kVt7oG2/TCun7TsGqwL20ef
aE7zWt8LrQcgqWktuQ4b6u2jzzWrcxrsg6aD9tEPuqilh+x8w7PQjOZ1S797
H7aPTmhByxv8d9PZ6LjmtHwAao+4VlOa19JGaLzlrDWpsxq47ayP2kcTmtV/
WnUHeps8R53RotYeg55BeK8ZDRz3rO+6Vkc0qwUNnoCWmLPWSS3q+nvmNcMz
/a55rTnpXYrDG03qkgaGoKPFu6RTmtPKU1B33zxN6F8talers38AXzSjFaft
MwwvdFQL+lvbI2Y+hM86pVvP2OeRc9enOq95jfgm/gM996GH
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN009I02Ecx/F3MTyYeIigP0RYRNkyM6tlZmVmtczWMrVaZrbKrGxaeYiI
iBAPER1CosMOMaSDeIghHSRiB6ERHcag8LSDh9FBxECiw4jehx8v+PE8n9+H
5/v8NseHOhIrgK8+a7fDxwis19XnYE5HtLEafmpSG6Mu3AETmtBV5+GHDmtz
EHI6ofUdULYTxnVA/+g3jV2A2hqY1aQGO2HlLnitg7qoOY12mVELaR3XNd1m
6GON7YZ5zWr4onl1MKXvtOISlDShvXvM0ozWX4Yt9fBWx5QYLGu/xvbaTWc1
eAWq98ErfamLuqDRHojsh2lN66arUBWCUR3TX7qk4V7oPACT+kkrrsG6Bvvo
E81rQZv6oP0gpDStZddhY6N99LlmdV6DcWg9ZB/9oEta3mTnG56FZrSgW2/6
7cP20SktauUR391yNjqpea3sh9BR9+qEFrS8GVpuO2tN6ZwGBpz1MftoUrP6
T2vuQLzFc9ScljR0HPruwnvNaKDVs77nXh3VrBY1eALaBp21TmtJN9w37yQ8
0+9a0LpT3qUEvNGULmtgCLrD3iWd0bxWn4aGYfM0qX+1pD1tzv4BfNGMVp2x
z0N4oWNa1N/a1W7mI/isM7rtrH1GnLs+1QUtaMR/4j+ZLKEb
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9I1GEcx/F3EoeDiUM09I+SKLsuM7Myu6zMrMzMrlKry+yyMiu9LBoi
IiLkhoiGEGm4IUQaxCEOaRCJGwyOaDgOCqcbHI4GEQOJhqP38PCCB57P8+H5
/n5bY0ORwVXAN9eGHfC5HTbp2vMwr081XAW/NKnhDijZCRMa1zUX4KcOa1MQ
sjqhdREo3QWjOqB/9btGL0JNCOY0qaFLsHo3vNNBXdKsRi6bUQ0pHdV1nWbo
M43ugQXNaGuXeTUwpR+0vBuKGtfevWZpWuuuwLZaGNOEllyFFe3X6D676ZyG
rkGwDt7qG13SRY1EoWM/TGtKt1yHygMwogn9rcva2gOdB2FSv2j5DVhfbx99
rjnNa2MvtB+CcU1p6U3Y3GAffaUZXdBQDFoO20c/6bKWhe18y7fQtOZ1e593
H7GPTmlBKxrdu+1sdFJzWnEH6o96Vic0r2XHoPmus9ZxnddAv7M+bh9NakZp
gup70KdjmtWi1p+A2AB81LQGmn3r+57VEc1oQUMnoe2Bs9ZpLerGh+a1wEv9
oXmtPeVVg/Bex3VFA0PQfdpvSWc0p8Ez0BA3T5P6T4va0+rsH8FXTWvlWfsM
w2tNaEH/aFebmY9hVme06px9njh3faGLmtcO/4n/GIWhrg==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0zFIlGEcx/FvIXE4mDhEQ1SGlJldZnaV2WVlZmWm11VqddllVmZq5tAQ
EREhN0Q0hEjDDXEcDeIQhzRIxEEORzQcQuF0g8PRIGIg0dB3ePnA+/L+3t/z
/J+3Mj4SGV4HfPPatgs+dUClbroIi/pEw9XwS5Ma7oSS3ZDWMd3YBT91XFtq
IK9pDUWgdA9M6pD+1e8auwT1tTCvSQ1GYcNeeKujuqJ5jV42IwgZndTNV8zQ
pxrbB0ua0/ar5tXBjL7X8m4Xst9uGte8ZjXUAzvrYUoTWtILazqosQN203kN
XoPaBnijr3VFlzV6HSIHYVYzuuMGVIVgQhP6W1e1PQbdh2BaP2v5Tdhy2D76
TBe0oM190HkEUprR0luwvdE++lJzuqTBOLQdtY9+1FUta7LzbfdCs1rQ6n6/
fcw+OqNFrQh7746z0Wld0IoBaDzuu5rWgpY1Q+tdZ60pXdTAPWd9wj6a1Jyu
Pwl192FApzSvDJp3Cvr1g2Y10OJeP/CRTmhOixo8DR1DzlpnlVbY+tA8faE/
tKANZzxLw/BOU7qmgRHobfMs6ZwuaO1ZaBo1T5P6T3kEfeecvX7VrFadt88Y
vNKEFvWP9rSb+Ri+6JzWXLDPuHPX57qsBY34T/wHVuOfRA==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9I1GEcx/F3R0gcDiYO0RD9NTOzy8yszMzKzMrsuq5Sq+sys7KzTBoa
IiIi5IaIhhBpuCFEGsQhDmmQiAscjmg4DgqnGxyOBhEDieg9/HjBD57P8+H5
Ps+m+FA4sQr45rdlO3zqhG267hzM6xNtqYJfmtKWLijZAZM6omvPw099rG3V
kNNJbQxD6U4Y04T+1e8auwD1NTCnKQ1FYM0ueKvDuqQ5jV40oxbSOqbro2bo
U43thgXNaucl80Iwre+1/DIE9thN+zSnGW28AlV1MK5JLemGFR3U2F676ZyG
eqC2Ht7oa13SRY32QmQfzGhat16FygYY1aT+1mXtvAbd+2FKP2v5ddjQaB99
pnktaGsMwgdgQtNaegM2H7SPvtSsLmgoDh2H7KMfdVnLmux807PQjBa0us+9
D9tHp7WoFc3+u+VsdErzWtEPTUdcq5Na0LIWaL/trHVC5zU44KyP2kdTmtXV
rVB3BwZ0XHMauGveMejXD5rR4HHP+p5rdVSzWtTQCegadNY6o4E22HjfPH2h
P7SgDSe9Swl4pxO6osEh6G33Lums5rX2FDQ/ME9T+k8DDyHe4ez1q2a08rR9
huGVJrWof7TnjJmP4IvOas1Z+4w4d32ui1rQiG/iP9FBoNY=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0zFI1GEcxvFvcITE4WDiEA0VkaeZXZeZWZldVmZWdtllpVaXXWZ1Wkk0
NERERMgNEQ0h0nBDiDSIQ4g0SNQNDkc0HAeF0w0OR4OIgUTf4c8H/vA+78P7
e9+tieFYah3w3a+6Gj6fhRrddA4W9alGQ/BbMxrtgrIamNLHuvE8/NIn2l4L
eZ3S5hiU74RxHdF/+kMTF6CxDhY0o5Fu2LAL3umormheey6aUQ+zOq6b42bo
M03shiXNadcl88Iwox+0sgcCe+ymSc1rVpsvQ20EJjStZVdgTVOa2Gs3XdDI
VQg3wFt9oyu6rD29EN8HczqrO/og1AhjmtY/uqpd/dC7H6b1i1Zegy1N9tHn
WtCitl2H7gMwqbNafgO2N9tHX2lOlzSSgM6D9tFPuqoVh+x807PQrBa1bsC9
D9tHZ7SkVS3+u+VsdFoLWpWEliOu1SktakUrdNx21jqpixocdNZH7aMZzen6
KDTcgSGd0LwGhsw7BoP6UbMabPOs77pWxzSnJY0ch9g9Z61zGjgB2+6bpy/1
pxa16aR3KQXvdVLXNDgM/e3eJZ3XgoZPQeuIeZpROsx8AAOa1G+a1dBp+zyE
15rWkv7Vvk4zH8FXndf6M/YZde76Qpe1qHHfxH/v+qFp
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9I1GEcx/F3DUdIiIOJQwRFlPkvuy4zu8rMrMysLjOzUrPLLjM1i4iG
hoiICLkhoiFEGm6I42gQhzikQSpucDii4TgonG5wOBpEDKT38OMFP3g+z4fn
+zzbh8YjYxuA7341u+FLF9Tp1vOwpM+0rQr+aELbLkDJHkjpE91yEX7rU+2o
hpymNByBshqY1knlEvzUqDbVwqImNNQNm+vgvT7WVc1p32Uz6iGt07qtx4y9
8FyjuqxZjVwxrwHm9KNW9EJgn900pjnNaPgq1AZhRuNa0gfrOqHR/XbTRQ1d
g2AI3ulbXdUV7bsOvQdgXtNadQOqG2FK4/pX1zTSD/0HYVa/asUA7Giyj77Q
vBa0fRB6DkFS01p2E3Y120dfa1aXNTQEXYfto591TcvDdr7lWWhGC1ofde8j
9tE5LWrlUf/ddjY6q3mtHIaWY67VlBa0vAU67zhrTeqSlsac9XH7aEKzuqkV
Gu/CqM5oTgMj5p2AEf2kGS1t86zvuVanNKtFDZ2E7lFnrfMaaIed983TV/pL
C9p8yrs0Bh80qetaOg6Dp71LuqB5DZ6B1gnzNKEbO8x8AMMa0x+a0eqz9pmE
NxrXov7TgU4zH8I3XdCGc/Z55Nz1pa5oQXt9E/8BM1ag/Q==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9I1GEcx/F30SAhIQ4mDlEQZXb5r+syMyuzy8rM1Myuq/Sqy8y07IaI
hoaIiAi5IaIhRBpuCJEGcYhDGiziBodDGo6DwukGh6NBxKD38OMFP3g+v8/z
fJ/frth4z9gm4LtP3V742gUNuuMirOhzDVfDH01puBtK98GsPtXtl+C3PtPO
GsjprLb2QPl+mNKEbu6FZY1rcwCWNKWhPth2AD7oE13XnEYvm1ELaZ3Snf1m
1MELjeuqZrXvinn1MK+ftHIAShrspiOa04y2XoXaRpjWpJZG3PBBmNC4LuuS
hq5BMAjv9Z2u65pGoxA5BAua1prrEAjBpCb1r25o3w0YPAxz+k0rb8LuJvvo
S81rQTsGYeAIzGhay4egutk++kazuqqhGHQftY9+0Q2taLHzLc9CM1rQ+tt+
+5h9dF6LWtXquzvORuc0r1VxaDvuWp3VglacgK67zlpndEXLhp31SftoSrO6
tQ2a7sGYTmtOS0bMOwWj+lkzWtbuWd93rU5qVosaOg39o85aF7QkDHsemKev
9ZcWtOWMd2kMPuqM0mHmOMQ0oYua1+BZaH9onqZ0yzkzH8GwjuhPzWjgvH0m
4K0mtaj/dKjTzMfwQxe18YJ9Es5dX+maFjTiP/EfAESgkQ==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9I1GEcx/F3Eg0SEuJg4lANZWZm/rkuM7vKzKzMzjKzy+q0uuxSK3GI
aGiIiIiQGyIaQqThhjikQRzikCCJuMHhkIbjoHC6wUEaRKz38OMFP3g+z4fn
+zw7o6PhkU3Ad7+GPfC1C5p0xwVY1ufaUQV/NKkd3VCyF2b0qW6/CL/1mXZV
Q05nNBSGsn0wpRO6uQeWNKYtNbCoSQ1egm374YM+0XXN6cBlM2ohrVO6q9eM
A/BCY7qiWe29Yl4dzOknreiD4oN207jmNKOhq1BXD9Oa0JJ+KGqAcY3pki5q
8BoEGuG9vtN1XdOBCESaYF7TWnMdagMwqQn9qxvaOwDRQzCr37TiBuwO2kdf
al4L2nkT+g9DStNadguqm+2jbzSrKxqMQviIffSLbmh5i50HPQvNaEHrh9z7
qH10Tle1stV/t52NzmpeK+9A2zHX6owWtDwE3XedtaZ0WUtjzvq4fTSpWd16
AprvwZhOa06Lh807CSP6WTNa2uZZ33etTmpWVzV4Cvrizlrntbgdqh6Yp6/1
lxa09bR3aQQ+akqLOswchSGd0AXNa+AMtI+Zp0nd0mnmQxjWuP7UjNaetc8j
eKsJXdV/OnjOzMfwQxe08bx9xp27vtI1LWjEN/EfeqKiIw==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0zFI1GEcxvGvINEgISEOJkIRZGZ2mZleZnaV2WVll5WZXpep1WWnWYRD
REODRESE3BDRECINN4RIgziESIFE3OBwSMNxUDjd4HA0iPRt+POBP7zP+/D+
3nfnwGgkUQR89zuyB75egGbddRHW9IWGq+GPpjTcBaV7YU6f6Y5L8Fufa1cN
ZHVOQxEo3wfTOqFbLsOqxrW1FlY0pcFu2L4fPuhT3dSsxq6YUQeLOq27r5px
ACY1ruua0Z5r5gVgQT9pZQ+UHLSbJjSraQ1dh/p6mNGklvZC8SF4onFd1RUN
3oCmBniv73RTNzTWB9HDsKSLWtcPgUaY0qT+7f9/gPaJwqDO6zetvAnVTfbR
l5rTvHbGoK8ZZnVRy29BbdA++kYzuq7BAeg+ah/9otyGihY766SmNa8Ng+59
zD66oAWtavXfkLPRec1p1TC0H3etzmleK9ogcsdZ66yuadldZ33CPprSjG4L
Qcs9GNcZzWpJ3LyTMKafNa1lpzzr+67VKc1oQYOnoXfEWeuSlrRDzQPz9LX+
0ry2nfEuJeCjzmpxh5mjMKwTuqw5bToLHWPmaUq3hs18CCOa0J+a1sA5+4zD
W01qQYsewVCnmfpDl7XxvH0eO3d9pRua16hv4h90VKC4
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9I1GEcx/F3BhINEhLiYGIQ/TEzu8zsPM3sKrPL6jIrK7uuUqvrNHMI
h4iGBomICHGIaAiRhhviOBrEIQ5zkIgbHA5pEKFwusHhaJDew48X/OD5PB+e
7/PsjA9Hk5uAH34te+B7N7Tqrguwpq80shf+akojF6F8H2T0he64BH/0pUZr
YUUzGo5C5X6Y1nHdchmWNaHtdbCkKQ31wPYD8EmfK1fM0LiG6yGr07q714yD
MKEJXde89l01rwHm9ItWX4OyQ3bTEV3RnIavQ2MAZnRKy/ug9DA804Qu65KG
bkCwET7qB+UmbGhcY0dgXrPacAsCTTCpU/pPS47apx8GdFYXtPo21DbbR1/r
qha0Owb9xyCtWa28A/VB++g7zeu6huLQ22If/aYld6EqZGed0JwWtOmee7fa
R+e0qDVt/rvvbHRWV7VmADqPu1YzWtCqdugZdNaa1jWtGHLWJ+yjKc3rtg5o
ewBjOqMrWvbQvJMwql81pxVhz/qRa3VS81rU0CmPM+GsdV7LTkPdY/P0rf7W
gnac8S4l4bOmtbTTzGEY0nFd1FUNnoWuEfM0pVu7zHwCSR3RX5rTwDn7jMJ7
ndKibn4KgxEz9acuavN5+4w5d32jG1rQmG/iP1MUoEw=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9I1GEcx/F3YiDRcISEOJg5lJWZ2WVmdv7JrjIzMzMrM7us1Oq0SxrC
IaKhQSIiQm6IaAiRhhtCjgZxkEsaJOIGh0MajoPC6QaHo6H38OMFP3g+z4fn
+zy7IxO90S3Ad7+WvbDcDW265yJs6Cvtroa/mtDuHijdB0l9obsuwR99qX37
IatJDfdC+QGY02nddhnWNartNbCmCQ31wc6D8Emfa9EVM3REw7WQ0jmt7jfj
EMxoVDc1o4NXzauDJf2ilQMQOGw3jWlW0xq+Bg31MK9xLb0OJUfgmUZ1Xdc0
dAOag/BRP2jRoAdz1D4a0RVNaf1NCDbArMb1nxYfs88QjOqi/tDKW1DTaB99
rTnNa88wDB+HBU1p+W2oa7KPvtOMbmooAgMn7KPftPgOVDTbWWc0rXltHHHv
k/bRJS1oVch/d52NLmpOq+5BZ4trNal5rWiF/vvOWhd0Q8tGnXWbfTShGd3R
Dq1j8FTnNauBcfNOwZR+1bSWdXjWD1yrs5rRgoZOw9BDZ60rGghD7SPz9K3+
1rx2nPEuReGzLmjJWTMnYFyndVVz2nwOuibN04Ru7zTzMUxqTH9pWoPn7ROD
9xrXgm59AmNdZupPXdWmC/aZcu76RvEt5DWi/wG/Yp/g
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9IlHEAxvFvIgYSDRIS4qAiZFZmZmZm1+W/rjK7tMyszK7LSk0vk2gI
h4iGBomICHGIaAiRhhviOBrEoQ5pkIgbHA5pOITC6QaHI/oOLx944fe8D+/z
vpWRyd6JbcB3r/Y98K0HOrXmAmzqSw3XwF+NazgMpXshqc+18iL80RfaXwtZ
TWqoF8r3wYLO6I4+WNeYduyHNY1r8BLsPgAf9ZkWXjZDRzRUByld0Np+Mw7C
rMZ0SzM6dMW8eljWz1o1ACWH7KbTmtW0hq5CcwMs6ryWDkLxYXiqMV3XNQ1e
g0AjfND3WngdCo7YR6O6oiltvAFNTTCn8/pPi47aZwhGdUl/aNVNqGu2j77S
Dc1p7zBEjkFCU1p+Cxpa7KNvNaNbGozA4HH76Fctug0VrXbWWU1rTluiPvuE
fXRZ81od8N4dt9El3dDqEeg+6VlNak4rgjBw1601oZtads+tT9lH45rRXW3Q
dh+e6KJmtWTUvHZ4rF80rWUdvusxz+qcZjSvwU4YHndrXdGSLqh/YJ6+0d+a
067TfksT8EkTWhwycxLGdUZXdUMDZ6AnZp7GdedZMx/ClE7rL01r0zn7TME7
nde8bn8EY91m6k9d1dbz9pl2d32tBf4LOY3qfznPoXI=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9IlHEAxvFvIGIg0SAhIUImVmZlZnaZ2XWZf64yu6zMrOyyy0rPukSi
IRwiGhokIiLkhoiGEGm4IQ5pEKE4pEEibnA4pEGEwukGh6Pv8PKBF37P+/A+
77sjOhaJbwK+e3Xsgh/d0KW152FdX2lkN/zTlEZ6oHwPzOkL3XkB/upL7auF
VZ3TcAQq98KMTuqWi7CiCW2vg2VNaagXtu+DT/pciy+ZocMa3g8ZndG6y2Yc
gClN6IbmdPCKefWwoF+0ug/KDtpNJ3RVsxq+Cs0NMKtJLe+H0kPwTBO6ossa
ugbBRvioH7R4AIoO20djuqgZbboOgSaY1qRyA0qO2EdHdF5/avVNqA/YR1/r
mua1dxCGjkJaM1p5Cxqb7aPvNKcbGorCwDH76DctuQ1VLXbWKc1qXluGfPZx
++iCFrSm1Xt33EbndU1rYtB9wrM6p3mtCkL/XbfWtK5rxbBbn7SPpjSn20LQ
dg+e6qyuatl9807BE/2qWa1o810/8KxOa04LGjoN0RG31kUta4eGUfP0rf7R
vHZ2+C3F4bOmtbTTzDGI66Qu6ZoGu6DnoXma0q1hMx/BuE7ob81q4Ix9EvBe
k1rQzY9h9KyZ+kuXtPWcfcbdXd9okf9CXmP6H9XuogU=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0zFIlGEcx/FvDSIGEg1HSIiBmZVZmZldZnZdZnqWXWZlZnWZXVZ61RES
DeEQ4dAgEREhDhEOIdJwQ8jhIAZxSINE3OBwSMMhFE43OPQdXj7wwPN7fs/7
f9+dsZHo8Cbgu0/HbvhxHjq15gKs6xvtroZ/mtLuLijbA2l9rbsuwl8d1969
kNe0RqJQsQ9mdEy3XoJVTWpbDaxoSsPdsGM/TOsrLb5shg5ppBYyOqO1PWYc
gAlN6obmNHbFvIOwqF+16ioEDtlNRzWvWY1cg6Y6mNUpLeuF0sPwUpO6qisa
vg6hevisn7S4D4qO2EfjuqQZbbwBwQaY1Cnd3A8lR+2jw7qgP7XqJtQ12kff
6poWtOcWDB6DOc1oxW1oCNpHP2hONzQcg/7j9tF5LbkDlU121gnNakGbBzz7
hH10UbkL1c2u6bgu6JpWD0LXSfdqWgta2QJ995y1zum6lsed9Sn7aEpzuj0E
rffhhc5qXgND5p2G5/pNs1oe9l0/cK9Oak556F3OwIBO65IGWqH+kXn6Xv9o
QdvP+i0Nwxed09I2M0cgoWO6rGsaOgfRhHma0m3tZj6GZzqqvzWrwQ77PIGP
OqVEYMtTGNGE/tJlbem0T9K56zst8l8oaFz/Aw5+oJo=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9I1GEcx/F3R4OIgUTDERLmoJeVWZmZXWZml5mdedllZWZmZpf5r5CQ
aAiHCIcGiYgIcYhwCJGGG0KkwRxCpEEibnA4pOE4KJxukN7Djxc88Hyez/P7
/n57e4Zig9uA7z6tZfAjCm1a0Qqb+lrjIfinSY1fhqJ9sKivtKwN/uqkdpZD
Rhc1GoOS/TCnE7rzCmzomDYfgHVNaqQd9hyEWX2p+VfN0AGNVsCKzmll3IxD
MKVjuqVp7b1mXiUs6xcNdUDwsN10XDOa0uh1qDsC8zqjRTeg8Ci80DHd0HWN
3ITGKvikHzW/E/KO2UcTuqorWnsLwtUwrTO6vQsKjttHh3VJf2roNlTV2Eff
aFZz2tEN/SdgQVe05A7U1NpH32tatzTSA90n7aPftOAulIbtrFOa0pzW93r2
KfvosgbuQXmdazqpS5rV8j6InXavLmpOS+uh676z1gXd1OJ+Z33GPprUtO5u
gKYH8FznNaPBhHln4Zl+1ZQWN/quH7pXpzWtgQHvcg76dFZXNRiB6kfm6Tv9
ozltOe+3NAifdUELm8wcglGd0DXNauMFaB82T5O6q9nMEXiq4/pbUxq+aJ9R
+KAzGmiBHY9hREf1l65pwyX7PHHu+lbz/BdymtD/iNyiLA==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9I1GEcx/F3IA0iBhINR0iJ0GlWZmVmZmZml112+S+zMrMys0tLb5CQ
aAiHCIcGiYgIuSHEIUQabojjCBSHEGmQiBscDmk4DgqnG3oPP17wwPN5Ps/v
+/vtHxzrGN0BLPt0HoAf7dCt1VdhW99qbxD+aUJ7I1BaASl9oxXX4K/OaH8l
ZDWlkQ4oPwiLOq27O2FLJzVcBZua0FAX7DsEC/pai7rN0FGNHIY1XdSaHjOO
wKxOKtcho0MaroZV/aqVvRA4ajed0qymNXIDmmpgSeNa2gclx+CVTuqWbmro
JrQeh3n9rEW3oPCEfTSq67qmDbehsRbmNK47+6H4pH10XFf0p1begdo6++g7
zWle+wZg5BQkdU3L70J9vX30o2aU0/YZhEGd1+9afA+CDXbWWU1rXpvve/YZ
++iqFjyAqkbXdEZXNKdVQ9B11r2a0rwGm2DgobPWpG5r2bCzPmcfTWhG9zZD
2yN4qUua1cCIeefhhX7TtJa1+K4fu1fnNKMFUe9yAYZ1Qdc10Ap1T8zTD/pH
89p+0W9pFL5oUktCZo5BTKd1Q3Paegl6npqnCd3TZuYzeK5T+lvT2njZPuPw
SeNaEIZdEzChMf2lG9pyxT4x567vtdB/Ia9R/Q8LB6HA
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9I1GEcx/F3DtIgYiDRIGEhVqddZVZmZpeZmdllZ/nnsrLLysxOK3OQ
kGgIhwiHBomICLkhxCFEGm4IOQrEIUQaJOIGh0MaDqFwOnoPP17wwPN5Ps/v
+/vtig1F4luA7z6de+BHGLq16hJs6huN7oV/mtRoG5Tug5S+1orL8FcntTcA
WU1pJALlFTCnE7q9HdZ1TMOVsKZJbbkCu/fDrL7Swqtm6LBGgrCsc1rdYcYB
mNIxzeuEjPZr+CAs6Ret7IKSQ3bTcc1qWiPd0FAF85rQ0igUH4aXOqbruqYt
16C5Gmb0kxb2QMER+2hcV3RZ669D6ChMa0K33oCiY/bREV3Un1p5E2pq7KNv
dUNz2tMLg8dhQZe1/BbU1dpHP2hG807YJwZ9OqPftOg2BOrsrFOa1pw29nn2
SfvokubfgWC9azqpi7qhwbvQccq9mtKcBkIQu+esdUE3tazfWZ+2jyY1ozsb
oPU+vNB5zWrJgHln4Ll+1bSWNfquH7hXpzWj+YPe5SwM6KyuaEkT1D40T9/r
H81p2zm/pTh81gUtbjZzCEZ1Qld1Q5vPQ9eweZrUHS1mPoJnOq6/Na2hC/Z5
DB81ofmtsO0JPNVR/aWr2nTRPiPOXd9pgf9CTuP6H4Vlo1I=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9I1GEcx/F34CANIgYSDUdJ2FVqVmZlZmZmdl1m11Wmp9VlVman2T8H
CYmGcIhwcJCIiDhuCHEIkYYbQq4GcQiRBom4weGQhkMonHoPP17wwPN5Ps/v
+/vtiA9GEpuAbz5du+BHG3RrzQXY0EmNBeGfpjXWDmW7IaNvtPIi/NUJje+B
vGY0GoHgXpjVcd16CdZ0VNsrYFXTGo7CzkqY0ddafNkMHdZoFSzprNZeMWMf
TOmoFlyFnPZrezUs6het6oDAfrvpmOY1q9Fr0HwA5jSlZZ1QehBe6aiu6aqG
uyBUA9P6SYtjUHTIPjqky7qkjd3QVAtJTenmHig5bB99qgv6U6uuQ90R++hb
XVeOQs8NSOi8LmnwJjTU2Uc/aE4LjtknDn06rd+15BZU1NtZpzSrHIeWXs/W
pC5q4W2obnBNJ3RB17W6DzpOuFczyh3zGqFXJ3VeN7T8rrM+aR9Na063N0Hb
PXipc5rXQL95p+CFftWsljf7ru+7V5Oa08IB73IaBnRGlzXQAvUPzNP3+kdJ
QOSM35J+1nktbTVzEEZ0XFd0XUNnoXPIPE3rtpCZD+G5julvzWrTOfsMw0dN
aWEYtjyCZzqiv3RFW8/b57Fz13da5L/AE+eu/wEkYp/p
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9I1GEcx/F3NzhIg4iBRMMVUtdVelmZlZmZmdlldtlVZv7LzMpOM4Ny
kJBoCIcIBweJiIjDIcQhRBpuiEsaxCEOaZCIGxwOaRChcOg9/HjBA8/n+Ty/
7++3s3sgltgCfPPp2AM/mqBLKy7Bpk5qewj+aUrbm6FkLyzoGy27DH91QnvC
sK4LGo9BeB/M6bhuvwJrOqqx/bCqKW1qgd0HYFZfa+FVM3RY46WQ0TmtjJtR
BlM6qnnXIKf9GovAkn7RyHUIHrSbjum6ZjV+A+rLYV6ntaQVig/BKx3VNV3V
ppsQPQwz+kkL26DgiH10SJc1o7W3oK4CkjqtW9uh6Kh99Kku6k+NdEBVpX30
rW5o4Bh0dsKgpjWj4S6oOW4f/aA5zTthn27o0xn9rkW3obTKzjqlWQ2chIYe
z9akLmn+HSivdk0ndFE3tLwXWk+5Vxc0cNe8GujVSU3rpob6nPVp+2hKc7qr
FprvwUud13UN3jfvDLzQr5rVUJ3v+oF7Nak5ze/3LmchobO6rMF6qH5onr7X
PxpIQMs5vyX9rGktbjBzAEZ0XFd0Q6PnoW3QPE3pjkYzH8FzHdPfmtW6C/YZ
go86rflR2PYYnumI/tIVbbxon2Hnru+0wH8h8MS563+ewKF7
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0zFIlGEcx/FvcIPD0SBiIBF0hJldpWZlVmZmZmZml9pVZteZZlZqZg3l
ICHREA4RDg4SERFyQ4hDiDTcUHI0iEMc0iARNzgc0nAIhfQdXj7wwPN7fs/7
f9+d8cHIwBbgm0/3bvjRAj1adRE2dUpjJfBPkxprheI9kNI3Wn4J/uqk9pZC
TlMajUB4L8zrhG6/DOs6pm1hWNOktrZByT6Y09da0G6GPtHofkjrvFZ3mHEA
pnVM865AVge0rQyW9YtWRCFUbjcd15xmNHoVGitgQRNafA2KDsIrHdN1XdPW
69BSCbP6SQs6If+QfXREVzSt9Teg4TDMaEK3dkHhEfvoU13Sn1pxE2qq7KNv
dUMDRyEeg2Fd1LSGb0FdtX30g2Y175h94tCvs/pdC7uh7LiddVozGjgBTbc9
W2d0WYM9UFnjmk7qkm5oZS90nnSvpjRwx7xa6NMpXdRNLe1z1qfso0nN6q46
iNyFl7qgOQ31m3caXuhXzWhpve/6nnt1RrMavO9dzsCQzumKhhqg9oF5+l7/
aGAAOs76LelnXdSiRjMHYVQndFU3tOUcdA2Zp0nd0WTmQ3iu4/pbM9pw3j7D
8FETGmyGbY/gmY7qL13V5gv2GXHu+k7z/RcCj527/gcZLaMN
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9IlHEcx/F3yw0O0iBiIFEgZWZXqV1lVmZml5ldl112ldll+SdTM4uG
cjhCokEcIhwcJCIiDocQhxBpOCjkaBCHEGmQiBscDmmQg6L38PCCL/w+z+d5
vs+zMzEYHdgCfPXq3g0/WqFXay86KIcpTeg/TWsi4ngPZPSNVl+CvzqpPRWw
qRmNRyG4F+Z1Qrdfhg1NaqwS1jWt0Tao2Adz+lqLr5ihTzUehBWd17qYGfth
WpNacBVyOqSxA7CsX7SmHcoO2k3HdFOzGr8GzVWwoDNaHofSahjXpG7oukav
Q6QGZvWTFt+AokP20Se6qivadBPCIUjpjG7tgJLD9tFnuqQ/teYW1B+xj77V
vAaOQlcnjOiirmjwNjTW2kc/aE4LjtknAf06q9+15A5U1dlZpzWrgePQ0uW9
NaXLWngXQiec6aQuaV5D96DjpGc1o4Fu8+qhT6d0UTkFlT3uWsc1rTnd1QBt
vfBKF3RTy/rMOw0v9ZtmtbLRd33fs5rSnBb2+yxnYFjndFXLmqDhgXn6Xv9o
YADaz/ot6Wdd1NKwmYMwqhO6pnmNnIPOIfM0rTuazXwIL3RMf2tWw+ftMwwf
dUYLW2DbI3iuo/pL17T1gn1G3Lu+0yL/hcBj967/AXdtoqE=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9I1GEcx/F3Tjc4SIOIgVSDmdl1lV5WZmVmdpnZZXbZVXZdVv4ts4iG
cpCQaBCHCAcHiYgIcQhxCJGGC+KQBnEIkQaJuMHhkIbjoN7Djxc88Hyez/P7
/n47EoPRgS3AN5/eXfCzFfq17gIUVMCUJpU2SGlSK3fDkr7VmovwTye1pxJy
uqTxKIT2wIJO6PZLsKmjGquCDU1peztU7YV5faMll83QZxoPwqouaH2HGftg
Wke18ApkdUhjIVjRrxqOQfl+u+mY5jSj8avQcgAWdVYrO6HsIIzrqG7qhrZf
g2g1zOlnLYlDcY199Kmu6ao2X4dIGGZ0VrfegNJD9tHnuqy/NHwTGmrto+80
r4HD0N0FTzStqxq6BU1H7KMfNauFR+2TgAGd0x9aehuq6+ys05rRwDFoTXq2
zuiKFt2B2nrXdFKXNa+13dB13L26pIG75p2APp3StBachOA9Z63jmtKsVjRA
x314rYua0/Ie807BK/2uGQ02+q573aszmtWiPu9yGoZ1Xte0vAka+83TD/pX
AwPQecZvSb9oWsuazRyEEZ3Qdc1r9CwkHpinKd0ZMfMhvNQx/aMZjZyzzxB8
0lktaoFtj+CFjuhvXde28/YZdu76Xov9FwKPnbv+B/SdozQ=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0zFIlGEcx/Gv4XSDw9EgYmARdNllZqXXVWZlZmZmZmaXXXWZWZmnZRHR
UA4SEg3iEOHgIBERITeEOIRI4A0h0iAOcUiDRNzgcEjDIX2Hlw888Pye3/P+
33d7ItnWXwAs+CR3wa8WGNTaC1AYgknt0S2tkNYeDe+GJX2vNRehoBwmtE/z
uqTxNqjaA3M6rjsuwYaOaCwM65rWjnao2Auz+k5LLpuhLzReARmd07oOM/bB
lI5o0RXI6ZDGKmFFv2ukE0L77aajmtesxq9CSxXMa0rDMSg7AGM6ohu6rh3X
oP0gzOhXLemC4kP20ee6qhltug7N1TCtKd0ah9Ia++hLXdbfGrkB9RH76Afd
1MBh6L0Jz3RRM1p1Cxqj9tHPmtOiI/ZJwIDO6E8tvQ3VR+2sU5rVwDFo7fZs
ndYVDd6BaK1rOqHLuqnRHkgcd68uaeCueXXQr5O6qIUnoLLXWeuYpjWn5Seh
8x681XnNa+i+eafgjf7QrFbW+64fuFenNafBPu9yGp7qrK5qqAEaHpqnn/Sf
Bvqh64zfkn7TRS1rNDMJwzqua7qp7Wehe8A8TevOJjMH4bWO6l/NavM5+zyC
L5rSYDNsewyvdFj/6Jq2nbfPkHPXj1rsvxB44tz1P43Ao8c=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9I1GEcx/F3FE43OEiDiJFEfy67zK7Sy8qszMwuu9TMLrvMzKxO04yI
aCgHCYkGcYhwcJCIiDgcQhxCpOCGOKRBHEKkQSJucDik4eg9/HjBA7/P7/P8
vs+zvas/ltwEfPcZ2gW/ojCstRehYDdMaa9uaYa09mpoDyzqO62+BJuDMKlJ
zeuiJmIQ3gvzOqE7LsOGjmq8HNY1re0tULEP5vStlrSaoc81EYIVnde6NjP2
w7SOauEVyOljjVfAsn7TSDsED9hNxzSvWU1cheZKWNAZDXVA2UEY11Hd0HVt
vwZtYZjVL1oSh+JD9tFnuqor2nQdoochpTO6tRNKj9hHX+iS/tbIDaivso++
VxIQqIY+faoZXdHwTWiM2Ec/aU4Lj9qnCwZ1Vn9q6S2oqrGzTmtWA8cg1u23
NaXLWnQbao67ppO6pJxwrQe6dVoXNXDHvFoY0CnNaMFJqOx11jquac1peR10
3IU3uqB5DfaZdwpe6w/NauVp//U939WU5rTovns5A090Tlc1WA8ND8zTj/pP
A0noPOtZ0q+a0bIGM/thRCd0TRlwTuegR+c0rTsbzXwIr3RM/2pWo+ftMwif
dUaLmmDbELzUEf2ja9pywT6PnLt+0GLvQmDYuet/p1KiXA==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9IlHEcx/F3B4XTDQ7SIKIgZWVmZlfpZWVWZmZ2mdllZleZXaZmRn+I
aCiHIyQaxCHCweGIiIjDIcRBxBpuiEMaxCEOaZCIGxwOaeg9PLzg9/B8ns/v
932esthQZHAT8M3r0Xb41QZPtPEcFFTAtMZ1SzukNa7VO2BJ32v9edi8E6Z0
WIl4T2Ma2gULOqnbLsCGJrSnEtY1rdEOqNkNc/pOSy6aUQUvNKZZXdCmTjP2
QFITWngJ8vpYe6phRb9ruAsq99pNx5XLkNOYRmpgUWe0Ogrl+2BCE7qh6xq9
Al21MKtftaQbivfbR5/rqma17Sq0hyClM7q1B0oP2Edf6rL+1vA1aD5oH/2g
gV4IHoIBfaYZzWroOrTW2Uc/a14L6+0Tg1Gd1Z9aegPqwnbWpOY0eBg6bvpu
TemKFt2ChgbXdEqXNXDEtT7o06QuafC2eUdhRKc1owXHoLbfWeuEpjWvVY3Q
fQfe6qJy3LOOm6dv9IfmtLbJs77rs5rSvBYNuJcT8FTndFUrT0LLPfP0k/7T
4CD0nvJb0nnNaHmzmUMwppO6poFh53Qa+nVO01rRYuZ9eK3j+ldz2n7GPiPw
RWe0qBXKHsArHdM/uqadZ+0z6tz1oxb7LwQfOnf9D4nUn/I=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9IlHEcx/F3h1A43eAgDWIGZlaXmV1WalZmZWZ2mZmZXddVZtdZZg39
IxrK4QiJBnGIcHCQiIg4bghxCJOGG0KkQRxCpEEibnA4JHoPDy/4PTyf5/P7
fZ9nU2wgklwHfPN6tAV+tcETbToNhRUwoQnd0A5ZTWj1VpjXd1p/BtZXwrgO
aiDiPY1r7TaY0TGtOAtrmtLodljVrPZ0QM0OmNa3WnrOjBA817gu6Yw2d5qx
EyY1pUXnIa8PNVoFi/pdG7ogtMtuOqKBC5DTuHZUw6xmtLobynfDqKZ0TVe1
5yJ018CUftHSHijZYx99psu6pO2XIBKGtGZ0Yy+U7bWPvtAF/a0Nl6Gl1j76
XguiENwHSX2qc7qktVegbb999JPmteiAfWLwQKf0p5Zdhbo6O+uk5jRYD51x
361pXdTia9DY4JqO64IWHHTtOvTppM5r8IZ5jTCkEzqnhYcg3OesdVSzmteq
w9B7E97orAaOeNb95ulr/aE5DTd51rd8VtOa1+KEezkKj3ValzXUDK23zdOP
+k+DSYgd81vSrzqn5cfNHIBhHdMVLbjjnE5Av05rVitbzLwLr3RE/2pOIyft
MwifNaPFrbD5HrzUYf2jK9p1yj5Dzl0/aIn/QvC+c9f/BEGhhA==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9I1GEcx/F3cBwUTjc4SIOJ0WVWZpeZlZqVWZnZdZmZXXbZVWanlUVD
9I+GcpCQaBCHCAcHiYiI44YQhxJpuCFEGsQhDmmQiBscDuk9/HjB8+P5/D6/
58uzKTEQTa0Dvvs82QK/2+CZNp+GojBMako3tENWUxrZCgv6XhvOwPoKmNAh
DUR9p0mt2wazOq4VZ2FNRzRRCaua1XgMarbDjL7TsnNm7IAXmtSczmpLhxk7
YUpHtPg8FPSRJqpgSX9oYydU7bKbjmrgAuQ1qR3VMKcZjXRBeDeM6Yiu6arG
L0J3BKb1q5Z1Q+ke++hzXdacRi9BrAbSmtGNcSjfax99qYv6RxsvQ2utffSD
BnsgtA8G9anOa07rrkB7nX30sxa0eL99EvBQp/WXll+F+gN21inNa+ggdPb6
bU3rkpZcg6Z613RCFzXY4FoS+nRKFzR03bxGeKCTOq9Fh6D2hrPWMc1qQaub
oOcmvNU5DRz2rPvM0zf6U/Nae8SzvuVeTWtBS/r9l6PwWGd0Wauaoe22efpJ
OWafFPTqkH7TeQ23mDkAwzquKxocdE7HoV9nNKuVJ8y8A691VP9pXmMn7XMX
vmhGS1ph8z14pcP6V1e065R9hpy7ftRS70LovnPX/+Mrohc=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9I1GEcx/F3DYdQON3gcASJaJlZmV12XaWXlVmZmV1mZnZddpWpWUk0
RPRvKAcJiQZxiHBwkIiIOG4QEQqRhhvikAZxCJEGibih4eg9/HjB8+P5PJ/f
8+W3OTHQ1r8O+OrztAJ+tcBzbToNxVtgSgd1YytkdVDDW2FR32vDGdhQCZM6
rIE232lKo9tgXie06qwHVMGoJvWfZrWnHeq2w5y+07JzZlTDC03pis5rc9zt
O2BaR7XkPBT0kSZ3wrJ+11gH1Oyym45p4ALkNaUdNbCgGQ13QuVuGNdR5aKd
tEe7a2FWZ7SsC0r32Eef6aquaPsliIchrRnd1A3le+2jL3VJf2vsMrTU2Uc/
aFEPBPfBkD7RnK5o9Aq0Reyjn7WgJfvtk4CHOqs/tfwq1EftrNOa1+AB6Ex6
tqZ1WUPXoPGgazqpS1p0yLVe6NNpXdTgdfPq4YFOaU6LGyCSctY6rlktaG0M
EjfgrS5o4LB3fdM8faM/NK+RRu/6lns1rQUN9fktR+Cxzumq1hyF1tvm6Sdd
f8w+/dCrw/pNc1rZZOYAjOiErmnRoHM6Dv06p1mtbjbzDrzWMf2reY2fsM8Q
fNGMhk5CxV14pSP6R9e065R97jl3/ail/gvB+85d/wOGJ6Gr
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9I1GEcx/F30iAHhdMNDVIgpmVmdZnZdZWalVnZZXaZmV122VVql4FE
Q0T0B8rhCIkGcYhwcDgiIuK4QcQgRBpuiEMaxCFEGiTihobew48XPA+/z+/z
PF9+W+JD0cF1wFefZ1vh12l4oW1noKwKpjWlGzsgryltqIZFfa/NZ2HDNpjS
US2NuqdJjWyHeZ3U2nNQUgNpTeg/zWu8Exp3wJy+08rzZtTCc03qis5re5cZ
OyGjad10wcJ18EgTuqzftSUGoV1203EtvQhFTWr3bljQnDZ0Q80emNC0llyy
k8a1LwSzOqOVPVCx1z76VFd1RbsuQ6wesprTzb1Qtc8++lKX9Le2XIGOBvvo
Bw30QXA/jOgTLeiKRq5CZ6N99LMS94wHRB/qrP7UqmvQFLazZrSowYPQ0++3
NavLWn4dWiOu6ZQuaeCQawkY1IwuavCGeYfhgU5rQcuOQHjAWeuE5pWbUN8E
/fpWF7S02btOmqdv9IcWNdziXd/yXc0qR+1z27PoY53TVQ21QvSOefpJ1x+z
zyAM6Kh+04LWHDdzCMZ0Utc0MOycTsCwzmle69rMvAuvdVz/alFjJ+2Tgi+a
0/J2qL4Hr3RM/+ia9p6yz4hz149a4b8QvO/c9T9F9p9B
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0zFIlGEcx/FvhzTIQeF0Q4M1mGmZWV12mVnpZWVWZmaXmV2XmV1qZg0S
DRERReVwhESDOEQ4OBwRESE3iDmESMMNcUiDOMQhDRJxQ/QdXj7wPLy/9/c8
f97N8cG2gXXAV5/nW+FXK7zQltNQUg7TOqIbz0BWRzSyDZb0vTadhQ0VMKWj
Wtzmnia1oRIWdFKrz0HRdkhpn/7TrCbaoW4HzOs7LT9vRhU806TmdUFbO8zY
CWlN6aYLEKiGR9qnK/pdo50Q3mU3Hdfii1DQpHbVwKJmNBKDqt0woSktumQn
TWh8D8zprJZ3Qdle++hTXdW8dl6GWBhmNKNbuqFin330pS7rb41egbZa++gH
DfZAaD/c1yea07w2XIWOiH30swbinvGAffShzulPrbgGjXV21rQWNHQQuhN+
W2d0RUuvQ3O9azqlyxo85FovDGlalzR0w7wGeKDTmtOSw1Df56x1QrMauAm1
R6BX3+qiFh/1rvvN0zf6Qwta3+hd3/JdndFAk32SnkUf67yuajgK7bfN00+6
/ph9BqBfR/Wb5rSq2cxBGNNJXdPgkHM6DsM6r1mtOWHmHXit4/pXCxo7aZ9h
+KIZLW2ByrvwSsf0j65pzyn7jDh3/ahl/guhe85d/wPAVKDT
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN00FIk2Ecx/FvMKSDDApPOwRJ0Fpay6yWLTMrNSszKzNbZsvMls0ykw4S
HSIigsrDCIkO4iHCg4cRERGyQ8kOIdLBQwzpIB5iSAeJ2KHv4eUDz8v7e3/P
83/fzcmhjvQ64JvXi63wuw1eadtpqAjDjI7qxnZY1FGNb4Mlfa/NZ2BDBKZ1
TMs7vKdpbdwO8zqlNWehrAoymlLOmaf9Wl8NeX2nkfNm7IDnmtaizmt7pxk7
IasZ3XQBAlF4rCld0R/a0gWxXXbTCS2/CCVNa08NLGhO490Q3Q2TmtGyS3aq
tY/26Zx+1UgCwnvso890VYvafRkSe2FWc7qlB6r22Udf6rL+0ZYrbjVmH/2g
wV4I7YcH+lQLWtTGq9BVZx/9rIGkezxgH32kc/pLq65BU9zOmtWShg5Cb5/v
1lld0crr0Frvmk7rsgYPudYPw5rVJQ3dMK8BHuqMFrTiMDQMOGud1EUN3IS6
RhjQt7qg5Uc865R5+kZ/akkbjnrWt3xWZzVwzD6D7kWfaF5XNdYEnbfN00+6
vtk+aRjUMf2uBY22mDkE4zqlaxq845yOw4jmdVFrW828C691Qv9pSRMn7DMM
XzSnlSeh+p7fuY7rX13T5Cn7jDh3/ahh/4XQfeeu/wFzQKBn
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN009Ik3Ecx/F3HYZ0GIPC0w4F0p9ls8yszJaZlS4rszIzW7bMzGyuspAO
Eh0iIjqUgYREB/EQ4cHDiIgIERLZIUQ67BBDOoiHGNJBIkbvw8MLfg/P5/n8
ft/n2ZQcaE2tAb55vdoCv0/Ba205DaVbYUqHdEML5HRIY9tgUT9o0xlYH4FJ
HdZgq/c0rQ3bYV4ntOoslJTDqPbr2nPmaa/W7YCsvtfy82ZE4YWmtaDz2tpm
RgVkdFQ3XoDATnii/bqsPzTeDjW77KZjGrwIRU1rVyUs6IzGOqByN4zrqJZc
slOVfbRH53RWyzshssc++lxXtKCdlyFRDdM6o5sTEN1rH32pS/pH41egbZ99
9KOGuiC8Hx7qM81rQRuuQkeNffSLBpLu8YB99LHO6S+NXoPGWjtrRosaPgjJ
bt+t07qsZdehOeaaTuqShg651gODmtFFDd8wrw4e6ZTmtfQw1Pc6ax3XnAZu
Qm099Ok7XdDgEc+6zzx9qz+1qPUNnvUtn9VpDRy1T7970aea1RWtOQbtt83T
z7ruuH1SkNJh/a55rWw0cwBGdEJXNZR2Tk3wQLOa0+q4mXfgjY7pPy1q4oR9
7sJXndGyZqi45/euI/pXV7X7pH0Gnbt+0oj/Qvi+c9f/7Z6h+Q==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN009Ik3Ecx/F30GFIhyEUngZ1MKu1Zi2zWmZmVmpWy8rMzFaZmU1bfwjp
INFBIqJDGY2Q6DA8RHjwMCIiQhaE7BAiHTzEkA7iIYZ0kIjeh4cX/B6eD5/v
78uzPjmYSK0Cvvq83Ai/2+CVJo5DRRVM6bCuOwHzOqz1m2BB32vLSVi7GSZ1
RIMJ32lam7bArE5ozSkoC0NGU7q63Tzt14atUNB3GjltRgSeaVpLOqvtZ8zY
BjnN6IazEIjCqKZ0SX9oawfEq+2m4xo852DbzdKkzmle6zshtgOymtGy83aK
2Uf7dEa/aaQLwjvto091WUvafQF6amBa81rVDdFd9tHnuqh/tPUidNTaRz9o
eQ+EdsMDfaJFLWnTJejaYx/9rIGkM+61jz7SGf2l0cvQHLez5pQr5u0THdVp
XdLKq9BW55lO6qKW7/esF+5pThc0dM28enioU1rUigPQ2OeuNavzGrgOdQ0w
oG91ToMHvet+8/SN/lRu+G2jd61ZndbAIfsMOIs+1oIua7wJOm+ap590zWH7
pGBIR/S7FjV2xMxBGNMJXdHyIfd0FO5rQee1ttnMW/Bax/WfknZPLfbRL5rX
ylaovg0vdEz/6or2HrPPHfeuHzXsvxC66971P6CIn48=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0zFI1GEcxvFvDg2HNMhB4XRB0GVlpnWZ1WVmZqWXmVmZmV2XmZledkGE
NEg0SEQ0lNAVEg2HQ4SDwxEREdcNITeESINDHNIgDiHSINF3ePnA++d9eN73
x39zfLh9aB3wzfVqK/yJwWvtOA3lYZjRUd3UBgs6qg3bYFE/aOsZ2FgB0zqm
Ze1+05Q2b4c5ndLas1C6A9Ka1PUd5umgNu6Egr7XqnNmVMJzTemKzmlnpxm7
IKtp3XIeAlUwrkld1p8auwDR3XbTSS27CCXVZmlC5zWvDV0QqYGMprX0kp32
2EcHdFa/a1U3VO61jz7TVV3R3ssQj0BO81rRA9X77KMvdEn/auwKdNXaRz9q
sBdC++GhPtWirmjzVeips49+0UDcOx6wjz7WWf2t1deg5aCdNaslCfMOQZ+O
a06XNXwd2qLu6bQuafCwe31wX7O6qKEb5tXDI53RopYfgaZ+Z60ZXdDATahv
gCF9p/NadtS3HjBP3+ovLbnl2UbfWjOa08Ax+wx6F32iBV3VaBN03zZPP+uG
4/YZghEd0x9a1EizmcMwoVO6psGkczoBD7SgC1p30sw78EYnlVP2GXFOmtCv
mtdwC9TchZc6of90Tftb7ZNy7vpJK/0XQvecu/4HzzGgIg==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9I1GEcx/F34dBwSMMhFC7d0B+zuq6zLrMyM7Or9LrKrMzM7DKz08wc
IqRBokEioqEcrpJoOBwiHByOiJA6HEIcQqThhhBpEIc4pCF6Dw8veH48Hz7P
8+W3qbMvmV4DfHO93gJ/muCttjRD+VaY0mHdmICCDmv9NljSj9p8BjZUwKSO
aDDpNx3S+HaY1wmtPgullZDRAV13zjxNa8MOmNMPGjlvxk54oUNa1HltbTFj
F+Q0o5svQCAMozqgK/pTE61Qu9tuOq7Bi1ASMUtTuqAzWn8JYnsgqxktvWyn
qH20V2f1u0baIFxlH32uq1rUzivQtRfyOqOV7RDdZx99qcv6VxNXoS1mH/2k
ZR0Q2g+P9JkualHj16Cj2j46rYFO73jAPvpEZ/W3Rq9DU42dNaclXeYdhG4d
1byuaMUNSB5yTyd1WcsOu5eCB5rTJQ3dNK8WHuuULmr5EWjsdtaa1YIGbkFd
HfTre13Q4FHfusc8fae/tOS2Z+t9a81qXgPH7NPrXfSpzumq1jZA+x3z9Iuu
P26fNAzqiP7QRY01mtkHYzqh/7Ss3zmdgIc6pwWtiZt5F97ouK49aZ8B56Qp
/aozWnEKqu7BKx1TTpupPdo+6Nz1s4b9F0L3nbv+ByXBoLU=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0zFIlHEcxvFvETc0HNJwCIUQCFldVmZnXWZ12WV2lV5WZmV2mV1mp5mF
Q4Q0SDRIRDSUw1EWDeIQ4eAgEVFx3CByQ4g03BAiDeIQIg19h5cP/F/eh+f3
//FuTvUmM2uA7z5vt8Df0/BOW89AWQVM6ZBuaoKiDml8KyzqJ21uho3bYFKH
NZT0nQ5qYjvM6YTWnoWSMGR1QNe3mKd92rADCvpRq8+ZUQkvdVBXdE7bzpux
E6Y1qxUXILgLRnRAl/WXJlshtttuOqahixCoMkvTOq95jbdBdA+Ma1ZLLtmp
2j6a0Vmd0erLULXXPvpCV3VFO69AVwRymtfKdojU2Edf6ZL+0+RVaN9nH/2s
pR1Qvh8e63Nd0BVNXINU1D76TYMpZzxgH32qs/pHI9ehqdbOOq2BTvMOQreO
aE6XNXwDWuo800ld0tJDnnXBQ53WRS2/ad5heKJTuqBlR6Ax7a51XIsavAX1
MejXDzqvoaPedbd5+l5/a+C239Z71zquOQ0es0+Ps+gzLeiqxuLQccc8/aob
jtsnAw90WH/qgkYbzOyFUZ1QTjhLn3vSR1rQotY1mnkX3uiYrjtpn373pGn9
oXkNJ6DmHrzWUV17yswB6NEOndEvWuW/UH7fvet/DLGgSQ==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9IlHEcx/F3EeHQcEjDIRS2XGV1WdmldZnVZZeZ1XlZmZVdZnaZmpmE
Q4Q0SDRIRDSUg4T9GcQhwsHhiKgIcRC5IUQabohDGsQhDonew8MLfg/Ph8/3
9+XZlOpOdK0Cvvm83Qx/G+C9Np+G0i0wpYO68QzkdFDjW2FRP2njWdhQBpM6
pMGE73RAG7bBvE5odSMUb4dR7dd1SfO0V+t2QFY/auScGWF4qQNa0HltaTJj
J2R0VMvOQ6AchrVfl/WXJi9AbJfddEyDF6Fot1ma1gWd0XgzRPfAuI5q8SU7
VdhHe3ROZzXSAhV77aMvdEUL2n4ZOiIwrTNafgUq99lHX+mS/tPkVWittI9+
1pJWCFXBY32ueS1owzVo228f/a6BlDMesI8+1Tn9o5XXIRG1s2a0qM28g9Cp
wzqtyxq+AU3VnumkLmnJIc/a4aFmdFFDN82rgSc6pXktPQz1He5axzWngVtQ
ewT69IMuaPCod502T9/pby267bcx71rHdVoDx+zT6Sz6TLO6orFaSN0xT7/q
+uP26YIHOqQ/Na/RuJndMKITuvqEs/S4J32kWc1pTZ2Zd+GNjunak/bpdU+a
1h86o+F6qLoHr3VE15wysw+6NKWz+kUr/BdC9927/geHD6Hb
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9IlHEcx/F3EBE3NBzSIELl0lVWZnXZWZdZXWZml6lZmdV1mdl1mllI
OERIg0SDRERDOUhIf+BwCHFwOKIiQhxEHEKk4YY4pEEc4pDew8MLfg/Ph8/3
9+XZkuhuTK8Bvvl82Ar/GuCTtp2F0hBM6aBujkNOB7VuGyzphDafg03bYVKH
tLjRdzqg8R2woONafR6KymBU+3VDk3nap/U7YV4/a2WzGbvgtQ5oQRe0vcWM
3ZDVUS27AMFyGNZ+XdHf2tIKsT120zEtvgiBCrM0pYs6o3WXILoXMjqqRZft
tM8+2qtzOquVbRDebx99pata0M4r0BWGaZ3RinaIHLCPvtFlpdI+VyGhE/pF
S65B6CA81Zea14LGr0NHxD76Q4MJZ6yyjz7XOf2rkRvQdMjOmtVA0rzDkNZh
ndYVLb8JrVHPdFKXteSIZx3wWLO6pKFb5lXDM53SvJYehYZOd60ZzWnwNtTW
wEP9qItafMy77jJP3+sfDdzx2+PetWZ0WoMn7JNyFn2h87qqsRgk75qn33Xj
Sfuk4ZEO6S/Na7TWzG4Y0XFde8pZetyTPtF5zWlNnZn34J2O6frT9ul1T5rS
nzqj5fVQdR/e6oiuO2NmH/RoUmf1q4b9F0IP3Lv+Bzcpom4=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0zFI1GEcxvFvDRFxQ8MhDYdgCNVVVpeVXWddZmV2mV2lZmVmZmZ2mlmE
hEOENEg0SEQ0lMMREkbiEOLgIBURcdwgckOINNwQhzSIQ0jf4c8H3pf34Xnf
H/+Stp5kag3w1e/jFvhXB5+05SyUboUZHdLN9ZDXIU1sgyWd0sZzUBKGaR3W
UNI9HdTkdljQSa06D0U7IK0DuvGCefpQ63ZCTj9r9KIZZfBGB3VVF7S1wYxd
MKtpLWuE4G4Y0QFd0d/a1AQ1e+ymYxq6BIGIWZrSRc1qohnie2FC01p02U7l
9tF+ndc5jV6Bin320dfKVTtpl3bvh4xmtbwFYgfso291WddW2OcatOuUftHi
VggfhGf6Sgu6qsnr0Bm1j/7QYJt3PGQffaHz+ldjN6AhZmed1UC7eZXQqyOa
0RWN3ITmw67ptC5r8RHXOuCJzuqShm+ZF4fnOqMFLT0K9Z3OWic0r8HbUFsF
j3RcFzV0zLfuMk8/6B8N3PFstW+tE5rR4HH7dHsXfak55a5nT0CHjut33XTS
Pil4rMP6SwsarzGzB0Z1Uted8i69zkmfak7zWl1r5j14r2O64bR9+pyTpvSn
ZjWSgMr78E5Hdf0ZM/uhTzt0Tr9phf9C+IFz1/8MD6IC
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9I1GEcx/F30hARDg2HNBxGYf+usjKr6zrruqzMLrus1KzsKrvMzsss
IiQcIqRBokEioqEcjpAQuhxCHBwsIiIOBxGHCGm4IUQaxCF6Dz9e8Dw8Hz7P
8+W3NtWVzCwDPvt92AD/EvBR205BxUaY0H5d3wBF7dfEJljQMW0+Des2w7gO
aDDpnvZp4xb4paMaPwNlIchpr65uNE8faMNWmNVPGjlrxjZ4rX3KOTM0pfHt
MKk5rTwPgUoY1F5d0t/a0gR1O+ymwxpshtKdZmlW53RKEy0Q2wV5zWnZBTtV
2Ufv64xOa6QVwrvto6+05KKdqqFTM1rQKa2+BNE99tE3uqjL99rnMrTrmH7R
8jYI7YOn+lLnlbBvdQU6NK/fNZDyjvvto891Rv9q9Co0Reysk1p6zbwD0K2D
WtAlrboOrVHXdFwXtbzGtXZ4rJO6oKEb5h2EZzqh81pxCJJpZ615LWrgJtTH
4KGO6JwGD/vWHebpe/2jpbc8G/etNa8FDRyxT6d30Rc6qyW3PVsLaR3Rb7rm
qH0y8EgH9KfOa+yYmV0wpKO64rh3yTonfaKzWtTaOjPvwDsd1lUn7NPtnDSr
P3RKq+qh5i681SFdedLMHujRtE7rVw37L4TuOXf9D2wwoJc=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0U9I02Ecx/F3Ih0iwkOHIR2WUK1/VlbLatksW1ZmZmalZrWsbNm0ZRER
Eh4ipINEB4mIDuVhhISHZRDiQWhERMTwILJDhHTYIYZ0EA+9D7/fC56H58Pn
eb5r473NyWXAF7+PG/ydgk8a11AIpnVI1zdBQYe0aSMs6KS2n4Z1m2BKhzXY
7J4Oautm+K0TGjsD5VsgrQO6usU8fajNWyGvn7XmrBmV8EYHtaTVDO3S2DbI
alqrzkFgO4zogC7pH+04Dw077KZjGrwAZVVmaUrndUab2qBuJ2Q0reXtdtpl
H32gczqrNR0Q2W0ffa2lF+0UhqT2aU5ntLoTonvso291UZdX2+cSdOukftWK
y1C5F57pKy1qyT7f6gr0aEZ/aCDuHffbR1/onP7T6FVoi9hZs1rWZd4B6NcR
zemShq9BZ41rOqWLWnHQtevwRLO6oJU3zIvCc53WooZqoaXbWWtGCxq4CY2H
4JGO67wGD/vWCfP0g/7VsluerfOtNaM5DRyxT4930Zea19Lbno1BQsf1u645
ap8kPNZh/aVFras3sxdGdUJXHPMufc5Jn2peC1p/3Mw78F7HdNUJ+6Sck6b0
p85ouAFq78I7HdWVJ83sh/ua0Fn9ppFG+9xz7vof0XihKg==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0U9I02Ecx/F3IdIhIjx0GBIkgrb+rbIyq7W01rIyW2ZWamZmZTbNVkRE
SHiIkA4SHSQiOpSHERIehlGIB4MRERFjB5EdIqSDhxjSQaT34ccLnh/Ph8/3
+W7o7IsnVgBf/D5WwMpT8Em7NFgJMzqslY2woMMa3wiLOqVtp6EiCNM6omVx
/+mQtmyC3zqpsTNQuhlSOqjrmszTh9q0BfL6WSNnzdgKb3RIi5rN0G6NbYOM
prTqHARCMKqDuqx/tL0FGrbbTce17DyU7DBLkzqvOY1fgOhOSGtKSy/aqco+
+kDndFYjrRDeZR99rcVtdtoN/TqgWc1pTTvU7rGPvtUlXVVtn0vQo1P6Vcs7
ILQXnukrLWhRjW91GRKa1h8a6HTGffbRFzqn/7T2CrTut7NmtKTLvANwT0c1
q8tafRU6wp7ptC5p+UHPuuGJZnRRQ9fMi8BzndGCBg9B83V3rWld0MANaKyF
Rzqh81pW51v3mKcf9K+W3PTuYd9a05rVwBH79DqLvtS8Ft/ybhR6dUK/6/qj
9knAYx3RX1rQaMzMPhjTSV19zFn63ZM+1bwuaH29mbfhvY7r2uP2GXBPmtSf
mtPqE1B3B97pmK45aWYS7muvzuo3DTfY56571/9L5aK8
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0U9I02Ecx/F3ECIdImKHDkMKhqWtf6usltVas8ysbE0rKzUrs7JpZhIR
ERIeIqSDRIcRER3Kg4SEhyFUIuRBIiJCdhDZIUI67BBDOkjvw48X/B6eD5/n
+13X3p1MLwO++H1cD8tPwmft0PAGmNYhrWyAgg5pqgIWdVJbT0FFJUzpsIaS
numgNm+E3zqhdaehLAyjOqBrUubpQ23aBHn9pPFGMzbDGx3UkiYztFPrtsCM
jmrVGQhuhYwOKGfhj7Zpwza76ZiGzkEgYpb264LmNNUMtdshq6Nadt5OO+yj
D3Re5zR+AWI77aOvtfSinaqgV/t0VnNa3QKJXfbRt7qkK3bbpxW6dFK/ankb
RPbAM32lRS2JOqtL0KNZ/aHBdt+41z76Quf1nyYuQ0u1nXVGA1fM2wf3NKOz
yn6IXoV2zeiULmn5Af91wBOd0UWNXDMvBs91WosaPug4O921ZrWgweuQjMMj
HdcFDR1y1jfM0w/6VwM3vZtw1prVWQ3W2KfLt+hLzWvpLe8ehrSO63dde8Q+
aXisw/pLi1pba2Y3jOiErjzqW3rckz7VvBa0vs7M2/Bex3T1Mfv0uift15+a
02g91NyBdzqiq46b2Qf3Na1z+k1jJ+xz173rfxXIolA=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0T9IlHEcx/F3DiHSEBE3NBzWcFma/bOyuqzsOssuq0svMyu9rMzqvMxC
IiJCwiFCGiQaJCIayuEICYfDoczA4YiIiOMGkRsipMEhRBp6Dw8veB5+n+fz
/X3XJnvjqWXAF59P62H5Cfis3VpdATM6rFUnYUGHNbEBlnRKO09B5UaY1hEN
xf2mQ9peCb91UmOnobwKMjqoa5rN04faugmK+lEjLWZUwxsd0tKEGdqjsc2Q
04zWnoHgFhjVQS1phT+a1PhWu+m4hs5CYJtZOqDzWtBEGzRuh6xmtPycnWrs
ow90Tmc10g71O+yjr7XsvJ12Qr/e1bwWtO4CRHfZR98qF2FFrX00pVP6VSs6
oGY3PNNXuqile7yrTujTrP7QYNIZ99pHX+ic/tPoJegI21lzGugybx/c01HN
a0kdhC9Dl47qtHLFf+/3nT7RnC5pzVXzDsBzndFFrT4Ibd3uWrO6oMFr0FwP
j3RC5zV0yLvuMU8/6F8NXPdsxLvWrOY1eNg+N5xFX2pRy256NgppndDvuq7B
Pil4rCP6Sxe18YiZvTCmk7ryqLOk3ZM+1aIuaFOjmbfgvY7r6mP26XNPOqA/
taDhGDTchnc6pquOm9kP9zWts/pN65vsc8e963+DB6Hk
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0U1IVGEYhuE7cREpLYrCRYtJgiYrm/60rNRqmsaaJlMzTbNSszJTmyxC
IiICw00hLSRaDBHRolxkSCAMLsIMXAwRESEJIgkR0mIWIRLdLQ4XnI/znOd7
37XNXVWdS4AP/5/1sPQ4fNR2DQVhUge0sBIyOqD1G2BRx7XlhGcFMKGDGqzy
TPu1aSP80jGNV0P+Jnijfbqmxjy9pw2b4Ye+18hJMwrhpfbrsloztEPjWyCt
w1pyCgIhSGqfZtfBb23Vmq120xEN1kPeNrO0V+d1WutOQ2w7pHRY8xvstMM+
eldndUYjjRDeaR99oblnIKcIbuotndJpLW+CaLF99JVmnYXlu+yj3Tqun7Tg
HBTvhsf6XBc0p8RZnYceTelXDTR7xz320ac6q3812uLM9zpHTWteq3n74LYm
dUqzS6H0ArRpUic0q81/l/lOH2paF7Xoonnl8EQndUFD+6HxkrvWlGY0cBlq
D8B9HdV5DR501u3m6Tv9o3lX/DbsrDWlUxo4ZJ8O76LPdE5zr/ptBBI6ql90
3WH7dMIDHdSfuqCxqJldMKRjurLCu3S7J32kc5rRyiNmXoO3OqKrj9on4Z60
V7/pdy2LQcV1eK1DuuoYrOiBO5rQGf2s4bh9brh3/QcilKOO
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0l9ozXEcxvG3WrtYjDSlXSin5c9xxjYc28xsw8zGzMHMxsxhszEbM5KW
JE20FOFiycVCcoG0aa1oUVoTFyNJOkzrhKRxsQut5X3x9Or7O+c8fX7n+5kf
bY20TAO+mNcLIWkrvNFmzVoEb/W6ZlTAhN7QqsU+0xqd0iFND0KmGd4G3RqM
+Jl2ad0S+K0vtGI7pIWgTzu1Vy/pvB32a3U61Jrvnl9pyU67lsID7dLplXZp
i1Ysg3f6REe0T/N2QSDDbnPZJFbBX23Qykxn1X4N7obULDu1Q/9oTMd1VKur
oXy53eapSatxxhVwQc9rXMe0ZA8Ur3Q+va8z9/ofhiFZZ+hpPaMx880U1ULp
KujRh5qwD2ZlO5+26ZC+1/Q6COdASHP0pt7TpFy7Td1+OKWD+kkDUd99tfPp
bY0reVB2AKJaqvXaqyMaXgO55uxBZ9GYJuZDQT00ao8Oa0KDM6yFJr2ijXpV
R3RKowXObm4dcld0UrMKvcNGd0QHdUIDTe5NEVzUAe3UZzquwXV2m2tm4DD8
09Qjdqz3bnRQYxrY4HzNvqPe1bje0R+afNT7Lfb35rn56HnBRshucQ+0W3/p
pJaX2N0Kj/Wlzt7kbuocDR3zfjVufpoJz5FSu4+7B9qvc8ucr8171Q79rKOa
vxm+aqGWnYBHmrLF75uUdjin7TqmH7S43PlOujf6H9C8tRc=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0l1MzWEcwPGv2VoXWFzErAttZxJHJYmSkJA4SYnoRaKkUiE2ZrExllkb
s3SBucg0XDCT1jBr2LQ2bHmZ2QqtpVkzL1sumO/Fd5/z7Dzn2e9/nn90eX1e
3QRgwF7GwKSN8ErrNGmOn7VVE3Phj7ZpcSxc0lJlE/RqwlxItj7XVzSY53fz
oEXL9bs+1bx8iAlCl57VB3pOZ22GcS2Z734bdf1Csws8Kw5ua4tO2eJZ2qD5
8fBWO/WNdmn6VggkQLO1WHgh/NYqLVzgrNqtwW0QlegePa6/9LP+1CEt3g65
C+G+ddvsIohOgtN6Skd0WLOLIWuR8+ktnVbijMkwVSP0qB7TTzZsmaUQWgzt
ekfDdvibJc6njdqr7zShDFJTIF7TtE07dHKq+618JxzRHv2ogXKffanz6TUd
0YlpkLMLKjWkVdqp/ZqyzP12Yjdc10ENT4eMCqjWdu3TsEpnWA61ekFr9KL2
Kyugwqrt6h54rf80aSWUVfneaI+Oa2AvFGV45/pYm/WJ/tDgKjhvrfawGv5q
VI1nZEKT9uigBlY7Xy2c0Q4d1Rv6TSP2eb9r4JH12AfXsWv9D+t8v/Syjuk/
zc3y7Hq4p881ch080xka1+D96lcbs3HXBdmevd/3S7t15nrnO+C9apMO6JBm
bIAvmqmhg3BXp4fca5GNcFIP67C+16wc5zsEN/U/A4S0VA==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0l1MzXEcgPEns+HCzLpsbZqVyOlFJQmhUEqpDimFikgqRWNr1GxhMzs2
F83GzGgWsoXN7FzZmbGVzcvyckG6sMZNM4yM5bl49tn/nO9++/5f4urbyluj
gDF7uQjmlsIrbdPMRH/TPs3YCr81Xf/oJa1bDFFlMKKNmrUELttVC5T7XxKE
tEG/6RMNVkDCUqjQRH2kIY0LwpT2akMAntmwFW3zrGQY1JDO2+5Z2qHlKdCu
QX2rYc2thPhUuK4h/WG/rGkHVKV5poY1UAWxy+CCntSQ9uhPndDaaihLh8ca
1gUZsNDO7HRH/aITWlQDhZlwV2/poN7R6FpbDl16Qsd0QouzoNT6d8GQztrt
3Ar3004d0Tc6rO80bY/3lO3z1gH9p9Er4bh1WaQOPmh8vXM57qfX9KvOWOWe
OlNLG6BZH+qoxux1fjXcsJs27vWcNZC3zznt1+c6uxGSc91TU7VF+3RUo9ZC
9n7n9YW9tmmvM9f5bRxwTiM6pQlNUL3ePbVGz2lEv2sgDyoPOq9/bdpimz0j
H7o1ouMavwHyD8FpzdOzOqCTOr/F97vRZ6gRTdwESZbTCuf1ik7qtJYVQH0b
3NM6faBPNaYQUg77fvWiTmpws7tZVbvfqoY1psj9Onyv2qMftVs/6WctKIaS
I3BfhzR2C5yyXjt21O9A32thift1wm39D867tRc=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0lFIU1Ecx/FfQlE+hIUEhURJTF22dOoqm2XmLNfStdqyldOmiZbNlRYR
EikhFRYrCoaERA8jpCyiwmJEwZCQ9MFEag9Bo8LMQCRMLKLvw5fPwz2cc+69
/7X+FldggaTf9D5DWlopjWEQLZnSKIbR4pT+YAH+xTtYkyX1oB+T9knDmGeU
CqmX7pLJxbP1UgjrcQYH0bNfysqW3GjEKF7DlxjC9APSPNZukBpoiN6Rw82e
JqkfQ5jiYU9sQ/dGqRU9GMcX+AGjWHxQMuRI3XSTZmmOjldJ3lz2xiiaDkmr
zazBDryBnTiHX3EWJ9DnlVx50gC9ovR8aR1dPix14SROoOOIZC+QHuNDfIT9
uKJaWmaRUjEV2/ECfqFJqtgkOSnik57g4hrWbea+eBZH8CMOYxzza6WiLZIZ
i7EH+zClkLPoPLVT7Kj0CQ1+1m3lvngPp3ChVfqBi9BVJzWhE5txAMfRWiSV
UITuU6JeSt4mlR5jHUZwBJMbpNzt0hI0YxBvYwDDOI5JxVIjBWiUxkiNzNoO
ZgrDGMN5zGySqkukDPThdXyD3RjDX2jaKd2iHvpHKuVfnmAvvIgxTKDBJpU1
S1fQhlfxAf7EPpzG5SeZizLpNQ2ScZeUTdYAZ2MvTqNa+Fa7mW18hnX4HIdw
Zbn0FtMwJ8hc4BTNkMcuVZH3FDOPUUzbw31PMwfYiZ+xAxP4HW0O6RuWY2Wr
9BRX7ZXW0CXqonNtzB3G0V7Bfc/wbvgfckLFHg==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN00FIk2Ecx/GvDA8WHqIoJEJGxFpmtmqZWZlZLTNbqauWmc1aVjZXLZCI
iJAOIR5CpIOHCOkQHmJEh4jYoYNIBxEKTzt0GB0kDCQ6jKjv4eXzXp7f+3ue
//MGB7JdwxXArE/naSjeh6VOeKjPtEa36IccfDwFCe3RX/eg1AFP9YkGtVYL
d+HTSejTXi3fgT/tMKXj2qghXciaeQIGNaEBXYnBq2F4ri3aoMUMfDkOjzSl
NVo+Bu9um6ftGtbSkHs4CqOa1qAGtHALXrZBv0a1fBPmj8CkprRO/7a69oYd
Na1NGtDFw/YZhJy2apUWr8N0C4xoVKt14RC8SUNWY1qtpWswc9A+GtPNWjxg
n6uu1aRW6fIAvG6GMW3TsH7fb58UPNa0btRKzTfZ5wp0aLMW9/ntfnigGd2g
q/V9o30uQ7fGdHkv/OhzVjqqtbpJ81HP8ZJz17gu7YGfvc5dxzSkYf28G+Yu
2lnTurIL/iXN00kNakQLEc/2grPXjJZ32kdf6Mx5qNeYzja4x3Pm6Yj+3gFr
dULzCbM0rvP19umBIR3XCg3r1HY7dZunSZ2rM6PLu6QTWqkRnd5mxlnvkmb1
axhWaUanz7iHrc5ap/Rb3HfN6WII1uh6fes/sU7/Aztaok4=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0zFIlGEcx/GvhDhYOERQScQhYddlZleZXVZmVpeZnaVXXWZqdVnpdZWD
RESEOIQ4hEjDDRFHQziEREOE3BAh0iBC4XRDw9EgYSDRcNR3ePm8y/N7f8/z
f95AX6pjqAT44tN+FvIPYbkNHutzrdRq/fgAPp2BuHbp7/tQaIUxfaZVGtBc
GmZPQ492a/Ee/I1CRie0QYO6mDLzFAxoXEt19SS8HoIX2qR1mh+EryfgifZr
pRZb4P1d87RVQ1q4A3PHYVSTWqWlmrsNr5qhV+u1OAALx2BK+7VG/zW59pYd
NakRLdWlo/ZJwrA2a7nmb0L2CIxovVbo4mF4ewPSGtUKLVyH6Ub7aFS3af6Q
ffpdqwkt15U+eBOBcW3RkP44aJ9eeKpJ3aJlOtNgn2vQpo2aP+C3e+CRpnST
rtMP9fa5Cp0a1ZX98LPbWemoBnSrzuzzHK84d43p8l74lXDuOq5BDennMMxf
trMmdXUPlOiYTl3yrDWsuTrP9qKz15QWd9tHX+p0HGo1qnO17rHLPB3RP7tg
g07qTKdZGtOFGvtcgEGd0DUa0sxOO503TxM6HzKjw7ukk1qmYc3uMCPmXdK0
fgvCWk1p9px70IhmtsP3dt91WJeqYb1u1nf+Exv1P46DoeI=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0zFIlGEcx/GvRBwOFg7RUBYiYnZdZnaV2WVlZnWZ6VV6lZma1WV5XRc4
SEREiEOIQ4g03BBxNIRDSDREhIPDIQ0iFE43NBwNEgYSDdd3ePm8y/N7f8/z
f97KgWTXSAmw4NN5AfKPYbUdnupLrdBa/ZyGL+chrj365xEUojChL7Raq3Q+
BV/PQb/2afEh/DsLGZ3SJg3qctLMMzCscQ3oehu8HYFX2qINmn8A307DMx3S
Ci22wsf75mm7hrQwDLlTMK4JrdaAzt+DNy0wqI1aTMDSSZjRIa3TEs3dteMJ
12pEA7py3D53YFRbtUzztyHbDGPaqOW6fAzeD0Fao1quhVswG7GPRrVG80ft
M+ha7dUyXRuAd00wqW0a0p9H7NMPzzWhO7VU5xrtcxM6tFnzh/12HzzRlG7T
zfrpkH1uQLdGde0g/Op1VjquVVqpc2HP8bpz15iuHoDf15y7TmpQQ7rQAItX
7awJXd8PG3RCZ+KetYZ1vt6z7XH2mtLiPvvoa53thnqNaq7OPV4xT8f0717Y
qtM6d9ksjelSyD6XIKlTulFDmtljp5h52quLQTO6vEs6raUa1uxuMzq9S5rW
77WwSVOavegeNKKZXfCjw3cd1ZUa2KI79IP/xHb9D9qmonU=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0zFIlGEcx/HvERHiYOIQDWEWcpldl5ldddllZWZ1mdpVetWlZlaXml0O
DhIREeIQ4hAiDTdESEM0xBENEXFEg0iDCIXTDQ1Hg4SBRNB3ePm8y/N7f8//
ed6q3uGOoQDwxafzHBQewEocHukzrdRa/ZiBT2chqd365z4Uz8CkPtWgVmt+
BD6fhj7t0YD+a4XsPZjWRg3p0rCZp2BQk1qiay3wagiea7M2aGEQvp2Exzqg
lRrQ93fNa4Y2DWsxDfMnYELTGtQSzd+Bl8ehX6Ma0MVjMHvbPK3TdTp/y45N
rtWYlujyUfsMwJi2aJkWbsJcDMY1qhW6dATe9MOoxrVCizfgbaN9NK41Wjhs
nz7XakrLdLUXXkdhSls1rD8P2acHnmhaq7RUcwftcx3atUkLB/x2Ch5qRrdo
uX6I2OcadGlcV/fDr6uelU5otW7XXINzvOK5a0JX9sHvpOeuUxrSsH6th4Vu
O2ta1/bCep3U2S5nrRHN1znby569ZjSg5fpij7O4BPUa1/mwe7xono7r392w
WWc0lzBLE7oYss8FGNFp3aBhze6yU6d5mtKFWjM6vEs6o6Ua0bmdZrR7l3RU
v9fARs3o3Hn3oDHN7oAfbb7rmC4HYZNu03f+E1v1PxCXoAs=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9I1GEcx/F3HBEhDiYO0RBHfy4zuy4zu+qyy8rM6lKzq/QqNTOr8yo7
HBwkIiLEIcQhRBpuiJCGaAiJhoi4oeGQBhEKpxsajgYJA4l6Dz9ev+X5/D7P
93l+wd5M+9AaIO/TeQ6KD2H5LDzW5xrUWv00DJ/PQEq79c8DKLXChD7Tag1p
/j58OQ392qcB/dcCuXswpY0a1sWMmacgoykt09VmeD0EL7RZG7SYhm8n4YkO
alAD+uGueSegTSNaugOF4zCuaa3WMs3fhldNMKAxDejCMZgZNE/rdK0Wbtkx
7lqNa5kuHbXPAIxqi1Zo8SbMNsKYxrRKF4/A234Y0YRWaekGvIvZRxNao8XD
9ulzrfZoha70wptDMKmtGtGfB+3TA081rVu0XOei9rkOHdqkxQN++xo80qxu
1kr92GCfq9ClCV3ZD79SnpWOa0i36Vy9c+z23DWpy/vgd5fnrpMa1oh+rYP5
K3bWtK7uhXU6oTOXnbVGNR9xtpc8e81qQCv15R5nkYR6TWgh7B4vmqdj+nc3
bNJpnes0S5O6UGufCzCsU7peI5rbZacO87RH52vMaPcu6bSWa1Rnd5rR5l3S
Ef1eDRs0q7Pn3YPGNbcDfiR811FdCsFG3a7v/Se26n9+taGd
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9I1GEcx/G3wxERh4OJQzSIhJ5mdl1mZnXZZWVmdZrZVXrlZWaWl/3h
cHCQiIgQhxCHEGm4IeJoiIaQaIiQGxpEGkQonG5oOBokDKTew4/Xb3k+v8/z
fZ5f5UC6a7QEWPTpPQeFR7DeCU/1pVZpg355CF/PQlL79e8DKHbAtL7QOg1p
fsysMzCkgxrQEs3eh9l2aNWwrqbNPA1jmtSgbp6Ct6PwStu1WQv34PtJeKYj
WqUB/XTXvDbo1ogWR2DpBExpWus0qPk78CYGwxrVgK4ch/lh87RRt+jSbTu2
ulZjGtS1Y/YZggnt0DIt3IJcFCY1qhW6ehTeD8K4xrVCizfhwxH7aFzrtXDY
PinXakrLdGMA3rXAjHZqRH8dss8NeK5p3aWlutBsn+vQo21aOOi3k/BEM1qp
5fq5yT790Kdx3TgAv/s8K53SkFbrQqNzvOa5a0LX98Ofq567zmhYI/otAstX
7Kxp3dwHW3Va5xPOWls0H3a2lz17zWhAy/X1XmfRC00a16UG93jJPJ3Uf3tg
p87pQo9ZmtCVevtchMc6q9s0otndduo2T1O6XGdGl3dJ57RUWzRXa0bcu6Tj
+iME2zWjuQvuQWOarYGf533XCV2rhh1aqx/9J2r0Pyt4ojA=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9IlHEcx/G3NBwRcTSYOEREiNn5J7suM7vqssvKzPI0s6v8U5eZqV0X
hDg4SEREiEOIQ4g03BBxNERDSDRExA0NIg0iFE43NBwNEgb2Hh5ez/D8Ps/n
9/09z56BsY7REuCrV89FKDyC9TZ4qi+1Quv1S8ZnLkC/9um/h1BshRl9oTUa
0nwavp2HIR3UgG7R7AOYOwfNGtbVMTPPQkb7NaibLfB2FF5pqzZpYQR+nIFn
OqIVGtBP982LQ5dGtDgMS6dhWtNao0HN34M3zTCsMQ3oyilYGDJPG3SrLt21
Y8y1Gtegrp20zyBMapuWauEO5E7AlMa0XFePw/sUTGhCy7V4Gz5E7aMJrdPC
Mfvccq2mtFQ3BuBdE8xqu0b091H79MNzTWul7tDFRvv0Qbe2aOGI7+6FJzqu
e7VMPzfY5yb0akI3DsOfG56VTmtIq3Qx4hyve+6a1PVD8DfpueushjWi38Ow
fM3OmtbNg7BNZ3Shx1lrVPP1zvaqZ6/jGtAyfX3AWXRDoyZ0qc49XjFPp7RE
d+t8rZ26zNKkrtTYpxMe65xu14hmq+2UME9TuhwyQzM63+GsNKq5/WZc9lvS
Cf1ZBTt1XHOX3IPGNbsPfrV7r5O6Vgm7tFY/+k9U63+WiaHE
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9IlHEcx/G3RMMREUeDiUM4hJld55+uy8yuuuyyMtO6zOwqveoy06su
hzgcHCQiIsQhxCEkGm6IkIZoCIkGibihQaRBhMLphoajQcLoPTy8nuX5PJ/f
9/s8NYPZntEKYNGr/xyUHsF6JzzVl1qrzbqYg69nIa2D+u8hlM/AtL7QsIa0
+AC+nYZhHdKAbtbCfZjtgHaN6GrWzFMwpmkNaoW+G4VXCejUNi2NwI+T8Eyz
WqsB/XzPvHbo1aiWh2HpBExpTsMa1OJdeBuHEY1rQFeOw+sh87RFt+jSHTse
81lNaFDXjtonAxPapZVaug3zMZjUuFbr6hH4cAvGNanVWr4JH9vso0lt1NJh
+6R9VjNaqRuD8L4VZrRbo/r7kH0G4LnmtE6360KLfW5An3Zo6aDvvg5PNK+7
tEq/RO1zDQY0qRsH4E/KXemUhrReFyLO8ap715Su74e//e5dZzSiUf3eDMtX
7Kw5rdCtOt3kHPuctca02OhsL7t7zWtAq/RNg7PohVZN6lLYM14yTyd1k9bo
3D47Jc3SlK6E7HMRHuusbtOoFvba6YJ5mtHlejN0TOd6nJXGdH6PGd1+Szqu
P+tgh+Z1/rxn0IQWdsOvLu91QtdqYac26Sf/iQb9D3gIoVg=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9IlHEcx/F3SDQcEXE0mDhIg11m1+Wf6zKzqy4zK1Ory8yu1KvM1KwO
hzgcHCQiIsQhxCEkGhwijoZoCImIiLih4ZAGEQqnGxqOBgl7Dw+vZ3k+z+f3
/T5PVf9Y1+gm4ItX3zkoPoT1s/BEX2hIG/TrA/h2BtI6qGipHWbvw3ONaFjz
4/D9NIzosAZ0iy7eg/k2aNWoro6ZeQomNK1BLdO3o/CyFTq0RYsj8PMkPNVx
DWlAP901LwE9GtPSMBROwIxmNKJBzd+BN8dhTBMa0JVj8GrIPG3SrVq4bce4
z2qbBnXtqH1uwZR2arkWb0KuBaY1oZW6egTep2FSk1qppUH40GwfTWqdFg/b
Z8BndUjLdaMf3jXBnHZrTP8css8NeKYZrdEduhSzz3Xo1XYtHvTdKXisWa3W
Cv0ctc81GNCkbjTC3z53pTMa1lpdanCOV927pnS9Hv71uned06jG9EcdLF+x
s2a0TLfp7AHn2OOsNa75iLO97O41qwGt0Nf7nUUSmjWphbBnvGSeTutm3aUL
++x00SxN6UqtfS7AI53X7RrTxb126jZPh3S5xgyd0IUuZ6Vxze0xo9NvSSf1
Vwh2alZz5z2Dtunibvjd4b1O6Vo1VGmjfvSfqNf/+Oih6w==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0zFIlHEcxvGvgUTDERFHg4lERNlldpnpeZnZVZddVmpWl5mdpVeZmhkc
DnE4OEhERIRDiENINNwQcTREQ4g4RMQNDSINIhRONzQcDVLf4eXzLu/zPv/f
73139Y92jpQBS159F6D4GDba4Zm+1pA26Ndx+HYe0jqom7SUgJlH8FLrNKyF
Mfh+DkZ1WAO6RXMPYa4N2jSia6NmnoUJTWtQy/XDCLyJQ4e2anEYfp6B5zqu
IQ3o4gPzTkOPRrU0BMun4JVmtE6DWrgP72MwpnEN6OpJeHvPPG3Wrbp8146t
PqsJDer6CfukYUq7tEKLg5BvgWmNa5WuHYdPAzCpSa3S0h343GwfTWq9Fo/Z
57bP6pBWaJl+jMJsP3RrVP802ScFLzSjNbpDFyL2uQW92q7FRt/dB081q9Va
qUsN9rkJA5rUMv3b666O2kfDWqsL9c7xhnvXlG4cgX897l1nNaJR/VEHK9ft
rBkt1206c9g5Jp21xrQQdrbX3L1mNaCV+u6Qs7gKLZrU5VrPeMU8ndbNukfn
D9qp2yxN6WqNfS7DE53T7RrV3AE7dZmnQ7oSMkMndL7TWWlM8/vN6PBb0kn9
VQ07Nav5S55BE5rbB78veq9Tur4XdmuTfvGfaNT/fdKhfw==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0zFIlHEcxvGvGEg0HBFxNJg4hJVdZtdlpqeZWV12WZpZXWZ6lVqdZtZw
OMTh4CAREREOIg4h0XBDxNEQDSHSEBE3NBzSIELhdEPD0WDf4eXzLu/zPv/f
732rh8a7x8qAFa/BC1B8DJtxeK7zGtJG/TYJ38/DqI7oFi11wtwjeKURDWt+
An6cgwkd14Bu0+xDWIxBpzbp+riZZ2FKRzWoFfphDN6cgR5t12IKfp2GF/pE
QxrQlQfmdUC/RrV0Hwqn4LWmNaJBzd+D9+0wqTEN6NpJeDtqnrbqdi2M2LHN
ZzWuQd04YZ9hmNFerdTiXci1wqzGtFrXW+DTHZjWhFZr6TZ8jtpHE9qgxWb7
JH1WU1qp5fqxCRaGoE+j+ve4fQbhpaa1TnfpcqN9bsGAdmnxmO8egGea0Vqt
0q8N9rkJw5rQcv3X766O2kfDWq/LEed4w71rUjePQJnO60LCPWlUf4Zh9bqd
Na0VukPnDjvHa85aOzRf72yvunvNaECr9N0hZ9EHbZrQQp1nvGKezupWrdGl
g3bqNUuTuhayjz7VxcuwU6OaPWCnHvM0pau1ZuiULnU7K+3Q3H4zLvkt6bT+
3ge7NaO5i55B45rdC3+6vNcZ3aiBPdqiX/wnmvU/TX+hEw==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9IlHEcx/H3EQYSDUdEHA12OJiVXWZ2mdn5J7vqMtM0s7pM7Sq98jKL
hsMhDgcHiYiIcJBwCIkGh4ijIRpCoiEibmg4pEGEwumGhiPoPTy8nuX5PJ/f
9/s84ZFM70QAWPEaPQelBxDQp7rQBRFt1m9T8P0spHVcN2s5AfP34YVGtVEL
k/DjDEzppAZ1qy7fg8XT0KUtup4x8xRMa1pDWqnvJ+B1HPq1U0t34ddJeKaP
NKJB/XLHvE4Y0piW01A8AS81q1ENaWEc3nXAQ01oUNfa4c2Yedqm27R4245t
PqvdGtKNVvvcglkd0Cot3YR8DOY0odW6fhw+pmBGk1qt5RvwqcU+mtQmLR2z
z6jPakartEI/NMOrERjUmP49ap9heK5ZrdedutJkn+swrD1aOuK7h+CJ5rRO
w/o1ap9rMKZJrdB/SXd12D7aqA260ugcr7p3TWlAN+nCIftccU8a058NsHrZ
zprVSt2u8wed46Cz1rgW6p3tJXevOQ1qWN8ecBYD0KFJLUY840XzdE63aK0u
7bdTv1ma0rU6++hjXeyDHRrT5X12umCeZnR1rxk6rUu9zkrjmt9jRo/fks7o
71rYpTnNn/cM2q3Lu+FPt/c6qxs1UKPt+tl/oVX/A4+PoKc=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9IlHEcx/F3SBhINBwRcTRcImVWdpldl5ld/uuqy04rM6tLza7S0y6L
aDgcQhwcJCIiwkHCISQaboiQhmgQiYaIuKFBpEGEwumGhqPew8PrWZ7P8/l9
v88T6h/tHNkALHoNnoPiAyjTZzqbgLA26rcx+H4WMjqsm7R0Bmbuw0uNakQL
WfhxGh7qmAZ0i+bvwVwcOrRJ10bNPAXjmtGgVuiHEXjTDt3arsUM/GqD5/pY
wxrQL8PmtUKfxrQ0BMst8EpzGtWgFu7C+2Z4pAkN6OpJeHvHPG3Wrbp8244x
n9WkBnX9hH3SMKU9GtLiLVhogmlNaJWuHYdPgzCpKa3S0k343GgfTWmDFo/Z
Z8BnNashLdePDfC6H3o1pn+P2qcPXmhO63SHLkXtcwMGtEuLR3x3Cp7qhNZq
pX6N2Oc6DGlKy/XfNXd12D4a0XpdqneOV927prVMN+rsIfv0uieN6c86WLli
Z81phW7TmYPOscdZa1wLYWd72d3rhAa0Ut8dcBbd0KopXa71jJfM02ndrDU6
v99OF83StK7us48+0bkLsF1jmt9rpy7zNKsrNWbouM53OiuN68IeM5J+Szqp
v6thp07ownnPoEnN74Y/Hd7rlK7vgmpt00X/hRb9D/2tojk=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN009Ik3Ecx/G3BwkDiQ4jIkaEiZVZmZnZMrNl/lm1dFmZWU0zW+VWrYjo
MDyEePAgERERO0h4CIkOO0SMDhEREh0iYocOQzqIUHjaocN6Hx5ez+X5PJ/f
9/s8W0ZS/ckK4LPX+Cko3YNKfapzJ6FJ2/V7Gn6cgJQmda2WI5C9Cy80pK1a
uAM/e+GB3teArtfcbZjvgT7t0JWUmd0wqSkNarW+T8LrLhjUHi1NwO/j8Ewf
aZMG9Ost8zphVMNavgnFY/BSMxrSoBZuwLswPNSoBnT5KLxJmKedukGL1+3Y
4bMa06CuHrHPOMzokNZo6Rrk22FWo1qnK4fh4xhMa1zrtHwVPrXZR+PapqVD
9hn1WU1rjVbphxC8GoFhDeu/g/aJw3PNaLNu1sVW+1yBMR3Q0gHffRme6JQ2
aq1+a7HPJZjQuFZphWb322fYPWmLLjY7x4vuXRNaqWt0bp99htyThvVXEyxd
sLNmtFo3anavcxx01hrRQqOzPe/udUoDWqtv9ziLc9ClcS3u9oxnzdNZXacN
urDLTgNmaUKXG+yjj3X+DGzSsOZ22ilmnqZ1qd4MndSFfmelEc3vMKPPb0mn
9c922KpTmj/tGTSmuW3wN+q9zuhqHdRrr37xX+jW/y0Kosw=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN00FIk2Ecx/Hv6CBhINFhRMTwYGuVWdkyMzOzZaazppmVmeUys5VzlURE
h+EhhgcPEhERsYOEh5DosEPE6BAeQqJDRHjoMKSDCIWnHYK+h5fPywvP7/09
/+d9q4fTPeMBYNFrrBvKD6BCn+tcHKLaqt/vw48uyOiEbtKA5u/Bq05o1iZd
zsDPM/BIH2pQt2hhAuY7oFfbdC1t5mmY0oyGtEo/jsPbdhjQTi3fhd+n4IU+
0agG9esd82IwojENaOkkvE5BVps1pMu34UMbPNaEBnX1BLwbM0/bdauWbtmx
1bXapyFdP26fUZjRQa3R8k0otsCsJjSia8fg8whMa1IjGtDFZvvc8Jm2aPmo
fZKu1Umt0Ur91ARvhmFIY/rviH2uw0vNaoNW61Kjfa7BqPZr+bDvHoJnmtN6
Deu3BvtchbQmtVI3aP6QfQY9J23UpahzvOK5a0ordKPOHbTPgOekMf1VDyuX
7axZrdJtmj/gHC85a43r8n5ne9Gz15wGNazv9zmLfujQpJbq3OMF83RWN2ud
Luy1U59ZmtLVWvvoU50/D9s1poU9duo1Tyd1ZbcZOqULPc5K41rcZUbCb0mn
9U8EdmhOi+fcg/ZpYSf8Peu9zuh6GGq1W7/4L3Tpf4XYoWE=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN00FIk2Ecx/FvjA4SBhIdRkSMDnOtMitbZrbMbJnZbMvMykxrmdk0XSAR
0WF4iOHBg0REROwg4SEkOuwQIR2iQ0h0iAgPHYZ0EKHwtEN9Dy+flxee3/t7
/s/7hgbHUqMbgE9eI+egch+q9JnOdUJMW/V7Dn6chZxO6GYNaHECXnZAXJt1
eRx+noGH+kCDulVL92C+Hbq1TdfGzDwNU5rTkNboh1F4k4A+7dRKFn6fguf6
WGMa1K93zWuDIU1oQMsn4dUI5DWuIV2+A+9b4ZGmNairJ+DtsHnartu0fNuO
La7VHg3p+nH7DMGM9mtYK7dgMQ6zmtaorh1zfhmY1oxGNaCfm+1z02faopWj
9rnhWp3UsFbrxyZ4PQgDmtB/R+wzAC80r426U5ca7XMdhrVXK4d9dz881YI2
aES/xexzDcY1o9W6UYuH7NPnOWmTLjU4x6ueu2a1Sjfp3EH7XPGcNKG/DsDK
ZTtrXmt0uxb3O8deZ61JXa53tpc8ey1oUCP6bp+z6IEOzWi5zj1eNE9ndYvW
68JeO3WbpVld3WMffaLzF2CHJrS0205p83RSV6Jm6JQupJyVJnVxlxnn/ZZ0
Wv9EoFYLutjlHrRHS7XwN+m9zuh6GOo0pV/8F7r0P/P2ovM=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN00FIk2Ecx/Gvh9FBwkCiw4iQETWXlVnZMrNlZsvMZk5bVqZWy0xXqYcR
ER3EQ4gHDxIREbGDhIeQ6LBDxIiQDiHRISI8dBjSQYTC06Dv4eXz8sLze3/P
/3nfqoFM52gZ8Nlr5DyUxqFcn+t8O0S1RX+Mwc9zMKHjukUDmnsAr9ogpk26
ch9+nYVH+lCDuk3z92AhDj3aqusZM8/AlE5oSCv14yi8bYU+7dDSCPw5DS/0
iUY1qN/umtcCQxrXgBZPwethmNSYhnTlDnxohsea1KCunYR3Q+Zpm27X4m07
xlyrKQ3pxgn7pGFW+zWspVtQaII5TWqNrh+HpZswo2mt0YB+abTPDZ9ps5aO
2WfQtZrVsFbopwZ4MwCDGtcyLfbDy6P20QbdqctR+1yHYe3V0hHf3QfPdFrr
NaLf6+1zDcY0rRW6SXOH7XPVc9JGXT7kHK947prRct2s8wft0+s5aVx/18Hq
ZTvrpFbqDs0dcI4pZ60JXal1tpc8e53WoEb0/X5n0QPtmtbiPveoWZ3rhq1a
p4t77ZQ0SzO6VmMffaoLXVClcc3vsdNF8zSrqxEzdEoXO52VJrRQbUbCb0ln
9G8YqnVaCxfcg6Y0vxv+dXivs7qxC2q1W7/6L3TpfyBHooc=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9IlHEcx/F3NBwNEgYSDUdIiNVpV5mVXWZ2mdllppedelmpWV2m1/XP
QSKiQRzicHCQiIgIBwmHkGi4IeJwiIaQaIiIGxoOaRChcLrew8Pr4YHf5/n8
vr/nqRxMd41tAJa80uegdB/K9IXOt0NEW/XHPfh5Fsb1oW7RgM7dhdcxiGqz
FjLw6ww81kca1G2auwMLbdCrbbqWNvM0TOm4VmmFfhqDd60woJ1aGoU/p+Cl
PtWIBvXbbfNaYERjGtDiSXgzApMa1Sot3IKPUXiiCQ3q6gl4nzJP23W7Fm/a
sdm1mtQqXT9unxswo0Ma0tJ1yDfBrCY0rGvH4PMwTGtKwxrQL432ueYzbdHS
UfsMuVYnNKTluhSBt4MwrDHdqMUBeHXEPtqo1brcYJ+rMKr9Wjrsu6/Ac81q
g9bq90P2uQwPNKXluknnDtqn33PSJl2ud46XPHfNaJlu1vkD9kl6ThrT33Ww
0mdnndQKrdS5/c6x11lrXAv7nG2PZ69ZDWqtftjrLBLQoSktht2jTujsRdiq
9bq4x07dZmlGV2vto8904QLs0JjmauwUN08ndCVkhk7pYpez0rjmd5vR6bek
0/p3F9RoVvPn3YMmNbcT/nV4rzO6Xg112qdf/Rd69D+OZaQZ
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0zFIlHEcxvHvOzRIg4SBRMMhEZeVXlZmZWZml5ldpnaW6WlpZnWp2RXl
cEREgzjE4eAgERERN0g4hETDDRFHQzSERENE3NBwSIMcFC59h5fPywvvw/P/
/d63aniyeyIA8l5TZyG4B+X6/C4sxqBJ2/VHCn6egWl9oJu1TLN34FUHRLVV
C1Pw6zQ80oca0q2auw1L7dCvHVqaNPMUzOq0hrVSP07A2zYY0R4N9M9JeDEO
T7RJQ/rtlnlRGNeYlmnxBLxOwoxGNayFm/ChFR5rn4Z07Ti8u2GedmqVFq/b
scV3NaFhXT9mnzGY11Gt0UDzzbBwzTyt09JR+DwKc5rUOi3TL032ueozbdNA
CyO+ewTSWqMV+qkR3gzDmMZ0gxavwMvD9tFmrdaVQ/a5DJM6pIGWhuDZQcho
o0b0e4N9BuG+JrVCN2r2gH0S7klbdKXeOQ64d01puW7Sxf326XdPGtPf+2D1
kp11Rit1m2b3Osc+Z61xLdQ524vuXjMa0oi+3+MsLkCXJrUY8Yya1oVe2KIN
ulxrp7hZmtK1GvvoU106D9s1prndduoxT9O6ussMndXlbmelcc3vNKPLb0nn
9G811GpG8+c8gyY0twP+dXqv87oehnod1K/+CwP6H0aooLA=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0zFIlHEcxvFv3NBwNEgYSDQcEXZZnWZlVnaZ2WVml5pamZ1aZlbnZXZD
ORwR0SAOcTg4SERExA0SDiHRcEPI0RANIdEQETc0HNIgB4XQd3j5vLzwPjz/
3+99Q8OprvENwLLX5DkIpKFCX9yHhQ6Iarv+mISfZ2FKH+oWDWruHrxuh5i2
anECfp2Bx/pIQ7pN83dhsQ0GtEPLKTNPw4xOaVirdHkc3sVgRHs0oH9Owcsk
PNWohvTbHfNaIaVxDWrpJLy5DdMa07AWb8HHFnii/RrStRPwfsw87dTtWrpp
x2bf1YSGdf24fUZhTkc1ogEtRGH+hnlar+Vj8HkEZjWp9RrUL032ue4zbdOA
Fq/57lHIaEQr9dMReDsMYxrXjVoagleH7aPNWqMrjfYZhAkd0oCWE/D8EGS1
Sev0e4N9rsIDTWqlbtLcQfsMuCdt0ZUDzvGKe9e0VuhmXdhvn373pHH9XQ+r
l+2s01qlOzS3zzlectbap8U6Z3vR3WtWQ1qnH2qdRR90a1JLEc+oGZ3vha3a
qEt77dRjlqZ1bY999JkuXoBqjWt+t526zdOMrtaYoTO61OWstE8Lu8zo9FvS
Wf0bhlrNauG8Z9CE5nfCv7j3Oqfr1dCgw/rVf2FQ/wO0xqJC
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0zFIlHEcxvFvww0NR4OEgUTEEWaX1WlXmZVdZnaZ2WlqV5mdmmaWl5k4
lMMREQ3iEIeDg0RERDhIOIREww0RR0M0hERDRNzQcEiDHBT2HV4+Ly+8D8//
93vf7X3p9tENwAeviXMQmIAyfX4PFlshpq36Yxx+noUpfaBbNKgLd+FVC8S1
WQtj8OsMPNKHGtJtmrsDS3Ho1TYtpc08DTM6pWGt0I+j8LYZhrRbA/rnFLy4
DU80piH9dsu8JhjThAa1eBJej8C0xjWshZuerREea4+GdO0EvBs2Tzt0hxZv
2DHmu5rSsK4ft88QzOmwRjSg+QaYHzRPo1o6Bp+vw6ymNapB/XLUPgM+0xYN
aKHfd49ARiNarp/q4U0fjGhCN2oxBS8P20cbtVpX6uxzDca1XwNa6oVnhyCr
DVqr3w/a5yrc17SW6yZdOGCfHvekTboSdY5X3LtOaplu1sX99rnsnjShv2th
9ZKddVortFIXapxj0llrUgsRZ3vR3WtWQ1qr7/c5i27o1LQW93pGzeh8F2zV
el3eY6dOs3RS16rto0916QJUaUJzu+3UYZ5mdDVshs7ocruz0qTmd5mR8FvS
Wf1bBTWa1fx5z6Apze2Ef23e65yuV0KdDupX/4UB/Q8i86PU
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9IlHEcx/G30w0NR4OEgYTDYWaX1XldZVZ2mdllppepWZleln9Su0zC
oRwkIhrEIQ4HB4mIiLhBwiEkGo4IkYZoCImGiLih4ZAGOajew8Pr4YHnw+f3
/T5PRf94+1gJ8MHr3jkITEKpPr8LSy0Q11b9MQE/z8K0PtDtGtTsHXiVgIQ2
az4Nv87AI32oIa3Q3G1YboY+bdPiuJmnYU6nNazlujoGb5tgSLs1oH9OwYtR
eKJxDem3W+Y1woQmNaiFk/B6BGY1oWHND8PHODzWXg3p5gl4N2SedmilFgbt
2OC7mtKwlujqTVg4DiMa0YCuHYPFG+ZpTItH4fMAzGtaYxrUL/X2ue4zbdGA
5lO+ewRmNKJl+qkO3vTDqCZ1ixb64OVh+2ij1uj6Iftcg0kd0IAWe+HZQcho
g0b1e8w+V+G+prVMt2r2gH2uuCdt0vWoc7zs3nVKS3WbLtXap8c9aVJ/R2Dj
kp11Vsu1SrP7nWO3s9Yeze9ztl3uXjMa0qi+3+ssOqFT01qo8Yw6o4sXYYfW
68oeO3WYpVO6GbaPPtXlC1CtSc3ttlPSPJ3RjWozdE5X2p2V9ujaLjPa/JZ0
Xv9WQa1mdO28Z9CU5nbCv1bvdUFLtE6HK+Gr/8Kg/gdzEaNo
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0zFIlHEcxvGvNN3QcDRIGIg0XGZ2WZ3XVWZll5ldpnaZ2VVql5V6V10S
4VAOR0Q0iEOIg4NERETcIOEQEg03hEhDNIREQ0Tc0HBIgxz0HV4+8L68D8//
93vfuqFsT6YKKHo9PAuBCajWV/dhMQFx7dZfOfh9Bqb0sW7ToBbuwdtOSGin
lu7Cn9PwVJ9oSLdr8Q4sdcCw9mola+YpmNEpDWutrmTgQzuM6oAG9N9JeD0O
zzWuIf0xZl4cJjSpQS2fgHejMK0JDWvpNnxug2c6qCHdOA4fb5mnfVqv5Zt2
POa7mtawbtKVEZg/CuMa0YCutsLCDfM0ppUj8DUNc5rTmAb1W4t9rntPuzSg
pWHfPQx5jWiNfjkE74cgq0ndrOVBeHPQPtquTboWs881eKAjGtDKVXh5AGa1
TaP6M2qfK/BIc1qjW7TQbJ+Ue9IOXYs4x8vuXSe1Wrfq4n77DLgnTerffbB+
yc46rbXaoIW9zrHfWWtKS03O9qK711kNaVQ/7XEWfdCvOS2HPaPmdeEC1Gmr
Lu+2U9IsndSNRvvoC106D42a1OIuO/Wap3ldbzBDZ3S5x1lpSld3mtHtt6Rz
ijbrbL3PznkGTWtxB1RpWue73Lu2aCYE3/0XxvQ/hYmi/A==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN00FIk3EcxvFvRacdOowOEgYjopaZLau5VpmVLTMzNVtmZmm2rHRqjYjw
UB5GRHQQDzE8eJCIiIgdJDyERMQOIdIhOoREh4jYocOQDrK+h5cPvC/vw/P/
/d431JduH14DfPJ6cAYCGajQl3dhrgUS2qG/7sDv0zChj3SzBjU/Bm+aoVVb
tDgKf07BE32sYd2qhRGYb4IB7dRy2syTMKUTGtGQLg7D+wQMaY8G9N8JeDUE
zzShYf1x27xGuKdJDWrpOLy9BZPaqhEt3oTPx+Cp9mtYV4/Ch0HztEurtHTD
jg2+qymN6HpdTMHMEUhrVAO6VA+z183TuJYPw9cBmNaMxjWo3w7Z55r3tE0D
Wuz33YOQ1ahW6pc4vOuDUU3qBi1dhdcH7KNNWqvLMftcgfs6qAEt98KLOshp
o8b0Z9Q+l+GhZrRSN2p+v3163JM26/I+53jJveu4Vugmndtrn273pEn9Wwsr
F+2skxrSas3vcY5dzlp7tRhxthfcveY0rDH9uNtZJKFbM1qq8Yya1dnzsEUb
dGGXnTrN0nFdrbaPPtf5c1CjSS3stFOHeZrVlSozdEoX2p2V9urSDjPa/JZ0
WtdqnebCPjvrGTSlhe2wTlM60+retV7HtsF3/4UR/Q/zp6SO
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0zFIlHEcxvHvQdF0Q4M0SFhIWF1mdlnpdZVZ2WVmp6ldZnaW2WV5mdYR
EQ7VcEREgzjE4eAgERERN0g4hITDDSHSEA0h0SARNzQc0mDf4eUD78v78Px/
v/fd2p9uHw4AC16PzkLwHpTrmzGYbYWYdurKKPw+A0/1iW7RMs3fhfctENc2
LY7An9PwXJ9pSKu0cAfmYjCo3RrQlVMwmTZTw1qpi8PwqRnS2qdB/XcS3t6G
lxrTkP68Zd4JeKAJLdPScfgwBBMa17AWb8KXJnihAxrStWPwOWWe9mi1lm7Y
sdF3NaVh3aCLgzB9FEa0XoO6dARmrpunUQ3otwGYOgwZjWqZfo/a55r3tEOD
Wrzqu4cgq/VaoV8j8LEfRjWhG7WUhHcN9tEWrdPlevtcgYc6pEEN6OuDkOuD
Zo3orwP2uQyPNaMVuknz++3T6560VZfrnOMl967jWq6bdXaffXrckyb0bxhW
L9pZJ7RSazS/1zkmnLUmtVjrbC+4e81pSCO6sMdZdEOvZrRU4xk1qzNdsE2b
dH63nTrN0nFdq7aPvtK581CrCS3sslOHeZrV1ZAZOqnz7c5Kk7q004y435JO
6Tpt0NwOn53zDJrSwnZYrymdbnPv2qj3q+CH/8KY/gdrc6Mj
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0zFIlHEcxvHvcVA03dBwNIhcIGZ1mdlldV5WZmWXmV5mdpnpVWaXmpnQ
FREO1XCERIM4hDg4SEREhINEQ4g03BAiDdEQEg0ScUPDIUHf4eUD78v/4fn/
fryRvuH2oQCw5PPoDITGoExf34WFFkhqp66Nwu/T8FSf6FYN6/wdeJeElLZp
cQT+nIIJfaZRrdLCbfjYDAPapUFdOwlTw2ZqTCt0eQg+nYAR7dWQ/jsObwbh
hSY1qj9vmdcEDzStYS0dg/dZmNSUxrR4E740wnPt16gGdGnAvKPQrdVaumHH
I57VrMZ0ky73w+xhGNW4hnSlAeaum6cNGtRv12DmEOS0QcP6PWGfq77TDg1p
MePZeshrXCP6NQ4f+mBM07pZS73w9qB9tEXrdPWAfa7AQx3UkAb11X6Y7oFm
TeivOvtchsea04hu0fl99ul2T9qqqzHneMm967iWabku7LVP2j1pWv/WwvpF
O+ukVmiNzu9xjl3OWjNarHG2OqHTF5y1JvTzbmfRCT2a01K1d9S8zp2HSm3S
xV126jBLxzWg5foy6q7PQa2mtbDTTinzNK/rO8zQKV1sd1aa0ZXtZuiIzrTB
Bq3X6Sq/nfUOmtXCNtioWZ1tde/aqPcr4Yf/wj39D/0xoLk=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9IlHEcx/F3iFA03dAgDXIYXGZ1mdllpddVZmWXqV1mdpnaVWan1SUN
1x/CoRqOkGgQhzgcHCQiIsJBoiGOaLghRBqiISQaJOKGhkPqPTy84Hn4ffj8
vl+e4OBY1+gaoODz8CQExqFaX92GhTjEtVdXMvD7BDzRx7pJq3T+Frxth4R2
a+km/DkOk/pUw1qnxRvw4RiMaJ9W6spRmB4zUyMa0sVR+NgGGR3SgP47Aq/T
8FzjGtaf181rhXua1CotH4Z3IzClCY1o6Rp8OQTPdFjDWqGfhs07CP1ar+Wr
dox5VtMa0fW6eAVmD8C4NmtAl6Iwd9k8jWmlfkvBTAtkNaZV+r3ZPpd8pz0a
0NKQZ/dDTpu1Rr/ug/eDcEeTukHLA/Bmr320Q5t0uck+F+GBjmlAK/XlHsj3
Q7tG9VfEPhfgkWa1Rjfq/G77JN2Tdupyo3M87951Qqs1qAu77NPnnjSpfxtg
9ZyddUpD2qDzO51jr7PWlJbqna1Oav6ss9aoft7hLHpgQLNaDntHzencGajV
Ni1st1PCLJ3QCg3qi23u+jQ0alKLW+3UbZ7mdLXODJ3WQpez0pQubTFDMzrT
CWu1RfO1fjvlHTStxc2wTtM62+HetVXvh+CH/8Jd/Q9rXqJL
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0z9IlHEcx/G3gxwUTTc0HA2HWF1mdZnZZXVeV5mVmZpdZnap2VWml5VE
g/QPh2o4QqJBHOJwcJCIiIgbJBpCouGGEGmIhpBokIgbGg57Dw8veB5+Hz6/
75cn3J/tGKkAPvk8OgnBMQjr69sw3wpt2qMrt+DPCXiqT3SjhrRwE94dh5R2
aWkU/h6DSX2mUa3V4g342ALD2qsBXTkK01kzNaYRXRyxSzOM6aAGtULfDMOL
I/bRqP66bt5huKdpDWn5ELwfgilNaUxL1+BrEp7rkEa1Uj9fNe8g9Gmdlq/Y
MeFZzWpM1+liBmab4I7GNahLcZi7bJ4mNaDfB2HmAIxrUkP6Y799LvlOuzWo
pQHP7oOcxrVavzXCh364q2ldr+U+eLvXPtqujbocs89FeKCjGtSAvtoD+TS0
akJ/N9jnAjzWca3WDVrYbZ9e96SdulzvHM+7d53QsFbp/C779LgnTeu/Olg9
Z2ed0ojWa2Gnc+x21prRUtTZ6qTmzzprTeiXHc4iBQM6ruXt3lFzOncGarRF
F7bZqcssndBKrdKXte76NDRoWotb7dRpnuZ0tcYMndaFDmelGV3aYoaO6Uw7
rNEmzUf8dso7aFaLm2GtZnW2zb1rsz7cBD/9F+7rf1fhot4=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN009Ik3Ecx/H36CCDotMOHUaEyCxbVsvMlpWuVWZlambLzKaZrdK1LCQ6
SPTHQ3UYIdFBPMTw4EEiIiJ2kIiIiA4eQqRDdAiJDhKxQ4f1Pjy84Hn4ffj8
vl+eDf3ZjpEA8MHn/nEI3YRKfXkD5o9Bu/bqyij8OQqP9ZFWa1iL1+FNK6S0
W0s5+HsEJvWJxrRWF67B+xbIap8GdeUwTGfN1LjW6OIIfDwEYzqkIV2lr4bh
2UH7aEx/XTUvCXc0rWEtH4C3V2BKUxrX0mX4moCnOqwxrdDPGfOaYUDrtHzJ
jk2e1ZzGda0uDsHsfrilTRrSpX0wd9E8TWpQvw/CzF4Y16SG9UejfS74Tns0
pKUBz+6BvDZpRL/F4V0/3Na0rtNyGl7vto92aqMuN9jnPNzVUQ1pUF/sgkIf
tGlCf9fb5xw81HGN6Hot7rRPr3vSLl2uc45n3btOaKVW6fwO+/S4J03rvxgE
NK9TZ9yT1mtxu3NMOWvNaGmbs9VJLZx21prQL1udRTcM6riWa72j5nXuFES1
VT9tsVOXWTqhFVqlz6Pu+iQ0aFoXNtup0zzNa0CjOl1jRoez0owubTJDx3Sm
HVZrsxY2+u2Ed9CcLlTDGs3pbJt71xZ9EIGf/gv39D9jUqJy
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN00FIk3EcxvHvkA4yKDrt4GF4kDXLltUys2U11yqzUjMzM9NlZiuXLQ8S
HSSiDKrDCIkO4iGGBw8RERGxg0SHiOiwQ4h0iA4h0UEidgj6Hl4+8L78f+/z
Pj/e2uFc13gA+OB17ziEJqFOX92EpQ7o1kFdy8OfY/BYH2m9hrV0A962Q7/2
aWUC/h6FWX2icW3U8nXfcQQmdEiDunYY5nPO1IQ26PI4fEzDlI5pSNfp62vw
7JB5NK6/rjovBXc0o2EN6LsszLWZRxNauQJfk/BUcxrXav085ryDMKJNGtDy
Ac9ehrwmdKMuj8LifrilSQ3pSiu8uOQ8TWtQv4/Awj6Y1rSG9UfCPBe9pwMa
0krGs3uhoEmN6rcWeD8MtzWjNRrQN3vMMwQ92qqrzea5AHd1UkMa1Je7oTgI
nZrS303mOQ8PdVqjWqulXeYZcE/aq6txezzn3nVG6zSiSzvN0++eNKP/dkCV
FnTurHvSZi1tt8c+u9asVhrtVme1eMauNaVfttlFL4zqtAa0RgsxuzgNMe3Q
T1vN1OMsndFqjejzBnd9Clo0o+UtZup2nha0SmM6v9kZXXalWV2pd4ZO6UIn
rNc2LUZ9dtJv0LyWN8EGzeviCfeu7fogAj/9F+7rfxfSoAg=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN009IkwEcxvFvDOkgQtFpBw+jw1qzbFktM1tWc60ySzMzM1NbZjbNbHSQ
6DAiwujPYYREB/EQw4OHiIiI2EGiQ0R02CFEOkSHkOggETvU9zA+sPE+PO/z
Y6HB8Y6xNcB7P/eOQzAHYX11AxbboEsHdHUS/hyDx/pI6zSkpevw9ij0aa9W
JuDvEZjRJxrXBi1fgw9pmNQhrdHVwzA3bqYmtF6XxuBjCqZ0VIO6Vl9n4Vmr
fTSuv66al4Q7mtGQBvTdKMweso8mtHIFvh6Epzqhca3WzyPmHYBhbdSAllt8
9jLkNKEbdGkYFvbDLU1qUJcT8OKSeZrWGv2egfl9kNe0hvRHs30u+p32a1Ar
Qz67Fwqa1Kh+a3L/QbitGa3VgL7ZY58B6NYWXWm0zwW4qzc1qDX6cjcU+6FT
U/o7bp/z8FDzGtWNWtplnz7vpD26stMdz3l3ndawRnRxh316vZNm9F8DVGlB
Z896J23S0nZ37HFrzWol5rY6o8Uzbq0p/bLNLbphRPMa0Fot1LvFaYhpu37a
aqcus3RaqzWiz7d461PQrBkt19mp0zwtaJXGdC5qRodbaVaXN5uhUzp/EtZp
qxYj/nbCd9CcljfBes3pQrt31zZ9EIaf/hfu63+F8KGa
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN00FIk3EcxvGvhxEdZFB02kFCotaaZWa1zGxZzbXKtMzMzNRs2dJVJqOD
RIcREULZYYREh/AQw4OHiIiI2EGkQ0R02CFEOkSHkOggEYO+h5cP/F/+P573
+fFuHMx2jlUBCz4PT0JoAsL65rZnJ6Bbh3R1HP4ehyc6rXVaq6Vb8D4F/dqn
lZvw7xjM6FONaaOWb8DHJEzosAZ1tQ1ms87UuNbr0hh8SsCkjmpI1+rbUXh+
1Dwa09/XnXcE7mtaazWgHzLw4rB5NK6Va/CtFZ7puMa0Wr+MOO8QjGiTBrQc
9+5VyGlcN+hSGuYPwl1NaEiXW+DVFedpSoP6YxjmDkBeU1qrP5vNc9kzHdCQ
Voa8ux8KmtCofm+CxUG4p2mt0YC+22eeAejRVl2JmecSPNA7GtKgvt4LxX7o
0qT+2WOei/BY8xrVTVrabZ4+96S9utJojxfcu05pWCO6sMs8ve5J01qla7TQ
YJ7z7kmbtbTTHnvsWrNaqbdbndHiObvWpH7dYRfdkNG8BrRGC9vt4iw0aId+
rjNTl7N0Sqs1oi+j7voMtGhay9vMpBktnDabNuhsxBmddqVZXd7qDJ3UuQ5Y
p21aDPvulN+gOS1vgfWa0/l2967tOr0ZfvkvPNL/gXGhLg==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN00FIk3EcxvFvdBjRQYSi0w47iNVas2xZLTNbVnOtUis1M1MzWzbXKonR
QaLDiAgPWTBCokN4CPHgISIiIiQkOkREhx1CpEN0CIkOErG+h5cPvC//H8//
+fGGBnLto6uA9z73j0FwDML66gYspKFbh3TlOvw9Cg91Uuu0RuevwdsU9Guf
VvLwrxWm9LHGtUHLV+FjEm7qsFbryhGYzjlTE1qvi6Pw6TCMa06DulZfZ+Hp
IfNoXH9fcV4L3NWM1mhA343As4Pm0YRWLsO3BDzRMY1rlX7JOO8AjGijBrTc
7NlLUNCEbtDFYZjbD7c1qUFdaoIXF52naa3WH0Mwuw+KmtYa/dlongu+00EN
amXQs3uhpEmN6vc4fBiAO5rRkAb0zR7z9EOPtujybvOch3t6S4NarS93wUwf
dGpK/zSY5xw80KJGtVbnd5qn1z1pry7H7PGse9cJDWtEF3aYp8c9aUZX6xot
1ZvnjHvSJp3fbo/ddq15rWyzW53SmS671pR+rbOLTshqUQMa0lLULk5DTDv0
81YznXKWTmiVRvR5xF2fhGbNaHmLmTSrpQ6zaUynw85otyvN69JmZ+i4zrbB
Om3VmU1+O+EdtKDljbBeCzp33L1rmz6qhV/+C5P6H++PosA=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN009IkwEcxvHvDh1GdBiDotMID8tqrVm2rJaZLStdK83KzEzNzJYuWxEx
Okh0GBHhoT80QqJDeAjx4EEiIiJ2kOgQER12CJEO0SEkOkjU9zA+sPE+PHt+
vOv68+2jAaDi5/4RiFyHmL6+BvMZ6NYhXS7A3zZ4pA+1TqNauQrvWmFA+zSg
/w7D5Bg81ZQ2aPUKfDwEN3VYw7p8EKbyZmpa63VhFD61wLiOaURX6ZsReH7A
PprS35fNS8NdzWlUg/o+By/220fTGtBvzfDsEtzQlIb0y7B5+2BEGzWo1Saf
vQhFTetaXRiC2b1wW1s1oouNMHfBPM1qWH8MwsweKGlWo/ozZZ/zfqeDGtGA
zu2G8oB5mtDvu+BDP9zRnNZoUN/utE8f9GiLLjXY5xzc01sa0bC+2gHTvdCl
Gf2TtM9ZeKAlTWitVrbbp8c7aa8u1bvjGe+uExrTuM5vs0+3d9KcrtCVWt5q
n9PeSZu0UueOXW6tBQ1oSCcT9jnl1prRr1vc4iTktaRBrdFy3C1OQFI79fNm
O3WapRMa0ri+jHnr49CsOa1uspPmtdxhN03q1EYz2t1KC7q4wQwd15ljsFrb
dLrW3476H7So1fWwRos6m/Xu2qFPovDLd+Gx/gew9KBW
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN00FIkwEchvFHdugwosMQik7fQWpZrTXLltUys2Wla5ZpmZmamdlcyzxE
SAeJDiMiPFTQCokO4SHEgweJiAjxINEhIjrsECIdokNIdJB6DuMHG9/Lu/fP
F/TmW4crgHk/D1sgGIWYvr0Ji83QpYO6OgL/TsATfaw1GtWFG/DhOPRrn4a0
QicL8PwYpLROy9fhUxPc1iGt1NWjMJU3U9Naq0vD8DkN4zqiga7Tdzl4ecQ+
mtI/18xrhPua06iGdX4IXh22j6Y1pN8b4MVVuKUpjejXQfMOQV7rNazlep+9
AmOa1o26NACzB+GuNmugyymYu2yeZrVSf/bDzAEoalaj+mu/fS75nQ5ooCGd
2welPvM0oT/q4GMv3NOcVmlY3++1Tw90a5OuJO1zER7oHQ20Ut/sgelu6NSM
/q21zwV4pEVNaLUu7LZPl3fSHl3Z5Y7nvbtOaEzjulhjn07vpDldo2u1lLDP
Oe+kDbqw0x3PurWOakgjOhm3T4dba0a/7XCLdihoUcNapaWYW5yBpLbrl+12
ajNLJzSicX29zVufhkbNaXmrnbSgpVN206ROVZvR6lY6qstbzNBxncnCem3R
6ai/nfQ/6JiWN8MGHdPZjHfXNn22CX77LjzV/03HoOk=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0zFIlHEcxvGvxA0NRzQcB0VD3HDVZXVdZ9lldZnZZaXnVWZlpmZmppdd
4hBxNEg0HBHhUA1XSTSEQ4iDg0RESDhINEREww0h0hANIdFg3+HlA+/L/+H5
/368G7vzrUNVwJzPo5MQGYG4vrsFCyegUwd0pQBV+lSfHIcajen8Tc82QZ/2
akBX6cQwPD8Gaa3Tyg34nIE7OqhhXTkKk3kzNaO1ujgEXxphTEc0omv1/SC8
OmIfTevf6+Y1wAPNa0yD+nEAXh+2j2Y0oD/q4eU1uK1pDem3fvMOwbDWa1Ar
ac9ehaJmdIMu9sHMQbinzRrRpQMwe8U8zWlYf/XC9H4oaU5j+rvOPpd9p/0a
0YDO7oNyj3ma1J8p+NQN9zWvUQ3qh7326YIubdLlWvtcgod6VyMa1rd7YKoT
OjSr/3bb5yI81pImtVrna+zT4Z60R5eTzvGCe9dxjWtCF3bZ57x70ryu1jVa
TtjnnHvSBp3f6RzbnbWOakBDOhG3z1lnrVn9vsNZtEFBSxrUqJa3O4szkNJ2
/brNTqfN0nENaULfVLvrU9Coea1stZMWtJyzm6Z0MmZGq7PSUV3aYoaO6XQW
1mmLTm32W4t30KJWNsF6LepMs3vXNn0RhT/+C8/0P8KzoXw=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN00FIkwEchvFnROzQYUSHMSiiw6hVy2qtWbaslpktK7eszMrUzMzUlo3w
EDE6SHSQiPBQHUZZdAgPIR48SERIxA4SHSKiww4h0iE6hETQcxg/2Phe3r1/
vnVdQ7nBADDn59ExiBYhoe9uwnwzdOqABnSZPh2GJ0ehVuNauQEfstCnvRrU
5TpRgGdHIKP1Wr0On5vgjg5pRAM6OWTmYchqnS4MwpdGGNVbGtVV+n4AXh2y
j2b07zXzGuCBFjSuIf3YD68P2kezGtQfGXh5FW5rRsP6rc+8AzCsDRrS6n6f
vQIlzepaXeiFmX1wT1s0qov1MHvZPG3ViP7qgem9MKatGtffaftc8jvt16gG
dXYPlLvN05T+rINPXXBfCxrTkM7ttk8ndGuzLu2yz0V4qHc1qhF9WwtTHdCh
ef2Xss8FeKxjmtIarey0z3nvpD26lHTHc95dxzWhSZ3fYZ9276QFXaErtZyw
z1nvpI1a2e6ObW6tIxrUsE5ss88Zt9a8ft/qFqehqGMa0piWa9ziFKS1Xb9u
sVOrWTquYU3qm7i3PglNWtDqZjtpUct5u2laJzeZkXMrHdHFjWboqE63wGrN
6VTM3074H7Sk1Q2wRks6c9y7a5u+WA9/fBee63+KMKEQ
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN009IkwEcxvFvSMQOHUZ0GIPC0yqrZbXWLFtWy8yWpa5VZqVmZqbLlkh4
iBgdJDqMiPBQHUbYn0N4CPHgQSIkInaQ6BARHXYIkQ7RISTqexgf2Hgfnj0/
3uruXOvQCmDez6PjEBmBmL67CQtp6NGcVulKfZqHJ8egTqNavgEfmmFA+zWg
q3RyGJ4dhZQ2aOU6fG6COzqsYa3SqZyZRyCt9bo4BF8aYVxvaUTX6vwgvDps
H03p32vmpeCB5jWqQf04AK8P2UfTGtAfB+HFVbitKQ3pt37zDsCINmpQKw0+
ewUKmtZqXeyD2f1wT9s0oktJmLtsnmY1rL96YWYfFDWrUf1db59LfqeDGtGA
zu2FUo95mtCfe+BTN9zXvNZoUN/X2acLerVFlxP2uQgP9a5GNKxvd8P0BejS
jP6L2+c8PNaiJrRWy7vs0+mdtE+XY+54zrvrhMY0rgs77dPhnTSvq3WNlnbY
56x30iYtb3fHM26tYxrQkE7W2ue0W2tGv29ziyyMalGDWqOlqFucgqR26tet
dsqYpRMa0ri+2eKt26FZ81rZbCcd1VKb3TSpUzVmtLqVjunSJjN0XGdOwjpt
1+mN/nbC/6AFrWyA9VrQ2Rbvrh36MgJ/fBee63/4TqKi
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN009Ik3Ecx/G3B4nYocOIDmOQdKhVq5bVWrNsWS0zW1q6VpmlmZnpMhsh
4SFidJDoIBHhoTqMkP5AeAjx4EFEIiI8SHSIiA47hEgH6RBS78PDC56H5/N8
ft8vT1VHvrm/ApjzenoSIgWI69xtWGiELh3QSl2lLwbh+Qmo0ZjO34JPDdCn
vRrQ1To+AC+PQ1rrtHwTvtbDfR3UsFbqRN7MY5DRWl3sh29pGNG7GtF1+qEP
3hy1j6b13w3zjsBjLWhMg/q5F94dto9mNKC/6uDVdbinaQ3pjx7zDsEdrdeg
llO+ew2KmtENutgN0wfhobZoRJdqYeaqeZrTsC53wdQBGNWcxvTPfvtc8Z7m
NaIBnamBUqd5mtTfSfjSAY+0oFEN6sd99rkM3dqkKwn7XIIn+kAjGtbZvTDZ
Dp2a1QpdvgjP4n5bk1qt83vs0+aetEdXdjvHC+5dxzSuCV3YZZ/z7kkLukbX
aqnaPufckzbo/E7nmHPWOqwBDel4zD5nnbVm9ecOZ5GFIR3VoEa1tN1ZtEJK
2/X7Nju1mKVjGtKEvo+66zPQqAUtb7WTDmnptN00pRNbzGh2VjqsS5vN0BGd
aoL12qqTEZ+d8gxa1PImqNKiTmfcu7bp243w13/htf4HE7+jNQ==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN009Ik3Ecx/G3dJCIHTqM6DCkIvqzatWysjXLltUys2mla5VpmZnpMpMR
Eh4iRgeJDhIhHqrDCImi8BDiwYNIRETsIOEhIjrsECIdpEPY+/Dwgufh+Tyf
3/fLs64929hbBsx6jZ6G8ABU6ce7MFcPndqv5bpSX/bDi1NQrVEt3oEvdZDV
Hg3oKh3vg1cnIam1WroN80l4qANaoeU6kTXzBKS0Rhd64ftxGNb7Gta1+qkH
3hyzjya1TOdr4ektyGlUg/q1G94ftY+mNKC/E/D6JjzQpIb0Z5d5R+Ce1mlQ
SzW+ewPymtKNutAJ04fhsTZrWBcPwcx18zSjFbrUAVPVMKIZjerfuH2ueU/7
NKwBnTkIhavmaVz/xOBbOzzRnEY0qJ8P2KcNurRJl6vscwWe6SMNa4XO7ofJ
VujQtK7QpcvwfJ/f1rhWanGvfS65J+3W5UrnqKM6dtG9a0zn9tgn4540p6t1
jRai9rngnrRei7udY9pZ65AGNKTju+zT4qw1rb92OotmGNQRDWpECxFncR4S
2qY/dtjpnFk6piGN6Yft7vosNGhOS9vspINaaLKbJnQibEajs9IhXdxqhg7r
VArWa4tObvHZGc+geS1thg2a1+kG966t+m4T/PNfeKv/Ae03osk=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN009Ik3Ecx/H3kA4SsUOHER1kUNi/VVbLytYsW1bLTJeVrlVqZWa6zCRG
SOwQIR0kOkiEeKgOIySCykOIBw8SERGxg4SHiOiwQwzpIB3qfXh4wfPwfJ7P
7/vlCXdlWwcCwLzXxEmIDEOdfrwNC03Qq8NaqSv1xRA8PwH1GtXiLfiShEHN
alBX6dQgvDwOSW3U0k1YPAYP9I6GtVKns2YehZQ2aHkAvjfCmN7TiK7VT/3w
+oh9NKkVupiAJzcgp1EN6dc+eHvYPprSoP5ugFfX4b4mtUp/9pp3CO5qk4a0
dNB3r8GoprRayz0wVw+PtF0juhR3XlfN04yGdfkKzB6Acc1oVP/G7HPZezqk
EQ3q/H4odJuncf1TB9+64LHmtEZD+nmffTqhT9s0oOVL8HQvPNSIhvXDHpi5
CD2a1hW6fAGe1fptjWutFnfbJ+OetF8DWqETUZg87941pgu77JN2T5rT1bpG
Czvt0+GetFmLO5xju7PWvAa1Sqdq7HPOWWtaf213FmdhRMc1pDVa2OYszkBC
u/XHVjtpXifbzNKYvo+469PQojktbbGTjmghZTdN6PRmM1qdleZ1aZMZOqaz
LbBOO3Rmo89OeQYd1dIGWK+jOtfs3rVT31XDP/+FN/ofHnShXg==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0U9Ik3Ecx/G3iHSQiB06jOggQmb/VlktK1uzbFktU1tWulaalZkuM4kY
IbFDxOgg0UEixEN1GCHRoQxCPEhIRETEDhIeIqLDDjGkgwS9Dw8veB5+n9/n
+X6rutNtg2XAB5+JExAagQb9dAsW4tCvt7VSV+qLYXh+HBo1rIWb8PUYDOuQ
BnSVTg3By6MQ12Yt3oDFZnigd7RaK3U6beYRSGiTlgbhRwzG9J6GdK1+HoDX
h+2jca3QxSZ4ch0yGtagfuuHN4fsowkN6J+D8Ooa3Ne4VumvPvMa4a62aFCL
Uc9ehZwmtFZLV2DuADzSTg3pUgTmL5unKa3W5V6Y3Q/jmtKw/muwzyXf6YiG
NKDz+yDfY55G9e9e+N4NjzWjdRrUL3vscxEGtEPLtXQBntbDQw1ptX7cDTMp
6NOkrtDl8/As7N0a1Xot7LJP0j1pWsu1Qid2wmSXe9eILuywT6d70oyu1jWa
r7PPOfekrVrY7hzPOmvNakCrdGqbfc44a03q763OogNGdVyDWqf5kLM4DTHt
1Z9b7KRZnUyYpRF9v9ldn4J2zWhxk510VPPtdtOYTm80o81ZaVaXNpihYzrb
Cuu0S2dq/XbSf9CcFtdDjeZ0rsW9a4++q4Eyfav/AYSZofE=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0U9IkwEcxvFvhEgHidihw4gIGWn2762slpWtWbaslpotK11aZmW6zCQi
Rkh4iJAOEh0kQjxUhxESHcIoxIMHiYiI2EHCQ0R02CGGdJD6HsYHNt7nffb8
1nVmmvqWAbN+xk9AMAi1+ukWzB+HXr2jZbpSXw7Ai2NQp1HN34SvDTCoAxrS
VTrZD6+OQlIbtHADFhLwUO9qRMt0KmPmEUhpvRb74Ec9jOp9DXStfu6FN4ft
o0kt1YVD8PQ6ZDWqYf3WA2/r7KMpDemfOLy+Bg80qeX666p5B+GeNmpYCzGf
vQIjmtIqLXa7zQF4rG0a6GItzF02Tzs0oktdMLMfxrRDo/pvn30u+Z3e1kBD
OrcXchfN07j+rYHvnfBEs1qtYf2yxz4dkNFWLdHiBXgWhUcaaEQ/7obpNPRo
WlfoUjs83+W7Na41mt9pnzbvpP1aoqU6Xg0T5727xnR+h33OeSfN6mpdo7nt
9jnrnbRZ89vcsdWtdVhDWq6TgX3OuLWm9fdWt0jBkI5pWKs1t8UtTkNCu/Xn
ZjvpsE60mKUx/bDJW5+CFs1qYaOddEhzzXbThE5VmdHkVjqsixvM0FGdaYQK
bdfpSn876X/QES1UQKWO6GzSu2uXvl8Py/Wd/gfyt6OD
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0T9IlHEcx/G3Q4g0SMQNDUc4yJVm/57K6rIy07LL6jSzy0pPK7PSy0wi
Io6QuCHiaJBokAhxqIYjJBpCKEXCQSIiQhwkHCKi4YY4pMHew8MLnh/P5/n8
vt+yrlRzfxHwyWfsBARDUKtfbsNiE6T0npbqGn09CK+OQ4NGdeEWfI/BHR3S
kK7ViQF4cwzi2qT5m7DUCI/1vka0VCdTZh6FhDZqoR9+HoERfaiBlunXPnjX
YB+Na4ku1cPzG5DWqIZ1/jq8P2wfTWhI/9bB22vwSONarr97zTsED7RFw5qv
9durkNWEVmmhB2YPwlPt0ECXD8DcFfO0WyO6chlm9sOodmtUi3T+ku9q4K4G
GtK5fZDrNk/r9V8UfnTBM01rtYb12177JGFA27VYC53wYg880UAj+nk3THdA
nyZ1ta5chJfV/lvrtUYXdtnngnvSQS3WEh3bCePn3bvW6eIO+7S7J03rOl2v
ucA+59yTturCdueYcNaa0ZCW68Q2+5x11prUP1udhQ7raJt302rNbXEWZyCm
vfprs500o+OtZmmdfqxy16ehTdOa32QnHdZci900ppOVZjQ7K83ocoUZOqIz
cajQTp3e6Nkp76BZzW+ASs3q7En3rj06FYFV+kH/A9dBoxc=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0U9Ik3Ecx/H36BAiHSRihw4iHdZKs3+rrJaVLS1blsvMlpVbVma5zCQi
IkZI7BAxOkh0kAjxUB1GSHQID2k7eJCIiJAdJDxERIcdQiTofXh4wfPwfH6f
3/dbk8q0DwSAos/4cYgMQ5N+uQ0LcRjU+1qlq/XNELw+Bi0a1dIt+N4Kd/WO
BnWNTg7C26OQ0DYt34TFI/BEH2hYq3QqY2YLJLVVlwbgZzOM6iON6Dr9egPe
H7aPJrRSF2Pw4jpkNarVOt8PHw7ZR5Ma1L9N8O4aPNaEhvR3n3kH4aF2aLWW
D/jvVchrUut16QrM7odn2qMRXW6Eucvmaa+GNaDFfTDW6zuN6gqdv+S7KNzT
iAZ1bi8U0uZps/7bAz9S8Fyz2qDV+m23fXpgSLu1QpcuwssGeKoRDevnXTBz
ATKa1lUa0Fc7Pfu8Z2ijlnbYp9s96bBWaKWOR2DinHvXmC5st0/SPWlW12qN
FrbZ56x70k4tbXWOXc5acxrUkE5usc8ZZ61p/bPZWeiIjnV6N23QQr2zOA1x
7ddfm+ykOZ3oMEtj+rHOXZ+CLs1qudZOOqKFhN00rlMbzWh3VprT5Q1m6KgW
T0KtpnQm7LcT3kHzWl4PdZrX2Tb3rn36KQQrdVr/Axhvoqs=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0U9Ik3Ecx/F3SIdI6VAUO3QYEbVWmf3batW0sqVlprlMc1nmsjI1M4mI
iBiBsUsxOkh0kAjxUB00JAjCQ5iBB4mICEmQSIiIDjuESL0PDy94fjyf3+f5
foMtXbWdi4Bxn8FjEOmFcv10HWaroEfv6HJdqS974MVRqNRS/XYNvh6BW3pT
A7pKR7vhVSUktUbzV2GuAh7qXQ3rCh3rMvMwpLRK5zvhZwL69b5GdK1+7oA3
h+yjSS3SuXJ4egUyGtegTrfD24P20ZQG9O8BeH0ZHmhSQ/r7knn74Z7Wa1Dz
ZX57EXKa0hKdb4PJUnisrRrRhThMXTBP2zSsBTqxDwbSvtO4LtbpVt/thdsa
1YBO7YHh8+Zphf6LwfcWeKIZjWlQv+y2zzno1WYt1Pmz8GwXPNKohvVj1P01
Q7emdZkW6POId5/xDi3TmZ32SbknvaGFWqSDO2Coyb1rQme32+e0e9KMrtY1
OrLNPo3uSRt0ZqtzbHDWmtWAhnS0xD6nnLWm9c8WZ6F9OlDvv2lMR4qdxUmo
1g79tRmWalaHkmZpQt9tgh910KQZzW+0k/bp8Am7abWOhc2odVaa1YUNZmi/
TtRAsbbqeMiz49CoOc2v90xzOlnt3rVdP6yDJfpe/wOsbaRV
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0V9ojXEcx/H3LpYLaVxIswvppOHY2ObPjhlmmNlhzjY7ZubYmGNjO9iW
JEms1NoNjYslRdHaBS44LReIWmuyi5EkVtaSloSLc8Ga98WvVz1Pz/f5/L6f
pU2JqvY0YNgzsBdCXVCmHzphag906WVdqJn6qMMThrCW6tez8LkCLuoFzdJM
HToDyd0Q1WpNnYbpcriuVzRHF+nrBDzeBTGt1Jl2+FEG/dqjIc3Wj23wfCd0
alQzdHoH3D8F3VqiAZ04CS+3m0djmqV/S+FZK9zQWg3qrxbnbYNrWqcBTZX4
7Qno05gW6EwcxrbCbY1roc5ugfHjztNWzdF0Hd0M95qhRUt0jk4c81kxXNIi
Xazjm+DJUedpWNP0WxPcKfIuWqwB/bTRPI1wThs1Q/8dgQchuKVFmqvvC2Ek
Bh0a1wWarg83+O/DUKGlOrkevjTYk57XDJ2vA+tg8JC9a7lOrTVPvT1pty7R
ZZosgBcH7UnrdTIffte5a+3VLA3qUJ55DtiTxvXPGnehPXo36t20WJOr4V0t
RDShP3Nhnvbq4H5nabkO58D3GjvRq5paZSbt0afVZtOIvgo6o8pdaa/OrnSG
9utoBPK1WUdW+G4fNOhNTS2HPO3TsUp71zZ9mw1z9Y3+B50/pQA=
       "],
       VertexColors->None], 
      Line3DBox[{20635, 10595, 20739, 10702, 10804, 20839, 10808, 20841, 
       10811, 20843, 10812, 20844, 10705, 20743, 10602, 10601, 20640, 10599, 
       20639, 10596, 20637, 10592, 20635},
       VertexColors->None], 
      Line3DBox[{20638, 10598, 20741, 10699, 20740, 10703, 10805, 20840, 
       10809, 20842, 10704, 20742, 10600, 10597, 20638},
       VertexColors->None], 
      Line3DBox[{21435, 11409, 21539, 11515, 11617, 21638, 11620, 21639, 
       11623, 21641, 11624, 21642, 11518, 21542, 11416, 11415, 21440, 11413, 
       21439, 11410, 21437, 11406, 21435},
       VertexColors->None], 
      Line3DBox[{21438, 11412, 21540, 11516, 11621, 21640, 11517, 21541, 
       11414, 11411, 21438},
       VertexColors->None], 
      Line3DBox[{22233, 12221, 22337, 12327, 12429, 22436, 12432, 22437, 
       12435, 22439, 12436, 22440, 12330, 22340, 12228, 12227, 22238, 12225, 
       22237, 12222, 22235, 12218, 22233},
       VertexColors->None], 
      Line3DBox[{22236, 12224, 22338, 12328, 12433, 22438, 12329, 22339, 
       12226, 12223, 22236},
       VertexColors->None], 
      Line3DBox[{23031, 13033, 23135, 13139, 13241, 23234, 13244, 23235, 
       13247, 23237, 13248, 23238, 13142, 23138, 13040, 13039, 23036, 13037, 
       23035, 13034, 23033, 13030, 23031},
       VertexColors->None], 
      Line3DBox[{23034, 13036, 23136, 13140, 13245, 23236, 13141, 23137, 
       13038, 13035, 23034},
       VertexColors->None], 
      Line3DBox[{23829, 13845, 23933, 13951, 14053, 24032, 14056, 24033, 
       14059, 24035, 14060, 24036, 13954, 23936, 13852, 13851, 23834, 13849, 
       23833, 13846, 23831, 13842, 23829},
       VertexColors->None], 
      Line3DBox[{23832, 13848, 23934, 13952, 14057, 24034, 13953, 23935, 
       13850, 13847, 23832},
       VertexColors->None], 
      Line3DBox[{24627, 14657, 24731, 14763, 14865, 24830, 14868, 24831, 
       14871, 24833, 14872, 24834, 14766, 24734, 14664, 14663, 24632, 14661, 
       24631, 14658, 24629, 14654, 24627},
       VertexColors->None], 
      Line3DBox[{24630, 14660, 24732, 14764, 14869, 24832, 14765, 24733, 
       14662, 14659, 24630},
       VertexColors->None], 
      Line3DBox[{25425, 15469, 25529, 15575, 15677, 25628, 15680, 25629, 
       15683, 25631, 15684, 25632, 15578, 25532, 15476, 15475, 25430, 15473, 
       25429, 15470, 25427, 15466, 25425},
       VertexColors->None], 
      Line3DBox[{25428, 15472, 25530, 15576, 15681, 25630, 15577, 25531, 
       15474, 15471, 25428},
       VertexColors->None], 
      Line3DBox[{26223, 16281, 26327, 16387, 16489, 26426, 16492, 26427, 
       16495, 26429, 16496, 26430, 16390, 26330, 16288, 16287, 26228, 16285, 
       26227, 16282, 26225, 16278, 26223},
       VertexColors->None], 
      Line3DBox[{26226, 16284, 26328, 16388, 16493, 26428, 16389, 26329, 
       16286, 16283, 26226},
       VertexColors->None], 
      Line3DBox[{27021, 17093, 27125, 17199, 17301, 27224, 17304, 27225, 
       17307, 27227, 17308, 27228, 17202, 27128, 17100, 17099, 27026, 17097, 
       27025, 17094, 27023, 17090, 27021},
       VertexColors->None], 
      Line3DBox[{27024, 17096, 27126, 17200, 17305, 27226, 17201, 27127, 
       17098, 17095, 27024},
       VertexColors->None], 
      Line3DBox[{27819, 17905, 27923, 18011, 18113, 28022, 18116, 28023, 
       18119, 28025, 18120, 28026, 18014, 27926, 17912, 17911, 27824, 17909, 
       27823, 17906, 27821, 17902, 27819},
       VertexColors->None], 
      Line3DBox[{27822, 17908, 27924, 18012, 18117, 28024, 18013, 27925, 
       17910, 17907, 27822},
       VertexColors->None], 
      Line3DBox[{28617, 18717, 28721, 18823, 18925, 28820, 18928, 28821, 
       18931, 28823, 18932, 28824, 18826, 28724, 18724, 18723, 28622, 18721, 
       28621, 18718, 28619, 18714, 28617},
       VertexColors->None], 
      Line3DBox[{28620, 18720, 28722, 18824, 18929, 28822, 18825, 28723, 
       18722, 18719, 28620},
       VertexColors->None], 
      Line3DBox[{29415, 19530, 29520, 19637, 19739, 29618, 19742, 29619, 
       19745, 29621, 19746, 29622, 19640, 29522, 19537, 19536, 29421, 19534, 
       29420, 19532, 29418, 19526, 29415},
       VertexColors->None], 
      Line3DBox[{29416, 19531, 19634, 19638, 19743, 29620, 19639, 29521, 
       19535, 19533, 29419, 19527, 29416},
       VertexColors->None]}, {}, {}}},
   VertexColors->{
     Hue[0.7929573448108859, 1, -17.474999625757572`], 
     Hue[0.7929573448108859, 1, -17.100757209075603`], 
     Hue[0.7929573448108859, 1, -16.726514792393633`], 
     Hue[0.7929573448108859, 1, -16.35227237571166], 
     Hue[0.7929573448108859, 1, -15.97802995902969], 
     Hue[0.792957344810886, 1, -15.603787542347721`], 
     Hue[0.792957344810886, 1, -15.229545125665748`], 
     Hue[0.7929573448108863, 1, -14.855302708983777`], 
     Hue[0.7929573448108869, 1, -14.481060292301807`], 
     Hue[0.792957344810888, 1, -14.106817875619837`], 
     Hue[0.7929573448108905, 1, -13.732575458937868`], 
     Hue[0.7929573448108962, 1, -13.358333042255902`], 
     Hue[0.7929573448109084, 1, -12.984090625573941`], 
     Hue[0.7929573448109356, 1, -12.609848208891991`], 
     Hue[0.7929573448109952, 1, -12.235605792210071`], 
     Hue[0.7929573448111262, 1, -11.861363375528208`], 
     Hue[0.7929573448114143, 1, -11.487120958846475`], 
     Hue[0.7929573448120479, 1, -11.112878542165026`], 
     Hue[0.7929573448134409, 1, -10.738636125484206`], 
     Hue[0.7929573448165037, 1, -10.364393708804764`], 
     Hue[0.7929573448232382, 1, -9.990151292128353], 
     Hue[0.7929573448380453, 1, -9.615908875458608], 
     Hue[0.792957344870602, 1, -9.24166645880352], 
     Hue[0.7929573449421852, 1, -8.867424042180653], 
     Hue[0.7929573450995774, 1, -8.49318162562864], 
     Hue[0.7929573454456399, 1, -8.118939209232414], 
     Hue[0.7929573462065371, 1, -7.744696793178712], 
     Hue[0.7929573478795425, 1, -7.370454377878134], 
     Hue[0.7929573515580256, 1, -6.9962119642334715`], 
     Hue[0.7929573596460073, 1, -6.621969554229714], 
     Hue[0.792957377429274, 1, -6.247727152231319], 
     Hue[0.792957416529827, 1, -5.873484767834549], 
     Hue[0.7929575025012685, 1, -5.49924242213903], 
     Hue[0.7929576915289487, 1, -5.125000161537371], 
     Hue[0.7929581071488655, 1, -4.7507580880356475`], 
     Hue[0.7929590209816832, 1, -4.376516425924033], 
     Hue[0.7929610302407959, 1, -4.002275668387488], 
     Hue[0.792965448004647, 1, -3.6280368999599855`], 
     Hue[0.7929751612247424, 1, -3.2538025059837548`], 
     Hue[0.7929965167946251, 1, -2.8795777347897973`], 
     Hue[0.7930434662914109, 1, -2.505374143490335], 
     Hue[0.7931466684300623, 1, -2.1312172273775554`], 
     Hue[0.7933734509459465, 1, -1.7571634507032254`], 
     Hue[0.7938714482386966, 1, -1.3833389229418522`], 
     Hue[0.794963303873275, 1, -1.0100303154256751`], 
     Hue[0.7973486599646449, 1, -0.6379124314492823], 
     Hue[0.8025159981740454, 1, -0.26867415982197085`], 
     Hue[0.8134737058080757, 1, 0.0930886773867925], 
     Hue[0.8354125663808488, 1, 0.4341911431808394], 
     Hue[0.8730987079310746, 1, 0.7213798408786523], 
     Hue[0.9198586368798097, 1, 0.9085010492196399], 
     Hue[0.9575447784300359, 1, 0.9955547682038012], 
     Hue[0.9794836390028097, 1, 1.0286947190917266`], 
     Hue[0.9904413466368402, 1, 1.0411742985649353`], 
     Hue[0.9956086848462409, 1, 1.0461784436195949`], 
     Hue[0.9979940409376108, 1, 1.0483029763251737`], 
     Hue[0.9990858965721892, 1, 1.0492367854909674`], 
     Hue[0.9995838938649394, 1, 1.0496546744115656`], 
     Hue[0.9998106763808235, 1, 1.049843314419207], 
     Hue[0.999913878519475, 1, 1.049928814988398], 
     Hue[0.9999608280162607, 1, 1.049967640370907], 
     Hue[0.9999821835861434, 1, 1.0499852858589214`], 
     Hue[0.9999918968062389, 1, 1.049993308564661], 
     Hue[0.99999631457009, 1, 1.0499969568191303`], 
     Hue[0.9999983238292026, 1, 1.0499986159645565`], 
     Hue[0.9999992376620204, 1, 1.0499993705349129`], 
     Hue[0.9999996532819372, 1, 1.0499997137151598`], 
     Hue[0.9999998423096172, 1, 1.049999869795472], 
     Hue[0.9999999282810589, 1, 1.049999940781924], 
     Hue[0.9999999673816119, 1, 1.0499999730671252`], 
     Hue[0.9999999851648785, 1, 1.0499999877507011`], 
     Hue[0.9999999932528602, 1, 1.0499999944289151`], 
     Hue[0.9999999969313432, 1, 1.049999997466223], 
     Hue[0.9999999986043487, 1, 1.0499999988476167`], 
     Hue[0.9999999993652459, 1, 1.0499999994758862`], 
     Hue[0.9999999997113085, 1, 1.0499999997616287`], 
     Hue[0.9999999998687006, 1, 1.0499999998915868`], 
     Hue[0.9999999999402839, 1, 1.0499999999506926`], 
     Hue[0.9999999999728406, 1, 1.0499999999775746`], 
     Hue[0.9999999999876477, 1, 1.0499999999898009`], 
     Hue[0.999999999994382, 1, 1.0499999999953613`], 
     Hue[0.9999999999974449, 1, 1.0499999999978904`], 
     Hue[0.9999999999988379, 1, 1.0499999999990406`], 
     Hue[0.9999999999994714, 1, 1.0499999999995635`], 
     Hue[0.9999999999997596, 1, 1.0499999999998015`], 
     Hue[0.9999999999998906, 1, 1.0499999999999097`], 
     Hue[0.9999999999999503, 1, 1.049999999999959], 
     Hue[0.9999999999999774, 1, 1.0499999999999814`], 
     Hue[0.9999999999999897, 1, 1.0499999999999916`], 
     Hue[0.9999999999999953, 1, 1.049999999999996], 
     Hue[0.9999999999999979, 1, 1.0499999999999983`], 
     Hue[0.999999999999999, 1, 1.0499999999999992`], 
     Hue[0.9999999999999996, 1, 1.0499999999999998`], 
     Hue[0.9999999999999998, 1, 1.0499999999999998`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.918352145925817, 1, -17.474999625757572`], 
     Hue[0.918352145925817, 1, -17.100757209075603`], 
     Hue[0.918352145925817, 1, -16.726514792393633`], 
     Hue[0.918352145925817, 1, -16.35227237571166], 
     Hue[0.918352145925817, 1, -15.97802995902969], 
     Hue[0.918352145925817, 1, -15.603787542347721`], 
     Hue[0.9183521459258172, 1, -15.229545125665748`], 
     Hue[0.9183521459258173, 1, -14.855302708983777`], 
     Hue[0.9183521459258175, 1, -14.48106029230181], 
     Hue[0.918352145925818, 1, -14.106817875619841`], 
     Hue[0.9183521459258194, 1, -13.732575458937879`], 
     Hue[0.9183521459258223, 1, -13.35833304225592], 
     Hue[0.9183521459258286, 1, -12.984090625573984`], 
     Hue[0.9183521459258424, 1, -12.609848208892085`], 
     Hue[0.9183521459258727, 1, -12.235605792210276`], 
     Hue[0.9183521459259394, 1, -11.861363375528658`], 
     Hue[0.9183521459260862, 1, -11.487120958847465`], 
     Hue[0.9183521459264088, 1, -11.112878542167202`], 
     Hue[0.9183521459271182, 1, -10.73863612548899], 
     Hue[0.9183521459286779, 1, -10.364393708815282`], 
     Hue[0.9183521459321072, 1, -9.99015129215148], 
     Hue[0.9183521459396475, 1, -9.615908875509458], 
     Hue[0.9183521459562267, 1, -9.241666458915326], 
     Hue[0.9183521459926796, 1, -8.867424042426487], 
     Hue[0.9183521460728297, 1, -8.493181626169159], 
     Hue[0.9183521462490577, 1, -8.118939210420868], 
     Hue[0.9183521466365352, 1, -7.744696795791799], 
     Hue[0.9183521474884925, 1, -7.370454383623602], 
     Hue[0.9183521493617144, 1, -6.9962119768661895`], 
     Hue[0.9183521534804187, 1, -6.621969582005615], 
     Hue[0.9183521625363255, 1, -6.247727213302947], 
     Hue[0.9183521824477903, 1, -5.873484902114377], 
     Hue[0.9183522262276437, 1, -5.49924271738359], 
     Hue[0.9183523224874599, 1, -5.125000810698785], 
     Hue[0.9183525341358355, 1, -4.750759515360282], 
     Hue[0.9183529994894197, 1, -4.376519564200645], 
     Hue[0.9183540226581424, 1, -4.002282568499647], 
     Hue[0.9183562722451994, 1, -3.6280520709289465`], 
     Hue[0.9183612180770802, 1, -3.2538358604063573`], 
     Hue[0.9183720906946712, 1, -2.8796510604557746`], 
     Hue[0.9183959873448848, 1, -2.505535310483121], 
     Hue[0.9184484847768541, 1, -2.131571318252936], 
     Hue[0.9185636962071402, 1, -1.7579406889275602`], 
     Hue[0.9188159743403677, 1, -1.3850415306431165`], 
     Hue[0.9193656817093732, 1, -1.013743416147755], 
     Hue[0.9205507287358916, 1, -0.6459305213961415], 
     Hue[0.9230471123964893, 1, -0.28561225979421057`], 
     Hue[0.9280559680121757, 1, 0.059026010646172744`], 
     Hue[0.9371704258141411, 1, 0.37280977243477786`], 
     Hue[0.9510656112780389, 1, 0.6332227342342487], 
     Hue[0.9672865346477775, 1, 0.8203439425752356], 
     Hue[0.9811817201116756, 1, 0.9341733974577384], 
     Hue[0.990296177913641, 1, 0.9946320523511061], 
     Hue[0.9953050335293275, 1, 1.0242361985926949`], 
     Hue[0.9978014171899254, 1, 1.0381603536727355`], 
     Hue[0.9989864642164439, 1, 1.0445898756030934`], 
     Hue[0.9995361715854493, 1, 1.0475341777897034`], 
     Hue[0.9997884497186768, 1, 1.048877436187231], 
     Hue[0.9999036611489629, 1, 1.049489223543826], 
     Hue[0.9999561585809322, 1, 1.0497676479956124`], 
     Hue[0.9999800552311459, 1, 1.0498943147049296`], 
     Hue[0.9999909278487369, 1, 1.0499519314363188`], 
     Hue[0.9999958736806175, 1, 1.0499781375957005`], 
     Hue[0.9999981232676746, 1, 1.0499900567069715`], 
     Hue[0.9999991464363973, 1, 1.0499954776879434`], 
     Hue[0.9999996117899815, 1, 1.0499979432102782`], 
     Hue[0.9999998234383571, 1, 1.0499990645537456`], 
     Hue[0.9999999196981734, 1, 1.0499995745509128`], 
     Hue[0.9999999634780268, 1, 1.049999806502096], 
     Hue[0.9999999833894916, 1, 1.0499999119954968`], 
     Hue[0.9999999924453984, 1, 1.0499999599748004`], 
     Hue[0.9999999965641027, 1, 1.0499999817961978`], 
     Hue[0.9999999984373246, 1, 1.0499999917207556`], 
     Hue[0.9999999992892818, 1, 1.049999996234529], 
     Hue[0.9999999996767593, 1, 1.0499999982874317`], 
     Hue[0.9999999998529874, 1, 1.0499999992211093`], 
     Hue[0.9999999999331374, 1, 1.0499999996457539`], 
     Hue[0.9999999999695903, 1, 1.0499999998388858`], 
     Hue[0.9999999999861694, 1, 1.049999999926724], 
     Hue[0.9999999999937097, 1, 1.0499999999666734`], 
     Hue[0.9999999999971392, 1, 1.0499999999848428`], 
     Hue[0.9999999999986988, 1, 1.0499999999931064`], 
     Hue[0.9999999999994083, 1, 1.0499999999968648`], 
     Hue[0.9999999999997309, 1, 1.049999999998574], 
     Hue[0.9999999999998775, 1, 1.0499999999993515`], 
     Hue[0.9999999999999444, 1, 1.049999999999705], 
     Hue[0.9999999999999747, 1, 1.049999999999866], 
     Hue[0.9999999999999885, 1, 1.049999999999939], 
     Hue[0.9999999999999948, 1, 1.0499999999999723`], 
     Hue[0.9999999999999977, 1, 1.0499999999999874`], 
     Hue[0.9999999999999989, 1, 1.0499999999999943`], 
     Hue[0.9999999999999996, 1, 1.0499999999999974`], 
     Hue[0.9999999999999998, 1, 1.049999999999999], 
     Hue[0.9999999999999999, 1, 1.0499999999999996`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.043746947040748, 1, -17.474999625757572`], 
     Hue[1.043746947040748, 1, -17.100757209075603`], 
     Hue[1.043746947040748, 1, -16.726514792393633`], 
     Hue[1.043746947040748, 1, -16.35227237571166], 
     Hue[1.043746947040748, 1, -15.97802995902969], 
     Hue[1.043746947040748, 1, -15.603787542347721`], 
     Hue[1.043746947040748, 1, -15.229545125665748`], 
     Hue[1.043746947040748, 1, -14.855302708983777`], 
     Hue[1.0437469470407479`, 1, -14.48106029230181], 
     Hue[1.0437469470407477`, 1, -14.106817875619843`], 
     Hue[1.0437469470407468`, 1, -13.732575458937879`], 
     Hue[1.0437469470407452`, 1, -13.358333042255923`], 
     Hue[1.043746947040742, 1, -12.984090625573991`], 
     Hue[1.0437469470407341`, 1, -12.6098482088921], 
     Hue[1.0437469470407175`, 1, -12.235605792210306`], 
     Hue[1.0437469470406804`, 1, -11.861363375528727`], 
     Hue[1.0437469470405993`, 1, -11.487120958847612`], 
     Hue[1.043746947040421, 1, -11.112878542167529`], 
     Hue[1.0437469470400287`, 1, -10.738636125489712`], 
     Hue[1.043746947039166, 1, -10.364393708816868`], 
     Hue[1.0437469470372696`, 1, -9.99015129215497], 
     Hue[1.0437469470330996`, 1, -9.615908875517126], 
     Hue[1.0437469470239311`, 1, -9.241666458932189], 
     Hue[1.043746947003772, 1, -8.867424042463561], 
     Hue[1.0437469469594474`, 1, -8.49318162625068], 
     Hue[1.04374694686199, 1, -8.118939210600107], 
     Hue[1.0437469466477078`, 1, -7.7446967961859], 
     Hue[1.0437469461765594`, 1, -7.370454384490119], 
     Hue[1.0437469451406327`, 1, -6.9962119787714245`], 
     Hue[1.0437469428629125`, 1, -6.621969586194711], 
     Hue[1.0437469378548272`, 1, -6.247727222513627], 
     Hue[1.043746926843416, 1, -5.873484922366142], 
     Hue[1.0437469026323432`, 1, -5.499242761911657], 
     Hue[1.043746849398884, 1, -5.125000908603647], 
     Hue[1.0437467323534584`, 1, -4.750759730625323], 
     Hue[1.0437464750046126`, 1, -4.376520037504638], 
     Hue[1.0437459091750128`, 1, -4.00228360914114], 
     Hue[1.0437446651200948`, 1, -3.628054358895154], 
     Hue[1.0437419300248787`, 1, -3.2538408904364235`], 
     Hue[1.043735917468025, 1, -2.8796621172980714`], 
     Hue[1.0437227031579854`, 1, -2.5055596078263465`], 
     Hue[1.0436936758443742`, 1, -2.1316246756323984`], 
     Hue[1.0436299846235062`, 1, -1.7580576897683284`], 
     Hue[1.0434905795799212`, 1, -1.3852972580279002`], 
     Hue[1.043187099981558, 1, -1.0142984135663762`], 
     Hue[1.0425341488598492`, 1, -0.6471166394055512], 
     Hue[1.0411641774031533`, 1, -0.28806514816754847`], 
     Hue[1.0384361233645691`, 1, 0.054287738613279735`], 
     Hue[1.033531154752895, 1, 0.36478890268582254`], 
     Hue[1.0261529714079156`, 1, 0.6223676089161837], 
     Hue[1.017593975632833, 1, 0.8094888172571707], 
     Hue[1.0102157922878534`, 1, 0.9261525277087829], 
     Hue[1.0053108236761792`, 1, 0.9898937803182131], 
     Hue[1.002582769637595, 1, 1.0217833102193572`], 
     Hue[1.0012127981808991`, 1, 1.0369742356633258`], 
     Hue[1.00055984705919, 1, 1.0440348781844726`], 
     Hue[1.0002563674608271`, 1, 1.0472784504049195`], 
     Hue[1.000116962417242, 1, 1.0487604353464623`], 
     Hue[1.0000532711963739`, 1, 1.049435866164364], 
     Hue[1.0000242438827627`, 1, 1.049743350652387], 
     Hue[1.0000110295727231`, 1, 1.0498832578626325`], 
     Hue[1.0000050170158694`, 1, 1.049946901406252], 
     Hue[1.0000022819206533`, 1, 1.0499758496294924`], 
     Hue[1.0000010378657354`, 1, 1.0499890160654777`], 
     Hue[1.0000004720361355`, 1, 1.0499950043839517`], 
     Hue[1.0000002146872897`, 1, 1.049997727945236], 
     Hue[1.0000000976418644`, 1, 1.049998966648883], 
     Hue[1.000000044408405, 1, 1.0499995300228457`], 
     Hue[1.000000020197332, 1, 1.0499997862503305`], 
     Hue[1.0000000091859211`, 1, 1.049999902784817], 
     Hue[1.0000000041778356`, 1, 1.0499999557857038`], 
     Hue[1.0000000019001154`, 1, 1.0499999798909605`], 
     Hue[1.0000000008641887`, 1, 1.0499999908542375`], 
     Hue[1.0000000003930405`, 1, 1.0499999958404291`], 
     Hue[1.0000000001787581`, 1, 1.0499999981081918`], 
     Hue[1.0000000000813007`, 1, 1.0499999991395894`], 
     Hue[1.0000000000369762`, 1, 1.049999999608678], 
     Hue[1.0000000000168172`, 1, 1.0499999998220235`], 
     Hue[1.0000000000076485`, 1, 1.0499999999190548`], 
     Hue[1.0000000000034786`, 1, 1.0499999999631855`], 
     Hue[1.000000000001582, 1, 1.0499999999832565`], 
     Hue[1.0000000000007196`, 1, 1.049999999992385], 
     Hue[1.0000000000003273`, 1, 1.0499999999965366`], 
     Hue[1.0000000000001488`, 1, 1.0499999999984249`], 
     Hue[1.0000000000000677`, 1, 1.0499999999992837`], 
     Hue[1.0000000000000309`, 1, 1.0499999999996743`], 
     Hue[1.000000000000014, 1, 1.049999999999852], 
     Hue[1.0000000000000064`, 1, 1.0499999999999325`], 
     Hue[1.0000000000000029`, 1, 1.0499999999999694`], 
     Hue[1.0000000000000013`, 1, 1.049999999999986], 
     Hue[1.0000000000000007`, 1, 1.0499999999999936`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999972`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999987`], 
     Hue[1., 1, 1.0499999999999994`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.1691417481556805`, 1, -17.474999625757572`], 
     Hue[1.1691417481556805`, 1, -17.100757209075603`], 
     Hue[1.1691417481556805`, 1, -16.726514792393633`], 
     Hue[1.1691417481556805`, 1, -16.35227237571166], 
     Hue[1.1691417481556805`, 1, -15.97802995902969], 
     Hue[1.1691417481556803`, 1, -15.603787542347721`], 
     Hue[1.1691417481556803`, 1, -15.229545125665748`], 
     Hue[1.16914174815568, 1, -14.855302708983777`], 
     Hue[1.1691417481556796`, 1, -14.481060292301807`], 
     Hue[1.1691417481556785`, 1, -14.10681787561984], 
     Hue[1.1691417481556763`, 1, -13.732575458937871`], 
     Hue[1.1691417481556712`, 1, -13.358333042255907`], 
     Hue[1.16914174815566, 1, -12.984090625573957`], 
     Hue[1.1691417481556354`, 1, -12.609848208892025`], 
     Hue[1.1691417481555813`, 1, -12.235605792210144`], 
     Hue[1.1691417481554627`, 1, -11.861363375528372`], 
     Hue[1.1691417481552013`, 1, -11.487120958846834`], 
     Hue[1.1691417481546271`, 1, -11.112878542165816`], 
     Hue[1.1691417481533644`, 1, -10.738636125485947`], 
     Hue[1.1691417481505877`, 1, -10.364393708808588`], 
     Hue[1.169141748144483, 1, -9.990151292136762], 
     Hue[1.16914174813106, 1, -9.615908875477094], 
     Hue[1.169141748101547, 1, -9.24166645884417], 
     Hue[1.1691417480366555`, 1, -8.867424042270033], 
     Hue[1.169141747893977, 1, -8.493181625825159], 
     Hue[1.1691417475802655`, 1, -8.118939209664505], 
     Hue[1.1691417468904999`, 1, -7.744696794128768], 
     Hue[1.169141745373893, 1, -7.370454379967049], 
     Hue[1.1691417420392882`, 1, -6.996211968826429], 
     Hue[1.169141734707401, 1, -6.621969564328374], 
     Hue[1.1691417185865804`, 1, -6.2477271744355205`], 
     Hue[1.1691416831412957`, 1, -5.873484816655527], 
     Hue[1.1691416052068055`, 1, -5.49924252948301], 
     Hue[1.1691414338502502`, 1, -5.125000397557309], 
     Hue[1.1691410570846064`, 1, -4.750758606978108], 
     Hue[1.1691402286831274`, 1, -4.376517566931961], 
     Hue[1.1691384072709217`, 1, -4.002278177128217], 
     Hue[1.169134402563496, 1, -3.628042415877502], 
     Hue[1.1691255976978967`, 1, -3.2538146334046614`], 
     Hue[1.1691062401058758`, 1, -2.879604396886421], 
     Hue[1.1690636872600753`, 1, -2.5054327526499858`], 
     Hue[1.1689701697412955`, 1, -2.1313460275280027`], 
     Hue[1.1687647657989872`, 1, -1.7574463304982737`], 
     Hue[1.168314180958443, 1, -1.3839593638790635`], 
     Hue[1.1673285087887357`, 1, -1.0113870366711784`], 
     Hue[1.1651856617536365`, 1, -0.6408590319787146], 
     Hue[1.1605918489746525`, 1, -0.27497309368997436`], 
     Hue[1.1510549600576954`, 1, 0.0801321099044594], 
     Hue[1.13268050889082, 1, 0.4100000375285776], 
     Hue[1.102683290968876, 1, 0.6854326789620997], 
     Hue[1.0664584571868059`, 1, 0.8725538873030869], 
     Hue[1.0364612392648613`, 1, 0.9713636625515388], 
     Hue[1.0180867880979856`, 1, 1.0157381516093933`], 
     Hue[1.0085498991810282`, 1, 1.0348753646969315`], 
     Hue[1.003956086402044, 1, 1.0432318430901626`], 
     Hue[1.001813239366945, 1, 1.0469462550796707`], 
     Hue[1.0008275671972375`, 1, 1.0486163445537566`], 
     Hue[1.0003769823566933`, 1, 1.0493717946165175`], 
     Hue[1.000171578414385, 1, 1.0497145142687596`], 
     Hue[1.0000780608956052`, 1, 1.0498702058287475`], 
     Hue[1.000035508049805, 1, 1.0499409782742832`], 
     Hue[1.0000161504577838`, 1, 1.0499731584380148`], 
     Hue[1.0000073455921845`, 1, 1.0499877926471453`], 
     Hue[1.0000033408847588`, 1, 1.0499944480783998`], 
     Hue[1.0000015194725531`, 1, 1.0499974749566279`], 
     Hue[1.0000006910710741`, 1, 1.0499988515924512`], 
     Hue[1.0000003143054303`, 1, 1.0499994776952222`], 
     Hue[1.000000142948875, 1, 1.0499997624514927`], 
     Hue[1.0000000650143848`, 1, 1.0499998919609466`], 
     Hue[1.0000000295691, 1, 1.049999950862924], 
     Hue[1.0000000134482796`, 1, 1.0499999776520406`], 
     Hue[1.0000000061163923`, 1, 1.0499999898359578`], 
     Hue[1.0000000027817875`, 1, 1.0499999953773071`], 
     Hue[1.0000000012651806`, 1, 1.0499999978975598`], 
     Hue[1.000000000575415, 1, 1.0499999990437923`], 
     Hue[1.0000000002617035`, 1, 1.0499999995651086`], 
     Hue[1.000000000119025, 1, 1.0499999998022078`], 
     Hue[1.0000000000541336`, 1, 1.0499999999100424`], 
     Hue[1.0000000000246205`, 1, 1.0499999999590865`], 
     Hue[1.0000000000111975`, 1, 1.0499999999813923`], 
     Hue[1.0000000000050928`, 1, 1.049999999991537], 
     Hue[1.0000000000023161`, 1, 1.049999999996151], 
     Hue[1.0000000000010534`, 1, 1.0499999999982494`], 
     Hue[1.0000000000004792`, 1, 1.0499999999992038`], 
     Hue[1.0000000000002178`, 1, 1.049999999999638], 
     Hue[1.000000000000099, 1, 1.0499999999998355`], 
     Hue[1.000000000000045, 1, 1.0499999999999252`], 
     Hue[1.0000000000000204`, 1, 1.049999999999966], 
     Hue[1.0000000000000093`, 1, 1.0499999999999845`], 
     Hue[1.0000000000000042`, 1, 1.049999999999993], 
     Hue[1.000000000000002, 1, 1.049999999999997], 
     Hue[1.0000000000000009`, 1, 1.0499999999999985`], 
     Hue[1.0000000000000004`, 1, 1.0499999999999994`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.2945365492706116`, 1, -17.474999625757572`], 
     Hue[1.2945365492706116`, 1, -17.100757209075603`], 
     Hue[1.2945365492706116`, 1, -16.726514792393633`], 
     Hue[1.2945365492706116`, 1, -16.35227237571166], 
     Hue[1.2945365492706116`, 1, -15.97802995902969], 
     Hue[1.2945365492706116`, 1, -15.603787542347721`], 
     Hue[1.2945365492706116`, 1, -15.229545125665748`], 
     Hue[1.2945365492706111`, 1, -14.855302708983777`], 
     Hue[1.2945365492706107`, 1, -14.481060292301807`], 
     Hue[1.2945365492706096`, 1, -14.106817875619834`], 
     Hue[1.2945365492706071`, 1, -13.73257545893786], 
     Hue[1.2945365492706014`, 1, -13.358333042255884`], 
     Hue[1.2945365492705891`, 1, -12.984090625573904`], 
     Hue[1.294536549270562, 1, -12.60984820889191], 
     Hue[1.2945365492705025`, 1, -12.235605792209887`], 
     Hue[1.294536549270372, 1, -11.861363375527803`], 
     Hue[1.2945365492700847`, 1, -11.487120958845585`], 
     Hue[1.294536549269453, 1, -11.112878542163072`], 
     Hue[1.2945365492680638`, 1, -10.73863612547991], 
     Hue[1.2945365492650094`, 1, -10.36439370879532], 
     Hue[1.2945365492582939`, 1, -9.990151292107589], 
     Hue[1.2945365492435281`, 1, -9.615908875412952], 
     Hue[1.2945365492110623`, 1, -9.241666458703138], 
     Hue[1.2945365491396792`, 1, -8.867424041959945], 
     Hue[1.2945365489827267`, 1, -8.49318162514336], 
     Hue[1.2945365486376312`, 1, -8.118939208165415], 
     Hue[1.2945365478788604`, 1, -7.7446967908326725`], 
     Hue[1.2945365462105296`, 1, -7.3704543727198315`], 
     Hue[1.2945365425423254`, 1, -6.996211952891772], 
     Hue[1.2945365344769435`, 1, -6.621969529292408], 
     Hue[1.2945365167433662`, 1, -6.24772709740098], 
     Hue[1.2945364777520583`, 1, -5.873484647277577], 
     Hue[1.2945363920207793`, 1, -5.499242157067102], 
     Hue[1.294536203520967, 1, -5.124999578716433], 
     Hue[1.2945357890608002`, 1, -4.7507568065712045`], 
     Hue[1.2945348777736634`, 1, -4.376513608332796], 
     Hue[1.2945328740910536`, 1, -4.002269473271453], 
     Hue[1.2945284684880718`, 1, -3.6280232785844406`], 
     Hue[1.294518781521327, 1, -3.253772556273291], 
     Hue[1.2944974813302954`, 1, -2.8795118834540823`], 
     Hue[1.2944506422592184`, 1, -2.505229353958664], 
     Hue[1.2943476281068267`, 1, -2.1308988729569993`], 
     Hue[1.294120993942523, 1, -1.756463469888337], 
     Hue[1.293622041784753, 1, -1.3817998472814874`], 
     Hue[1.2925218939720897`, 1, -1.006646493126435], 
     Hue[1.2900883905702691`, 1, -0.6304756402137468], 
     Hue[1.284671240189335, 1, -0.2523642520243705], 
     Hue[1.2724852949279613`, 1, 0.1284831332040175], 
     Hue[1.244946546856569, 1, 0.5072423826112329], 
     Hue[1.1874858888739184`, 1, 0.8440993783822599], 
     Hue[1.107050660396696, 1, 1.031220586723249], 
     Hue[1.049590002414044, 1, 1.0686060076341963`], 
     Hue[1.022051254342651, 1, 1.0640891749089525`], 
     Hue[1.009865309081277, 1, 1.0574842063625358`], 
     Hue[1.0044481587003427`, 1, 1.0536152348551309`], 
     Hue[1.002014655298522, 1, 1.0516867986244138`], 
     Hue[1.0009145074858588`, 1, 1.0507758611513323`], 
     Hue[1.000415555328089, 1, 1.0503546552264542`], 
     Hue[1.000188921163785, 1, 1.0501616688397633`], 
     Hue[1.0000859070113934`, 1, 1.0500736045200696`], 
     Hue[1.0000390679403162`, 1, 1.0500334917066223`], 
     Hue[1.0000177677492845`, 1, 1.050015235569385], 
     Hue[1.00000808078254, 1, 1.0500069299402062`], 
     Hue[1.0000036751795582`, 1, 1.0500031519351638`], 
     Hue[1.0000016714969484`, 1, 1.050001433555793], 
     Hue[1.0000007602098113`, 1, 1.0500006519993554`], 
     Hue[1.0000003457496445`, 1, 1.050000296536098], 
     Hue[1.0000001572498325`, 1, 1.0500001348674004`], 
     Hue[1.0000000715185533`, 1, 1.0500000613388962`], 
     Hue[1.0000000325272456`, 1, 1.050000027897464], 
     Hue[1.000000014793668, 1, 1.0500000126880067`], 
     Hue[1.0000000067282864`, 1, 1.050000005770614], 
     Hue[1.000000003060082, 1, 1.0500000026245246`], 
     Hue[1.0000000013917514`, 1, 1.050000001193656], 
     Hue[1.0000000006329803`, 1, 1.0500000005428851`], 
     Hue[1.0000000002878848`, 1, 1.0500000002469088`], 
     Hue[1.0000000001309326`, 1, 1.0500000001122962`], 
     Hue[1.0000000000595493`, 1, 1.0500000000510734`], 
     Hue[1.0000000000270834`, 1, 1.0500000000232286`], 
     Hue[1.0000000000123177`, 1, 1.0500000000105645`], 
     Hue[1.0000000000056022`, 1, 1.0500000000048049`], 
     Hue[1.000000000002548, 1, 1.0500000000021854`], 
     Hue[1.0000000000011589`, 1, 1.050000000000994], 
     Hue[1.0000000000005271`, 1, 1.0500000000004521`], 
     Hue[1.0000000000002398`, 1, 1.0500000000002057`], 
     Hue[1.000000000000109, 1, 1.0500000000000935`], 
     Hue[1.0000000000000495`, 1, 1.0500000000000425`], 
     Hue[1.0000000000000226`, 1, 1.0500000000000194`], 
     Hue[1.0000000000000102`, 1, 1.050000000000009], 
     Hue[1.0000000000000047`, 1, 1.050000000000004], 
     Hue[1.0000000000000022`, 1, 1.050000000000002], 
     Hue[1.0000000000000009`, 1, 1.050000000000001], 
     Hue[1.0000000000000004`, 1, 1.0500000000000005`], 
     Hue[1.0000000000000002`, 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.4199313503855429`, 1, -17.474999625757572`], 
     Hue[1.4199313503855429`, 1, -17.100757209075603`], 
     Hue[1.4199313503855429`, 1, -16.726514792393633`], 
     Hue[1.4199313503855429`, 1, -16.35227237571166], 
     Hue[1.4199313503855429`, 1, -15.97802995902969], 
     Hue[1.4199313503855429`, 1, -15.603787542347721`], 
     Hue[1.4199313503855429`, 1, -15.229545125665748`], 
     Hue[1.4199313503855426`, 1, -14.855302708983777`], 
     Hue[1.4199313503855424`, 1, -14.481060292301803`], 
     Hue[1.4199313503855417`, 1, -14.10681787561983], 
     Hue[1.4199313503855404`, 1, -13.73257545893785], 
     Hue[1.4199313503855377`, 1, -13.358333042255865`], 
     Hue[1.4199313503855315`, 1, -12.984090625573861`], 
     Hue[1.419931350385518, 1, -12.609848208891815`], 
     Hue[1.4199313503854882`, 1, -12.235605792209682`], 
     Hue[1.4199313503854225`, 1, -11.861363375527358`], 
     Hue[1.4199313503852784`, 1, -11.487120958844603`], 
     Hue[1.4199313503849615`, 1, -11.112878542160914`], 
     Hue[1.4199313503842648`, 1, -10.738636125475164`], 
     Hue[1.4199313503827324`, 1, -10.364393708784883`], 
     Hue[1.4199313503793638`, 1, -9.990151292084642], 
     Hue[1.4199313503719566`, 1, -9.6159088753625], 
     Hue[1.4199313503556703`, 1, -9.241666458592205], 
     Hue[1.4199313503198612`, 1, -8.867424041716031], 
     Hue[1.419931350241127, 1, -8.493181624607063], 
     Hue[1.4199313500680115`, 1, -8.118939206986242], 
     Hue[1.4199313496873782`, 1, -7.744696788239994], 
     Hue[1.4199313488504692`, 1, -7.370454367019245], 
     Hue[1.4199313470103345`, 1, -6.996211940357733], 
     Hue[1.4199313429643792`, 1, -6.621969501733467], 
     Hue[1.4199313340684245`, 1, -6.247727036806372], 
     Hue[1.4199313145086385`, 1, -5.873484514046508], 
     Hue[1.419931271501969, 1, -5.499241864128102], 
     Hue[1.4199311769418743`, 1, -5.124998934622491], 
     Hue[1.4199309690292785`, 1, -4.750755390379737], 
     Hue[1.419930511882671, 1, -4.376510494492335], 
     Hue[1.419929506725084, 1, -4.002262626681543], 
     Hue[1.4199272965763508`, 1, -3.6280082242995118`], 
     Hue[1.419922436669357, 1, -3.2537394535881035`], 
     Hue[1.4199117491616746`, 1, -2.8794390879931715`], 
     Hue[1.4198882410720364`, 1, -2.505069240115133], 
     Hue[1.419836508805043, 1, -2.1305465531785472`], 
     Hue[1.4197225486597125`, 1, -1.7556874934734485`], 
     Hue[1.4194709375733239`, 1, -1.380087287583389], 
     Hue[1.418912619667191, 1, -1.0028499830941107`], 
     Hue[1.4176598899145603`, 1, -0.621976731112585], 
     Hue[1.41477822282142, 1, -0.232932712178739], 
     Hue[1.4077604879057495`, 1, 0.17492168347785142`], 
     Hue[1.388175337058644, 1, 0.6277715070201524], 
     Hue[1.3130622543408124`, 1, 1.1711034047581326`], 
     Hue[1.1068690960447358`, 1, 1.3582246130991316`], 
     Hue[1.0317560133269, 1, 1.1891351320431203`], 
     Hue[1.0121708624797938`, 1, 1.110527725182788], 
     Hue[1.005153127564123, 1, 1.0769157462081678`], 
     Hue[1.0022714604709828`, 1, 1.0621141439562927`], 
     Hue[1.0010187307183518`, 1, 1.055483308656738], 
     Hue[1.0004604128122192`, 1, 1.0524884208494314`], 
     Hue[1.0002088017258304`, 1, 1.0511306316413425`], 
     Hue[1.0000948415804998`, 1, 1.0505139886182149`], 
     Hue[1.0000431093135067`, 1, 1.0502337183636006`], 
     Hue[1.0000196012238682`, 1, 1.0501062871675324`], 
     Hue[1.0000089137161858`, 1, 1.0500483382545724`], 
     Hue[1.0000040538091919`, 1, 1.050021984225135], 
     Hue[1.0000018436604587`, 1, 1.050009998525074], 
     Hue[1.0000008385028718`, 1, 1.0500045473962543`], 
     Hue[1.0000003813562641`, 1, 1.050002068190822], 
     Hue[1.0000001734436685`, 1, 1.0500009406300395`], 
     Hue[1.000000078883574, 1, 1.0500004278064003`], 
     Hue[1.0000000358769043`, 1, 1.0500001945699649`], 
     Hue[1.0000000163171183`, 1, 1.050000088492072], 
     Hue[1.0000000074211637`, 1, 1.0500000402469474`], 
     Hue[1.0000000033752083`, 1, 1.0500000183046545`], 
     Hue[1.0000000015350736`, 1, 1.0500000083251129`], 
     Hue[1.0000000006981644`, 1, 1.0500000037863324`], 
     Hue[1.0000000003175311`, 1, 1.0500000017220563`], 
     Hue[1.0000000001444158`, 1, 1.0500000007832058`], 
     Hue[1.0000000000656817`, 1, 1.0500000003562087`], 
     Hue[1.0000000000298725`, 1, 1.050000000162007], 
     Hue[1.0000000000135862`, 1, 1.0500000000736822`], 
     Hue[1.000000000006179, 1, 1.0500000000335112`], 
     Hue[1.0000000000028104`, 1, 1.0500000000152412`], 
     Hue[1.000000000001278, 1, 1.0500000000069318`], 
     Hue[1.0000000000005813`, 1, 1.0500000000031526`], 
     Hue[1.0000000000002645`, 1, 1.050000000001434], 
     Hue[1.0000000000001203`, 1, 1.0500000000006522`], 
     Hue[1.0000000000000546`, 1, 1.0500000000002967`], 
     Hue[1.0000000000000249`, 1, 1.050000000000135], 
     Hue[1.0000000000000113`, 1, 1.0500000000000613`], 
     Hue[1.000000000000005, 1, 1.050000000000028], 
     Hue[1.0000000000000024`, 1, 1.0500000000000127`], 
     Hue[1.000000000000001, 1, 1.0500000000000058`], 
     Hue[1.0000000000000004`, 1, 1.0500000000000027`], 
     Hue[1.0000000000000002`, 1, 1.0500000000000014`], 
     Hue[1., 1, 1.0500000000000005`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.545326151500475, 1, -17.474999625757572`], 
     Hue[0.545326151500475, 1, -17.100757209075603`], 
     Hue[0.545326151500475, 1, -16.726514792393633`], 
     Hue[0.545326151500475, 1, -16.35227237571166], 
     Hue[0.545326151500475, 1, -15.97802995902969], 
     Hue[0.545326151500475, 1, -15.603787542347721`], 
     Hue[0.5453261515004751, 1, -15.229545125665748`], 
     Hue[0.5453261515004753, 1, -14.855302708983777`], 
     Hue[0.5453261515004754, 1, -14.481060292301803`], 
     Hue[0.5453261515004757, 1, -14.106817875619829`], 
     Hue[0.5453261515004764, 1, -13.73257545893785], 
     Hue[0.5453261515004781, 1, -13.358333042255863`], 
     Hue[0.5453261515004817, 1, -12.984090625573856`], 
     Hue[0.5453261515004896, 1, -12.609848208891803`], 
     Hue[0.545326151500507, 1, -12.235605792209654`], 
     Hue[0.5453261515005452, 1, -11.861363375527295`], 
     Hue[0.5453261515006291, 1, -11.487120958844468`], 
     Hue[0.5453261515008139, 1, -11.112878542160614`], 
     Hue[0.54532615150122, 1, -10.738636125474503`], 
     Hue[0.5453261515021128, 1, -10.364393708783428`], 
     Hue[0.5453261515040759, 1, -9.990151292081444], 
     Hue[0.5453261515083925, 1, -9.615908875355467], 
     Hue[0.5453261515178831, 1, -9.241666458576741], 
     Hue[0.5453261515387505, 1, -8.867424041682032], 
     Hue[0.5453261515846323, 1, -8.493181624532308], 
     Hue[0.5453261516855139, 1, -8.118939206821876], 
     Hue[0.545326151907325, 1, -7.744696787878602], 
     Hue[0.5453261523950272, 1, -7.370454366224636], 
     Hue[0.5453261534673512, 1, -6.996211938610604], 
     Hue[0.5453261558251001, 1, -6.621969497892011], 
     Hue[0.5453261610091481, 1, -6.247727028360053], 
     Hue[0.5453261724074607, 1, -5.873484495475345], 
     Hue[0.5453261974692636, 1, -5.499241823295132], 
     Hue[0.5453262525734329, 1, -5.1249988448417145`], 
     Hue[0.5453263737329423, 1, -4.750755192975298], 
     Hue[0.5453266401318999, 1, -4.376510060449021], 
     Hue[0.54532722588132, 1, -4.002261672315635], 
     Hue[0.5453285138364541, 1, -3.628006125798014], 
     Hue[0.5453313459491995, 1, -3.253734839018742], 
     Hue[0.5453375742041311, 1, -2.879428939218572], 
     Hue[0.5453512742957775, 1, -2.505046913177135], 
     Hue[0.5453814254054958, 1, -2.1304974015853926`], 
     Hue[0.5454478568094788, 1, -1.7555791280487647`], 
     Hue[0.5455945886389382, 1, -1.379847589220056], 
     Hue[0.5459204740009482, 1, -1.0023159329918843`], 
     Hue[0.5466531715497, 1, -0.620767538418586], 
     Hue[0.5483467539510587, 1, -0.2300933446636746], 
     Hue[0.5525232837168935, 1, 0.18218078415507388`], 
     Hue[0.5646672085926397, 1, 0.650733044454167], 
     Hue[0.6237727870199326, 1, 1.2976008959287548`], 
     Hue[0.9215533644805372, 1, 1.4847221042697631`], 
     Hue[0.9806589429078346, 1, 1.212096669477136], 
     Hue[0.9928028677835813, 1, 1.1177868258600105`], 
     Hue[0.9969793975494162, 1, 1.0797551137232326`], 
     Hue[0.9986729799507751, 1, 1.0633233366502919`], 
     Hue[0.9994056774995268, 1, 1.056017358758965], 
     Hue[0.9997315628615367, 1, 1.052728119212764], 
     Hue[0.9998782946909962, 1, 1.0512389970660267`], 
     Hue[0.9999447260949793, 1, 1.0505631402113695`], 
     Hue[0.9999748772046976, 1, 1.0502560453015988`], 
     Hue[0.9999885772963439, 1, 1.050116435942132], 
     Hue[0.9999948055512755, 1, 1.050052952823934], 
     Hue[0.9999976376640209, 1, 1.050024082726633], 
     Hue[0.9999989256191552, 1, 1.0500109528909825`], 
     Hue[0.9999995113685751, 1, 1.0500049814395678`], 
     Hue[0.9999997777675328, 1, 1.0500022655952623`], 
     Hue[0.9999998989270421, 1, 1.0500010304108154`], 
     Hue[0.9999999540312114, 1, 1.0500004686393702`], 
     Hue[0.9999999790930143, 1, 1.0500002131411286`], 
     Hue[0.999999990491327, 1, 1.0500000969383916`], 
     Hue[0.9999999956753749, 1, 1.0500000440884047`], 
     Hue[0.9999999980331238, 1, 1.0500000200517818`], 
     Hue[0.9999999991054479, 1, 1.0500000091197212`], 
     Hue[0.9999999995931501, 1, 1.050000004147727], 
     Hue[0.9999999998149612, 1, 1.0500000018864217`], 
     Hue[0.9999999999158428, 1, 1.0500000008579606`], 
     Hue[0.9999999999617246, 1, 1.050000000390208], 
     Hue[0.999999999982592, 1, 1.0500000001774699`], 
     Hue[0.9999999999920827, 1, 1.0500000000807148`], 
     Hue[0.9999999999963991, 1, 1.0500000000367098`], 
     Hue[0.9999999999983623, 1, 1.050000000016696], 
     Hue[0.9999999999992552, 1, 1.0500000000075935`], 
     Hue[0.9999999999996613, 1, 1.0500000000034535`], 
     Hue[0.9999999999998459, 1, 1.0500000000015708`], 
     Hue[0.99999999999993, 1, 1.0500000000007144`], 
     Hue[0.9999999999999681, 1, 1.050000000000325], 
     Hue[0.9999999999999855, 1, 1.0500000000001477`], 
     Hue[0.9999999999999934, 1, 1.0500000000000673`], 
     Hue[0.999999999999997, 1, 1.0500000000000307`], 
     Hue[0.9999999999999987, 1, 1.050000000000014], 
     Hue[0.9999999999999993, 1, 1.0500000000000063`], 
     Hue[0.9999999999999997, 1, 1.050000000000003], 
     Hue[0.9999999999999999, 1, 1.0500000000000014`], 
     Hue[0.9999999999999999, 1, 1.0500000000000007`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.6707209526154063, 1, -17.474999625757572`], 
     Hue[0.6707209526154063, 1, -17.100757209075603`], 
     Hue[0.6707209526154063, 1, -16.726514792393633`], 
     Hue[0.6707209526154063, 1, -16.35227237571166], 
     Hue[0.6707209526154063, 1, -15.97802995902969], 
     Hue[0.6707209526154063, 1, -15.603787542347721`], 
     Hue[0.6707209526154064, 1, -15.229545125665748`], 
     Hue[0.6707209526154065, 1, -14.855302708983777`], 
     Hue[0.6707209526154071, 1, -14.481060292301807`], 
     Hue[0.6707209526154081, 1, -14.106817875619832`], 
     Hue[0.6707209526154105, 1, -13.732575458937857`], 
     Hue[0.6707209526154156, 1, -13.358333042255877`], 
     Hue[0.6707209526154269, 1, -12.98409062557389], 
     Hue[0.6707209526154516, 1, -12.609848208891878`], 
     Hue[0.6707209526155059, 1, -12.235605792209817`], 
     Hue[0.6707209526156254, 1, -11.861363375527654`], 
     Hue[0.6707209526158879, 1, -11.487120958845257`], 
     Hue[0.6707209526164655, 1, -11.112878542162347`], 
     Hue[0.6707209526177351, 1, -10.738636125478317`], 
     Hue[0.6707209526205269, 1, -10.364393708791814`], 
     Hue[0.6707209526266651, 1, -9.990151292099878], 
     Hue[0.6707209526401615, 1, -9.615908875396], 
     Hue[0.6707209526698362, 1, -9.241666458665863], 
     Hue[0.670720952735083, 1, -8.867424041877983], 
     Hue[0.6707209528785428, 1, -8.49318162496315], 
     Hue[0.6707209531939718, 1, -8.118939207769179], 
     Hue[0.6707209538875143, 1, -7.7446967899614565`], 
     Hue[0.6707209554124254, 1, -7.370454370804269], 
     Hue[0.6707209587652889, 1, -6.996211948679972], 
     Hue[0.6707209661373228, 1, -6.621969520031803], 
     Hue[0.6707209823464173, 1, -6.247727077039434], 
     Hue[0.670721017985805, 1, -5.873484602508074], 
     Hue[0.6707210963471364, 1, -5.4992420586311255`], 
     Hue[0.6707212686424964, 1, -5.124999362282346], 
     Hue[0.6707216474737514, 1, -4.750756330690661], 
     Hue[0.6707224804238889, 1, -4.37651256199647], 
     Hue[0.670724311870915, 1, -4.002267172640306], 
     Hue[0.6707283388044187, 1, -3.6280182200136917`], 
     Hue[0.6707371933234532, 1, -3.253761433323832], 
     Hue[0.6707566638816842, 1, -2.8794874245528534`], 
     Hue[0.6707994834405492, 1, -2.5051755630953485`], 
     Hue[0.6708936760075777, 1, -2.130780541568959], 
     Hue[0.6711009926014389, 1, -1.7562030019951764`], 
     Hue[0.6715578537268272, 1, -1.3812257539715025`], 
     Hue[0.6725673343668097, 1, -1.0053775137519827`], 
     Hue[0.6748108663724048, 1, -0.6276535538858339], 
     Hue[0.6798587786027495, 1, -0.24601042747901025`], 
     Hue[0.6914988534271529, 1, 0.14309755560330628`], 
     Hue[0.7193921784885129, 1, 0.5413398060952024], 
     Hue[0.7850435166685128, 1, 0.9128122341903214], 
     Hue[0.8856774359468902, 1, 1.0999334425313116`], 
     Hue[0.9513287741268918, 1, 1.1027034311181667`], 
     Hue[0.9792220991882528, 1, 1.078703597308242], 
     Hue[0.9908621740126565, 1, 1.0638380309078963`], 
     Hue[0.9959100862430013, 1, 1.0564373211830438`], 
     Hue[0.9981536182485965, 1, 1.052955777998866], 
     Hue[0.999163098888579, 1, 1.0513499544613176`], 
     Hue[0.9996199600139675, 1, 1.0506151231196146`], 
     Hue[0.9998272766078286, 1, 1.0502800002278037`], 
     Hue[0.999921469174857, 1, 1.050127395383385], 
     Hue[0.999964288733722, 1, 1.0500579506078505`], 
     Hue[0.999983759291953, 1, 1.0500263585188447`], 
     Hue[0.9999926138109875, 1, 1.0500119885109553`], 
     Hue[0.9999966407444913, 1, 1.0500054525663114`], 
     Hue[0.9999984721915173, 1, 1.050002479892119], 
     Hue[0.9999993051416548, 1, 1.0500011278798993`], 
     Hue[0.9999996839729097, 1, 1.0500005129701842`], 
     Hue[0.9999998562682697, 1, 1.0500002333033764`], 
     Hue[0.9999999346296012, 1, 1.0500001061083986`], 
     Hue[0.9999999702689889, 1, 1.0500000482590113`], 
     Hue[0.9999999864780834, 1, 1.0500000219486112`], 
     Hue[0.9999999938501173, 1, 1.0500000099824158`], 
     Hue[0.9999999972029809, 1, 1.050000004540088], 
     Hue[0.9999999987278919, 1, 1.0500000020648708`], 
     Hue[0.9999999994214344, 1, 1.0500000009391208`], 
     Hue[0.9999999997368634, 1, 1.0500000004271202`], 
     Hue[0.9999999998803233, 1, 1.050000000194258], 
     Hue[0.99999999994557, 1, 1.0500000000883503`], 
     Hue[0.9999999999752448, 1, 1.0500000000401823`], 
     Hue[0.9999999999887411, 1, 1.0500000000182754`], 
     Hue[0.9999999999948793, 1, 1.0500000000083118`], 
     Hue[0.9999999999976711, 1, 1.0500000000037804`], 
     Hue[0.9999999999989407, 1, 1.0500000000017193`], 
     Hue[0.9999999999995183, 1, 1.050000000000782], 
     Hue[0.999999999999781, 1, 1.0500000000003558`], 
     Hue[0.9999999999999003, 1, 1.050000000000162], 
     Hue[0.9999999999999547, 1, 1.0500000000000738`], 
     Hue[0.9999999999999793, 1, 1.0500000000000336`], 
     Hue[0.9999999999999907, 1, 1.0500000000000154`], 
     Hue[0.9999999999999958, 1, 1.050000000000007], 
     Hue[0.9999999999999981, 1, 1.0500000000000032`], 
     Hue[0.9999999999999991, 1, 1.0500000000000016`], 
     Hue[0.9999999999999996, 1, 1.0500000000000007`], 
     Hue[0.9999999999999998, 1, 1.0500000000000003`], 
     Hue[0.9999999999999999, 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.7961157537303374, 1, -17.474999625757572`], 
     Hue[0.7961157537303374, 1, -17.100757209075603`], 
     Hue[0.7961157537303374, 1, -16.726514792393633`], 
     Hue[0.7961157537303374, 1, -16.35227237571166], 
     Hue[0.7961157537303374, 1, -15.97802995902969], 
     Hue[0.7961157537303375, 1, -15.603787542347721`], 
     Hue[0.7961157537303376, 1, -15.229545125665748`], 
     Hue[0.7961157537303378, 1, -14.855302708983777`], 
     Hue[0.7961157537303384, 1, -14.481060292301807`], 
     Hue[0.7961157537303395, 1, -14.106817875619837`], 
     Hue[0.796115753730342, 1, -13.732575458937868`], 
     Hue[0.7961157537303476, 1, -13.358333042255902`], 
     Hue[0.7961157537303599, 1, -12.984090625573943`], 
     Hue[0.7961157537303869, 1, -12.609848208891995`], 
     Hue[0.7961157537304461, 1, -12.235605792210075`], 
     Hue[0.7961157537305764, 1, -11.861363375528223`], 
     Hue[0.796115753730863, 1, -11.487120958846505`], 
     Hue[0.7961157537314929, 1, -11.112878542165094`], 
     Hue[0.796115753732878, 1, -10.738636125484359`], 
     Hue[0.7961157537359234, 1, -10.364393708805094`], 
     Hue[0.7961157537426196, 1, -9.990151292129083], 
     Hue[0.7961157537573423, 1, -9.61590887546021], 
     Hue[0.7961157537897139, 1, -9.241666458807046], 
     Hue[0.7961157538608901, 1, -8.867424042188409], 
     Hue[0.7961157540173872, 1, -8.493181625645692], 
     Hue[0.7961157543614817, 1, -8.118939209269902], 
     Hue[0.7961157551180518, 1, -7.744696793261139], 
     Hue[0.7961157567815432, 1, -7.37045437805937], 
     Hue[0.7961157604391074, 1, -6.996211964631963], 
     Hue[0.7961157684810941, 1, -6.6219695551058875`], 
     Hue[0.7961157861632302, 1, -6.247727154157787], 
     Hue[0.7961158250414248, 1, -5.873484772070326], 
     Hue[0.7961159105239592, 1, -5.499242431452347], 
     Hue[0.79611609847666, 1, -5.125000182014804], 
     Hue[0.7961165117329615, 1, -4.750758133059874], 
     Hue[0.7961174203686952, 1, -4.37651652491971], 
     Hue[0.7961194182001683, 1, -4.002275886050429], 
     Hue[0.796123810834525, 1, -3.628037378533861], 
     Hue[0.7961334687860996, 1, -3.2538035582004667`], 
     Hue[0.7961547027601119, 1, -2.879580048149567], 
     Hue[0.7962013845360997, 1, -2.5053792290768966`], 
     Hue[0.7963039962687071, 1, -2.13122840502833], 
     Hue[0.7965294721478333, 1, -1.7571880071066033`], 
     Hue[0.7970245556322966, 1, -1.3833928175330283`], 
     Hue[0.7981098091221105, 1, -1.01014833400471], 
     Hue[0.8004797266211509, 1, -0.6381695359401793], 
     Hue[0.8056089087421342, 1, -0.2692273311633684], 
     Hue[0.8164650882752928, 1, 0.0919361202529938], 
     Hue[0.8381240568698474, 1, 0.4319918873655544], 
     Hue[0.8751490824819003, 1, 0.7180362610230402], 
     Hue[0.9209666712484356, 1, 0.9051574693640279], 
     Hue[0.9579916968604889, 1, 0.993355512388516], 
     Hue[0.979650665455044, 1, 1.0275421619579281`], 
     Hue[0.990506844988203, 1, 1.0406211272235375`], 
     Hue[0.9956360271091865, 1, 1.045921339128698], 
     Hue[0.9980059446082269, 1, 1.0481849577461388`], 
     Hue[0.9990911980980408, 1, 1.0491828908997916`], 
     Hue[0.9995862815825041, 1, 1.049630118008188], 
     Hue[0.9998117574616303, 1, 1.0498321367684322`], 
     Hue[0.9999143691942377, 1, 1.0499237294018369`], 
     Hue[0.9999610509702255, 1, 1.049965327011137], 
     Hue[0.9999822849442378, 1, 1.0499842336422087`], 
     Hue[0.9999919428958124, 1, 1.049992829990786], 
     Hue[0.9999963355301691, 1, 1.0499967391561886`], 
     Hue[0.9999983333616422, 1, 1.0499985169688788`], 
     Hue[0.9999992419973759, 1, 1.0499993255106865`], 
     Hue[0.9999996552536774, 1, 1.049999693237727], 
     Hue[0.9999998432063782, 1, 1.0499998604821548`], 
     Hue[0.9999999286889126, 1, 1.0499999365461465`], 
     Hue[0.9999999675671072, 1, 1.0499999711406574`], 
     Hue[0.9999999852492434, 1, 1.0499999868745271`], 
     Hue[0.99999999329123, 1, 1.0499999940304237`], 
     Hue[0.9999999969487942, 1, 1.0499999972849858`], 
     Hue[0.9999999986122856, 1, 1.0499999987651885`], 
     Hue[0.9999999993688556, 1, 1.0499999994383973`], 
     Hue[0.9999999997129502, 1, 1.0499999997445784`], 
     Hue[0.9999999998694473, 1, 1.049999999883832], 
     Hue[0.9999999999406235, 1, 1.0499999999471659`], 
     Hue[0.999999999972995, 1, 1.0499999999759706`], 
     Hue[0.9999999999877179, 1, 1.0499999999890712`], 
     Hue[0.999999999994414, 1, 1.0499999999950296`], 
     Hue[0.9999999999974595, 1, 1.0499999999977394`], 
     Hue[0.9999999999988445, 1, 1.049999999998972], 
     Hue[0.9999999999994745, 1, 1.0499999999995324`], 
     Hue[0.999999999999761, 1, 1.0499999999997873`], 
     Hue[0.9999999999998913, 1, 1.0499999999999032`], 
     Hue[0.9999999999999506, 1, 1.049999999999956], 
     Hue[0.9999999999999775, 1, 1.04999999999998], 
     Hue[0.9999999999999898, 1, 1.049999999999991], 
     Hue[0.9999999999999953, 1, 1.0499999999999958`], 
     Hue[0.9999999999999979, 1, 1.049999999999998], 
     Hue[0.999999999999999, 1, 1.0499999999999992`], 
     Hue[0.9999999999999996, 1, 1.0499999999999996`], 
     Hue[0.9999999999999998, 1, 1.0499999999999998`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.9215105548452691, 1, -17.474999625757572`], 
     Hue[0.9215105548452691, 1, -17.100757209075603`], 
     Hue[0.9215105548452691, 1, -16.726514792393633`], 
     Hue[0.9215105548452691, 1, -16.35227237571166], 
     Hue[0.9215105548452692, 1, -15.97802995902969], 
     Hue[0.9215105548452692, 1, -15.603787542347721`], 
     Hue[0.9215105548452692, 1, -15.229545125665748`], 
     Hue[0.9215105548452693, 1, -14.855302708983777`], 
     Hue[0.9215105548452697, 1, -14.48106029230181], 
     Hue[0.9215105548452702, 1, -14.106817875619841`], 
     Hue[0.9215105548452714, 1, -13.732575458937879`], 
     Hue[0.9215105548452742, 1, -13.358333042255921`], 
     Hue[0.9215105548452802, 1, -12.984090625573986`], 
     Hue[0.9215105548452935, 1, -12.609848208892085`], 
     Hue[0.9215105548453228, 1, -12.235605792210277`], 
     Hue[0.9215105548453872, 1, -11.861363375528667`], 
     Hue[0.9215105548455288, 1, -11.487120958847479`], 
     Hue[0.92151055484584, 1, -11.112878542167236`], 
     Hue[0.9215105548465242, 1, -10.738636125489066`], 
     Hue[0.9215105548480287, 1, -10.364393708815447`], 
     Hue[0.9215105548513366, 1, -9.990151292151847], 
     Hue[0.9215105548586098, 1, -9.615908875510263], 
     Hue[0.9215105548746017, 1, -9.241666458917095], 
     Hue[0.9215105549097633, 1, -8.867424042430377], 
     Hue[0.9215105549870741, 1, -8.493181626177714], 
     Hue[0.9215105551570596, 1, -8.118939210439674], 
     Hue[0.9215105555308113, 1, -7.744696795833149], 
     Hue[0.9215105563525895, 1, -7.3704543837145176`], 
     Hue[0.9215105581594557, 1, -6.99621197706609], 
     Hue[0.9215105621322619, 1, -6.621969582445143], 
     Hue[0.9215105708673786, 1, -6.247727214269349], 
     Hue[0.9215105900735135, 1, -5.8734849042392305`], 
     Hue[0.9215106323025398, 1, -5.499242722055559], 
     Hue[0.9215107251525133, 1, -5.12500082097115], 
     Hue[0.921510929303592, 1, -4.750759537946306], 
     Hue[0.921511378172751, 1, -4.37651961386064], 
     Hue[0.9215123650971366, 1, -4.002282677685932], 
     Hue[0.9215145349948136, 1, -3.6280523109877203`], 
     Hue[0.9215193056213236, 1, -3.25383638817162], 
     Hue[0.9215297930577128, 1, -2.8796522205847364`], 
     Hue[0.9215528430298311, 1, -2.505537859923016], 
     Hue[0.9216034799610897, 1, -2.13157691717295], 
     Hue[0.9217146060397483, 1, -1.7579529675837635`], 
     Hue[0.921957927601461, 1, -1.3850683749769745`], 
     Hue[0.9224880674225955, 1, -1.0138017084630218`], 
     Hue[0.9236306950900411, 1, -0.6460552496619647], 
     Hue[0.9260366993821167, 1, -0.28587081428578376`], 
     Hue[0.9308603412497634, 1, 0.058524399920408254`], 
     Hue[0.9396265135849946, 1, 0.3719553742676991], 
     Hue[0.9529713785418098, 1, 0.632060214580555], 
     Hue[0.9685391763034588, 1, 0.819181422921542], 
     Hue[0.9818840412602742, 1, 0.9333189992906596], 
     Hue[0.9906502135955055, 1, 0.9941304416253416], 
     Hue[0.9954738554631524, 1, 1.023977644101122], 
     Hue[0.997879859755228, 1, 1.0380356254069123`], 
     Hue[0.9990224874226736, 1, 1.0445315832878268`], 
     Hue[0.9995526272438082, 1, 1.0475073334558453`], 
     Hue[0.9997959488055208, 1, 1.0488651575310273`], 
     Hue[0.9999070748841795, 1, 1.0494836246238117`], 
     Hue[0.9999577118154381, 1, 1.0497650985557174`], 
     Hue[0.9999807617875563, 1, 1.049893154575968], 
     Hue[0.9999912492239457, 1, 1.0499514036710558`], 
     Hue[0.9999960198504556, 1, 1.049977897536927], 
     Hue[0.9999981897481325, 1, 1.049989947520685], 
     Hue[0.9999991766725181, 1, 1.0499954280279495`], 
     Hue[0.9999996255416771, 1, 1.0499979206242538`], 
     Hue[0.9999998296927559, 1, 1.0499990542813806`], 
     Hue[0.9999999225427294, 1, 1.0499995698789433`], 
     Hue[0.9999999647717556, 1, 1.0499998043772423`], 
     Hue[0.9999999839778905, 1, 1.049999911029095], 
     Hue[0.9999999927130072, 1, 1.0499999595352725`], 
     Hue[0.9999999966858134, 1, 1.0499999815962966`], 
     Hue[0.9999999984926796, 1, 1.0499999916298388`], 
     Hue[0.9999999993144578, 1, 1.0499999961931794`], 
     Hue[0.9999999996882096, 1, 1.0499999982686254`], 
     Hue[0.9999999998581951, 1, 1.0499999992125562`], 
     Hue[0.9999999999355059, 1, 1.0499999996418639`], 
     Hue[0.9999999999706676, 1, 1.0499999998371166`], 
     Hue[0.9999999999866593, 1, 1.0499999999259193`], 
     Hue[0.9999999999939325, 1, 1.0499999999663074`], 
     Hue[0.9999999999972404, 1, 1.0499999999846763`], 
     Hue[0.9999999999987449, 1, 1.0499999999930307`], 
     Hue[0.9999999999994292, 1, 1.0499999999968304`], 
     Hue[0.9999999999997404, 1, 1.0499999999985585`], 
     Hue[0.9999999999998819, 1, 1.0499999999993443`], 
     Hue[0.9999999999999463, 1, 1.0499999999997018`], 
     Hue[0.9999999999999756, 1, 1.0499999999998644`], 
     Hue[0.9999999999999889, 1, 1.0499999999999383`], 
     Hue[0.9999999999999949, 1, 1.049999999999972], 
     Hue[0.9999999999999977, 1, 1.0499999999999874`], 
     Hue[0.999999999999999, 1, 1.0499999999999943`], 
     Hue[0.9999999999999996, 1, 1.0499999999999974`], 
     Hue[0.9999999999999998, 1, 1.049999999999999], 
     Hue[0.9999999999999999, 1, 1.0499999999999996`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.0469053559602008`, 1, -17.474999625757572`], 
     Hue[1.0469053559602008`, 1, -17.100757209075603`], 
     Hue[1.0469053559602008`, 1, -16.726514792393633`], 
     Hue[1.0469053559602008`, 1, -16.35227237571166], 
     Hue[1.0469053559602008`, 1, -15.97802995902969], 
     Hue[1.0469053559602008`, 1, -15.603787542347721`], 
     Hue[1.0469053559602008`, 1, -15.229545125665748`], 
     Hue[1.0469053559602008`, 1, -14.855302708983777`], 
     Hue[1.0469053559602006`, 1, -14.48106029230181], 
     Hue[1.0469053559602002`, 1, -14.106817875619843`], 
     Hue[1.0469053559601995`, 1, -13.732575458937879`], 
     Hue[1.0469053559601977`, 1, -13.358333042255923`], 
     Hue[1.0469053559601942`, 1, -12.984090625573991`], 
     Hue[1.046905355960186, 1, -12.609848208892098`], 
     Hue[1.046905355960168, 1, -12.235605792210304`], 
     Hue[1.0469053559601285`, 1, -11.861363375528722`], 
     Hue[1.0469053559600416`, 1, -11.487120958847605`], 
     Hue[1.0469053559598507`, 1, -11.112878542167511`], 
     Hue[1.0469053559594308`, 1, -10.738636125489666`], 
     Hue[1.0469053559585078`, 1, -10.36439370881677], 
     Hue[1.0469053559564783`, 1, -9.990151292154755], 
     Hue[1.0469053559520156`, 1, -9.61590887551666], 
     Hue[1.0469053559422037`, 1, -9.241666458931157], 
     Hue[1.04690535592063, 1, -8.867424042461296], 
     Hue[1.0469053558731956`, 1, -8.493181626245695], 
     Hue[1.0469053557688996`, 1, -8.118939210589149], 
     Hue[1.0469053555395815`, 1, -7.744696796161803], 
     Hue[1.0469053550353735`, 1, -7.3704543844371395`], 
     Hue[1.0469053539267579`, 1, -6.996211978654935], 
     Hue[1.046905351489214, 1, -6.62196958593858], 
     Hue[1.04690534612972, 1, -6.2477272219504645`], 
     Hue[1.0469053343456576`, 1, -5.8734849211279005`], 
     Hue[1.046905308435736, 1, -5.499242759189103], 
     Hue[1.0469052514669774`, 1, -5.12500090261751], 
     Hue[1.0469051262086753`, 1, -4.750759717463506], 
     Hue[1.046904850802089, 1, -4.376520008565718], 
     Hue[1.0469042452691033`, 1, -4.002283545513943], 
     Hue[1.0469029139204693`, 1, -3.628054219004021], 
     Hue[1.0468999869056748`, 1, -3.253840582891325], 
     Hue[1.0468935524449567`, 1, -2.87966144127087], 
     Hue[1.046879410845666, 1, -2.505558122299587], 
     Hue[1.046848346425999, 1, -2.131621413577709], 
     Hue[1.0467801846095164`, 1, -1.7580505377091538`], 
     Hue[1.046630990601576, 1, -1.3852816301402082`], 
     Hue[1.046306182481423, 1, -1.0142645168863063`], 
     Hue[1.0456072583227147`, 1, -0.6470442870663984], 
     Hue[1.0441404715848501`, 1, -0.2879158975869025], 
     Hue[1.0412182910848433`, 1, 0.05457475051641736], 
     Hue[1.035960512372124, 1, 0.36527161948217035`], 
     Hue[1.0280453412869959`, 1, 0.6230172659616214], 
     Hue[1.0188600146732052`, 1, 0.8101384743026084], 
     Hue[1.010944843588077, 1, 0.9266352445051308], 
     Hue[1.0056870648753578`, 1, 0.9901807922213508], 
     Hue[1.002764884375351, 1, 1.0219325608000032`], 
     Hue[1.0012980976374861`, 1, 1.0370465880024786`], 
     Hue[1.0005991734787778`, 1, 1.0440687748645423`], 
     Hue[1.0002743653586248`, 1, 1.0472940782926112`], 
     Hue[1.0001251713506845`, 1, 1.0487675874056375`], 
     Hue[1.0000570095342018`, 1, 1.049439128219053], 
     Hue[1.0000259451145348`, 1, 1.0497448361791457`], 
     Hue[1.000011803515244, 1, 1.0498839338898345`], 
     Hue[1.000005369054526, 1, 1.049947208951351], 
     Hue[1.0000024420397315`, 1, 1.049975989520626], 
     Hue[1.0000011106910975`, 1, 1.049989079692675], 
     Hue[1.0000005051581118`, 1, 1.049995033322871], 
     Hue[1.0000002297515256`, 1, 1.0499977411070536`], 
     Hue[1.0000001044932234`, 1, 1.0499989726350212`], 
     Hue[1.000000047524465, 1, 1.0499995327453988`], 
     Hue[1.0000000216145435`, 1, 1.0499997874885723`], 
     Hue[1.000000009830481, 1, 1.04999990334798], 
     Hue[1.0000000044709871`, 1, 1.0499999560418352`], 
     Hue[1.0000000020334432`, 1, 1.0499999800074515`], 
     Hue[1.0000000009248273`, 1, 1.0499999909072184`], 
     Hue[1.0000000004206193`, 1, 1.0499999958645254`], 
     Hue[1.0000000001913012`, 1, 1.049999998119151], 
     Hue[1.0000000000870055`, 1, 1.0499999991445739`], 
     Hue[1.0000000000395708`, 1, 1.0499999996109448`], 
     Hue[1.0000000000179972`, 1, 1.0499999998230545`], 
     Hue[1.0000000000081852`, 1, 1.0499999999195235`], 
     Hue[1.0000000000037228`, 1, 1.0499999999633987`], 
     Hue[1.000000000001693, 1, 1.0499999999833534`], 
     Hue[1.00000000000077, 1, 1.049999999992429], 
     Hue[1.0000000000003502`, 1, 1.0499999999965568`], 
     Hue[1.0000000000001592`, 1, 1.049999999998434], 
     Hue[1.0000000000000724`, 1, 1.0499999999992877`], 
     Hue[1.0000000000000329`, 1, 1.049999999999676], 
     Hue[1.0000000000000149`, 1, 1.0499999999998526`], 
     Hue[1.0000000000000069`, 1, 1.049999999999933], 
     Hue[1.000000000000003, 1, 1.0499999999999696`], 
     Hue[1.0000000000000013`, 1, 1.0499999999999863`], 
     Hue[1.0000000000000007`, 1, 1.0499999999999936`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999972`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999987`], 
     Hue[1., 1, 1.0499999999999994`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.1723001570751326`, 1, -17.474999625757572`], 
     Hue[1.1723001570751326`, 1, -17.100757209075603`], 
     Hue[1.1723001570751326`, 1, -16.726514792393633`], 
     Hue[1.1723001570751326`, 1, -16.35227237571166], 
     Hue[1.1723001570751326`, 1, -15.97802995902969], 
     Hue[1.1723001570751326`, 1, -15.603787542347721`], 
     Hue[1.1723001570751324`, 1, -15.229545125665748`], 
     Hue[1.1723001570751321`, 1, -14.855302708983777`], 
     Hue[1.1723001570751317`, 1, -14.481060292301807`], 
     Hue[1.1723001570751306`, 1, -14.10681787561984], 
     Hue[1.1723001570751284`, 1, -13.732575458937871`], 
     Hue[1.1723001570751233`, 1, -13.358333042255907`], 
     Hue[1.172300157075112, 1, -12.984090625573955`], 
     Hue[1.172300157075087, 1, -12.609848208892023`], 
     Hue[1.1723001570750324`, 1, -12.235605792210139`], 
     Hue[1.1723001570749123`, 1, -11.86136337552836], 
     Hue[1.1723001570746483`, 1, -11.487120958846806`], 
     Hue[1.1723001570740679`, 1, -11.112878542165754`], 
     Hue[1.1723001570727913`, 1, -10.738636125485808`], 
     Hue[1.1723001570699847`, 1, -10.364393708808285`], 
     Hue[1.1723001570638136`, 1, -9.990151292136094], 
     Hue[1.172300157050245, 1, -9.615908875475629], 
     Hue[1.1723001570204117`, 1, -9.241666458840946], 
     Hue[1.172300156954816, 1, -8.867424042262945], 
     Hue[1.172300156810589, 1, -8.493181625809575], 
     Hue[1.1723001564934732`, 1, -8.11893920963024], 
     Hue[1.1723001557962223`, 1, -7.744696794053426], 
     Hue[1.1723001542631575`, 1, -7.370454379801392], 
     Hue[1.1723001508923654`, 1, -6.996211968462194], 
     Hue[1.1723001434809128`, 1, -6.621969563527522], 
     Hue[1.1723001271851499`, 1, -6.247727172674663], 
     Hue[1.1723000913552142`, 1, -5.873484812783882], 
     Hue[1.1723000125749805`, 1, -5.4992425209703235`], 
     Hue[1.1722998393588617`, 1, -5.125000378840255], 
     Hue[1.1722994585045265`, 1, -4.750758565824515], 
     Hue[1.1722986211130408`, 1, -4.3765174764469394`], 
     Hue[1.172296779933832, 1, -4.002277978178806], 
     Hue[1.1722927317620824`, 1, -3.628041978454002], 
     Hue[1.1722838313202706`, 1, -3.2538136716877943`], 
     Hue[1.172264263533836, 1, -2.8796022826144876`], 
     Hue[1.172221248294186, 1, -2.5054281053024736`], 
     Hue[1.1721267129702615`, 1, -2.1313358158540368`], 
     Hue[1.17191906572767, 1, -1.7574239096104287`], 
     Hue[1.1714635225197936`, 1, -1.3839102202505826`], 
     Hue[1.1704668255049822`, 1, -1.0112797272478657`], 
     Hue[1.1682991734220334`, 1, -0.6406266880304015], 
     Hue[1.1636483916018998`, 1, -0.274479623718769], 
     Hue[1.1539774440814157`, 1, 0.08113419002329658], 
     Hue[1.1352910592428151`, 1, 0.41183103361436335`], 
     Hue[1.1046726368742554`, 1, 0.6880929842970991], 
     Hue[1.0676275202008785`, 1, 0.8752141926380863], 
     Hue[1.0370090978323183`, 1, 0.9731946586373246], 
     Hue[1.0183227129937173`, 1, 1.0167402317282304`], 
     Hue[1.008651765473233, 1, 1.035368834668137], 
     Hue[1.0040009836530992`, 1, 1.043464187038476], 
     Hue[1.0018333315701504`, 1, 1.0470535645029828`], 
     Hue[1.000836634555339, 1, 1.0486654881822373`], 
     Hue[1.000381091347463, 1, 1.0493942155043625`], 
     Hue[1.000173444104871, 1, 1.0497247259427251`], 
     Hue[1.0000789087809467`, 1, 1.0498748531762598`], 
     Hue[1.0000358935412965`, 1, 1.049943092546217], 
     Hue[1.000016325754862, 1, 1.0499741201548816`], 
     Hue[1.0000074253130504`, 1, 1.0499882300706447`], 
     Hue[1.0000033771413006`, 1, 1.0499946470278119`], 
     Hue[1.0000015359620917`, 1, 1.0499975654416493`], 
     Hue[1.000000698570606, 1, 1.0499988927460444`], 
     Hue[1.000000317716271, 1, 1.0499994964122759`], 
     Hue[1.0000001445001523`, 1, 1.0499997709641784`], 
     Hue[1.0000000657199184`, 1, 1.0499998958325905`], 
     Hue[1.0000000298899827`, 1, 1.0499999526237813`], 
     Hue[1.0000000135942197`, 1, 1.0499999784528933`], 
     Hue[1.0000000061827672`, 1, 1.0499999902001924`], 
     Hue[1.0000000028119753`, 1, 1.0499999955429642`], 
     Hue[1.0000000012789103`, 1, 1.0499999979729022`], 
     Hue[1.0000000005816594`, 1, 1.0499999990780586`], 
     Hue[1.0000000002645437`, 1, 1.0499999995806932`], 
     Hue[1.0000000001203166`, 1, 1.0499999998092957`], 
     Hue[1.0000000000547211`, 1, 1.049999999913266], 
     Hue[1.0000000000248876`, 1, 1.0499999999605527`], 
     Hue[1.0000000000113192`, 1, 1.049999999982059], 
     Hue[1.000000000005148, 1, 1.0499999999918403`], 
     Hue[1.0000000000023415`, 1, 1.049999999996289], 
     Hue[1.000000000001065, 1, 1.0499999999983123`], 
     Hue[1.0000000000004843`, 1, 1.0499999999992324`], 
     Hue[1.0000000000002203`, 1, 1.049999999999651], 
     Hue[1.0000000000001001`, 1, 1.0499999999998413`], 
     Hue[1.0000000000000455`, 1, 1.0499999999999279`], 
     Hue[1.0000000000000207`, 1, 1.0499999999999672`], 
     Hue[1.0000000000000093`, 1, 1.0499999999999852`], 
     Hue[1.0000000000000042`, 1, 1.0499999999999934`], 
     Hue[1.000000000000002, 1, 1.049999999999997], 
     Hue[1.0000000000000009`, 1, 1.0499999999999987`], 
     Hue[1.0000000000000004`, 1, 1.0499999999999994`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.2976949581900639`, 1, -17.474999625757572`], 
     Hue[1.2976949581900639`, 1, -17.100757209075603`], 
     Hue[1.2976949581900639`, 1, -16.726514792393633`], 
     Hue[1.2976949581900639`, 1, -16.35227237571166], 
     Hue[1.2976949581900636`, 1, -15.97802995902969], 
     Hue[1.2976949581900636`, 1, -15.603787542347721`], 
     Hue[1.2976949581900636`, 1, -15.229545125665748`], 
     Hue[1.2976949581900634`, 1, -14.855302708983777`], 
     Hue[1.2976949581900628`, 1, -14.481060292301807`], 
     Hue[1.2976949581900616`, 1, -14.106817875619834`], 
     Hue[1.2976949581900592`, 1, -13.732575458937859`], 
     Hue[1.2976949581900536`, 1, -13.358333042255882`], 
     Hue[1.2976949581900414`, 1, -12.984090625573902`], 
     Hue[1.2976949581900146`, 1, -12.609848208891906`], 
     Hue[1.2976949581899555`, 1, -12.23560579220988], 
     Hue[1.2976949581898256`, 1, -11.861363375527791`], 
     Hue[1.2976949581895398`, 1, -11.487120958845555`], 
     Hue[1.297694958188912, 1, -11.112878542163005`], 
     Hue[1.297694958187531, 1, -10.738636125479761`], 
     Hue[1.2976949581844945`, 1, -10.36439370879499], 
     Hue[1.2976949581778188`, 1, -9.990151292106862], 
     Hue[1.29769495816314, 1, -9.615908875411355], 
     Hue[1.2976949581308659`, 1, -9.241666458699621], 
     Hue[1.2976949580599038`, 1, -8.867424041952212], 
     Hue[1.2976949579038772`, 1, -8.49318162512636], 
     Hue[1.2976949575608177`, 1, -8.118939208128033], 
     Hue[1.2976949568065228`, 1, -7.744696790750482], 
     Hue[1.2976949551480343`, 1, -7.370454372539119], 
     Hue[1.2976949515014704`, 1, -6.996211952494437], 
     Hue[1.2976949434836693`, 1, -6.621969528418776], 
     Hue[1.2976949258547088`, 1, -6.2477270954801005`], 
     Hue[1.2976948870934253`, 1, -5.873484643054083], 
     Hue[1.2976948018679053`, 1, -5.499242147780788], 
     Hue[1.2976946144801143`, 1, -5.124999558298345], 
     Hue[1.2976942024649505`, 1, -4.750756761677325], 
     Hue[1.2976932965535724`, 1, -4.376513509623053], 
     Hue[1.2976913046901315`, 1, -4.002269256234007], 
     Hue[1.2976869250710918`, 1, -3.628022801370391], 
     Hue[1.2976772952205355`, 1, -3.2537715069716917`], 
     Hue[1.2976561205378778`, 1, -2.8795095761423655`], 
     Hue[1.2976095570648951`, 1, -2.505224279922542], 
     Hue[1.2975071471324735`, 1, -2.130887712253826], 
     Hue[1.297281833027688, 1, -1.7564389099027082`], 
     Hue[1.2967857422437974`, 1, -1.3817457473469206`], 
     Hue[1.2956916851194569`, 1, -1.0065270685763805`], 
     Hue[1.2932705812030205`, 1, -0.6302108363763801], 
     Hue[1.2878756723529796`, 1, -0.25177205017085047`], 
     Hue[1.2757122591687948`, 1, 0.1298240541001907], 
     Hue[1.248082825895842, 1, 0.5102579069371423], 
     Hue[1.1898701943322736`, 1, 0.8497959657232376], 
     Hue[1.107824763857793, 1, 1.0369171740642267`], 
     Hue[1.0496121322942233`, 1, 1.071621531960106], 
     Hue[1.0219826990212695`, 1, 1.0654300958051257`], 
     Hue[1.0098192858370845`, 1, 1.058076408216056], 
     Hue[1.0044243769870433`, 1, 1.0538800386924976`], 
     Hue[1.002003273070607, 1, 1.0518062231744683`], 
     Hue[1.0009092159462665`, 1, 1.0508299610858993`], 
     Hue[1.0004131251623758`, 1, 1.0503792152120828`], 
     Hue[1.0001878110575904`, 1, 1.0501728295429356`], 
     Hue[1.0000854011251685`, 1, 1.0500786785561915`], 
     Hue[1.000038837652186, 1, 1.0500357990183382`], 
     Hue[1.0000176629695283`, 1, 1.0500162848709842`], 
     Hue[1.0000080331189718`, 1, 1.0500074071542556`], 
     Hue[1.0000036534999324`, 1, 1.0500033689726105`], 
     Hue[1.0000016616364915`, 1, 1.0500015322655352`], 
     Hue[1.0000007557251134`, 1, 1.0500006968932347`], 
     Hue[1.0000003437099494`, 1, 1.0500003169541856`], 
     Hue[1.0000001563221583`, 1, 1.0500001441537141`], 
     Hue[1.0000000710966386`, 1, 1.0500000655623898`], 
     Hue[1.0000000323353548`, 1, 1.0500000298183443`], 
     Hue[1.0000000147063945`, 1, 1.0500000135616394`], 
     Hue[1.0000000066885935`, 1, 1.0500000061679498`], 
     Hue[1.0000000030420293`, 1, 1.0500000028052363`], 
     Hue[1.0000000013835408`, 1, 1.0500000012758453`], 
     Hue[1.0000000006292462`, 1, 1.0500000005802654`], 
     Hue[1.0000000002861866`, 1, 1.0500000002639098`], 
     Hue[1.00000000013016, 1, 1.0500000001200285`], 
     Hue[1.000000000059198, 1, 1.05000000005459], 
     Hue[1.0000000000269238`, 1, 1.050000000024828], 
     Hue[1.000000000012245, 1, 1.050000000011292], 
     Hue[1.000000000005569, 1, 1.0500000000051357`], 
     Hue[1.0000000000025329`, 1, 1.0500000000023357`], 
     Hue[1.000000000001152, 1, 1.0500000000010623`], 
     Hue[1.000000000000524, 1, 1.0500000000004832`], 
     Hue[1.0000000000002383`, 1, 1.0500000000002199`], 
     Hue[1.0000000000001084`, 1, 1.0500000000001], 
     Hue[1.0000000000000493`, 1, 1.0500000000000456`], 
     Hue[1.0000000000000224`, 1, 1.0500000000000207`], 
     Hue[1.0000000000000102`, 1, 1.0500000000000094`], 
     Hue[1.0000000000000047`, 1, 1.0500000000000043`], 
     Hue[1.000000000000002, 1, 1.050000000000002], 
     Hue[1.0000000000000009`, 1, 1.050000000000001], 
     Hue[1.0000000000000004`, 1, 1.0500000000000005`], 
     Hue[1.0000000000000002`, 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.4230897593049956`, 1, -17.474999625757572`], 
     Hue[1.4230897593049956`, 1, -17.100757209075603`], 
     Hue[1.4230897593049956`, 1, -16.726514792393633`], 
     Hue[1.4230897593049956`, 1, -16.35227237571166], 
     Hue[1.4230897593049956`, 1, -15.97802995902969], 
     Hue[1.4230897593049954`, 1, -15.603787542347721`], 
     Hue[1.4230897593049954`, 1, -15.229545125665748`], 
     Hue[1.4230897593049954`, 1, -14.855302708983777`], 
     Hue[1.4230897593049951`, 1, -14.481060292301803`], 
     Hue[1.4230897593049945`, 1, -14.10681787561983], 
     Hue[1.4230897593049934`, 1, -13.73257545893785], 
     Hue[1.4230897593049905`, 1, -13.358333042255865`], 
     Hue[1.4230897593049847`, 1, -12.98409062557386], 
     Hue[1.4230897593049716`, 1, -12.609848208891814`], 
     Hue[1.423089759304943, 1, -12.235605792209679`], 
     Hue[1.4230897593048797`, 1, -11.86136337552735], 
     Hue[1.4230897593047407`, 1, -11.487120958844589`], 
     Hue[1.4230897593044354`, 1, -11.11287854216088], 
     Hue[1.4230897593037637`, 1, -10.73863612547509], 
     Hue[1.423089759302287, 1, -10.364393708784721`], 
     Hue[1.4230897592990404`, 1, -9.990151292084283], 
     Hue[1.4230897592919018`, 1, -9.61590887536171], 
     Hue[1.423089759276206, 1, -9.241666458590469], 
     Hue[1.4230897592416953`, 1, -8.867424041712212], 
     Hue[1.4230897591658156`, 1, -8.493181624598664], 
     Hue[1.4230897589989766`, 1, -8.118939206967775], 
     Hue[1.4230897586321432`, 1, -7.744696788199392], 
     Hue[1.4230897578255766`, 1, -7.370454366929972], 
     Hue[1.4230897560521565`, 1, -6.9962119401614435`], 
     Hue[1.4230897521528887`, 1, -6.621969501301886], 
     Hue[1.4230897435794603`, 1, -6.247727035857442], 
     Hue[1.4230897247288214`, 1, -5.873484511960067], 
     Hue[1.4230896832813738`, 1, -5.499241859540581], 
     Hue[1.423089592149587, 1, -5.124998924535763], 
     Hue[1.4230893917749246`, 1, -4.750755368201667], 
     Hue[1.4230889512022682`, 1, -4.3765104457282895`], 
     Hue[1.423087982486718, 1, -4.002262519460222], 
     Hue[1.4230858524661951`, 1, -3.6280079885370853`], 
     Hue[1.4230811687494649`, 1, -3.2537389351529473`], 
     Hue[1.4230708686853057`, 1, -2.8794379478158936`], 
     Hue[1.4230482127160164`, 1, -2.5050667318233373`], 
     Hue[1.4229983551784553`, 1, -2.130541031581366], 
     Hue[1.4228885226092174`, 1, -1.7556753212531866`], 
     Hue[1.422646013825377, 1, -1.3800603699079728`], 
     Hue[1.4221078396163058`, 1, -1.0027900432480543`], 
     Hue[1.4209000319500544`, 1, -0.6218411867848876], 
     Hue[1.4181202023133652`, 1, -0.23261540109090073`], 
     Hue[1.4113410519268725`, 1, 0.1757262558694641], 
     Hue[1.3923381394667067`, 1, 0.6302432381488974], 
     Hue[1.3178695617874465`, 1, 1.1823854410344459`], 
     Hue[1.1052201975175544`, 1, 1.3695066493754453`], 
     Hue[1.03075161983829, 1, 1.1916068631718653`], 
     Hue[1.0117487073781233`, 1, 1.1113322975744007`], 
     Hue[1.0049695569916304`, 1, 1.0772330572960063`], 
     Hue[1.0021897273549412`, 1, 1.06224968828399], 
     Hue[1.0009819196886895`, 1, 1.0555432485027947`], 
     Hue[1.0004437454796187`, 1, 1.052515338524847], 
     Hue[1.0002012366957782`, 1, 1.0511428038616046`], 
     Hue[1.0000914041265403`, 1, 1.050519510215396], 
     Hue[1.0000415465889791`, 1, 1.050236226655396], 
     Hue[1.0000188906196898`, 1, 1.05010742734481], 
     Hue[1.0000085905555305`, 1, 1.050048856689729], 
     Hue[1.0000039068388005`, 1, 1.050022219987561], 
     Hue[1.0000017768182776`, 1, 1.050010105746395], 
     Hue[1.0000008081027274`, 1, 1.0500045961602997`], 
     Hue[1.0000003675300708`, 1, 1.050002090368893], 
     Hue[1.0000001671554086`, 1, 1.0500009507167674`], 
     Hue[1.0000000760236218`, 1, 1.05000043239392], 
     Hue[1.0000000345761741`, 1, 1.0500001966564059`], 
     Hue[1.0000000157255353`, 1, 1.0500000894410026`], 
     Hue[1.0000000071521067`, 1, 1.050000040678529], 
     Hue[1.0000000032528389`, 1, 1.0500000185009415`], 
     Hue[1.0000000014794188`, 1, 1.050000008414386], 
     Hue[1.0000000006728522`, 1, 1.0500000038269344`], 
     Hue[1.000000000306019, 1, 1.0500000017405224`], 
     Hue[1.00000000013918, 1, 1.0500000007916044`], 
     Hue[1.0000000000633003`, 1, 1.0500000003600285`], 
     Hue[1.0000000000287894`, 1, 1.050000000163744], 
     Hue[1.0000000000130937`, 1, 1.0500000000744723`], 
     Hue[1.0000000000059552`, 1, 1.0500000000338707`], 
     Hue[1.0000000000027085`, 1, 1.0500000000154048`], 
     Hue[1.000000000001232, 1, 1.0500000000070062`], 
     Hue[1.0000000000005602`, 1, 1.0500000000031866`], 
     Hue[1.000000000000255, 1, 1.0500000000014493`], 
     Hue[1.000000000000116, 1, 1.0500000000006593`], 
     Hue[1.0000000000000526`, 1, 1.0500000000002998`], 
     Hue[1.000000000000024, 1, 1.0500000000001364`], 
     Hue[1.0000000000000109`, 1, 1.050000000000062], 
     Hue[1.0000000000000049`, 1, 1.0500000000000282`], 
     Hue[1.0000000000000022`, 1, 1.050000000000013], 
     Hue[1.000000000000001, 1, 1.050000000000006], 
     Hue[1.0000000000000004`, 1, 1.0500000000000027`], 
     Hue[1.0000000000000002`, 1, 1.0500000000000014`], 
     Hue[1., 1, 1.0500000000000005`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.5484845604199272, 1, -17.474999625757572`], 
     Hue[0.5484845604199272, 1, -17.100757209075603`], 
     Hue[0.5484845604199272, 1, -16.726514792393633`], 
     Hue[0.5484845604199272, 1, -16.35227237571166], 
     Hue[0.5484845604199272, 1, -15.97802995902969], 
     Hue[0.5484845604199273, 1, -15.603787542347721`], 
     Hue[0.5484845604199273, 1, -15.229545125665748`], 
     Hue[0.5484845604199273, 1, -14.855302708983777`], 
     Hue[0.5484845604199275, 1, -14.481060292301803`], 
     Hue[0.5484845604199278, 1, -14.106817875619829`], 
     Hue[0.5484845604199287, 1, -13.73257545893785], 
     Hue[0.5484845604199304, 1, -13.358333042255863`], 
     Hue[0.5484845604199342, 1, -12.984090625573856`], 
     Hue[0.5484845604199426, 1, -12.609848208891805`], 
     Hue[0.5484845604199613, 1, -12.235605792209657`], 
     Hue[0.548484560420002, 1, -11.861363375527299`], 
     Hue[0.5484845604200916, 1, -11.487120958844477`], 
     Hue[0.5484845604202888, 1, -11.112878542160635`], 
     Hue[0.5484845604207225, 1, -10.738636125474548`], 
     Hue[0.5484845604216756, 1, -10.36439370878353], 
     Hue[0.5484845604237714, 1, -9.990151292081665], 
     Hue[0.5484845604283797, 1, -9.61590887535595], 
     Hue[0.5484845604385118, 1, -9.241666458577809], 
     Hue[0.5484845604607895, 1, -8.867424041684377], 
     Hue[0.5484845605097723, 1, -8.493181624537462], 
     Hue[0.5484845606174721, 1, -8.118939206833208], 
     Hue[0.5484845608542747, 1, -7.744696787903513], 
     Hue[0.5484845613749387, 1, -7.37045436627941], 
     Hue[0.5484845625197374, 1, -6.9962119387310375`], 
     Hue[0.5484845650368377, 1, -6.621969498156811], 
     Hue[0.5484845705712564, 1, -6.247727028942276], 
     Hue[0.5484845827399389, 1, -5.873484496755496], 
     Hue[0.5484846094955765, 1, -5.499241826109839], 
     Hue[0.5484846683240325, 1, -5.124998851030502], 
     Hue[0.5484847976722612, 1, -4.750755206582824], 
     Hue[0.5484850820761169, 1, -4.376510090368604], 
     Hue[0.5484857074140561, 1, -4.002261738102292], 
     Hue[0.5484870824167232, 1, -3.628006270452918], 
     Hue[0.5484901059385889, 1, -3.2537351571140025`], 
     Hue[0.5484967551240784, 1, -2.879429638809772], 
     Hue[0.5485113810855118, 1, -2.5050484522892775`], 
     Hue[0.5485435696637537, 1, -2.130500790038914], 
     Hue[0.5486144893004081, 1, -1.755586599501963], 
     Hue[0.5487711302812988, 1, -1.3798641199191912`], 
     Hue[0.5491190019706588, 1, -1.002352784797828], 
     Hue[0.5499010219818488, 1, -0.6208510885721545], 
     Hue[0.5517080052202212, 1, -0.23029016155583393`], 
     Hue[0.5561602738109468, 1, 0.1816732156251356], 
     Hue[0.569067667271214, 1, 0.6490770037493832], 
     Hue[0.6305966109587042, 1, 1.2863558659719485`], 
     Hue[0.9178879494612175, 1, 1.4734770743129557`], 
     Hue[0.9794168931487123, 1, 1.210440628772352], 
     Hue[0.9923242866089802, 1, 1.1172792573300725`], 
     Hue[0.9967765551997059, 1, 1.0795582968310733`], 
     Hue[0.9985835384380785, 1, 1.0632397864967231`], 
     Hue[0.9993655584492684, 1, 1.0559805069530208`], 
     Hue[0.9997134301386285, 1, 1.052711588513629], 
     Hue[0.9998700711195191, 1, 1.0512315256128284`], 
     Hue[0.9999409907561735, 1, 1.0505597517578482`], 
     Hue[0.9999731793344154, 1, 1.0502545061894566`], 
     Hue[0.9999878052958489, 1, 1.0501157363509317`], 
     Hue[0.9999944544813383, 1, 1.0500526347286736`], 
     Hue[0.9999974780032039, 1, 1.050023938071729], 
     Hue[0.9999988530058712, 1, 1.050010887104325], 
     Hue[0.9999994783438103, 1, 1.0500049515199852`], 
     Hue[0.999999762747666, 1, 1.0500022519877363`], 
     Hue[0.9999998920958947, 1, 1.0500010242220288`], 
     Hue[0.9999999509243507, 1, 1.0500004658246638`], 
     Hue[0.9999999776799883, 1, 1.0500002118609775`], 
     Hue[0.9999999898486708, 1, 1.0500000963561682`], 
     Hue[0.9999999953830895, 1, 1.0500000438236046`], 
     Hue[0.9999999979001898, 1, 1.0500000199313486`], 
     Hue[0.9999999990449885, 1, 1.0500000090649473`], 
     Hue[0.9999999995656527, 1, 1.0500000041228152`], 
     Hue[0.9999999998024551, 1, 1.0500000018750917`], 
     Hue[0.9999999999101549, 1, 1.0500000008528076`], 
     Hue[0.9999999999591377, 1, 1.0500000003878642`], 
     Hue[0.9999999999814154, 1, 1.050000000176404], 
     Hue[0.9999999999915477, 1, 1.05000000008023], 
     Hue[0.9999999999961557, 1, 1.0500000000364893`], 
     Hue[0.9999999999982516, 1, 1.0500000000165957`], 
     Hue[0.9999999999992049, 1, 1.0500000000075478`], 
     Hue[0.9999999999996384, 1, 1.0500000000034329`], 
     Hue[0.9999999999998355, 1, 1.0500000000015612`], 
     Hue[0.9999999999999252, 1, 1.0500000000007101`], 
     Hue[0.999999999999966, 1, 1.050000000000323], 
     Hue[0.9999999999999846, 1, 1.050000000000147], 
     Hue[0.999999999999993, 1, 1.0500000000000669`], 
     Hue[0.9999999999999968, 1, 1.0500000000000305`], 
     Hue[0.9999999999999986, 1, 1.0500000000000138`], 
     Hue[0.9999999999999993, 1, 1.0500000000000063`], 
     Hue[0.9999999999999997, 1, 1.050000000000003], 
     Hue[0.9999999999999999, 1, 1.0500000000000014`], 
     Hue[0.9999999999999999, 1, 1.0500000000000007`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.6738793615348584, 1, -17.474999625757572`], 
     Hue[0.6738793615348584, 1, -17.100757209075603`], 
     Hue[0.6738793615348584, 1, -16.726514792393633`], 
     Hue[0.6738793615348584, 1, -16.35227237571166], 
     Hue[0.6738793615348584, 1, -15.97802995902969], 
     Hue[0.6738793615348584, 1, -15.603787542347721`], 
     Hue[0.6738793615348586, 1, -15.229545125665748`], 
     Hue[0.6738793615348588, 1, -14.855302708983777`], 
     Hue[0.6738793615348593, 1, -14.481060292301807`], 
     Hue[0.6738793615348604, 1, -14.106817875619832`], 
     Hue[0.6738793615348626, 1, -13.732575458937857`], 
     Hue[0.6738793615348678, 1, -13.358333042255877`], 
     Hue[0.6738793615348793, 1, -12.984090625573891`], 
     Hue[0.6738793615349041, 1, -12.609848208891881`], 
     Hue[0.6738793615349591, 1, -12.235605792209824`], 
     Hue[0.6738793615350798, 1, -11.861363375527667`], 
     Hue[0.6738793615353452, 1, -11.487120958845285`], 
     Hue[0.6738793615359289, 1, -11.112878542162411`], 
     Hue[0.6738793615372121, 1, -10.738636125478456`], 
     Hue[0.6738793615400334, 1, -10.364393708792118`], 
     Hue[0.6738793615462366, 1, -9.990151292100549], 
     Hue[0.6738793615598759, 1, -9.615908875397473], 
     Hue[0.6738793615898652, 1, -9.241666458669103], 
     Hue[0.6738793616558032, 1, -8.867424041885108], 
     Hue[0.673879361800783, 1, -8.493181624978817], 
     Hue[0.6738793621195542, 1, -8.118939207803628], 
     Hue[0.673879362820445, 1, -7.744696790037202], 
     Hue[0.6738793643615131, 1, -7.370454370970813], 
     Hue[0.6738793677499018, 1, -6.996211949046153], 
     Hue[0.6738793752000454, 1, -6.621969520836939], 
     Hue[0.6738793915808821, 1, -6.247727078809707], 
     Hue[0.6738794275978837, 1, -5.8734846064004245`], 
     Hue[0.6738795067894846, 1, -5.499242067189347], 
     Hue[0.6738796809103769, 1, -5.124999381099564], 
     Hue[0.673880063755461, 1, -4.7507563720647], 
     Hue[0.6738809055308235, 1, -4.376512652967215], 
     Hue[0.6738827563816728, 1, -4.00226737266264], 
     Hue[0.6738868259767614, 1, -3.6280186598201745`], 
     Hue[0.6738957742866729, 1, -3.2537624003958667`], 
     Hue[0.6739154510155633, 1, -2.879489551158377], 
     Hue[0.6739587236459765, 1, -2.5051802402636296`], 
     Hue[0.6740539112238237, 1, -2.1307908318757116`], 
     Hue[0.674263409894202, 1, -1.7562256589336778`], 
     Hue[0.6747250410838297, 1, -1.3812757219035678`], 
     Hue[0.675744872946145, 1, -1.005488110858565], 
     Hue[0.6780104728056329, 1, -0.6279002470403379], 
     Hue[0.683103237149325, 1, -0.24656963845100832`], 
     Hue[0.6948206588403074, 1, 0.14179064370446404`], 
     Hue[0.7227456129593398, 1, 0.5381731494940698], 
     Hue[0.7876699666126372, 1, 0.9059833923476401], 
     Hue[0.8862093949222178, 1, 1.0931046006886302`], 
     Hue[0.9511337485755171, 1, 1.0995367745170341`], 
     Hue[0.9790587026945504, 1, 1.0773966854093995`], 
     Hue[0.9907761243855331, 1, 1.0632788199358982`], 
     Hue[0.9958688887292254, 1, 1.0561906280285396`], 
     Hue[0.9981344885887132, 1, 1.0528451808922838`], 
     Hue[0.9991543204510287, 1, 1.051299986529252], 
     Hue[0.9996159516406563, 1, 1.0505924661811135`], 
     Hue[0.9998254503110346, 1, 1.0502697099210505`], 
     Hue[0.9999206378888819, 1, 1.0501227182151036`], 
     Hue[0.9999639105192951, 1, 1.0500558240023272`], 
     Hue[0.9999835872481855, 1, 1.0500253914468096`], 
     Hue[0.999992535558097, 1, 1.0500115487044723`], 
     Hue[0.9999966051531856, 1, 1.050005252543977], 
     Hue[0.9999984560040348, 1, 1.0500023889213739`], 
     Hue[0.9999992977793973, 1, 1.05000108650586], 
     Hue[0.9999996806244815, 1, 1.0500004941529664`], 
     Hue[0.9999998547453738, 1, 1.0500002247451552`], 
     Hue[0.9999999339369747, 1, 1.0500001022160486`], 
     Hue[0.9999999699539764, 1, 1.0500000464887378`], 
     Hue[0.999999986334813, 1, 1.050000021143476], 
     Hue[0.9999999937849566, 1, 1.0500000096162334`], 
     Hue[0.9999999971733453, 1, 1.0500000043735451`], 
     Hue[0.9999999987144134, 1, 1.0500000019891256`], 
     Hue[0.9999999994153043, 1, 1.0500000009046713`], 
     Hue[0.9999999997340754, 1, 1.0500000004114523`], 
     Hue[0.9999999998790552, 1, 1.0500000001871321`], 
     Hue[0.9999999999449933, 1, 1.0500000000851093`], 
     Hue[0.9999999999749825, 1, 1.0500000000387084`], 
     Hue[0.9999999999886218, 1, 1.050000000017605], 
     Hue[0.9999999999948251, 1, 1.050000000008007], 
     Hue[0.9999999999976464, 1, 1.0500000000036416`], 
     Hue[0.9999999999989295, 1, 1.0500000000016563`], 
     Hue[0.9999999999995132, 1, 1.0500000000007532`], 
     Hue[0.9999999999997786, 1, 1.0500000000003427`], 
     Hue[0.9999999999998993, 1, 1.050000000000156], 
     Hue[0.9999999999999541, 1, 1.0500000000000709`], 
     Hue[0.9999999999999791, 1, 1.0500000000000322`], 
     Hue[0.9999999999999906, 1, 1.0500000000000147`], 
     Hue[0.9999999999999957, 1, 1.0500000000000067`], 
     Hue[0.999999999999998, 1, 1.0500000000000032`], 
     Hue[0.9999999999999991, 1, 1.0500000000000014`], 
     Hue[0.9999999999999996, 1, 1.0500000000000007`], 
     Hue[0.9999999999999998, 1, 1.0500000000000003`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.7992741626497901, 1, -17.474999625757572`], 
     Hue[0.7992741626497901, 1, -17.100757209075603`], 
     Hue[0.7992741626497901, 1, -16.726514792393633`], 
     Hue[0.7992741626497901, 1, -16.35227237571166], 
     Hue[0.7992741626497901, 1, -15.97802995902969], 
     Hue[0.7992741626497902, 1, -15.603787542347721`], 
     Hue[0.7992741626497903, 1, -15.229545125665748`], 
     Hue[0.7992741626497906, 1, -14.855302708983777`], 
     Hue[0.7992741626497911, 1, -14.481060292301807`], 
     Hue[0.7992741626497922, 1, -14.106817875619837`], 
     Hue[0.7992741626497948, 1, -13.73257545893787], 
     Hue[0.7992741626498003, 1, -13.358333042255902`], 
     Hue[0.7992741626498125, 1, -12.984090625573945`], 
     Hue[0.7992741626498393, 1, -12.609848208891998`], 
     Hue[0.7992741626498981, 1, -12.235605792210082`], 
     Hue[0.7992741626500277, 1, -11.861363375528235`], 
     Hue[0.7992741626503124, 1, -11.487120958846536`], 
     Hue[0.7992741626509385, 1, -11.112878542165163`], 
     Hue[0.7992741626523152, 1, -10.738636125484506`], 
     Hue[0.799274162655342, 1, -10.364393708805425`], 
     Hue[0.7992741626619971, 1, -9.990151292129807], 
     Hue[0.79927416267663, 1, -9.615908875461805], 
     Hue[0.7992741627088036, 1, -9.241666458810553], 
     Hue[0.7992741627795448, 1, -8.867424042196118], 
     Hue[0.7992741629350852, 1, -8.493181625662642], 
     Hue[0.7992741632770761, 1, -8.11893920930717], 
     Hue[0.7992741640290212, 1, -7.74469679334308], 
     Hue[0.7992741656823434, 1, -7.370454378239539], 
     Hue[0.7992741693175484, 1, -6.996211965028105], 
     Hue[0.7992741773103731, 1, -6.621969555976894], 
     Hue[0.7992741948844154, 1, -6.24772715607289], 
     Hue[0.799274233524941, 1, -5.873484776281114], 
     Hue[0.7992743184849048, 1, -5.499242440710721], 
     Hue[0.7992745052886095, 1, -5.125000202371431], 
     Hue[0.799274916018554, 1, -4.750758177818477], 
     Hue[0.7992758190993825, 1, -4.376516623331334], 
     Hue[0.7992778047164819, 1, -4.002276102429096], 
     Hue[0.7992821704916129, 1, -3.6280378542834892`], 
     Hue[0.7992917693718593, 1, -3.253804604205129], 
     Hue[0.7993128733906021, 1, -2.879582347839605], 
     Hue[0.7993592690751251, 1, -2.5053842845536964`], 
     Hue[0.7994612500550052, 1, -2.1312395162164597`], 
     Hue[0.7996853308064691, 1, -1.7572124161259939`], 
     Hue[0.8001773069909444, 1, -1.3834463820600618`], 
     Hue[0.8012555382034787, 1, -1.0102655982477027`], 
     Hue[0.8036091200220515, 1, -0.6384248481009538], 
     Hue[0.8086983120964448, 1, -0.26977596505391244`], 
     Hue[0.8194496704881514, 1, 0.09079587965308245], 
     Hue[0.8408251884694615, 1, 0.42982560676781745`], 
     Hue[0.8771929345459165, 1, 0.7147584177240047], 
     Hue[0.922081228103872, 1, 0.9018796260649923], 
     Hue[0.9584489741803276, 1, 0.991189231790779], 
     Hue[0.9798244921616381, 1, 1.0264019213580167`], 
     Hue[0.9905758505533451, 1, 1.0400724933329935`], 
     Hue[0.9956650426277385, 1, 1.0456660269679237`], 
     Hue[0.9980186244463114, 1, 1.0480676935031459`], 
     Hue[0.9990968556588457, 1, 1.049129326372758], 
     Hue[0.999588831843321, 1, 1.0496057089887973`], 
     Hue[0.9998129125947849, 1, 1.0498210255803027`], 
     Hue[0.999914893574665, 1, 1.049918673925037], 
     Hue[0.999961289259188, 1, 1.0499630273210987`], 
     Hue[0.9999823932779308, 1, 1.0499831876375474`], 
     Hue[0.9999919921581772, 1, 1.0499923542411576`], 
     Hue[0.9999963579333083, 1, 1.049996522777522], 
     Hue[0.9999983435504077, 1, 1.0499984185572553`], 
     Hue[0.9999992466312361, 1, 1.0499992807520837`], 
     Hue[0.9999996573611806, 1, 1.0499996728811003`], 
     Hue[0.9999998441648853, 1, 1.0499998512237807`], 
     Hue[0.9999999291248491, 1, 1.0499999323353577`], 
     Hue[0.9999999677653747, 1, 1.0499999692255544`], 
     Hue[0.999999985339417, 1, 1.049999986003522], 
     Hue[0.9999999933322418, 1, 1.049999993634283], 
     Hue[0.9999999969674467, 1, 1.0499999971048177`], 
     Hue[0.9999999986207689, 1, 1.0499999986832464`], 
     Hue[0.9999999993727139, 1, 1.0499999994011293`], 
     Hue[0.999999999714705, 1, 1.0499999997276286`], 
     Hue[0.9999999998702453, 1, 1.0499999998761231`], 
     Hue[0.9999999999409865, 1, 1.0499999999436598`], 
     Hue[0.9999999999731601, 1, 1.049999999974376], 
     Hue[0.999999999987793, 1, 1.049999999988346], 
     Hue[0.9999999999944481, 1, 1.0499999999946996`], 
     Hue[0.999999999997475, 1, 1.0499999999975893`], 
     Hue[0.9999999999988516, 1, 1.0499999999989036`], 
     Hue[0.9999999999994778, 1, 1.0499999999995013`], 
     Hue[0.9999999999997624, 1, 1.0499999999997733`], 
     Hue[0.999999999999892, 1, 1.0499999999998968`], 
     Hue[0.9999999999999508, 1, 1.0499999999999532`], 
     Hue[0.9999999999999777, 1, 1.0499999999999787`], 
     Hue[0.9999999999999898, 1, 1.0499999999999903`], 
     Hue[0.9999999999999953, 1, 1.0499999999999956`], 
     Hue[0.9999999999999979, 1, 1.049999999999998], 
     Hue[0.999999999999999, 1, 1.0499999999999992`], 
     Hue[0.9999999999999996, 1, 1.0499999999999996`], 
     Hue[0.9999999999999998, 1, 1.0499999999999998`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.9246689637647219, 1, -17.474999625757572`], 
     Hue[0.9246689637647219, 1, -17.100757209075603`], 
     Hue[0.9246689637647219, 1, -16.726514792393633`], 
     Hue[0.9246689637647219, 1, -16.35227237571166], 
     Hue[0.9246689637647219, 1, -15.97802995902969], 
     Hue[0.9246689637647219, 1, -15.603787542347721`], 
     Hue[0.924668963764722, 1, -15.229545125665748`], 
     Hue[0.9246689637647221, 1, -14.855302708983777`], 
     Hue[0.9246689637647223, 1, -14.48106029230181], 
     Hue[0.9246689637647229, 1, -14.106817875619841`], 
     Hue[0.9246689637647241, 1, -13.732575458937879`], 
     Hue[0.9246689637647267, 1, -13.358333042255921`], 
     Hue[0.9246689637647325, 1, -12.984090625573986`], 
     Hue[0.9246689637647454, 1, -12.609848208892087`], 
     Hue[0.9246689637647736, 1, -12.235605792210281`], 
     Hue[0.9246689637648355, 1, -11.861363375528672`], 
     Hue[0.9246689637649719, 1, -11.487120958847495`], 
     Hue[0.9246689637652715, 1, -11.11287854216727], 
     Hue[0.9246689637659303, 1, -10.738636125489139`], 
     Hue[0.924668963767379, 1, -10.36439370881561], 
     Hue[0.9246689637705641, 1, -9.990151292152198], 
     Hue[0.9246689637775674, 1, -9.615908875511037], 
     Hue[0.9246689637929656, 1, -9.2416664589188], 
     Hue[0.9246689638268221, 1, -8.867424042434127], 
     Hue[0.9246689639012633, 1, -8.493181626185955], 
     Hue[0.9246689640649393, 1, -8.118939210457798], 
     Hue[0.924668964424818, 1, -7.744696795873], 
     Hue[0.9246689652160935, 1, -7.370454383802138], 
     Hue[0.9246689669558925, 1, -6.996211977258745], 
     Hue[0.9246689707812361, 1, -6.6219695828687355`], 
     Hue[0.9246689791921228, 1, -6.247727215200714], 
     Hue[0.9246689976853645, 1, -5.873484906287047], 
     Hue[0.9246690383469335, 1, -5.499242726558144], 
     Hue[0.9246691277504997, 1, -5.125000830871087], 
     Hue[0.9246693243238873, 1, -4.7507595597134635`], 
     Hue[0.9246697565318609, 1, -4.376519661720182], 
     Hue[0.9246707068232889, 1, -4.002282782913582], 
     Hue[0.9246727961772407, 1, -3.6280525423428456`], 
     Hue[0.9246773897205178, 1, -3.2538368968014515`], 
     Hue[0.9246874878497443, 1, -2.8796533386474366`], 
     Hue[0.9247096820861326, 1, -2.505540316906141], 
     Hue[0.9247584386700624, 1, -2.131582312977181], 
     Hue[0.9248654360902218, 1, -1.7579648004721429`], 
     Hue[0.9250997074424623, 1, -1.3850942431888675`], 
     Hue[0.925610081318536, 1, -1.013857873833713], 
     Hue[0.9267098879462881, 1, -0.6461753939062669], 
     Hue[0.9290247803428768, 1, -0.2861197287196342], 
     Hue[0.933662178940728, 1, 0.058041975718919336`], 
     Hue[0.9420795147473796, 1, 0.3711348509788749], 
     Hue[0.9548755837460791, 1, 0.6309452015199766], 
     Hue[0.9697933800186422, 1, 0.8180664098609636], 
     Hue[0.9825894490173419, 1, 0.9324984760018353], 
     Hue[0.9910067848239936, 1, 0.9936480174238529], 
     Hue[0.9956441834218449, 1, 1.0237287296672712`], 
     Hue[0.9979590758184338, 1, 1.0379154811626101`], 
     Hue[0.9990588824461859, 1, 1.0444754179171358`], 
     Hue[0.9995692563222596, 1, 1.0474814652439524`], 
     Hue[0.9998035276745001, 1, 1.0488533246426481`], 
     Hue[0.9999105250946595, 1, 1.0494782288195814`], 
     Hue[0.9999592816785893, 1, 1.0497626415725918`], 
     Hue[0.9999814759149777, 1, 1.0498920365132678`], 
     Hue[0.999991574044204, 1, 1.0499508950412244`], 
     Hue[0.9999961675874812, 1, 1.0499776661818014`], 
     Hue[0.999998256941433, 1, 1.049989842293035], 
     Hue[0.999999207232861, 1, 1.049995380168407], 
     Hue[0.9999996394408347, 1, 1.0499978988570962`], 
     Hue[0.9999998360142223, 1, 1.0499990443814444`], 
     Hue[0.9999999254177885, 1, 1.049999565376358], 
     Hue[0.9999999660793574, 1, 1.049999802329426], 
     Hue[0.9999999845725991, 1, 1.0499999100977302`], 
     Hue[0.9999999929834859, 1, 1.0499999591116798`], 
     Hue[0.9999999968088293, 1, 1.0499999814036431`], 
     Hue[0.9999999985486283, 1, 1.0499999915422182`], 
     Hue[0.9999999993399038, 1, 1.0499999961533288`], 
     Hue[0.9999999996997826, 1, 1.049999998250501], 
     Hue[0.9999999998634586, 1, 1.049999999204313], 
     Hue[0.9999999999378998, 1, 1.0499999996381149`], 
     Hue[0.9999999999717563, 1, 1.0499999998354115`], 
     Hue[0.9999999999871545, 1, 1.0499999999251437`], 
     Hue[0.9999999999941578, 1, 1.0499999999659548`], 
     Hue[0.9999999999973429, 1, 1.049999999984516], 
     Hue[0.9999999999987915, 1, 1.0499999999929577`], 
     Hue[0.9999999999994503, 1, 1.0499999999967973`], 
     Hue[0.99999999999975, 1, 1.0499999999985434`], 
     Hue[0.9999999999998863, 1, 1.0499999999993375`], 
     Hue[0.9999999999999483, 1, 1.0499999999996987`], 
     Hue[0.9999999999999765, 1, 1.049999999999863], 
     Hue[0.9999999999999893, 1, 1.0499999999999376`], 
     Hue[0.9999999999999951, 1, 1.0499999999999716`], 
     Hue[0.9999999999999978, 1, 1.0499999999999872`], 
     Hue[0.999999999999999, 1, 1.049999999999994], 
     Hue[0.9999999999999996, 1, 1.0499999999999974`], 
     Hue[0.9999999999999998, 1, 1.049999999999999], 
     Hue[0.9999999999999999, 1, 1.0499999999999996`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.0500637648796531`, 1, -17.474999625757572`], 
     Hue[1.0500637648796531`, 1, -17.100757209075603`], 
     Hue[1.0500637648796531`, 1, -16.726514792393633`], 
     Hue[1.0500637648796531`, 1, -16.35227237571166], 
     Hue[1.050063764879653, 1, -15.97802995902969], 
     Hue[1.050063764879653, 1, -15.603787542347721`], 
     Hue[1.050063764879653, 1, -15.229545125665748`], 
     Hue[1.050063764879653, 1, -14.855302708983777`], 
     Hue[1.0500637648796527`, 1, -14.48106029230181], 
     Hue[1.0500637648796525`, 1, -14.106817875619843`], 
     Hue[1.0500637648796516`, 1, -13.732575458937879`], 
     Hue[1.0500637648796498`, 1, -13.358333042255923`], 
     Hue[1.0500637648796458`, 1, -12.98409062557399], 
     Hue[1.0500637648796372`, 1, -12.609848208892098`], 
     Hue[1.050063764879618, 1, -12.235605792210302`], 
     Hue[1.0500637648795759`, 1, -11.861363375528716`], 
     Hue[1.0500637648794835`, 1, -11.487120958847594`], 
     Hue[1.05006376487928, 1, -11.112878542167488`], 
     Hue[1.050063764878833, 1, -10.73863612548962], 
     Hue[1.0500637648778495`, 1, -10.364393708816667`], 
     Hue[1.0500637648756876`, 1, -9.990151292154527], 
     Hue[1.0500637648709343`, 1, -9.615908875516158], 
     Hue[1.050063764860483, 1, -9.241666458930057], 
     Hue[1.0500637648375033`, 1, -8.867424042458875], 
     Hue[1.050063764786977, 1, -8.493181626240373], 
     Hue[1.050063764675884, 1, -8.118939210577448], 
     Hue[1.0500637644316204`, 1, -7.744696796136078], 
     Hue[1.0500637638945514`, 1, -7.370454384380577], 
     Hue[1.0500637627136828`, 1, -6.996211978530572], 
     Hue[1.0500637601172753`, 1, -6.621969585665138], 
     Hue[1.0500637544084834`, 1, -6.247727221349239], 
     Hue[1.0500637418564103`, 1, -5.87348491980597], 
     Hue[1.0500637142578435`, 1, -5.499242756282543], 
     Hue[1.0500636535762202`, 1, -5.12500089622679], 
     Hue[1.0500635201543678`, 1, -4.750759703412129], 
     Hue[1.050063226798493, 1, -4.376519977670919], 
     Hue[1.05006258180056, 1, -4.002283477586398], 
     Hue[1.0500611636823869`, 1, -3.62805406965807], 
     Hue[1.0500580459001307`, 1, -3.2538402545599467`], 
     Hue[1.0500511920667759`, 1, -2.8796607195513557`], 
     Hue[1.050036128734231, 1, -2.5055565363612935`], 
     Hue[1.0500030393789013`, 1, -2.131617931003313], 
     Hue[1.0499304335062325`, 1, -1.7580429020309392`], 
     Hue[1.04977150783549, 1, -1.3852649448861472`], 
     Hue[1.0494254922251784`, 1, -1.0142283239143859`], 
     Hue[1.04868083843486, 1, -0.6469670203650504], 
     Hue[1.0471176740228363`, 1, -0.28775645612594714`], 
     Hue[1.0440019636180013`, 1, 0.05488154378154875], 
     Hue[1.0383916601541747`, 1, 0.3657880464575429], 
     Hue[1.0299385993013896`, 1, 0.6237127978451456], 
     Hue[1.0201251655782637`, 1, 0.8108340061861324], 
     Hue[1.0116721047254786`, 1, 0.9271516714805035], 
     Hue[1.0060618012616518`, 1, 0.9904875854864821], 
     Hue[1.0029460908568169`, 1, 1.0220920022609583`], 
     Hue[1.001382926444793, 1, 1.0371238547038266`], 
     Hue[1.0006382726544747`, 1, 1.0441049678364624`], 
     Hue[1.0002922570441632`, 1, 1.0473107635466727`], 
     Hue[1.0001333313734206`, 1, 1.0487752230838518`], 
     Hue[1.0000607255007519`, 1, 1.0494426107934491`], 
     Hue[1.0000276361454221`, 1, 1.04974642211744], 
     Hue[1.0000125728128773`, 1, 1.049884655609348], 
     Hue[1.0000057189795222`, 1, 1.0499475372827296`], 
     Hue[1.000002601197266, 1, 1.0499761388665767`], 
     Hue[1.0000011830790931`, 1, 1.0499891476202188`], 
     Hue[1.00000053808116, 1, 1.049995064217669], 
     Hue[1.0000002447252854`, 1, 1.049997755158431], 
     Hue[1.000000111303433, 1, 1.04999897902574], 
     Hue[1.0000000506218094`, 1, 1.0499995356519591`], 
     Hue[1.0000000230232429`, 1, 1.0499997888105022`], 
     Hue[1.0000000104711697`, 1, 1.0499999039492054`], 
     Hue[1.0000000047623778`, 1, 1.0499999563152775`], 
     Hue[1.00000000216597, 1, 1.0499999801318154`], 
     Hue[1.0000000009851018`, 1, 1.0499999909637803`], 
     Hue[1.0000000004480327`, 1, 1.0499999958902502`], 
     Hue[1.000000000203769, 1, 1.0499999981308508`], 
     Hue[1.0000000000926759`, 1, 1.049999999149895], 
     Hue[1.0000000000421498`, 1, 1.049999999613365], 
     Hue[1.00000000001917, 1, 1.0499999998241552`], 
     Hue[1.0000000000087188`, 1, 1.0499999999200242`], 
     Hue[1.0000000000039653`, 1, 1.0499999999636265`], 
     Hue[1.0000000000018034`, 1, 1.049999999983457], 
     Hue[1.0000000000008202`, 1, 1.049999999992476], 
     Hue[1.000000000000373, 1, 1.0499999999965781`], 
     Hue[1.0000000000001696`, 1, 1.0499999999984437`], 
     Hue[1.0000000000000773`, 1, 1.0499999999992922`], 
     Hue[1.000000000000035, 1, 1.049999999999678], 
     Hue[1.000000000000016, 1, 1.0499999999998537`], 
     Hue[1.0000000000000073`, 1, 1.0499999999999334`], 
     Hue[1.0000000000000033`, 1, 1.0499999999999698`], 
     Hue[1.0000000000000016`, 1, 1.0499999999999863`], 
     Hue[1.0000000000000007`, 1, 1.0499999999999938`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999972`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999987`], 
     Hue[1., 1, 1.0499999999999994`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.1754585659945849`, 1, -17.474999625757572`], 
     Hue[1.1754585659945849`, 1, -17.100757209075603`], 
     Hue[1.1754585659945849`, 1, -16.726514792393633`], 
     Hue[1.1754585659945849`, 1, -16.35227237571166], 
     Hue[1.1754585659945846`, 1, -15.97802995902969], 
     Hue[1.1754585659945846`, 1, -15.603787542347721`], 
     Hue[1.1754585659945846`, 1, -15.229545125665748`], 
     Hue[1.1754585659945844`, 1, -14.855302708983777`], 
     Hue[1.175458565994584, 1, -14.481060292301807`], 
     Hue[1.1754585659945829`, 1, -14.10681787561984], 
     Hue[1.1754585659945804`, 1, -13.732575458937871`], 
     Hue[1.1754585659945753`, 1, -13.358333042255907`], 
     Hue[1.1754585659945638`, 1, -12.984090625573955`], 
     Hue[1.1754585659945387`, 1, -12.60984820889202], 
     Hue[1.1754585659944836`, 1, -12.235605792210134`], 
     Hue[1.1754585659943622`, 1, -11.861363375528345`], 
     Hue[1.1754585659940955`, 1, -11.487120958846777`], 
     Hue[1.1754585659935088`, 1, -11.112878542165692`], 
     Hue[1.1754585659922192`, 1, -10.738636125485668`], 
     Hue[1.1754585659893835`, 1, -10.36439370880798], 
     Hue[1.1754585659831487`, 1, -9.99015129213542], 
     Hue[1.1754585659694399`, 1, -9.615908875474148], 
     Hue[1.1754585659392978`, 1, -9.241666458837688], 
     Hue[1.1754585658730239`, 1, -8.867424042255783], 
     Hue[1.1754585657273053`, 1, -8.493181625793826], 
     Hue[1.17545856540691, 1, -8.11893920959561], 
     Hue[1.1754585647024485`, 1, -7.744696793977286], 
     Hue[1.175458563153529, 1, -7.370454379633979], 
     Hue[1.1754585597478777`, 1, -6.996211968094099], 
     Hue[1.1754585522597785`, 1, -6.621969562718183], 
     Hue[1.1754585357954903`, 1, -6.247727170895149], 
     Hue[1.1754584995950137`, 1, -5.873484808871217], 
     Hue[1.1754584200000604`, 1, -5.499242512367442], 
     Hue[1.1754582449925914`, 1, -5.125000359924885], 
     Hue[1.175457860199546, 1, -4.750758524234875], 
     Hue[1.175457014147816, 1, -4.376517385003156], 
     Hue[1.1754551539266354`, 1, -4.002277777121272], 
     Hue[1.1754510638845832`, 1, -3.6280415363949965`], 
     Hue[1.1754420713707718`, 1, -3.253812699777174], 
     Hue[1.1754223010918043`, 1, -2.879600145921825], 
     Hue[1.175378840378479, 1, -2.5054234086219545`], 
     Hue[1.1752833243837875`, 1, -2.131325495536971], 
     Hue[1.1750735151581027`, 1, -1.7574012490131994`], 
     Hue[1.1746131907746946`, 1, -1.383860545591373], 
     Hue[1.1736058507509541`, 1, -1.0111712315544918`], 
     Hue[1.1714141955766553`, 1, -0.6403916511466707], 
     Hue[1.166708026624752, 1, -0.27397988137025653`], 
     Hue[1.1569056502986799`, 1, 0.08215120143775767], 
     Hue[1.1379096656305099`, 1, 0.41369588329373874`], 
     Hue[1.1066666540802503`, 1, 0.6908120965387359], 
     Hue[1.0687919119143359`, 1, 0.8779333048797232], 
     Hue[1.0375489003640759`, 1, 0.9750595083167002], 
     Hue[1.0185529156959054`, 1, 1.0177572431426916`], 
     Hue[1.008750539369833, 1, 1.0358685770166494`], 
     Hue[1.0040443704179296`, 1, 1.0436992239222067`], 
     Hue[1.0018527152436307`, 1, 1.047162060196357], 
     Hue[1.0008453752198903`, 1, 1.0487151628414468`], 
     Hue[1.0003850508364822`, 1, 1.0494168761015916`], 
     Hue[1.0001752416107974`, 1, 1.0497350462597916`], 
     Hue[1.0000797256161056`, 1, 1.0498795498567786`], 
     Hue[1.0000362649027805`, 1, 1.0499452292388798`], 
     Hue[1.0000164946238128`, 1, 1.0499750920655022`], 
     Hue[1.0000075021100014`, 1, 1.0499886721296499`], 
     Hue[1.0000034120679495`, 1, 1.0499948480853463`], 
     Hue[1.0000015518467689`, 1, 1.0499976568854326`], 
     Hue[1.0000007057950386`, 1, 1.0499989343356846`], 
     Hue[1.0000003210019934`, 1, 1.049999515327646], 
     Hue[1.0000001459945245`, 1, 1.0499997795670597`], 
     Hue[1.0000000663995712`, 1, 1.0499998997452562`], 
     Hue[1.0000000301990946`, 1, 1.0499999544032954`], 
     Hue[1.0000000137348064`, 1, 1.0499999792622317`], 
     Hue[1.0000000062467072`, 1, 1.0499999905682866`], 
     Hue[1.0000000028410556`, 1, 1.0499999957103765`], 
     Hue[1.0000000012921364`, 1, 1.0499999980490426`], 
     Hue[1.0000000005876746`, 1, 1.049999999112688], 
     Hue[1.0000000002672795`, 1, 1.0499999995964429`], 
     Hue[1.000000000121561, 1, 1.0499999998164589`], 
     Hue[1.0000000000552869`, 1, 1.049999999916524], 
     Hue[1.000000000025145, 1, 1.0499999999620344`], 
     Hue[1.0000000000114362`, 1, 1.049999999982733], 
     Hue[1.0000000000052012`, 1, 1.0499999999921468`], 
     Hue[1.0000000000023657`, 1, 1.0499999999964285`], 
     Hue[1.0000000000010758`, 1, 1.0499999999983756`], 
     Hue[1.0000000000004894`, 1, 1.0499999999992613`], 
     Hue[1.0000000000002225`, 1, 1.049999999999664], 
     Hue[1.0000000000001013`, 1, 1.0499999999998473`], 
     Hue[1.000000000000046, 1, 1.0499999999999305`], 
     Hue[1.0000000000000209`, 1, 1.0499999999999683`], 
     Hue[1.0000000000000095`, 1, 1.0499999999999856`], 
     Hue[1.0000000000000044`, 1, 1.0499999999999936`], 
     Hue[1.000000000000002, 1, 1.0499999999999972`], 
     Hue[1.0000000000000009`, 1, 1.0499999999999987`], 
     Hue[1.0000000000000004`, 1, 1.0499999999999994`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.3008533671095166`, 1, -17.474999625757572`], 
     Hue[1.3008533671095166`, 1, -17.100757209075603`], 
     Hue[1.3008533671095166`, 1, -16.726514792393633`], 
     Hue[1.3008533671095166`, 1, -16.35227237571166], 
     Hue[1.3008533671095166`, 1, -15.97802995902969], 
     Hue[1.3008533671095164`, 1, -15.603787542347721`], 
     Hue[1.3008533671095164`, 1, -15.229545125665748`], 
     Hue[1.3008533671095162`, 1, -14.855302708983777`], 
     Hue[1.3008533671095155`, 1, -14.481060292301807`], 
     Hue[1.3008533671095144`, 1, -14.106817875619834`], 
     Hue[1.300853367109512, 1, -13.732575458937859`], 
     Hue[1.3008533671095064`, 1, -13.358333042255882`], 
     Hue[1.3008533671094942`, 1, -12.9840906255739], 
     Hue[1.3008533671094675`, 1, -12.609848208891902`], 
     Hue[1.3008533671094087`, 1, -12.235605792209872`], 
     Hue[1.3008533671092797`, 1, -11.861363375527775`], 
     Hue[1.300853367108996, 1, -11.487120958845523`], 
     Hue[1.3008533671083717`, 1, -11.112878542162935`], 
     Hue[1.3008533671069995`, 1, -10.73863612547961], 
     Hue[1.3008533671039826`, 1, -10.36439370879466], 
     Hue[1.300853367097349, 1, -9.990151292106138], 
     Hue[1.3008533670827631`, 1, -9.615908875409763], 
     Hue[1.3008533670506932`, 1, -9.241666458696127], 
     Hue[1.30085336698018, 1, -8.867424041944528], 
     Hue[1.300853366825141, 1, -8.493181625109463], 
     Hue[1.3008533664842523`, 1, -8.118939208090882], 
     Hue[1.300853365734731, 1, -7.7446967906687965`], 
     Hue[1.3008533640867377`, 1, -7.3704543723595135`], 
     Hue[1.3008533604632497`, 1, -6.996211952099531], 
     Hue[1.300853352496187, 1, -6.621969527550483], 
     Hue[1.300853334978786, 1, -6.247727093570962], 
     Hue[1.300853296462791, 1, -5.873484638856408], 
     Hue[1.3008532117765927`, 1, -5.499242138551242], 
     Hue[1.3008530255746176`, 1, -5.124999538005074], 
     Hue[1.3008526161667118`, 1, -4.750756717057881], 
     Hue[1.3008517159878505`, 1, -4.376513411516699], 
     Hue[1.3008497367280103`, 1, -4.0022690405231485`], 
     Hue[1.3008453848177501`, 1, -3.628022327072676], 
     Hue[1.3008358158762412`, 1, -3.253770464080045], 
     Hue[1.3008147750434131`, 1, -2.8795072829133987`], 
     Hue[1.30076850551874, 1, -2.5052192367973865`], 
     Hue[1.3006667401998562`, 1, -2.1308766192580935`], 
     Hue[1.3004428351926567`, 1, -1.7564144975393547`], 
     Hue[1.2999498026242073`, 1, -1.3816919659203777`], 
     Hue[1.2988622740590086`, 1, -1.0064083145556266`], 
     Hue[1.2964545556844802`, 1, -0.6299473584564521], 
     Hue[1.291084154803248, 1, -0.25118200176561056`], 
     Hue[1.2789485510023477`, 1, 0.13116432171091597`], 
     Hue[1.251239068082268, 1, 0.5132934208541645], 
     Hue[1.1922742246433624`, 1, 0.85559643492849], 
     Hue[1.1085791424661569`, 1, 1.0427176432694791`], 
     Hue[1.04961429902725, 1, 1.0746570458771283`], 
     Hue[1.0219048161071693`, 1, 1.0667703634158512`], 
     Hue[1.009769212306269, 1, 1.058666456621296], 
     Hue[1.0043988114250364`, 1, 1.0541435166124256`], 
     Hue[1.001991093050508, 1, 1.0519249771952226`], 
     Hue[1.000903564485309, 1, 1.0508837425124424`], 
     Hue[1.00041053191686, 1, 1.0504036275754363`], 
     Hue[1.0001866269096602`, 1, 1.0501839225386689`], 
     Hue[1.0000848615907765`, 1, 1.050083721681347], 
     Hue[1.0000385920661032`, 1, 1.0500380922473056`], 
     Hue[1.0000175512332754`, 1, 1.0500173277626312`], 
     Hue[1.0000079822917665`, 1, 1.0500078814519702`], 
     Hue[1.000003630381506, 1, 1.0500035846834694`], 
     Hue[1.000001651121666, 1, 1.05000163037189], 
     Hue[1.0000007509428048`, 1, 1.0500007415126795`], 
     Hue[1.000000341534899, 1, 1.0500003372474558`], 
     Hue[1.0000001553329236`, 1, 1.0500001533832595`], 
     Hue[1.0000000706467256`, 1, 1.050000069760064], 
     Hue[1.0000000321307305`, 1, 1.0500000317274822`], 
     Hue[1.0000000146133297`, 1, 1.0500000144299315`], 
     Hue[1.0000000066462669`, 1, 1.0500000065628563`], 
     Hue[1.0000000030227787`, 1, 1.050000002984843], 
     Hue[1.0000000013747856`, 1, 1.0500000013575321`], 
     Hue[1.0000000006252643`, 1, 1.0500000006174173`], 
     Hue[1.0000000002843754`, 1, 1.0500000002808065`], 
     Hue[1.0000000001293363`, 1, 1.0500000001277132`], 
     Hue[1.0000000000588234`, 1, 1.0500000000580851`], 
     Hue[1.0000000000267533`, 1, 1.0500000000264176`], 
     Hue[1.0000000000121676`, 1, 1.050000000012015], 
     Hue[1.000000000005534, 1, 1.0500000000054646`], 
     Hue[1.0000000000025169`, 1, 1.0500000000024854`], 
     Hue[1.0000000000011446`, 1, 1.0500000000011305`], 
     Hue[1.0000000000005207`, 1, 1.050000000000514], 
     Hue[1.0000000000002367`, 1, 1.0500000000002339`], 
     Hue[1.0000000000001077`, 1, 1.0500000000001064`], 
     Hue[1.000000000000049, 1, 1.0500000000000485`], 
     Hue[1.0000000000000222`, 1, 1.050000000000022], 
     Hue[1.0000000000000102`, 1, 1.05000000000001], 
     Hue[1.0000000000000047`, 1, 1.0500000000000045`], 
     Hue[1.000000000000002, 1, 1.050000000000002], 
     Hue[1.0000000000000009`, 1, 1.050000000000001], 
     Hue[1.0000000000000004`, 1, 1.0500000000000005`], 
     Hue[1.0000000000000002`, 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.4262481682244483`, 1, -17.474999625757572`], 
     Hue[1.4262481682244483`, 1, -17.100757209075603`], 
     Hue[1.4262481682244483`, 1, -16.726514792393633`], 
     Hue[1.4262481682244483`, 1, -16.35227237571166], 
     Hue[1.4262481682244483`, 1, -15.97802995902969], 
     Hue[1.4262481682244483`, 1, -15.603787542347721`], 
     Hue[1.426248168224448, 1, -15.229545125665748`], 
     Hue[1.426248168224448, 1, -14.855302708983777`], 
     Hue[1.4262481682244479`, 1, -14.481060292301803`], 
     Hue[1.4262481682244472`, 1, -14.10681787561983], 
     Hue[1.4262481682244461`, 1, -13.73257545893785], 
     Hue[1.4262481682244434`, 1, -13.358333042255865`], 
     Hue[1.4262481682244377`, 1, -12.98409062557386], 
     Hue[1.4262481682244252`, 1, -12.609848208891814`], 
     Hue[1.4262481682243975`, 1, -12.235605792209677`], 
     Hue[1.4262481682243369`, 1, -11.861363375527343`], 
     Hue[1.4262481682242032`, 1, -11.487120958844573`], 
     Hue[1.4262481682239092`, 1, -11.112878542160846`], 
     Hue[1.4262481682232633`, 1, -10.738636125475018`], 
     Hue[1.4262481682218429`, 1, -10.364393708784563`], 
     Hue[1.4262481682187196`, 1, -9.990151292083937], 
     Hue[1.4262481682118522`, 1, -9.61590887536095], 
     Hue[1.4262481681967532`, 1, -9.241666458588796], 
     Hue[1.4262481681635544`, 1, -8.867424041708533], 
     Hue[1.426248168090559, 1, -8.493181624590578], 
     Hue[1.426248167930062, 1, -8.118939206949996], 
     Hue[1.4262481675771732`, 1, -7.7446967881603], 
     Hue[1.4262481668012668`, 1, -7.370454366844013], 
     Hue[1.4262481650952596`, 1, -6.996211939972443], 
     Hue[1.426248161344215, 1, -6.621969500886324], 
     Hue[1.4262481530966888`, 1, -6.2477270349437335`], 
     Hue[1.4262481349626204`, 1, -5.873484509951071], 
     Hue[1.426248095090717, 1, -5.499241855123342], 
     Hue[1.4262480074231267`, 1, -5.1249989148234345`], 
     Hue[1.426247814665308, 1, -4.750755346846799], 
     Hue[1.42624739084011, 1, -4.376510398774258], 
     Hue[1.426246458948118, 1, -4.002262416218695], 
     Hue[1.4262444098947913`, 1, -3.628007761525466], 
     Hue[1.426239904213628, 1, -3.2537384359599937`], 
     Hue[1.426229995653222, 1, -2.8794368499545344`], 
     Hue[1.4262082007457078`, 1, -2.505064316609263], 
     Hue[1.4261602376655769`, 1, -2.1305357148134707`], 
     Hue[1.426054576380291, 1, -1.7556636002517292`], 
     Hue[1.4258212676183837`, 1, -1.3800344484792724`], 
     Hue[1.4253034599554284`, 1, -1.0027323139495212`], 
     Hue[1.4241411048620547`, 1, -0.6217106004465547], 
     Hue[1.4214644963474459`, 1, -0.23230946680009779`], 
     Hue[1.4149282924237812`, 1, 0.17650354844106042`], 
     Hue[1.396527603671256, 1, 0.6326477825613288], 
     Hue[1.3228347397978704`, 1, 1.1937798798758006`], 
     Hue[1.1034134284265833`, 1, 1.3809010882168011`], 
     Hue[1.0297205645531935`, 1, 1.194011407584297], 
     Hue[1.0113198758006674`, 1, 1.1121095901459972`], 
     Hue[1.0047836718770025`, 1, 1.0775389915868094`], 
     Hue[1.0021070633623936`, 1, 1.0623802746223232`], 
     Hue[1.0009447082690197`, 1, 1.0556009778013278`], 
     Hue[1.0004269006060647`, 1, 1.0525412599535477`], 
     Hue[1.0001935918441573`, 1, 1.0511545248630618`], 
     Hue[1.0000879305588715`, 1, 1.0505248269832914`], 
     Hue[1.0000399674787406`, 1, 1.0502386418694705`], 
     Hue[1.0000181725712263`, 1, 1.0501085252061697`], 
     Hue[1.0000082640108203`, 1, 1.0500493558826827`], 
     Hue[1.000003758329657, 1, 1.0500224469991803`], 
     Hue[1.0000017092763303`, 1, 1.050010208987922], 
     Hue[1.000000777384338, 1, 1.0500046431143317`], 
     Hue[1.0000003535591402`, 1, 1.0500021117237603`], 
     Hue[1.0000001608013214`, 1, 1.050000960429096], 
     Hue[1.0000000731337313`, 1, 1.0500004368111604`], 
     Hue[1.0000000332618277`, 1, 1.0500001986654024`], 
     Hue[1.0000000151277595`, 1, 1.050000090354711], 
     Hue[1.0000000068802333`, 1, 1.0500000410940913`], 
     Hue[1.0000000031291887`, 1, 1.0500000186899427`], 
     Hue[1.0000000014231816`, 1, 1.0500000085003451`], 
     Hue[1.0000000006472751`, 1, 1.0500000038660295`], 
     Hue[1.0000000002943863`, 1, 1.0500000017583033`], 
     Hue[1.0000000001338893`, 1, 1.0500000007996912`], 
     Hue[1.000000000060894, 1, 1.0500000003637064`], 
     Hue[1.0000000000276952`, 1, 1.0500000001654168`], 
     Hue[1.000000000012596, 1, 1.050000000075233], 
     Hue[1.0000000000057288`, 1, 1.0500000000342167`], 
     Hue[1.0000000000026055`, 1, 1.050000000015562], 
     Hue[1.000000000001185, 1, 1.0500000000070777`], 
     Hue[1.000000000000539, 1, 1.050000000003219], 
     Hue[1.0000000000002451`, 1, 1.050000000001464], 
     Hue[1.0000000000001115`, 1, 1.050000000000666], 
     Hue[1.0000000000000506`, 1, 1.050000000000303], 
     Hue[1.000000000000023, 1, 1.0500000000001377`], 
     Hue[1.0000000000000104`, 1, 1.0500000000000627`], 
     Hue[1.0000000000000047`, 1, 1.0500000000000285`], 
     Hue[1.0000000000000022`, 1, 1.050000000000013], 
     Hue[1.0000000000000009`, 1, 1.050000000000006], 
     Hue[1.0000000000000004`, 1, 1.0500000000000027`], 
     Hue[1.0000000000000002`, 1, 1.0500000000000014`], 
     Hue[1., 1, 1.0500000000000007`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.5516429693393794, 1, -17.474999625757572`], 
     Hue[0.5516429693393794, 1, -17.100757209075603`], 
     Hue[0.5516429693393794, 1, -16.726514792393633`], 
     Hue[0.5516429693393794, 1, -16.35227237571166], 
     Hue[0.5516429693393794, 1, -15.97802995902969], 
     Hue[0.5516429693393794, 1, -15.603787542347721`], 
     Hue[0.5516429693393794, 1, -15.229545125665748`], 
     Hue[0.5516429693393795, 1, -14.855302708983777`], 
     Hue[0.5516429693393796, 1, -14.481060292301803`], 
     Hue[0.5516429693393801, 1, -14.106817875619829`], 
     Hue[0.551642969339381, 1, -13.73257545893785], 
     Hue[0.5516429693393827, 1, -13.358333042255863`], 
     Hue[0.551642969339387, 1, -12.984090625573858`], 
     Hue[0.5516429693393958, 1, -12.609848208891806`], 
     Hue[0.5516429693394156, 1, -12.23560579220966], 
     Hue[0.5516429693394589, 1, -11.861363375527304`], 
     Hue[0.5516429693395541, 1, -11.487120958844487`], 
     Hue[0.5516429693397638, 1, -11.112878542160656`], 
     Hue[0.5516429693402245, 1, -10.738636125474597`], 
     Hue[0.5516429693412377, 1, -10.364393708783636`], 
     Hue[0.5516429693434655, 1, -9.9901512920819], 
     Hue[0.5516429693483635, 1, -9.615908875356467], 
     Hue[0.5516429693591332, 1, -9.241666458578944], 
     Hue[0.5516429693828124, 1, -8.867424041686872], 
     Hue[0.551642969434877, 1, -8.49318162454295], 
     Hue[0.5516429695493525, 1, -8.118939206845276], 
     Hue[0.5516429698010532, 1, -7.744696787930049], 
     Hue[0.5516429703544743, 1, -7.370454366337753], 
     Hue[0.5516429715712965, 1, -6.996211938859321], 
     Hue[0.5516429742467572, 1, -6.621969498438868], 
     Hue[0.551642980129367, 1, -6.247727029562445], 
     Hue[0.5516429930636274, 1, -5.873484498119079], 
     Hue[0.5516430215025632, 1, -5.499241829107989], 
     Hue[0.5516430840321385, 1, -5.124998857622635], 
     Hue[0.5516432215181475, 1, -4.750755221077201], 
     Hue[0.5516435238148962, 1, -4.376510122238152], 
     Hue[0.551644188495068, 1, -4.002261808176488], 
     Hue[0.5516456500036651, 1, -3.6280064245354176`], 
     Hue[0.5516488637433946, 1, -3.2537354959402327`], 
     Hue[0.5516559312381686, 1, -2.879430383993639], 
     Hue[0.5516714772961245, 1, -2.505050091700051], 
     Hue[0.5517056906015725, 1, -2.1305043992772505`], 
     Hue[0.5517810702254888, 1, -1.7555945576387517`], 
     Hue[0.5519475571258311, 1, -1.3798817267194072`], 
     Hue[0.5523172705226255, 1, -1.0023920320833273`], 
     Hue[0.5531482664732972, 1, -0.6209400516806487], 
     Hue[0.5550677328390844, 1, -0.23049962649007605`], 
     Hue[0.5597927327402693, 1, 0.18113375742079207`], 
     Hue[0.5734479580667541, 1, 0.647325641729295], 
     Hue[0.6371759800987523, 1, 1.274936098673996], 
     Hue[0.9144669892406215, 1, 1.4620573070150025`], 
     Hue[0.9781950112726244, 1, 1.2086892667522637`], 
     Hue[0.9918502365991098, 1, 1.1167397991257288`], 
     Hue[0.9965752365002949, 1, 1.079348831896831], 
     Hue[0.9984947028660821, 1, 1.0631508233882294`], 
     Hue[0.9993256988167538, 1, 1.0559412596675217`], 
     Hue[0.9996954122135483, 1, 1.0526939817134129`], 
     Hue[0.9998618991138905, 1, 1.051223567476039], 
     Hue[0.9999372787378069, 1, 1.050556142519512], 
     Hue[0.9999714920432549, 1, 1.050252866778682], 
     Hue[0.9999870381012109, 1, 1.050114991167065], 
     Hue[0.9999941055959848, 1, 1.0500522959024434`], 
     Hue[0.9999973193357143, 1, 1.0500237839892295`], 
     Hue[0.9999987808443113, 1, 1.050010817030129], 
     Hue[0.9999994455244832, 1, 1.0500049196504373`], 
     Hue[0.9999997478212318, 1, 1.0500022374933584`], 
     Hue[0.9999998853072408, 1, 1.050001017629896], 
     Hue[0.9999999478368162, 1, 1.0500004628265127`], 
     Hue[0.9999999762757519, 1, 1.0500002104973942`], 
     Hue[0.9999999892100123, 1, 1.0500000957359994`], 
     Hue[0.9999999950926222, 1, 1.0500000435415464`], 
     Hue[0.9999999977680828, 1, 1.0500000198030661`], 
     Hue[0.9999999989849051, 1, 1.0500000090066033`], 
     Hue[0.9999999995383262, 1, 1.05000000409628], 
     Hue[0.9999999997900269, 1, 1.0500000018630231`], 
     Hue[0.9999999999045024, 1, 1.050000000847319], 
     Hue[0.9999999999565669, 1, 1.0500000003853678`], 
     Hue[0.9999999999802462, 1, 1.0500000001752685`], 
     Hue[0.9999999999910159, 1, 1.0500000000797136`], 
     Hue[0.9999999999959139, 1, 1.0500000000362546`], 
     Hue[0.9999999999981416, 1, 1.0500000000164889`], 
     Hue[0.9999999999991548, 1, 1.0500000000074994`], 
     Hue[0.9999999999996156, 1, 1.0500000000034109`], 
     Hue[0.9999999999998251, 1, 1.0500000000015512`], 
     Hue[0.9999999999999205, 1, 1.0500000000007055`], 
     Hue[0.9999999999999638, 1, 1.050000000000321], 
     Hue[0.9999999999999836, 1, 1.050000000000146], 
     Hue[0.9999999999999926, 1, 1.0500000000000664`], 
     Hue[0.9999999999999966, 1, 1.0500000000000302`], 
     Hue[0.9999999999999984, 1, 1.0500000000000138`], 
     Hue[0.9999999999999993, 1, 1.0500000000000063`], 
     Hue[0.9999999999999997, 1, 1.050000000000003], 
     Hue[0.9999999999999999, 1, 1.0500000000000014`], 
     Hue[0.9999999999999999, 1, 1.0500000000000007`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.6770377704543111, 1, -17.474999625757572`], 
     Hue[0.6770377704543111, 1, -17.100757209075603`], 
     Hue[0.6770377704543111, 1, -16.726514792393633`], 
     Hue[0.6770377704543111, 1, -16.35227237571166], 
     Hue[0.6770377704543111, 1, -15.97802995902969], 
     Hue[0.6770377704543111, 1, -15.603787542347721`], 
     Hue[0.6770377704543113, 1, -15.229545125665748`], 
     Hue[0.6770377704543116, 1, -14.855302708983777`], 
     Hue[0.677037770454312, 1, -14.481060292301807`], 
     Hue[0.6770377704543131, 1, -14.106817875619832`], 
     Hue[0.6770377704543155, 1, -13.732575458937857`], 
     Hue[0.6770377704543207, 1, -13.358333042255879`], 
     Hue[0.6770377704543321, 1, -12.984090625573891`], 
     Hue[0.6770377704543573, 1, -12.609848208891883`], 
     Hue[0.6770377704544128, 1, -12.23560579220983], 
     Hue[0.6770377704545347, 1, -11.86136337552768], 
     Hue[0.6770377704548028, 1, -11.487120958845313`], 
     Hue[0.6770377704553923, 1, -11.112878542162473`], 
     Hue[0.6770377704566883, 1, -10.738636125478594`], 
     Hue[0.6770377704595382, 1, -10.364393708792427`], 
     Hue[0.6770377704658042, 1, -9.990151292101226], 
     Hue[0.6770377704795811, 1, -9.615908875398963], 
     Hue[0.6770377705098729, 1, -9.241666458672377], 
     Hue[0.6770377705764763, 1, -8.867424041892308], 
     Hue[0.6770377707229189, 1, -8.493181624994648], 
     Hue[0.6770377710449067, 1, -8.118939207838434], 
     Hue[0.6770377717528699, 1, -7.744696790113731], 
     Hue[0.6770377733094882, 1, -7.370454371139076], 
     Hue[0.6770377767320676, 1, -6.996211949416122], 
     Hue[0.677037784257387, 1, -6.621969521650402], 
     Hue[0.6770378008035149, 1, -6.247727080598288], 
     Hue[0.6770378371839469, 1, -5.873484610333028], 
     Hue[0.677037917174631, 1, -5.499242075836074], 
     Hue[0.6770380930524855, 1, -5.124999400111382], 
     Hue[0.6770384797606306, 1, -4.750756413866608], 
     Hue[0.6770393300297148, 1, -4.3765127448787124`], 
     Hue[0.6770411995554763, 1, -4.002267574753364], 
     Hue[0.6770453102093492, 1, -3.6280191041741547`], 
     Hue[0.6770543487854186, 1, -3.253763377465021], 
     Hue[0.6770742239321831, 1, -2.879491699737166], 
     Hue[0.6771179325739201, 1, -2.505184965707995], 
     Hue[0.6772140775843188, 1, -2.130801228148414], 
     Hue[0.6774256753808175, 1, -1.7562485479873955`], 
     Hue[0.6778918926755437, 1, -1.381326195912169], 
     Hue[0.6789216637031279, 1, -1.0055997994422816`], 
     Hue[0.6812083891216751, 1, -0.6281492314495081], 
     Hue[0.6863437636429082, 1, -0.247133298549298], 
     Hue[0.6981328782358318, 1, 0.14047747956051604`], 
     Hue[0.7260755824104604, 1, 0.5350160562122311], 
     Hue[0.7902669973896976, 1, 0.8992777374653128], 
     Hue[0.8867707730646103, 1, 1.0863989458063026`], 
     Hue[0.9509621880438491, 1, 1.0963796812351954`], 
     Hue[0.9789048922184788, 1, 1.0760835212654516`], 
     Hue[0.9906940068114027, 1, 1.0627151598376086`], 
     Hue[0.9958293813326358, 1, 1.0559416436193696`], 
     Hue[0.9981161067511831, 1, 1.0527334923085676`], 
     Hue[0.9991458777787674, 1, 1.0512495125206511`], 
     Hue[0.9996120950734936, 1, 1.0505695771273955`], 
     Hue[0.9998236928699923, 1, 1.0502593136483482`], 
     Hue[0.9999198378803911, 1, 1.050117992770738], 
     Hue[0.999963546522128, 1, 1.050053675423538], 
     Hue[0.9999834216688925, 1, 1.0500244143776554`], 
     Hue[0.999992460244962, 1, 1.0500111043504927`], 
     Hue[0.9999965708988349, 1, 1.0500050504532532`], 
     Hue[0.9999984404245963, 1, 1.0500022970098766`], 
     Hue[0.9999992906936804, 1, 1.0500010447039525`], 
     Hue[0.9999996774018256, 1, 1.050000475141149], 
     Hue[0.99999985327968, 1, 1.0500002160984283`], 
     Hue[0.9999999332703642, 1, 1.0500000982834454`], 
     Hue[0.9999999696507962, 1, 1.0500000447001567`], 
     Hue[0.9999999861969241, 1, 1.0500000203300142`], 
     Hue[0.9999999937222436, 1, 1.050000009246264], 
     Hue[0.9999999971448229, 1, 1.0500000042052797`], 
     Hue[0.9999999987014411, 1, 1.0500000019125972`], 
     Hue[0.9999999994094043, 1, 1.0500000008698656`], 
     Hue[0.9999999997313921, 1, 1.0500000003956222`], 
     Hue[0.9999999998778348, 1, 1.0500000001799323`], 
     Hue[0.9999999999444382, 1, 1.0500000000818348`], 
     Hue[0.99999999997473, 1, 1.0500000000372192`], 
     Hue[0.999999999988507, 1, 1.0500000000169276`], 
     Hue[0.9999999999947728, 1, 1.050000000007699], 
     Hue[0.9999999999976227, 1, 1.0500000000035017`], 
     Hue[0.9999999999989188, 1, 1.0500000000015925`], 
     Hue[0.9999999999995083, 1, 1.0500000000007244`], 
     Hue[0.9999999999997764, 1, 1.0500000000003293`], 
     Hue[0.9999999999998983, 1, 1.05000000000015], 
     Hue[0.9999999999999537, 1, 1.0500000000000682`], 
     Hue[0.9999999999999789, 1, 1.0500000000000311`], 
     Hue[0.9999999999999905, 1, 1.0500000000000143`], 
     Hue[0.9999999999999957, 1, 1.0500000000000065`], 
     Hue[0.999999999999998, 1, 1.050000000000003], 
     Hue[0.9999999999999991, 1, 1.0500000000000014`], 
     Hue[0.9999999999999996, 1, 1.0500000000000007`], 
     Hue[0.9999999999999998, 1, 1.0500000000000003`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.8024325715692429, 1, -17.474999625757572`], 
     Hue[0.8024325715692429, 1, -17.100757209075603`], 
     Hue[0.8024325715692429, 1, -16.726514792393633`], 
     Hue[0.8024325715692429, 1, -16.35227237571166], 
     Hue[0.8024325715692429, 1, -15.97802995902969], 
     Hue[0.802432571569243, 1, -15.603787542347721`], 
     Hue[0.8024325715692431, 1, -15.229545125665748`], 
     Hue[0.8024325715692433, 1, -14.855302708983777`], 
     Hue[0.8024325715692437, 1, -14.481060292301807`], 
     Hue[0.8024325715692449, 1, -14.106817875619837`], 
     Hue[0.8024325715692474, 1, -13.73257545893787], 
     Hue[0.802432571569253, 1, -13.358333042255902`], 
     Hue[0.8024325715692651, 1, -12.984090625573945`], 
     Hue[0.8024325715692917, 1, -12.609848208892002`], 
     Hue[0.8024325715693501, 1, -12.23560579221009], 
     Hue[0.8024325715694789, 1, -11.861363375528251`], 
     Hue[0.8024325715697618, 1, -11.487120958846567`], 
     Hue[0.8024325715703837, 1, -11.11287854216523], 
     Hue[0.8024325715717514, 1, -10.738636125484657`], 
     Hue[0.8024325715747583, 1, -10.364393708805753`], 
     Hue[0.8024325715813699, 1, -9.990151292130529], 
     Hue[0.8024325715959071, 1, -9.61590887546339], 
     Hue[0.8024325716278702, 1, -9.241666458814036], 
     Hue[0.8024325716981483, 1, -8.867424042203778], 
     Hue[0.8024325718526708, 1, -8.493181625679483], 
     Hue[0.8024325721924236, 1, -8.118939209344202], 
     Hue[0.8024325729394475, 1, -7.744696793424505], 
     Hue[0.8024325745819494, 1, -7.370454378418567], 
     Hue[0.8024325781933634, 1, -6.996211965421739], 
     Hue[0.8024325861338786, 1, -6.621969556842387], 
     Hue[0.8024326035929065, 1, -6.2477271579758735`], 
     Hue[0.8024326419805461, 1, -5.873484780465257], 
     Hue[0.8024327263844817, 1, -5.499242449910506], 
     Hue[0.8024329119656262, 1, -5.125000222599234], 
     Hue[0.8024333200074669, 1, -4.750758222293829], 
     Hue[0.8024342171777566, 1, -4.376516721120148], 
     Hue[0.8024361897985596, 1, -4.002276317438279], 
     Hue[0.8024405269953178, 1, -3.6280383270215353`], 
     Hue[0.8024500630247247, 1, -3.2538056435859017`], 
     Hue[0.8024710287801348, 1, -2.879584632954691], 
     Hue[0.8025171201159598, 1, -2.505389307931842], 
     Hue[0.8026184302485346, 1, -2.1312505565759015`], 
     Hue[0.802841027948705, 1, -1.7572366681956353`], 
     Hue[0.8033297046507, 1, -1.3834995956565568`], 
     Hue[0.804400496623534, 1, -1.0103820630972982`], 
     Hue[0.8067368539675506, 1, -0.638678273025785], 
     Hue[0.8117842457431501, 1, -0.27031987460050755`], 
     Hue[0.8224275585999826, 1, 0.08966825138852885], 
     Hue[0.843516210615142, 1, 0.4276924306652654], 
     Hue[0.8792304804984329, 1, 0.7115455209123686], 
     Hue[0.9232020910708085, 1, 0.8986667292533561], 
     Hue[0.9589163609540998, 1, 0.9890560556882269], 
     Hue[0.9800050129692597, 1, 1.0252742930934629`], 
     Hue[0.9906483258260924, 1, 1.0395285837863983`], 
     Hue[0.9956957176016922, 1, 1.0454126020430923`], 
     Hue[0.9980320749457088, 1, 1.0479512286535506`], 
     Hue[0.9991028669185429, 1, 1.0490761127762631`], 
     Hue[0.9995915436205378, 1, 1.049581456919156], 
     Hue[0.9998141413207082, 1, 1.0498099852208609`], 
     Hue[0.9999154514532831, 1, 1.0499136505468911`], 
     Hue[0.9999615427891081, 1, 1.049960742206013], 
     Hue[0.9999825085445182, 1, 1.0499821482567746`], 
     Hue[0.9999920445739251, 1, 1.0499918815031115`], 
     Hue[0.9999963817706832, 1, 1.049996307768338], 
     Hue[0.9999983543914862, 1, 1.049998320768441], 
     Hue[0.9999992515617759, 1, 1.0499992362767308`], 
     Hue[0.9999996596036166, 1, 1.0499996526532962`], 
     Hue[0.9999998451847611, 1, 1.0499998420239958`], 
     Hue[0.9999999295886968, 1, 1.0499999281512158`], 
     Hue[0.9999999679763364, 1, 1.0499999673225706`], 
     Hue[0.9999999854353642, 1, 1.0499999851380286`], 
     Hue[0.9999999933758794, 1, 1.0499999932406492`], 
     Hue[0.9999999969872935, 1, 1.0499999969257896`], 
     Hue[0.9999999986297954, 1, 1.0499999986018231`], 
     Hue[0.9999999993768193, 1, 1.0499999993640972`], 
     Hue[0.999999999716572, 1, 1.049999999710786], 
     Hue[0.9999999998710946, 1, 1.049999999868463], 
     Hue[0.9999999999413727, 1, 1.049999999940176], 
     Hue[0.9999999999733358, 1, 1.0499999999727916`], 
     Hue[0.9999999999878729, 1, 1.0499999999876253`], 
     Hue[0.9999999999944845, 1, 1.0499999999943719`], 
     Hue[0.9999999999974915, 1, 1.0499999999974403`], 
     Hue[0.9999999999988591, 1, 1.0499999999988359`], 
     Hue[0.9999999999994811, 1, 1.0499999999994705`], 
     Hue[0.999999999999764, 1, 1.0499999999997593`], 
     Hue[0.9999999999998926, 1, 1.0499999999998906`], 
     Hue[0.9999999999999512, 1, 1.0499999999999503`], 
     Hue[0.9999999999999778, 1, 1.0499999999999774`], 
     Hue[0.9999999999999899, 1, 1.0499999999999896`], 
     Hue[0.9999999999999954, 1, 1.0499999999999954`], 
     Hue[0.9999999999999979, 1, 1.0499999999999978`], 
     Hue[0.999999999999999, 1, 1.0499999999999992`], 
     Hue[0.9999999999999996, 1, 1.0499999999999996`], 
     Hue[0.9999999999999998, 1, 1.0499999999999998`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.927827372684174, 1, -17.474999625757572`], 
     Hue[0.927827372684174, 1, -17.100757209075603`], 
     Hue[0.927827372684174, 1, -16.726514792393633`], 
     Hue[0.927827372684174, 1, -16.35227237571166], 
     Hue[0.927827372684174, 1, -15.97802995902969], 
     Hue[0.927827372684174, 1, -15.603787542347721`], 
     Hue[0.9278273726841741, 1, -15.229545125665748`], 
     Hue[0.9278273726841743, 1, -14.855302708983777`], 
     Hue[0.9278273726841745, 1, -14.48106029230181], 
     Hue[0.927827372684175, 1, -14.106817875619843`], 
     Hue[0.9278273726841761, 1, -13.732575458937879`], 
     Hue[0.9278273726841787, 1, -13.358333042255921`], 
     Hue[0.9278273726841844, 1, -12.984090625573986`], 
     Hue[0.9278273726841966, 1, -12.609848208892089`], 
     Hue[0.9278273726842237, 1, -12.235605792210283`], 
     Hue[0.9278273726842833, 1, -11.86136337552868], 
     Hue[0.9278273726844143, 1, -11.487120958847509`], 
     Hue[0.9278273726847023, 1, -11.112878542167302`], 
     Hue[0.9278273726853354, 1, -10.73863612548921], 
     Hue[0.9278273726867277, 1, -10.364393708815763`], 
     Hue[0.9278273726897888, 1, -9.99015129215254], 
     Hue[0.9278273726965193, 1, -9.615908875511783], 
     Hue[0.9278273727113178, 1, -9.241666458920442], 
     Hue[0.9278273727438558, 1, -8.867424042437733], 
     Hue[0.9278273728153982, 1, -8.493181626193884], 
     Hue[0.9278273729727001, 1, -8.118939210475233], 
     Hue[0.9278273733185644, 1, -7.744696795911335], 
     Hue[0.9278273740790254, 1, -7.370454383886428], 
     Hue[0.927827375751072, 1, -6.996211977444074], 
     Hue[0.9278273794274465, 1, -6.6219695832762255`], 
     Hue[0.927827387510791, 1, -6.247727216096675], 
     Hue[0.9278274052838567, 1, -5.873484908257019], 
     Hue[0.9278274443619557, 1, -5.499242730889573], 
     Hue[0.9278275302839073, 1, -5.125000840394695], 
     Hue[0.9278277192021933, 1, -4.750759580653183], 
     Hue[0.9278281345787831, 1, -4.376519707760427], 
     Hue[0.9278290478630579, 1, -4.002282884141163], 
     Hue[0.9278310558506535, 1, -3.6280527649032397`], 
     Hue[0.9278354705025494, 1, -3.2538373860956735`], 
     Hue[0.927845175351854, 1, -2.8796544142041727`], 
     Hue[0.9278665051313415, 1, -2.5055426804678067`], 
     Hue[0.9279133622592554, 1, -2.1315875035546394`], 
     Hue[0.928016189327566, 1, -1.7579761829997695`], 
     Hue[0.9282413203367438, 1, -1.3851191254119588`], 
     Hue[0.9287317373675801, 1, -1.0139118916545284`], 
     Hue[0.9297883367684078, 1, -0.6462909137713417], 
     Hue[0.9320114142156339, 1, -0.2863589352119049], 
     Hue[0.9364615850973316, 1, 0.05757881287752564], 
     Hue[0.9445295643351445, 1, 0.3703481845074307], 
     Hue[0.9567782989285774, 1, 0.6298774910888825], 
     Hue[0.9710490737555961, 1, 0.8169986994298695], 
     Hue[0.9832978083490292, 1, 0.9317118095303913], 
     Hue[0.9913657875868422, 1, 0.9931848545824592], 
     Hue[0.99581595846854, 1, 1.0234895231750005`], 
     Hue[0.9980390359157661, 1, 1.0377999612975355`], 
     Hue[0.9990956353165938, 1, 1.0444214000963201`], 
     Hue[0.9995860523474301, 1, 1.0474565830208609`], 
     Hue[0.999811183356608, 1, 1.0488419421150212`], 
     Hue[0.9999140104249187, 1, 1.0494730382421231`], 
     Hue[0.9999608675528325, 1, 1.0497602780109263`], 
     Hue[0.9999821973323201, 1, 1.0498909609565312`], 
     Hue[0.9999919021816246, 1, 1.0499504057470028`], 
     Hue[0.9999963168335205, 1, 1.0499774436214073`], 
     Hue[0.9999983248211162, 1, 1.0499897410654548`], 
     Hue[0.9999992381053909, 1, 1.0499953341281618`], 
     Hue[0.9999996534819806, 1, 1.0499978779173769`], 
     Hue[0.9999998424002667, 1, 1.0499990348578354`], 
     Hue[0.9999999283222183, 1, 1.04999956104493], 
     Hue[0.9999999674003174, 1, 1.0499998003594535`], 
     Hue[0.9999999851733831, 1, 1.0499999092017696`], 
     Hue[0.9999999932567275, 1, 1.049999958704189], 
     Hue[0.999999996933102, 1, 1.0499999812183127`], 
     Hue[0.9999999986051487, 1, 1.0499999914579285`], 
     Hue[0.9999999993656097, 1, 1.049999996114993], 
     Hue[0.9999999997114739, 1, 1.0499999982330657`], 
     Hue[0.9999999998687759, 1, 1.0499999991963833`], 
     Hue[0.9999999999403182, 1, 1.0499999996345084`], 
     Hue[0.9999999999728562, 1, 1.0499999998337712`], 
     Hue[0.9999999999876548, 1, 1.0499999999243979`], 
     Hue[0.9999999999943853, 1, 1.0499999999656155`], 
     Hue[0.9999999999974464, 1, 1.0499999999843617`], 
     Hue[0.9999999999988386, 1, 1.0499999999928875`], 
     Hue[0.9999999999994718, 1, 1.0499999999967653`], 
     Hue[0.9999999999997597, 1, 1.0499999999985288`], 
     Hue[0.9999999999998908, 1, 1.049999999999331], 
     Hue[0.9999999999999503, 1, 1.0499999999996958`], 
     Hue[0.9999999999999774, 1, 1.0499999999998617`], 
     Hue[0.9999999999999897, 1, 1.049999999999937], 
     Hue[0.9999999999999953, 1, 1.0499999999999714`], 
     Hue[0.9999999999999979, 1, 1.0499999999999872`], 
     Hue[0.999999999999999, 1, 1.049999999999994], 
     Hue[0.9999999999999996, 1, 1.0499999999999974`], 
     Hue[0.9999999999999998, 1, 1.0499999999999987`], 
     Hue[0.9999999999999999, 1, 1.0499999999999996`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.0532221737991057`, 1, -17.474999625757572`], 
     Hue[1.0532221737991059`, 1, -17.100757209075603`], 
     Hue[1.0532221737991057`, 1, -16.726514792393633`], 
     Hue[1.0532221737991057`, 1, -16.35227237571166], 
     Hue[1.0532221737991057`, 1, -15.97802995902969], 
     Hue[1.0532221737991057`, 1, -15.603787542347721`], 
     Hue[1.0532221737991057`, 1, -15.229545125665748`], 
     Hue[1.0532221737991057`, 1, -14.855302708983777`], 
     Hue[1.0532221737991054`, 1, -14.48106029230181], 
     Hue[1.053222173799105, 1, -14.106817875619843`], 
     Hue[1.053222173799104, 1, -13.732575458937879`], 
     Hue[1.0532221737991023`, 1, -13.358333042255923`], 
     Hue[1.053222173799098, 1, -12.98409062557399], 
     Hue[1.0532221737990888`, 1, -12.609848208892096`], 
     Hue[1.0532221737990686`, 1, -12.2356057922103], 
     Hue[1.053222173799024, 1, -11.861363375528713`], 
     Hue[1.0532221737989258`, 1, -11.487120958847584`], 
     Hue[1.05322217379871, 1, -11.112878542167465`], 
     Hue[1.0532221737982357`, 1, -10.73863612548957], 
     Hue[1.0532221737971927`, 1, -10.364393708816559`], 
     Hue[1.0532221737948992`, 1, -9.990151292154286], 
     Hue[1.053222173789857, 1, -9.615908875515625], 
     Hue[1.0532221737787704`, 1, -9.241666458928888], 
     Hue[1.0532221737543936`, 1, -8.867424042456303], 
     Hue[1.0532221737007958`, 1, -8.493181626234719], 
     Hue[1.0532221735829492`, 1, -8.118939210565012], 
     Hue[1.0532221733238363`, 1, -7.744696796108735], 
     Hue[1.0532221727541176`, 1, -7.370454384320456], 
     Hue[1.0532221715014616`, 1, -6.9962119783983825`], 
     Hue[1.0532221687472128`, 1, -6.621969585374491], 
     Hue[1.0532221626913711`, 1, -6.247727220710188], 
     Hue[1.0532221493762302`, 1, -5.873484918400873], 
     Hue[1.0532221200998868`, 1, -5.49924275319312], 
     Hue[1.053222055729295, 1, -5.1250008894340064`], 
     Hue[1.0532219141964336`, 1, -4.750759688476725], 
     Hue[1.0532216030067905`, 1, -4.376519944832409], 
     Hue[1.0532209187978885`, 1, -4.002283405385255], 
     Hue[1.0532194144685176`, 1, -3.6280539109160976`], 
     Hue[1.053216107146009, 1, -3.2538399055715015`], 
     Hue[1.0532088366362375`, 1, -2.8796599524233333`], 
     Hue[1.053192857488656, 1, -2.5055548506340104`], 
     Hue[1.0531577561617997`, 1, -2.1316142292709994`], 
     Hue[1.0530807345046957`, 1, -1.758034785694172], 
     Hue[1.0529121382198032`, 1, -1.3852472086143959`], 
     Hue[1.0525450440969244`, 1, -1.0141898478578055`], 
     Hue[1.0517549201965053`, 1, -0.6468848649544416], 
     Hue[1.050095845211266, 1, -0.287586866166027], 
     Hue[1.0467872431845349`, 1, 0.05520807364461233], 
     Hue[1.0408247230812149`, 1, 0.36633819773215004`], 
     Hue[1.031832808891585, 1, 0.6244543282663124], 
     Hue[1.0213893649075212`, 1, 0.8115755366072994], 
     Hue[1.012397450717891, 1, 0.9277018227551105], 
     Hue[1.006434930614571, 1, 0.9908141153495456], 
     Hue[1.0031263285878398`, 1, 1.0222615922208784`], 
     Hue[1.0014672536026006`, 1, 1.0372060101144356`], 
     Hue[1.0006771297021815`, 1, 1.044143443893043], 
     Hue[1.0003100355793024`, 1, 1.0473284998184242`], 
     Hue[1.0001414392944101`, 1, 1.0487833394206194`], 
     Hue[1.0000644176373061`, 1, 1.0494463125257634`], 
     Hue[1.00002931631045, 1, 1.0497481078447228`], 
     Hue[1.000013337162868, 1, 1.0498854227373708`], 
     Hue[1.0000060666530968`, 1, 1.049947886271175], 
     Hue[1.0000027593305882`, 1, 1.0499762976085492`], 
     Hue[1.0000012550012172`, 1, 1.0499892198213627`], 
     Hue[1.0000005707923154`, 1, 1.04999509705618], 
     Hue[1.0000002596026722`, 1, 1.0499977700938345`], 
     Hue[1.0000001180698106`, 1, 1.049998985818524], 
     Hue[1.000000053699219, 1, 1.0499995387413823`], 
     Hue[1.0000000244228755`, 1, 1.0499997902155995`], 
     Hue[1.0000000111077347`, 1, 1.049999904588256], 
     Hue[1.000000005051893, 1, 1.0499999566059233`], 
     Hue[1.000000002297644, 1, 1.0499999802640037`], 
     Hue[1.000000001044988, 1, 1.0499999910239006`], 
     Hue[1.0000000004752696`, 1, 1.0499999959175934`], 
     Hue[1.0000000002161566`, 1, 1.0499999981432868`], 
     Hue[1.0000000000983098`, 1, 1.049999999155551], 
     Hue[1.0000000000447122`, 1, 1.0499999996159373`], 
     Hue[1.0000000000203355`, 1, 1.049999999825325], 
     Hue[1.0000000000092488`, 1, 1.0499999999205565`], 
     Hue[1.0000000000042064`, 1, 1.0499999999638683`], 
     Hue[1.0000000000019131`, 1, 1.0499999999835672`], 
     Hue[1.0000000000008702`, 1, 1.0499999999925262`], 
     Hue[1.0000000000003957`, 1, 1.049999999996601], 
     Hue[1.00000000000018, 1, 1.049999999998454], 
     Hue[1.000000000000082, 1, 1.049999999999297], 
     Hue[1.0000000000000373`, 1, 1.0499999999996803`], 
     Hue[1.0000000000000169`, 1, 1.0499999999998546`], 
     Hue[1.0000000000000078`, 1, 1.0499999999999339`], 
     Hue[1.0000000000000036`, 1, 1.04999999999997], 
     Hue[1.0000000000000016`, 1, 1.0499999999999863`], 
     Hue[1.0000000000000007`, 1, 1.0499999999999938`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999972`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999987`], 
     Hue[1., 1, 1.0499999999999994`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.1786169749140374`, 1, -17.474999625757572`], 
     Hue[1.1786169749140376`, 1, -17.100757209075603`], 
     Hue[1.1786169749140374`, 1, -16.726514792393633`], 
     Hue[1.1786169749140374`, 1, -16.35227237571166], 
     Hue[1.1786169749140374`, 1, -15.97802995902969], 
     Hue[1.1786169749140374`, 1, -15.603787542347721`], 
     Hue[1.1786169749140374`, 1, -15.229545125665748`], 
     Hue[1.178616974914037, 1, -14.855302708983777`], 
     Hue[1.1786169749140365`, 1, -14.481060292301807`], 
     Hue[1.1786169749140356`, 1, -14.10681787561984], 
     Hue[1.1786169749140332`, 1, -13.732575458937871`], 
     Hue[1.1786169749140278`, 1, -13.358333042255905`], 
     Hue[1.1786169749140163`, 1, -12.984090625573954`], 
     Hue[1.178616974913991, 1, -12.609848208892018`], 
     Hue[1.1786169749139352`, 1, -12.235605792210126`], 
     Hue[1.1786169749138127`, 1, -11.861363375528333`], 
     Hue[1.1786169749135433`, 1, -11.487120958846749`], 
     Hue[1.1786169749129511`, 1, -11.112878542165628`], 
     Hue[1.1786169749116486`, 1, -10.738636125485527`], 
     Hue[1.1786169749087851`, 1, -10.364393708807668`], 
     Hue[1.1786169749024888`, 1, -9.99015129213474], 
     Hue[1.178616974888645, 1, -9.615908875472652], 
     Hue[1.1786169748582065`, 1, -9.241666458834397], 
     Hue[1.17861697479128, 1, -8.867424042248546], 
     Hue[1.1786169746441275`, 1, -8.493181625777916], 
     Hue[1.178616974320579, 1, -8.118939209560633], 
     Hue[1.1786169736091838`, 1, -7.744696793900377], 
     Hue[1.1786169720450201`, 1, -7.370454379464879], 
     Hue[1.1786169686058503`, 1, -6.996211967722293], 
     Hue[1.1786169610440533`, 1, -6.621969561900679], 
     Hue[1.1786169444177237`, 1, -6.247727169097678], 
     Hue[1.178616907860962, 1, -5.87348480491907], 
     Hue[1.1786168274826343`, 1, -5.4992425036777535`], 
     Hue[1.1786166507527338`, 1, -5.125000340818647], 
     Hue[1.1786162621725105`, 1, -4.750758482225566], 
     Hue[1.1786154077937088`, 1, -4.376517292636621], 
     Hue[1.178613529263088, 1, -4.002277574034786], 
     Hue[1.1786093989612485`, 1, -3.6280410898745465`], 
     Hue[1.1786003179159321`, 1, -3.2538117180554202`], 
     Hue[1.1785803529261654`, 1, -2.879597987649282], 
     Hue[1.178536463835306, 1, -2.5054186644551404`], 
     Hue[1.1784400046930008`, 1, -2.131315070627128], 
     Hue[1.1782281156652041`, 1, -1.7573783575633308`], 
     Hue[1.1777631892397848`, 1, -1.383810359138652], 
     Hue[1.1767455925082948`, 1, -1.0110615907425842`], 
     Hue[1.1745307468616955`, 1, -0.6401540062485553], 
     Hue[1.1697707991988122`, 1, -0.27347402657258635`], 
     Hue[1.1598396876096473`, 1, 0.08318291532396371], 
     Hue[1.1405365401948948`, 1, 0.41559453399367974`], 
     Hue[1.108665500217313, 1, 0.6935906185428118], 
     Hue[1.069951474696726, 1, 0.8807118268837991], 
     Hue[1.0380804347191437`, 1, 0.9769581590166412], 
     Hue[1.0187772873043908`, 1, 1.0187889570288977`], 
     Hue[1.0088461757152254`, 1, 1.0363744318143193`], 
     Hue[1.0040862280523422`, 1, 1.0439368688203219`], 
     Hue[1.0018713824057428`, 1, 1.0472717010082642`], 
     Hue[1.0008537856742528`, 1, 1.0487653492941678`], 
     Hue[1.0003888592488333`, 1, 1.0494397675514602`], 
     Hue[1.0001769702210366`, 1, 1.0497454711696343`], 
     Hue[1.0000805110787314`, 1, 1.049884294023593], 
     Hue[1.0000366219878722`, 1, 1.049947387511423], 
     Hue[1.0000166569981055`, 1, 1.0499760737872557`], 
     Hue[1.000007575952789, 1, 1.0499891186501007`], 
     Hue[1.0000034456509495`, 1, 1.049995051171831], 
     Hue[1.0000015671203286`, 1, 1.049997749251968], 
     Hue[1.000000712741527, 1, 1.0499989763449942`], 
     Hue[1.0000003241613038`, 1, 1.0499995344338837`], 
     Hue[1.0000001474314033`, 1, 1.049999788256749], 
     Hue[1.0000000670530755`, 1, 1.049999903697403], 
     Hue[1.0000000304963137`, 1, 1.049999956200766], 
     Hue[1.0000000138699843`, 1, 1.0499999800797366`], 
     Hue[1.000000006308187, 1, 1.0499999909400948`], 
     Hue[1.0000000028690172`, 1, 1.0499999958794781`], 
     Hue[1.0000000013048536`, 1, 1.0499999981259516`], 
     Hue[1.0000000005934586`, 1, 1.0499999991476667`], 
     Hue[1.00000000026991, 1, 1.0499999996123517`], 
     Hue[1.0000000001227574`, 1, 1.0499999998236942`], 
     Hue[1.0000000000558311`, 1, 1.0499999999198146`], 
     Hue[1.0000000000253924`, 1, 1.049999999963531], 
     Hue[1.0000000000115488`, 1, 1.0499999999834135`], 
     Hue[1.0000000000052525`, 1, 1.0499999999924565`], 
     Hue[1.0000000000023888`, 1, 1.0499999999965692`], 
     Hue[1.0000000000010865`, 1, 1.0499999999984395`], 
     Hue[1.000000000000494, 1, 1.0499999999992904`], 
     Hue[1.0000000000002247`, 1, 1.0499999999996772`], 
     Hue[1.0000000000001021`, 1, 1.0499999999998533`], 
     Hue[1.0000000000000464`, 1, 1.0499999999999332`], 
     Hue[1.000000000000021, 1, 1.0499999999999696`], 
     Hue[1.0000000000000095`, 1, 1.0499999999999863`], 
     Hue[1.0000000000000044`, 1, 1.0499999999999936`], 
     Hue[1.000000000000002, 1, 1.0499999999999972`], 
     Hue[1.0000000000000009`, 1, 1.0499999999999987`], 
     Hue[1.0000000000000004`, 1, 1.0499999999999994`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.3040117760289687`, 1, -17.474999625757572`], 
     Hue[1.3040117760289687`, 1, -17.100757209075603`], 
     Hue[1.3040117760289687`, 1, -16.726514792393633`], 
     Hue[1.3040117760289687`, 1, -16.35227237571166], 
     Hue[1.3040117760289687`, 1, -15.97802995902969], 
     Hue[1.3040117760289687`, 1, -15.603787542347721`], 
     Hue[1.3040117760289685`, 1, -15.229545125665748`], 
     Hue[1.3040117760289682`, 1, -14.855302708983777`], 
     Hue[1.3040117760289678`, 1, -14.481060292301807`], 
     Hue[1.3040117760289665`, 1, -14.106817875619834`], 
     Hue[1.3040117760289642`, 1, -13.732575458937859`], 
     Hue[1.3040117760289585`, 1, -13.358333042255882`], 
     Hue[1.3040117760289465`, 1, -12.984090625573899`], 
     Hue[1.30401177602892, 1, -12.6098482088919], 
     Hue[1.3040117760288616`, 1, -12.235605792209867`], 
     Hue[1.3040117760287335`, 1, -11.86136337552776], 
     Hue[1.3040117760284515`, 1, -11.487120958845493`], 
     Hue[1.3040117760278318`, 1, -11.112878542162868`], 
     Hue[1.304011776026469, 1, -10.738636125479463`], 
     Hue[1.3040117760234722`, 1, -10.364393708794333`], 
     Hue[1.3040117760168832`, 1, -9.990151292105422], 
     Hue[1.3040117760023962`, 1, -9.615908875408186], 
     Hue[1.3040117759705432`, 1, -9.241666458692654], 
     Hue[1.304011775900507, 1, -8.867424041936893], 
     Hue[1.3040117757465162`, 1, -8.493181625092676], 
     Hue[1.3040117754079328`, 1, -8.118939208053973], 
     Hue[1.3040117746634798`, 1, -7.744696790587644], 
     Hue[1.3040117730266307`, 1, -7.370454372181082], 
     Hue[1.304011769427646, 1, -6.996211951707209], 
     Hue[1.3040117615144589`, 1, -6.621969526687875], 
     Hue[1.304011744115516, 1, -6.247727091674318], 
     Hue[1.3040117058599774`, 1, -5.873484634686206], 
     Hue[1.3040116217464508`, 1, -5.499242129382099], 
     Hue[1.3040114368036186`, 1, -5.124999517844613], 
     Hue[1.3040110301641992`, 1, -4.750756672730442], 
     Hue[1.3040101360723564`, 1, -4.376513314052367], 
     Hue[1.3040081701955866`, 1, -4.002268826223828], 
     Hue[1.3040038477080378`, 1, -3.628021855878096], 
     Hue[1.3039943434444814`, 1, -3.253769428009134], 
     Hue[1.303973444750386, 1, -2.879505004670688], 
     Hue[1.3039274874092388`, 1, -2.505214226571244], 
     Hue[1.3038264068472953`, 1, -2.1308655983481035`], 
     Hue[1.3036039994387394`, 1, -1.756390242459272], 
     Hue[1.3031142208103241`, 1, -1.3816385244076754`], 
     Hue[1.3020336565352428`, 1, -1.0062902789014505`], 
     Hue[1.2996403066629454`, 1, -0.6296853151303123], 
     Hue[1.2942966819545538`, 1, -0.25059435980413824`], 
     Hue[1.282194216592079, 1, 0.13250334954645326`], 
     Hue[1.2544156606543357`, 1, 0.5163479815725098], 
     Hue[1.194698836220135, 1, 0.8615027234190793], 
     Hue[1.1093129398088366`, 1, 1.0486239317600685`], 
     Hue[1.0495961153746345`, 1, 1.0777116065954735`], 
     Hue[1.0218175594368903`, 1, 1.0681093912513886`], 
     Hue[1.009715094074415, 1, 1.0592540985827683`], 
     Hue[1.0043714693660233`, 1, 1.0544055599385653`], 
     Hue[1.0019781194937258`, 1, 1.0520430128493985`], 
     Hue[1.0008975552186445`, 1, 1.0509371840251447`], 
     Hue[1.0004077765902293`, 1, 1.0504278826555191`], 
     Hue[1.0001853691816733`, 1, 1.0501949434486586`], 
     Hue[1.0000842886197299`, 1, 1.050088731907489], 
     Hue[1.0000383312785828`, 1, 1.050040370490016], 
     Hue[1.0000174325844873`, 1, 1.050018363833542], 
     Hue[1.0000079283209309`, 1, 1.0500083526465513`], 
     Hue[1.000003605833382, 1, 1.050003798982789], 
     Hue[1.0000016399566123`, 1, 1.0500017278362215`], 
     Hue[1.0000007458647693`, 1, 1.0500007858401175`], 
     Hue[1.0000003392253498`, 1, 1.0500003574079173`], 
     Hue[1.0000001542825179`, 1, 1.050000162552402], 
     Hue[1.0000000701689913`, 1, 1.0500000739302668`], 
     Hue[1.0000000319134528`, 1, 1.0500000336241258`], 
     Hue[1.0000000145145098`, 1, 1.050000015292541], 
     Hue[1.0000000066013226`, 1, 1.0500000069551785`], 
     Hue[1.0000000030023377`, 1, 1.0500000031632746`], 
     Hue[1.0000000013654888`, 1, 1.0500000014386843`], 
     Hue[1.000000000621036, 1, 1.050000000654326], 
     Hue[1.0000000002824525`, 1, 1.050000000297593], 
     Hue[1.0000000001284617`, 1, 1.050000000135348], 
     Hue[1.0000000000584255`, 1, 1.0500000000615575`], 
     Hue[1.0000000000265725`, 1, 1.0500000000279968`], 
     Hue[1.0000000000120854`, 1, 1.0500000000127332`], 
     Hue[1.0000000000054965`, 1, 1.0500000000057912`], 
     Hue[1.0000000000024998`, 1, 1.050000000002634], 
     Hue[1.0000000000011369`, 1, 1.050000000001198], 
     Hue[1.0000000000005171`, 1, 1.050000000000545], 
     Hue[1.0000000000002351`, 1, 1.0500000000002478`], 
     Hue[1.000000000000107, 1, 1.0500000000001128`], 
     Hue[1.0000000000000486`, 1, 1.0500000000000513`], 
     Hue[1.0000000000000222`, 1, 1.0500000000000234`], 
     Hue[1.00000000000001, 1, 1.0500000000000107`], 
     Hue[1.0000000000000047`, 1, 1.050000000000005], 
     Hue[1.000000000000002, 1, 1.0500000000000023`], 
     Hue[1.0000000000000009`, 1, 1.0500000000000012`], 
     Hue[1.0000000000000004`, 1, 1.0500000000000005`], 
     Hue[1.0000000000000002`, 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.4294065771439004`, 1, -17.474999625757572`], 
     Hue[1.4294065771439004`, 1, -17.100757209075603`], 
     Hue[1.4294065771439004`, 1, -16.726514792393633`], 
     Hue[1.4294065771439004`, 1, -16.35227237571166], 
     Hue[1.4294065771439004`, 1, -15.97802995902969], 
     Hue[1.4294065771439004`, 1, -15.603787542347721`], 
     Hue[1.4294065771439004`, 1, -15.229545125665748`], 
     Hue[1.4294065771439002`, 1, -14.855302708983777`], 
     Hue[1.4294065771439, 1, -14.481060292301803`], 
     Hue[1.4294065771438995`, 1, -14.106817875619829`], 
     Hue[1.4294065771438982`, 1, -13.73257545893785], 
     Hue[1.429406577143896, 1, -13.358333042255865`], 
     Hue[1.4294065771438902`, 1, -12.98409062557386], 
     Hue[1.4294065771438782`, 1, -12.609848208891814`], 
     Hue[1.4294065771438518`, 1, -12.235605792209673`], 
     Hue[1.4294065771437934`, 1, -11.861363375527338`], 
     Hue[1.429406577143665, 1, -11.48712095884456], 
     Hue[1.429406577143383, 1, -11.112878542160816`], 
     Hue[1.4294065771427626`, 1, -10.73863612547495], 
     Hue[1.4294065771413988`, 1, -10.364393708784412`], 
     Hue[1.4294065771384004`, 1, -9.990151292083604], 
     Hue[1.4294065771318072`, 1, -9.615908875360217], 
     Hue[1.4294065771173106`, 1, -9.241666458587188], 
     Hue[1.4294065770854365`, 1, -8.867424041705], 
     Hue[1.4294065770153543`, 1, -8.493181624582805], 
     Hue[1.429406576861263, 1, -8.118939206932907], 
     Hue[1.4294065765224573`, 1, -7.744696788122726], 
     Hue[1.4294065757775165`, 1, -7.3704543667613995`], 
     Hue[1.4294065741395945`, 1, -6.996211939790803], 
     Hue[1.4294065705382502`, 1, -6.621969500486944], 
     Hue[1.4294065626198744`, 1, -6.2477270340656075`], 
     Hue[1.4294065452095177`, 1, -5.87348450802031], 
     Hue[1.4294065069288604`, 1, -5.4992418508781205`], 
     Hue[1.429406422759991, 1, -5.1249989054893295`], 
     Hue[1.4294062376949264`, 1, -4.750755326323545], 
     Hue[1.429405830784099, 1, -4.376510353648731], 
     Hue[1.429404936082684, 1, -4.002262316997626], 
     Hue[1.429402968803649, 1, -3.6280075433540775`], 
     Hue[1.429398642933221, 1, -3.253737956205949], 
     Hue[1.429389129782509, 1, -2.8794357948420277`], 
     Hue[1.429368204538559, 1, -2.505061995426888], 
     Hue[1.4293221548951696`, 1, -2.1305306049824635`], 
     Hue[1.4292207069462486`, 1, -1.7556523351520477`], 
     Hue[1.4289966922407482`, 1, -1.3800095338334863`], 
     Hue[1.4284994656517773`, 1, -1.002676819556678], 
     Hue[1.4273830742502633`, 1, -0.621585031789039], 
     Hue[1.4248110226836856`, 1, -0.23201507456971293`], 
     Hue[1.4185219977735053`, 1, 0.1772529761050834], 
     Hue[1.4007432406355478`, 1, 0.6349818572667087], 
     Hue[1.3279670761234876`, 1, 1.2052710957555237`], 
     Hue[1.101439501020418, 1, 1.3923923040965247`], 
     Hue[1.0286633365083537`, 1, 1.196345482289677], 
     Hue[1.0108845793703953`, 1, 1.11285901781002], 
     Hue[1.0045955544602148`, 1, 1.0778333838171943`], 
     Hue[1.002023502893637, 1, 1.0625058432798389`], 
     Hue[1.000907111492123, 1, 1.0556564721941708`], 
     Hue[1.0004098849031522`, 1, 1.0525661745993333`], 
     Hue[1.0001858701976516`, 1, 1.0511657899627436`], 
     Hue[1.0000844222487308`, 1, 1.0505299368142993`], 
     Hue[1.0000383726053415`, 1, 1.0502409630518452`], 
     Hue[1.0000174473613914`, 1, 1.0501095803186768`], 
     Hue[1.0000079342106794`, 1, 1.050049835636727], 
     Hue[1.0000036083402513`, 1, 1.0500226651705693`], 
     Hue[1.0000016410612165`, 1, 1.0500103082089918`], 
     Hue[1.0000007463598013`, 1, 1.0500046882398575`], 
     Hue[1.000000339448974, 1, 1.0500021322470143`], 
     Hue[1.0000001543839094`, 1, 1.0500009697632016`], 
     Hue[1.00000007021504, 1, 1.0500004410563817`], 
     Hue[1.0000000319343827`, 1, 1.0500002005961633`], 
     Hue[1.0000000145240262`, 1, 1.050000091232837], 
     Hue[1.0000000066056502`, 1, 1.0500000414934705`], 
     Hue[1.000000003004306, 1, 1.050000018871584], 
     Hue[1.000000001366384, 1, 1.050000008582957], 
     Hue[1.0000000006214431`, 1, 1.0500000039036022`], 
     Hue[1.0000000002826377`, 1, 1.0500000017753917`], 
     Hue[1.000000000128546, 1, 1.0500000008074633`], 
     Hue[1.000000000058464, 1, 1.0500000003672412`], 
     Hue[1.0000000000265898`, 1, 1.0500000001670244`], 
     Hue[1.0000000000120932`, 1, 1.0500000000759642`], 
     Hue[1.0000000000055, 1, 1.0500000000345493`], 
     Hue[1.0000000000025016`, 1, 1.0500000000157133`], 
     Hue[1.0000000000011378`, 1, 1.0500000000071466`], 
     Hue[1.0000000000005174`, 1, 1.0500000000032503`], 
     Hue[1.0000000000002354`, 1, 1.0500000000014784`], 
     Hue[1.000000000000107, 1, 1.0500000000006724`], 
     Hue[1.0000000000000486`, 1, 1.0500000000003058`], 
     Hue[1.0000000000000222`, 1, 1.0500000000001393`], 
     Hue[1.00000000000001, 1, 1.0500000000000633`], 
     Hue[1.0000000000000047`, 1, 1.050000000000029], 
     Hue[1.000000000000002, 1, 1.0500000000000131`], 
     Hue[1.0000000000000009`, 1, 1.050000000000006], 
     Hue[1.0000000000000004`, 1, 1.0500000000000027`], 
     Hue[1.0000000000000002`, 1, 1.0500000000000014`], 
     Hue[1., 1, 1.0500000000000007`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.5548013782588318, 1, -17.474999625757572`], 
     Hue[0.5548013782588318, 1, -17.100757209075603`], 
     Hue[0.5548013782588318, 1, -16.726514792393633`], 
     Hue[0.5548013782588318, 1, -16.35227237571166], 
     Hue[0.5548013782588318, 1, -15.97802995902969], 
     Hue[0.5548013782588319, 1, -15.603787542347721`], 
     Hue[0.5548013782588319, 1, -15.229545125665748`], 
     Hue[0.5548013782588319, 1, -14.855302708983777`], 
     Hue[0.5548013782588321, 1, -14.481060292301803`], 
     Hue[0.5548013782588326, 1, -14.106817875619829`], 
     Hue[0.5548013782588335, 1, -13.73257545893785], 
     Hue[0.5548013782588355, 1, -13.358333042255863`], 
     Hue[0.5548013782588397, 1, -12.984090625573858`], 
     Hue[0.5548013782588492, 1, -12.609848208891806`], 
     Hue[0.5548013782588701, 1, -12.235605792209661`], 
     Hue[0.554801378258916, 1, -11.86136337552731], 
     Hue[0.5548013782590169, 1, -11.487120958844498`], 
     Hue[0.5548013782592388, 1, -11.11287854216068], 
     Hue[0.5548013782597268, 1, -10.738636125474649`], 
     Hue[0.5548013782607994, 1, -10.36439370878375], 
     Hue[0.5548013782631581, 1, -9.990151292082148], 
     Hue[0.5548013782683442, 1, -9.615908875357016], 
     Hue[0.554801378279747, 1, -9.241666458580147], 
     Hue[0.5548013783048186, 1, -8.86742404168952], 
     Hue[0.5548013783599444, 1, -8.493181624548772], 
     Hue[0.5548013784811505, 1, -8.118939206858078], 
     Hue[0.5548013787476502, 1, -7.744696787958197], 
     Hue[0.5548013793336104, 1, -7.3704543663996445`], 
     Hue[0.5548013806219769, 1, -6.996211938995402], 
     Hue[0.5548013834547444, 1, -6.621969498738074], 
     Hue[0.5548013896832288, 1, -6.247727030220315], 
     Hue[0.5548014033779733, 1, -5.873484499565556], 
     Hue[0.5548014334890077, 1, -5.499241832288405], 
     Hue[0.5548014996950779, 1, -5.124998864615517], 
     Hue[0.5548016452647233, 1, -4.750755236452722], 
     Hue[0.5548019653353132, 1, -4.376510156045113], 
     Hue[0.5548026690959369, 1, -4.0022618825106235`], 
     Hue[0.5548042165347873, 1, -3.6280065879848156`], 
     Hue[0.5548076192261828, 1, -3.2537358553639137`], 
     Hue[0.5548151022440793, 1, -2.879431174476287], 
     Hue[0.5548315622621987, 1, -2.5050518307617784`], 
     Hue[0.5548677867525286, 1, -2.1305082278690293`], 
     Hue[0.5549475963441914, 1, -1.7556029992764046`], 
     Hue[0.5551238619682586, 1, -1.3799004024484482`], 
     Hue[0.555515263427005, 1, -1.0024336582082125`], 
     Hue[0.5563948673842953, 1, -0.6210343866385775], 
     Hue[0.558425843802808, 1, -0.2307216235085927], 
     Hue[0.563420397257407, 1, 0.18056284055633176`], 
     Hue[0.577807125849684, 1, 0.6454818195698694], 
     Hue[0.6435193124150129, 1, 1.2633937991662183`], 
     Hue[0.9112820658438134, 1, 1.4505150075072235`], 
     Hue[0.976994252409147, 1, 1.206845444592838], 
     Hue[0.9913809810014246, 1, 1.1161688822612685`], 
     Hue[0.9963755344560237, 1, 1.0791268348783145`], 
     Hue[0.9984065108745364, 1, 1.0630564884303002`], 
     Hue[0.9992861148318267, 1, 1.055899633542636], 
     Hue[0.9996775162905732, 1, 1.0526753059843716`], 
     Hue[0.9998537819146402, 1, 1.0512151258383864`], 
     Hue[0.9999335915063032, 1, 1.0505523139277329`], 
     Hue[0.9999698159966333, 1, 1.0502511277169548`], 
     Hue[0.9999862760147525, 1, 1.050114200684417], 
     Hue[0.999993759032649, 1, 1.0500519364787628`], 
     Hue[0.9999971617240445, 1, 1.0500236205398312`], 
     Hue[0.9999987091628948, 1, 1.050010742695994], 
     Hue[0.9999994129235186, 1, 1.0500048858434756`], 
     Hue[0.9999997329941085, 1, 1.0500022221178371`], 
     Hue[0.9999998785637539, 1, 1.0500010106370135`], 
     Hue[0.9999999447698241, 1, 1.0500004596460975`], 
     Hue[0.9999999748808583, 1, 1.0500002090509157`], 
     Hue[0.999999988575603, 1, 1.050000095078129], 
     Hue[0.9999999948040874, 1, 1.0500000432423415`], 
     Hue[0.9999999976368548, 1, 1.0500000196669852`], 
     Hue[0.9999999989252214, 1, 1.0500000089447123`], 
     Hue[0.9999999995111816, 1, 1.0500000040681314`], 
     Hue[0.9999999997776812, 1, 1.050000001850221], 
     Hue[0.9999999998988875, 1, 1.0500000008414963`], 
     Hue[0.9999999999540132, 1, 1.0500000003827197`], 
     Hue[0.9999999999790848, 1, 1.0500000001740641`], 
     Hue[0.9999999999904876, 1, 1.050000000079166], 
     Hue[0.9999999999956737, 1, 1.0500000000360055`], 
     Hue[0.9999999999980324, 1, 1.0500000000163756`], 
     Hue[0.999999999999105, 1, 1.0500000000074479`], 
     Hue[0.999999999999593, 1, 1.0500000000033873`], 
     Hue[0.9999999999998149, 1, 1.0500000000015406`], 
     Hue[0.9999999999999158, 1, 1.0500000000007006`], 
     Hue[0.9999999999999617, 1, 1.0500000000003187`], 
     Hue[0.9999999999999826, 1, 1.050000000000145], 
     Hue[0.9999999999999921, 1, 1.050000000000066], 
     Hue[0.9999999999999964, 1, 1.05000000000003], 
     Hue[0.9999999999999983, 1, 1.0500000000000138`], 
     Hue[0.9999999999999992, 1, 1.0500000000000063`], 
     Hue[0.9999999999999997, 1, 1.050000000000003], 
     Hue[0.9999999999999999, 1, 1.0500000000000014`], 
     Hue[0.9999999999999999, 1, 1.0500000000000007`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.6801961793737635, 1, -17.474999625757572`], 
     Hue[0.6801961793737635, 1, -17.100757209075603`], 
     Hue[0.6801961793737635, 1, -16.726514792393633`], 
     Hue[0.6801961793737635, 1, -16.35227237571166], 
     Hue[0.6801961793737636, 1, -15.97802995902969], 
     Hue[0.6801961793737636, 1, -15.603787542347721`], 
     Hue[0.6801961793737638, 1, -15.229545125665748`], 
     Hue[0.680196179373764, 1, -14.855302708983777`], 
     Hue[0.6801961793737644, 1, -14.481060292301807`], 
     Hue[0.6801961793737656, 1, -14.106817875619832`], 
     Hue[0.6801961793737679, 1, -13.732575458937857`], 
     Hue[0.6801961793737732, 1, -13.358333042255879`], 
     Hue[0.6801961793737847, 1, -12.984090625573891`], 
     Hue[0.6801961793738103, 1, -12.609848208891885`], 
     Hue[0.6801961793738662, 1, -12.235605792209837`], 
     Hue[0.6801961793739894, 1, -11.861363375527693`], 
     Hue[0.68019617937426, 1, -11.487120958845344`], 
     Hue[0.6801961793748552, 1, -11.112878542162537`], 
     Hue[0.6801961793761637, 1, -10.738636125478736`], 
     Hue[0.6801961793790408, 1, -10.364393708792736`], 
     Hue[0.6801961793853668, 1, -9.99015129210191], 
     Hue[0.6801961793992759, 1, -9.615908875400466], 
     Hue[0.6801961794298585, 1, -9.241666458675684], 
     Hue[0.680196179497101, 1, -8.867424041899579], 
     Hue[0.6801961796449489, 1, -8.493181625010632], 
     Hue[0.6801961799700265, 1, -8.11893920787358], 
     Hue[0.6801961806847833, 1, -7.744696790191013], 
     Hue[0.6801961822563387, 1, -7.370454371308999], 
     Hue[0.6801961857117609, 1, -6.996211949789733], 
     Hue[0.6801961933092927, 1, -6.621969522471868], 
     Hue[0.6801962100141958, 1, -6.247727082404472], 
     Hue[0.6801962467437312, 1, -5.873484614304336], 
     Hue[0.6801963275019979, 1, -5.499242084567902], 
     Hue[0.6801965050675525, 1, -5.124999419310311], 
     Hue[0.6801968954864691, 1, -4.750756456079921], 
     Hue[0.680197753914427, 1, -4.376512837694765], 
     Hue[0.6801996413788362, 1, -4.002267778832887], 
     Hue[0.6802037914725285, 1, -3.628019552900615], 
     Hue[0.6802129167545131, 1, -3.253764364146397], 
     Hue[0.680232982488343, 1, -2.8794938694425136`], 
     Hue[0.6802771099100293, 1, -2.5051897375647094`], 
     Hue[0.6803741744003591, 1, -2.1308117262792887`], 
     Hue[0.6805877875590296, 1, -1.7562716600764847`], 
     Hue[0.6810584052580282, 1, -1.3813771558018872`], 
     Hue[0.6820976998018766, 1, -1.0057125339872701`], 
     Hue[0.6844046018416667, 1, -0.6284004017487974], 
     Hue[0.6895803372124476, 1, -0.24770115186584674`], 
     Hue[0.7014355213566201, 1, 0.13915871868383778`], 
     Hue[0.7293824718340917, 1, 0.5318699180624441], 
     Hue[0.7928359438092252, 1, 0.8926929220662512], 
     Hue[0.8873602355645352, 1, 1.079814130407241], 
     Hue[0.9508137075396703, 1, 1.0932335430854083`], 
     Hue[0.9787606580171428, 1, 1.074764760388773], 
     Hue[0.9906158421613157, 1, 1.06214730652106], 
     Hue[0.9957915775320967, 1, 1.05569047332008], 
     Hue[0.9980984795718868, 1, 1.0526207577635789`], 
     Hue[0.9991377741157352, 1, 1.0511985526309329`], 
     Hue[0.9996083918147339, 1, 1.0505464650383065`], 
     Hue[0.9998220049734045, 1, 1.050248815517474], 
     Hue[0.9999190694637342, 1, 1.0501132209140236`], 
     Hue[0.9999631968854206, 1, 1.0500515057181903`], 
     Hue[0.9999832626192504, 1, 1.050023427696279], 
     Hue[0.999992387901235, 1, 1.0500106556240312`], 
     Hue[0.9999965379949274, 1, 1.05000484637373], 
     Hue[0.9999984254593366, 1, 1.050002204193824], 
     Hue[0.9999992838872944, 1, 1.0500010024906383`], 
     Hue[0.9999996743062112, 1, 1.050000455942219], 
     Hue[0.9999998518717657, 1, 1.0500002073666006`], 
     Hue[0.9999999326300322, 1, 1.0500000943121377`], 
     Hue[0.9999999693595676, 1, 1.0500000428939726`], 
     Hue[0.9999999860644708, 1, 1.0500000195085462`], 
     Hue[0.9999999936620027, 1, 1.0500000088726535`], 
     Hue[0.9999999971174248, 1, 1.0500000040353585`], 
     Hue[0.9999999986889803, 1, 1.0500000018353155`], 
     Hue[0.9999999994037371, 1, 1.0500000008347172`], 
     Hue[0.9999999997288145, 1, 1.0500000003796366`], 
     Hue[0.9999999998766625, 1, 1.050000000172662], 
     Hue[0.9999999999439051, 1, 1.0500000000785281`], 
     Hue[0.9999999999744875, 1, 1.0500000000357153`], 
     Hue[0.9999999999883967, 1, 1.0500000000162437`], 
     Hue[0.9999999999947228, 1, 1.0500000000073877`], 
     Hue[0.9999999999975998, 1, 1.05000000000336], 
     Hue[0.9999999999989084, 1, 1.0500000000015282`], 
     Hue[0.9999999999995035, 1, 1.050000000000695], 
     Hue[0.9999999999997742, 1, 1.0500000000003162`], 
     Hue[0.9999999999998973, 1, 1.0500000000001437`], 
     Hue[0.9999999999999533, 1, 1.0500000000000653`], 
     Hue[0.9999999999999788, 1, 1.0500000000000298`], 
     Hue[0.9999999999999903, 1, 1.0500000000000136`], 
     Hue[0.9999999999999956, 1, 1.0500000000000063`], 
     Hue[0.999999999999998, 1, 1.050000000000003], 
     Hue[0.9999999999999991, 1, 1.0500000000000014`], 
     Hue[0.9999999999999996, 1, 1.0500000000000007`], 
     Hue[0.9999999999999998, 1, 1.0500000000000003`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.8055909804886949, 1, -17.474999625757572`], 
     Hue[0.805590980488695, 1, -17.100757209075603`], 
     Hue[0.8055909804886949, 1, -16.726514792393633`], 
     Hue[0.805590980488695, 1, -16.35227237571166], 
     Hue[0.805590980488695, 1, -15.97802995902969], 
     Hue[0.8055909804886952, 1, -15.603787542347721`], 
     Hue[0.8055909804886952, 1, -15.229545125665748`], 
     Hue[0.8055909804886954, 1, -14.855302708983777`], 
     Hue[0.8055909804886959, 1, -14.481060292301807`], 
     Hue[0.805590980488697, 1, -14.106817875619837`], 
     Hue[0.8055909804886996, 1, -13.73257545893787], 
     Hue[0.805590980488705, 1, -13.358333042255902`], 
     Hue[0.805590980488717, 1, -12.984090625573947`], 
     Hue[0.8055909804887434, 1, -12.609848208892004`], 
     Hue[0.8055909804888015, 1, -12.235605792210096`], 
     Hue[0.8055909804889294, 1, -11.861363375528265`], 
     Hue[0.8055909804892103, 1, -11.487120958846598`], 
     Hue[0.8055909804898279, 1, -11.112878542165298`], 
     Hue[0.8055909804911859, 1, -10.738636125484804`], 
     Hue[0.805590980494172, 1, -10.364393708806078`], 
     Hue[0.8055909805007374, 1, -9.990151292131245], 
     Hue[0.8055909805151731, 1, -9.615908875464964], 
     Hue[0.805590980546913, 1, -9.241666458817496], 
     Hue[0.8055909806167005, 1, -8.867424042211386], 
     Hue[0.8055909807701442, 1, -8.493181625696211], 
     Hue[0.805590981107525, 1, -8.118939209380985], 
     Hue[0.8055909818493335, 1, -7.744696793505379], 
     Hue[0.8055909834803684, 1, -7.370454378596384], 
     Hue[0.8055909870665694, 1, -6.9962119658127095`], 
     Hue[0.805590994951648, 1, -6.621969557702028], 
     Hue[0.8055910122887858, 1, -6.247727159865989], 
     Hue[0.8055910504084223, 1, -5.8734847846211045`], 
     Hue[0.8055911342230909, 1, -5.499242459048079], 
     Hue[0.8055913185085926, 1, -5.12500024269025], 
     Hue[0.8055917237016412, 1, -4.750758266468418], 
     Hue[0.8055926146080868, 1, -4.376516818247645], 
     Hue[0.8055945734557901, 1, -4.002276530993313], 
     Hue[0.8055988803662891, 1, -3.6280387965618504`], 
     Hue[0.8056083497901279, 1, -3.2538066759335607`], 
     Hue[0.8056291690287463, 1, -2.8795869025953653`], 
     Hue[0.8056749378792419, 1, -2.5053942972351955`], 
     Hue[0.8057755373377238, 1, -2.1312615217690523`], 
     Hue[0.8059965646643585, 1, -1.7572607538141958`], 
     Hue[0.8064817510837772, 1, -1.3835524376068304`], 
     Hue[0.8075446901763623, 1, -1.010497683869685], 
     Hue[0.8098629428322565, 1, -0.6389297168168555], 
     Hue[0.8148667481408032, 1, -0.27085887584297974`], 
     Hue[0.8253988592678277, 1, 0.08855352326135191], 
     Hue[0.8461973682691739, 1, 0.4255924776389377], 
     Hue[0.8812619288489325, 1, 0.7083968037504038], 
     Hue[0.924329051639761, 1, 0.8955180120913914], 
     Hue[0.9593936122195201, 1, 0.9869561026618994], 
     Hue[0.9801921212208666, 1, 1.024159564966286], 
     Hue[0.9907242323478916, 1, 1.0389895825439261`], 
     Hue[0.9957280376564385, 1, 1.045161158252022], 
     Hue[0.9980462903123327, 1, 1.0478356078811637`], 
     Hue[0.9991092294049179, 1, 1.0490232708259895`], 
     Hue[0.9995944158243364, 1, 1.0495573713005957`], 
     Hue[0.9998154431509713, 1, 1.0497990200277103`], 
     Hue[0.999916042609453, 1, 1.0499086612435382`], 
     Hue[0.9999618114599487, 1, 1.0499584725653386`], 
     Hue[0.9999826306985671, 1, 1.0499811159091155`], 
     Hue[0.9999921001224059, 1, 1.0499914119627962`], 
     Hue[0.9999964070329049, 1, 1.0499960942133046`], 
     Hue[0.9999983658806082, 1, 1.049998223640944], 
     Hue[0.9999992567870538, 1, 1.0499991921021419`], 
     Hue[0.9999996619801025, 1, 1.0499996325622805`], 
     Hue[0.999999846265604, 1, 1.049999832886423], 
     Hue[0.9999999300802727, 1, 1.0499999239953681`], 
     Hue[0.9999999681999091, 1, 1.0499999654324554`], 
     Hue[0.9999999855370469, 1, 1.049999984278388], 
     Hue[0.9999999934221255, 1, 1.0499999928496773`], 
     Hue[0.9999999970083266, 1, 1.0499999967479723`], 
     Hue[0.9999999986393614, 1, 1.04999999852095], 
     Hue[0.99999999938117, 1, 1.0499999993273155`], 
     Hue[0.9999999997185508, 1, 1.0499999996940574`], 
     Hue[0.9999999998719945, 1, 1.0499999998608547`], 
     Hue[0.999999999941782, 1, 1.0499999999367156`], 
     Hue[0.999999999973522, 1, 1.0499999999712177`], 
     Hue[0.9999999999879575, 1, 1.0499999999869096`], 
     Hue[0.999999999994523, 1, 1.0499999999940464`], 
     Hue[0.999999999997509, 1, 1.0499999999972922`], 
     Hue[0.9999999999988671, 1, 1.0499999999987686`], 
     Hue[0.9999999999994847, 1, 1.04999999999944], 
     Hue[0.9999999999997656, 1, 1.0499999999997454`], 
     Hue[0.9999999999998934, 1, 1.0499999999998841`], 
     Hue[0.9999999999999515, 1, 1.0499999999999472`], 
     Hue[0.9999999999999779, 1, 1.049999999999976], 
     Hue[0.99999999999999, 1, 1.0499999999999892`], 
     Hue[0.9999999999999954, 1, 1.0499999999999952`], 
     Hue[0.9999999999999979, 1, 1.0499999999999978`], 
     Hue[0.9999999999999991, 1, 1.049999999999999], 
     Hue[0.9999999999999996, 1, 1.0499999999999996`], 
     Hue[0.9999999999999998, 1, 1.0499999999999998`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.9309857816036267, 1, -17.474999625757572`], 
     Hue[0.9309857816036268, 1, -17.100757209075603`], 
     Hue[0.9309857816036268, 1, -16.726514792393633`], 
     Hue[0.9309857816036268, 1, -16.35227237571166], 
     Hue[0.9309857816036268, 1, -15.97802995902969], 
     Hue[0.9309857816036268, 1, -15.603787542347721`], 
     Hue[0.9309857816036269, 1, -15.229545125665748`], 
     Hue[0.9309857816036269, 1, -14.855302708983777`], 
     Hue[0.9309857816036271, 1, -14.48106029230181], 
     Hue[0.9309857816036277, 1, -14.106817875619843`], 
     Hue[0.9309857816036288, 1, -13.732575458937879`], 
     Hue[0.9309857816036312, 1, -13.358333042255921`], 
     Hue[0.9309857816036365, 1, -12.984090625573987`], 
     Hue[0.9309857816036484, 1, -12.60984820889209], 
     Hue[0.9309857816036744, 1, -12.235605792210286`], 
     Hue[0.9309857816037315, 1, -11.861363375528684`], 
     Hue[0.9309857816038571, 1, -11.487120958847523`], 
     Hue[0.9309857816041334, 1, -11.112878542167332`], 
     Hue[0.9309857816047407, 1, -10.738636125489277`], 
     Hue[0.9309857816060758, 1, -10.364393708815912`], 
     Hue[0.9309857816090117, 1, -9.990151292152865], 
     Hue[0.9309857816154669, 1, -9.6159088755125], 
     Hue[0.93098578162966, 1, -9.241666458922015], 
     Hue[0.9309857816608668, 1, -8.867424042441195], 
     Hue[0.9309857817294819, 1, -8.4931816262015], 
     Hue[0.930985781880348, 1, -8.118939210491972], 
     Hue[0.9309857822120613, 1, -7.744696795948141], 
     Hue[0.9309857829414085, 1, -7.3704543839673535`], 
     Hue[0.9309857845450443, 1, -6.996211977622008], 
     Hue[0.930985788071002, 1, -6.621969583667455], 
     Hue[0.930985795823621, 1, -6.2477272169568785`], 
     Hue[0.9309858128695114, 1, -5.873484910148372], 
     Hue[0.9309858503487515, 1, -5.499242735048138], 
     Hue[0.9309859327552521, 1, -5.125000849538226], 
     Hue[0.9309861139440411, 1, -4.750759600757218], 
     Hue[0.930986512325676, 1, -4.3765197519632455`], 
     Hue[0.9309873882431748, 1, -4.002282981328814], 
     Hue[0.9309893140738208, 1, -3.628052978581281], 
     Hue[0.9309935480966117, 1, -3.2538378558617183`], 
     Hue[0.9310028558479951, 1, -2.8796554468319657`], 
     Hue[0.9310233127892795, 1, -2.50554494968003], 
     Hue[0.9310682520978023, 1, -2.131592486874764], 
     Hue[0.9311668687501641, 1, -1.7579871107491736`], 
     Hue[0.9313827728192672, 1, -1.385143012158559], 
     Hue[0.9318530496616279, 1, -1.013963742122048], 
     Hue[0.9328660712262773, 1, -0.6464017705127971], 
     Hue[0.9349966601522811, 1, -0.2865883687471371], 
     Hue[0.939258663506311, 1, 0.05713498266723549], 
     Hue[0.9469767960198806, 1, 0.3695953569574796], 
     Hue[0.95867959493301, 1, 0.6288568887093933], 
     Hue[0.9723061866706162, 1, 0.8159780970503803], 
     Hue[0.9840089855837457, 1, 0.9309589819804402], 
     Hue[0.9917271180973155, 1, 0.9927410243721688], 
     Hue[0.9959891214513454, 1, 1.0232600896397686`], 
     Hue[0.9981197103773494, 1, 1.03768910455608], 
     Hue[0.9991327319419989, 1, 1.0443695496288008`], 
     Hue[0.9996030087843596, 1, 1.0474326962742606`], 
     Hue[0.9998189128534627, 1, 1.0488310143656179`], 
     Hue[0.9999175295058244, 1, 1.0494680549219988`], 
     Hue[0.9999624688143471, 1, 1.0497580087987028`], 
     Hue[0.9999829257556316, 1, 1.0498899283287384`], 
     Hue[0.9999922335070149, 1, 1.0499499359809576`], 
     Hue[0.999996467529806, 1, 1.0499772299433654`], 
     Hue[0.9999983933604519, 1, 1.0499896438778038`], 
     Hue[0.9999992692779507, 1, 1.0499952899253437`], 
     Hue[0.9999996676595857, 1, 1.049997857813342], 
     Hue[0.9999998488483746, 1, 1.0499990257143041`], 
     Hue[0.9999999312548753, 1, 1.0499995568863647`], 
     Hue[0.9999999687341153, 1, 1.0499997984681007`], 
     Hue[0.9999999857800058, 1, 1.0499999083415656`], 
     Hue[0.9999999935326247, 1, 1.0499999583129611`], 
     Hue[0.9999999970585824, 1, 1.0499999810403788`], 
     Hue[0.9999999986622182, 1, 1.0499999913770028`], 
     Hue[0.9999999993915655, 1, 1.0499999960781874`], 
     Hue[0.9999999997232788, 1, 1.0499999982163262`], 
     Hue[0.9999999998741448, 1, 1.04999999918877], 
     Hue[0.99999999994276, 1, 1.0499999996310456`], 
     Hue[0.9999999999739667, 1, 1.0499999998321965`], 
     Hue[0.9999999999881598, 1, 1.0499999999236815`], 
     Hue[0.999999999994615, 1, 1.0499999999652896`], 
     Hue[0.9999999999975508, 1, 1.0499999999842136`], 
     Hue[0.9999999999988861, 1, 1.0499999999928202`], 
     Hue[0.9999999999994934, 1, 1.0499999999967347`], 
     Hue[0.9999999999997696, 1, 1.049999999998515], 
     Hue[0.9999999999998952, 1, 1.0499999999993246`], 
     Hue[0.9999999999999524, 1, 1.0499999999996927`], 
     Hue[0.9999999999999784, 1, 1.0499999999998604`], 
     Hue[0.9999999999999901, 1, 1.0499999999999365`], 
     Hue[0.9999999999999956, 1, 1.0499999999999712`], 
     Hue[0.999999999999998, 1, 1.049999999999987], 
     Hue[0.9999999999999991, 1, 1.049999999999994], 
     Hue[0.9999999999999996, 1, 1.0499999999999974`], 
     Hue[0.9999999999999998, 1, 1.0499999999999987`], 
     Hue[0.9999999999999999, 1, 1.0499999999999996`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.0563805827185582`, 1, -17.474999625757572`], 
     Hue[1.0563805827185582`, 1, -17.100757209075603`], 
     Hue[1.0563805827185582`, 1, -16.726514792393633`], 
     Hue[1.0563805827185582`, 1, -16.35227237571166], 
     Hue[1.0563805827185582`, 1, -15.97802995902969], 
     Hue[1.0563805827185582`, 1, -15.603787542347721`], 
     Hue[1.0563805827185582`, 1, -15.229545125665748`], 
     Hue[1.056380582718558, 1, -14.855302708983777`], 
     Hue[1.0563805827185577`, 1, -14.48106029230181], 
     Hue[1.0563805827185575`, 1, -14.106817875619843`], 
     Hue[1.0563805827185564`, 1, -13.732575458937879`], 
     Hue[1.0563805827185544`, 1, -13.358333042255923`], 
     Hue[1.05638058271855, 1, -12.98409062557399], 
     Hue[1.0563805827185402`, 1, -12.609848208892096`], 
     Hue[1.0563805827185189`, 1, -12.235605792210297`], 
     Hue[1.0563805827184716`, 1, -11.861363375528708`], 
     Hue[1.0563805827183679`, 1, -11.487120958847573`], 
     Hue[1.0563805827181398`, 1, -11.112878542167442`], 
     Hue[1.0563805827176385`, 1, -10.738636125489517`], 
     Hue[1.0563805827165362`, 1, -10.364393708816442`], 
     Hue[1.0563805827141124`, 1, -9.990151292154028], 
     Hue[1.056380582708783, 1, -9.615908875515062], 
     Hue[1.0563805826970654`, 1, -9.241666458927648], 
     Hue[1.0563805826713013`, 1, -8.867424042453578], 
     Hue[1.056380582614653, 1, -8.49318162622873], 
     Hue[1.0563805824900991`, 1, -8.118939210551845], 
     Hue[1.0563805822162389`, 1, -7.744696796079784], 
     Hue[1.0563805816140952`, 1, -7.3704543842568], 
     Hue[1.056380580290145, 1, -6.996211978258423], 
     Hue[1.0563805773791395`, 1, -6.621969585066757], 
     Hue[1.0563805709786327`, 1, -6.247727220033564], 
     Hue[1.0563805569056677`, 1, -5.873484916913162], 
     Hue[1.0563805259630767`, 1, -5.49924274992205], 
     Hue[1.056380457928866, 1, -5.125000882241833], 
     Hue[1.0563803083407308`, 1, -4.750759672663177], 
     Hue[1.0563799794398618`, 1, -4.376519910063116], 
     Hue[1.05637925628941, 1, -4.00228332893894], 
     Hue[1.056377666341126, 1, -3.6280537428405975`], 
     Hue[1.0563741707801846`, 1, -3.2538395360633316`], 
     Hue[1.056366486454153, 1, -2.879659140188462], 
     Hue[1.0563495977696626`, 1, -2.5055530657794716`], 
     Hue[1.0563124982241583`, 1, -2.1316103098283197`], 
     Hue[1.0562310907760606`, 1, -1.7580261918460118`], 
     Hue[1.0560528886510998`, 1, -1.3852284280750207`], 
     Hue[1.0556648528993704`, 1, -1.0141491027636163`], 
     Hue[1.05482953447226, 1, -0.6467978481391923], 
     Hue[1.0530750455111242`, 1, -0.28740717288988993`], 
     Hue[1.049574232173286, 1, 0.055554292198334854`], 
     Hue[1.0432598270129123`, 1, 0.36692208809792126`], 
     Hue[1.0337280342292492`, 1, 0.6252419894348782], 
     Hue[1.0226525484893094`, 1, 0.8123631977758651], 
     Hue[1.0131207557056463`, 1, 0.9282857131208818], 
     Hue[1.0068063505452725`, 1, 0.9911603339032681], 
     Hue[1.0033055372074342`, 1, 1.0224412854970157`], 
     Hue[1.0015510482462984`, 1, 1.037293026929685], 
     Hue[1.0007157298191878`, 1, 1.0441841889872325`], 
     Hue[1.0003276940674584`, 1, 1.047347280357799], 
     Hue[1.0001494919424976`, 1, 1.0487919332687796`], 
     Hue[1.0000680844943999`, 1, 1.0494502319684424`], 
     Hue[1.0000309849488958`, 1, 1.0497498926992619`], 
     Hue[1.0000140962644053`, 1, 1.0498862349722422`], 
     Hue[1.0000064119383736`, 1, 1.0499482557793445`], 
     Hue[1.0000029163774322`, 1, 1.0499764656840487`], 
     Hue[1.000001326429148, 1, 1.0499892962676771`], 
     Hue[1.0000006032786963`, 1, 1.049995131825473], 
     Hue[1.0000002743778273`, 1, 1.0499977859073826`], 
     Hue[1.0000001247896921`, 1, 1.0499989930106972`], 
     Hue[1.0000000567554814`, 1, 1.0499995420124517`], 
     Hue[1.0000000258128905`, 1, 1.0499997917033113`], 
     Hue[1.0000000117399255`, 1, 1.0499999052648803`], 
     Hue[1.0000000053394187`, 1, 1.049999956913658], 
     Hue[1.0000000024284132`, 1, 1.049999980403964], 
     Hue[1.0000000011044632`, 1, 1.0499999910875557`], 
     Hue[1.0000000005023193`, 1, 1.0499999959465445`], 
     Hue[1.000000000228459, 1, 1.0499999981564538`], 
     Hue[1.000000000103905, 1, 1.0499999991615396`], 
     Hue[1.0000000000472569`, 1, 1.049999999618661], 
     Hue[1.0000000000214928`, 1, 1.049999999826564], 
     Hue[1.000000000009775, 1, 1.0499999999211198`], 
     Hue[1.0000000000044458`, 1, 1.0499999999641247`], 
     Hue[1.000000000002022, 1, 1.0499999999836835`], 
     Hue[1.0000000000009197`, 1, 1.049999999992579], 
     Hue[1.0000000000004183`, 1, 1.049999999996625], 
     Hue[1.0000000000001903`, 1, 1.049999999998465], 
     Hue[1.0000000000000866`, 1, 1.049999999999302], 
     Hue[1.0000000000000393`, 1, 1.0499999999996825`], 
     Hue[1.000000000000018, 1, 1.0499999999998557`], 
     Hue[1.0000000000000082`, 1, 1.0499999999999343`], 
     Hue[1.0000000000000038`, 1, 1.0499999999999703`], 
     Hue[1.0000000000000018`, 1, 1.0499999999999865`], 
     Hue[1.0000000000000007`, 1, 1.0499999999999938`], 
     Hue[1.0000000000000004`, 1, 1.0499999999999972`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999987`], 
     Hue[1., 1, 1.0499999999999994`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.1817753838334897`, 1, -17.474999625757572`], 
     Hue[1.1817753838334897`, 1, -17.100757209075603`], 
     Hue[1.1817753838334897`, 1, -16.726514792393633`], 
     Hue[1.1817753838334897`, 1, -16.35227237571166], 
     Hue[1.1817753838334897`, 1, -15.97802995902969], 
     Hue[1.1817753838334895`, 1, -15.603787542347721`], 
     Hue[1.1817753838334895`, 1, -15.229545125665748`], 
     Hue[1.1817753838334892`, 1, -14.855302708983777`], 
     Hue[1.1817753838334888`, 1, -14.481060292301807`], 
     Hue[1.1817753838334877`, 1, -14.10681787561984], 
     Hue[1.1817753838334852`, 1, -13.732575458937871`], 
     Hue[1.18177538383348, 1, -13.358333042255905`], 
     Hue[1.1817753838334684`, 1, -12.984090625573952`], 
     Hue[1.1817753838334426`, 1, -12.609848208892016`], 
     Hue[1.1817753838333864`, 1, -12.23560579221012], 
     Hue[1.1817753838332627`, 1, -11.861363375528319`], 
     Hue[1.181775383832991, 1, -11.487120958846718`], 
     Hue[1.181775383832393, 1, -11.112878542165562`], 
     Hue[1.1817753838310785`, 1, -10.738636125485385`], 
     Hue[1.1817753838281881`, 1, -10.364393708807356`], 
     Hue[1.181775383821833, 1, -9.990151292134053], 
     Hue[1.1817753838078597`, 1, -9.615908875471138], 
     Hue[1.1817753837771363`, 1, -9.241666458831075], 
     Hue[1.1817753837095841`, 1, -8.867424042241241], 
     Hue[1.1817753835610554`, 1, -8.493181625761856], 
     Hue[1.1817753832344808`, 1, -8.118939209525317], 
     Hue[1.1817753825164328`, 1, -7.7446967938227305`], 
     Hue[1.1817753809376406`, 1, -7.370454379294155], 
     Hue[1.1817753774663067`, 1, -6.996211967346917], 
     Hue[1.1817753698337898`, 1, -6.621969561075329], 
     Hue[1.1817753530519663`, 1, -6.24772716728296], 
     Hue[1.1817753161533158`, 1, -5.873484800928998], 
     Hue[1.1817752350232666`, 1, -5.499242494904678], 
     Hue[1.1817750566405318`, 1, -5.125000321529066], 
     Hue[1.1817746644261542`, 1, -4.750758439813131], 
     Hue[1.1817738020567337`, 1, -4.376517199383707], 
     Hue[1.1817719059564153`, 1, -4.002277368999323], 
     Hue[1.181767737021163, 1, -3.628040639068467], 
     Hue[1.1817585710197243`, 1, -3.2538107269090224`], 
     Hue[1.181738419177688, 1, -2.879595808646222], 
     Hue[1.181694118974699, 1, -2.505413874667524], 
     Hue[1.181596754582079, 1, -2.131304545216417], 
     Hue[1.1813828687652779`, 1, -1.757355244210373], 
     Hue[1.1809135213059314`, 1, -1.3837596803401426`], 
     Hue[1.1798860584972026`, 1, -1.0109508464558188`], 
     Hue[1.1776488454198926`, 1, -0.6399138394612753], 
     Hue[1.1728367537284898`, 1, -0.27296222229663325`], 
     Hue[1.1627796647836324`, 1, 0.08422909597256623], 
     Hue[1.1431718988810917`, 1, 0.4175269265670978], 
     Hue[1.1106693382633168`, 1, 0.6964291717300423], 
     Hue[1.0711060455701742`, 1, 0.8835503800710297], 
     Hue[1.0386034849523988`, 1, 0.978890551590059], 
     Hue[1.0189957190498578`, 1, 1.0198351376775001`], 
     Hue[1.008938630105, 1, 1.0368862360902726`], 
     Hue[1.0041265384135973`, 1, 1.0441770356076019`], 
     Hue[1.001889325336287, 1, 1.0473824452950298`], 
     Hue[1.0008618625275583`, 1, 1.0488160280926775`], 
     Hue[1.0003925150682118`, 1, 1.0494628809044177`], 
     Hue[1.0001786292514108`, 1, 1.0497559965803447`], 
     Hue[1.0000812648587907`, 1, 1.0498890838112098`], 
     Hue[1.0000369646558014`, 1, 1.0499495665144822`], 
     Hue[1.0000168128137654`, 1, 1.0499770649336535`], 
     Hue[1.0000076468123267`, 1, 1.0499895694561796`], 
     Hue[1.0000034778770743`, 1, 1.0499952562072943`], 
     Hue[1.000001581776756, 1, 1.0499978425048824`], 
     Hue[1.0000007194073353`, 1, 1.049999018757429], 
     Hue[1.0000003271929578`, 1, 1.0499995537234652`], 
     Hue[1.0000001488102228`, 1, 1.0499997970298243`], 
     Hue[1.0000000676801737`, 1, 1.0499999076874744`], 
     Hue[1.0000000307815233`, 1, 1.0499999580154848`], 
     Hue[1.0000000139996998`, 1, 1.0499999809050864`], 
     Hue[1.000000006367183, 1, 1.049999991315471], 
     Hue[1.0000000028958491`, 1, 1.0499999960502022`], 
     Hue[1.000000001317057, 1, 1.0499999982035984`], 
     Hue[1.0000000005990086`, 1, 1.0499999991829811`], 
     Hue[1.0000000002724343`, 1, 1.0499999996284128`], 
     Hue[1.0000000001239053`, 1, 1.049999999830999], 
     Hue[1.0000000000563531`, 1, 1.0499999999231369`], 
     Hue[1.00000000002563, 1, 1.049999999965042], 
     Hue[1.0000000000116567`, 1, 1.049999999984101], 
     Hue[1.0000000000053015`, 1, 1.049999999992769], 
     Hue[1.0000000000024112`, 1, 1.0499999999967113`], 
     Hue[1.0000000000010967`, 1, 1.0499999999985044`], 
     Hue[1.0000000000004987`, 1, 1.0499999999993197`], 
     Hue[1.000000000000227, 1, 1.0499999999996907`], 
     Hue[1.0000000000001033`, 1, 1.0499999999998593`], 
     Hue[1.0000000000000469`, 1, 1.049999999999936], 
     Hue[1.0000000000000213`, 1, 1.049999999999971], 
     Hue[1.0000000000000098`, 1, 1.0499999999999867`], 
     Hue[1.0000000000000044`, 1, 1.049999999999994], 
     Hue[1.000000000000002, 1, 1.0499999999999974`], 
     Hue[1.0000000000000009`, 1, 1.0499999999999987`], 
     Hue[1.0000000000000004`, 1, 1.0499999999999996`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.3071701849484214`, 1, -17.474999625757572`], 
     Hue[1.3071701849484214`, 1, -17.100757209075603`], 
     Hue[1.3071701849484214`, 1, -16.726514792393633`], 
     Hue[1.3071701849484214`, 1, -16.35227237571166], 
     Hue[1.3071701849484214`, 1, -15.97802995902969], 
     Hue[1.3071701849484212`, 1, -15.603787542347721`], 
     Hue[1.3071701849484212`, 1, -15.229545125665748`], 
     Hue[1.307170184948421, 1, -14.855302708983777`], 
     Hue[1.3071701849484205`, 1, -14.481060292301807`], 
     Hue[1.3071701849484194`, 1, -14.106817875619834`], 
     Hue[1.3071701849484167`, 1, -13.732575458937859`], 
     Hue[1.3071701849484114`, 1, -13.35833304225588], 
     Hue[1.3071701849483994`, 1, -12.984090625573897`], 
     Hue[1.3071701849483732`, 1, -12.609848208891897`], 
     Hue[1.3071701849483153`, 1, -12.23560579220986], 
     Hue[1.3071701849481878`, 1, -11.861363375527748`], 
     Hue[1.307170184947908, 1, -11.487120958845463`], 
     Hue[1.3071701849472925`, 1, -11.1128785421628], 
     Hue[1.3071701849459396`, 1, -10.738636125479315`], 
     Hue[1.3071701849429644`, 1, -10.36439370879401], 
     Hue[1.307170184936423, 1, -9.990151292104708], 
     Hue[1.3071701849220403`, 1, -9.615908875406616], 
     Hue[1.3071701848904167`, 1, -9.241666458689206], 
     Hue[1.3071701848208848`, 1, -8.867424041929311], 
     Hue[1.3071701846680033`, 1, -8.493181625076007], 
     Hue[1.3071701843318582`, 1, -8.118939208017322], 
     Hue[1.307170183592767, 1, -7.744696790507059], 
     Hue[1.3071701819677068`, 1, -7.3704543720038975`], 
     Hue[1.3071701783946423`, 1, -6.996211951317625], 
     Hue[1.3071701705384473`, 1, -6.621969525831286], 
     Hue[1.307170153264814, 1, -6.247727089790917], 
     Hue[1.3071701152847972`, 1, -5.873484630545118], 
     Hue[1.3071700317770667`, 1, -5.499242120276971], 
     Hue[1.3071698481662097`, 1, -5.1249994978249], 
     Hue[1.307169444455415, 1, -4.750756628712468], 
     Hue[1.3071685568026943`, 1, -4.3765132172684424`], 
     Hue[1.307166605083196, 1, -4.002268613420444], 
     Hue[1.3071623137207098`, 1, -3.6280213879722263`], 
     Hue[1.3071528778785726`, 1, -3.253768399167062], 
     Hue[1.3071321295562899`, 1, -2.879502742311864], 
     Hue[1.3070865025116853`, 1, -2.505209251219319], 
     Hue[1.3069861465840034`, 1, -2.1308546538743167`], 
     Hue[1.306765324702777, 1, -1.7563661542641584`], 
     Hue[1.3062789945425124`, 1, -1.3815854440937125`], 
     Hue[1.3052058279657628`, 1, -1.00617300923255], 
     Hue[1.3028278260227482`, 1, -0.629424814838365], 
     Hue[1.297513246382616, 1, -0.2500093781013055], 
     Hue[1.2854492981160328`, 1, 0.1338405417408992], 
     Hue[1.2576129926231465`, 1, 0.519420596785014], 
     Hue[1.1971449324164722`, 1, 0.8675168207069146], 
     Hue[1.1100252525319518`, 1, 1.0546380290479038`], 
     Hue[1.0495571923252764`, 1, 1.0807842218079777`], 
     Hue[1.0217208868323893`, 1, 1.0694465834458347`], 
     Hue[1.0096569385658059`, 1, 1.0598390802856013`], 
     Hue[1.0043423589256733`, 1, 1.0546660602305125`], 
     Hue[1.0019643569826586`, 1, 1.0521602825182987`], 
     Hue[1.000891190405909, 1, 1.0509902643391071`], 
     Hue[1.0004048602456443`, 1, 1.0504519708506326`], 
     Hue[1.000184038364418, 1, 1.0502058879224458`], 
     Hue[1.000083682436736, 1, 1.0500937072594148`], 
     Hue[1.0000380553921315`, 1, 1.05004263284884], 
     Hue[1.0000173070698488`, 1, 1.050019392675614], 
     Hue[1.0000078712277114`, 1, 1.0500088205524207`], 
     Hue[1.0000035798652254`, 1, 1.0500040117861733`], 
     Hue[1.0000016281457271`, 1, 1.0500018246201472`], 
     Hue[1.0000007404930065`, 1, 1.0500008298580925`], 
     Hue[1.0000003367822115`, 1, 1.0500003774276303`], 
     Hue[1.0000001531713547`, 1, 1.0500001716575305`], 
     Hue[1.0000000696636242`, 1, 1.0500000780713554`], 
     Hue[1.0000000316836073`, 1, 1.0500000355075276`], 
     Hue[1.000000014409974, 1, 1.0500000161491283`], 
     Hue[1.000000006553779, 1, 1.0500000073447617`], 
     Hue[1.0000000029807146`, 1, 1.0500000033404604`], 
     Hue[1.0000000013556545`, 1, 1.0500000015192699`], 
     Hue[1.0000000006165632`, 1, 1.0500000006909769`], 
     Hue[1.0000000002804181`, 1, 1.0500000003142622`], 
     Hue[1.0000000001275366`, 1, 1.0500000001429293`], 
     Hue[1.0000000000580047`, 1, 1.0500000000650054`], 
     Hue[1.0000000000263811`, 1, 1.050000000029565], 
     Hue[1.0000000000119984`, 1, 1.0500000000134464`], 
     Hue[1.000000000005457, 1, 1.0500000000061156`], 
     Hue[1.0000000000024818`, 1, 1.0500000000027814`], 
     Hue[1.0000000000011289`, 1, 1.050000000001265], 
     Hue[1.0000000000005134`, 1, 1.0500000000005754`], 
     Hue[1.0000000000002336`, 1, 1.0500000000002616`], 
     Hue[1.0000000000001061`, 1, 1.050000000000119], 
     Hue[1.0000000000000484`, 1, 1.0500000000000542`], 
     Hue[1.000000000000022, 1, 1.0500000000000247`], 
     Hue[1.00000000000001, 1, 1.0500000000000111`], 
     Hue[1.0000000000000044`, 1, 1.0500000000000052`], 
     Hue[1.000000000000002, 1, 1.0500000000000023`], 
     Hue[1.0000000000000009`, 1, 1.0500000000000012`], 
     Hue[1.0000000000000004`, 1, 1.0500000000000005`], 
     Hue[1.0000000000000002`, 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.432564986063353, 1, -17.474999625757572`], 
     Hue[1.432564986063353, 1, -17.100757209075603`], 
     Hue[1.432564986063353, 1, -16.726514792393633`], 
     Hue[1.432564986063353, 1, -16.35227237571166], 
     Hue[1.432564986063353, 1, -15.97802995902969], 
     Hue[1.432564986063353, 1, -15.603787542347721`], 
     Hue[1.4325649860633527`, 1, -15.229545125665748`], 
     Hue[1.4325649860633527`, 1, -14.855302708983777`], 
     Hue[1.4325649860633525`, 1, -14.481060292301803`], 
     Hue[1.432564986063352, 1, -14.10681787561983], 
     Hue[1.432564986063351, 1, -13.73257545893785], 
     Hue[1.4325649860633485`, 1, -13.358333042255865`], 
     Hue[1.4325649860633431`, 1, -12.984090625573858`], 
     Hue[1.4325649860633316`, 1, -12.609848208891812`], 
     Hue[1.4325649860633063`, 1, -12.23560579220967], 
     Hue[1.4325649860632503`, 1, -11.86136337552733], 
     Hue[1.4325649860631273`, 1, -11.487120958844546`], 
     Hue[1.432564986062857, 1, -11.112878542160786`], 
     Hue[1.432564986062263, 1, -10.738636125474883`], 
     Hue[1.4325649860609564`, 1, -10.364393708784267`], 
     Hue[1.4325649860580834`, 1, -9.990151292083285], 
     Hue[1.432564986051767, 1, -9.615908875359517], 
     Hue[1.4325649860378789`, 1, -9.241666458585645], 
     Hue[1.4325649860073422`, 1, -8.867424041701609], 
     Hue[1.4325649859402008`, 1, -8.493181624575351], 
     Hue[1.4325649857925753`, 1, -8.118939206916519], 
     Hue[1.4325649854679865`, 1, -7.744696788086691], 
     Hue[1.4325649847543047`, 1, -7.370454366682169], 
     Hue[1.4325649831851128`, 1, -6.996211939616594], 
     Hue[1.432564979734887, 1, -6.621969500103905], 
     Hue[1.4325649721487796`, 1, -6.247727033223409], 
     Hue[1.4325649554689912`, 1, -5.873484506168545], 
     Hue[1.4325649187946552`, 1, -5.49924184680659], 
     Hue[1.432564838157653, 1, -5.1249988965371225`], 
     Hue[1.4325646608582239`, 1, -4.750755306639987], 
     Hue[1.4325642710220179`, 1, -4.376510310369484], 
     Hue[1.432563413863552, 1, -4.002262221836091], 
     Hue[1.4325615291336962`, 1, -3.628007334108861], 
     Hue[1.4325573847783366`, 1, -3.2537374960798626`], 
     Hue[1.4325482707874255`, 1, -2.879434782894454], 
     Hue[1.4325282234657752`, 1, -2.505059769193079], 
     Hue[1.4324841054821336`, 1, -2.1305257041140475`], 
     Hue[1.4323869112492806`, 1, -1.755641530455614], 
     Hue[1.432172280909259, 1, -1.379985636100822], 
     Hue[1.4316958414990644`, 1, -1.002623583501198], 
     Hue[1.430625905247737, 1, -0.6214645383002522], 
     Hue[1.4281596975523008`, 1, -0.23173238399596152`], 
     Hue[1.422121949258041, 1, 0.1779739698521582], 
     Hue[1.4049845044458074`, 1, 0.6372421927421664], 
     Hue[1.3332761989836475`, 1, 1.2168403957848526`], 
     Hue[1.099288787079711, 1, 1.4039616041258545`], 
     Hue[1.0275804816175464`, 1, 1.1986058177651346`], 
     Hue[1.0104430368053121`, 1, 1.113580011557095], 
     Hue[1.0044052885110522`, 1, 1.0781160743909455`], 
     Hue[1.001939080815616, 1, 1.0626263367686255`], 
     Hue[1.0008691445642885`, 1, 1.055709708249651], 
     Hue[1.0003927051540937`, 1, 1.0525900723319979`], 
     Hue[1.0001780748140723`, 1, 1.0511765946591771`], 
     Hue[1.0000808805812194`, 1, 1.0505348376827153`], 
     Hue[1.0000367625975775`, 1, 1.050243189285654], 
     Hue[1.0000167152759274`, 1, 1.0501105922662495`], 
     Hue[1.0000076012850163`, 1, 1.0500502957628133`], 
     Hue[1.0000034569296568`, 1, 1.0500228744157862`], 
     Hue[1.000001572199801, 1, 1.0500104033705262`], 
     Hue[1.0000007150413348`, 1, 1.0500047315191054`], 
     Hue[1.000000325205129, 1, 1.0500021519305727`], 
     Hue[1.0000001479057, 1, 1.0500009787154077`], 
     Hue[1.0000000672686977`, 1, 1.0500004451279124`], 
     Hue[1.0000000305943615`, 1, 1.050000202447928], 
     Hue[1.0000000139145733`, 1, 1.0500000920750352`], 
     Hue[1.000000006328466, 1, 1.0500000418765092`], 
     Hue[1.00000000287824, 1, 1.0500000190457932`], 
     Hue[1.0000000013090482`, 1, 1.0500000086621888`], 
     Hue[1.0000000005953662`, 1, 1.0500000039396375`], 
     Hue[1.0000000002707776`, 1, 1.0500000017917808`], 
     Hue[1.000000000123152, 1, 1.050000000814917], 
     Hue[1.0000000000560105`, 1, 1.0500000003706313`], 
     Hue[1.000000000025474, 1, 1.0500000001685663`], 
     Hue[1.0000000000115858`, 1, 1.0500000000766654`], 
     Hue[1.0000000000052693`, 1, 1.0500000000348682`], 
     Hue[1.0000000000023965`, 1, 1.0500000000158585`], 
     Hue[1.00000000000109, 1, 1.0500000000072125`], 
     Hue[1.0000000000004958`, 1, 1.0500000000032803`], 
     Hue[1.0000000000002254`, 1, 1.050000000001492], 
     Hue[1.0000000000001026`, 1, 1.0500000000006786`], 
     Hue[1.0000000000000466`, 1, 1.0500000000003087`], 
     Hue[1.0000000000000213`, 1, 1.0500000000001404`], 
     Hue[1.0000000000000095`, 1, 1.0500000000000638`], 
     Hue[1.0000000000000044`, 1, 1.0500000000000291`], 
     Hue[1.000000000000002, 1, 1.0500000000000131`], 
     Hue[1.0000000000000009`, 1, 1.050000000000006], 
     Hue[1.0000000000000004`, 1, 1.0500000000000027`], 
     Hue[1.0000000000000002`, 1, 1.0500000000000014`], 
     Hue[1., 1, 1.0500000000000007`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.5579597871782842, 1, -17.474999625757572`], 
     Hue[0.5579597871782842, 1, -17.100757209075603`], 
     Hue[0.5579597871782842, 1, -16.726514792393633`], 
     Hue[0.5579597871782842, 1, -16.35227237571166], 
     Hue[0.5579597871782842, 1, -15.97802995902969], 
     Hue[0.5579597871782842, 1, -15.603787542347721`], 
     Hue[0.5579597871782843, 1, -15.229545125665748`], 
     Hue[0.5579597871782844, 1, -14.855302708983777`], 
     Hue[0.5579597871782846, 1, -14.481060292301803`], 
     Hue[0.5579597871782851, 1, -14.106817875619829`], 
     Hue[0.557959787178286, 1, -13.73257545893785], 
     Hue[0.557959787178288, 1, -13.358333042255863`], 
     Hue[0.5579597871782926, 1, -12.984090625573858`], 
     Hue[0.5579597871783026, 1, -12.609848208891808`], 
     Hue[0.5579597871783246, 1, -12.235605792209665`], 
     Hue[0.557959787178373, 1, -11.861363375527315`], 
     Hue[0.5579597871784796, 1, -11.487120958844509`], 
     Hue[0.5579597871787136, 1, -11.112878542160702`], 
     Hue[0.5579597871792285, 1, -10.738636125474704`], 
     Hue[0.5579597871803603, 1, -10.364393708783869`], 
     Hue[0.557959787182849, 1, -9.99015129208241], 
     Hue[0.5579597871883211, 1, -9.615908875357595], 
     Hue[0.5579597872003527, 1, -9.241666458581422], 
     Hue[0.5579597872268067, 1, -8.86742404169232], 
     Hue[0.5579597872849718, 1, -8.493181624554927], 
     Hue[0.557959787412861, 1, -8.118939206871609], 
     Hue[0.5579597876940547, 1, -7.744696787987947], 
     Hue[0.5579597883123232, 1, -7.370454366465059], 
     Hue[0.5579597896717269, 1, -6.996211939139228], 
     Hue[0.5579597926606854, 1, -6.621969499054308], 
     Hue[0.5579597992325915, 1, -6.2477270309156285`], 
     Hue[0.5579598136824273, 1, -5.873484501094361], 
     Hue[0.5579598454537023, 1, -5.499241835649832], 
     Hue[0.5579599153101946, 1, -5.124998872006396], 
     Hue[0.557960068906149, 1, -4.750755252703332], 
     Hue[0.557960406624529, 1, -4.376510191776175], 
     Hue[0.5579611491884321, 1, -4.00226196107542], 
     Hue[0.5579627819480129, 1, -3.628006760736726], 
     Hue[0.5579663722504352, 1, -3.253736235243408], 
     Hue[0.5579742678415052, 1, -2.879432009945968], 
     Hue[0.557991635322773, 1, -2.5050536687874247`], 
     Hue[0.5580298566600966, 1, -2.130512274295959], 
     Hue[0.5581140644382381, 1, -1.7556119210391745`], 
     Hue[0.5583000376556427, 1, -1.379920139500354], 
     Hue[0.5587129645790664, 1, -1.0024776455325985`], 
     Hue[0.5596407874158555, 1, -0.6211340499071609], 
     Hue[0.56178224625487, 1, -0.23095603002905607`], 
     Hue[0.5670430098116108, 1, 0.17996091834616745`], 
     Hue[0.582144273108951, 1, 0.6435484926488224], 
     Hue[0.6496358559184093, 1, 1.251775154645149], 
     Hue[0.9083239312598693, 1, 1.4388963629861533`], 
     Hue[0.9758155140693322, 1, 1.204912117671791], 
     Hue[0.990916777366673, 1, 1.1155669600511042`], 
     Hue[0.9961775409234142, 1, 1.0788924283578512`], 
     Hue[0.9983189997624287, 1, 1.0629568251617165`], 
     Hue[0.9992468225992178, 1, 1.05585564621825], 
     Hue[0.9996597495226415, 1, 1.052655568932466], 
     Hue[0.9998457227400462, 1, 1.0512062040756167`], 
     Hue[0.9999299305181877, 1, 1.0505482675008038`], 
     Hue[0.9999681518555112, 1, 1.0502492896913094`], 
     Hue[0.999985519336779, 1, 1.0501133652147356`], 
     Hue[0.999993414927849, 1, 1.0500515565992687`], 
     Hue[0.9999970052302714, 1, 1.050023447787921], 
     Hue[0.9999986379898521, 1, 1.0500106641311968`], 
     Hue[0.9999993805537553, 1, 1.0500048501124142`], 
     Hue[0.9999997182721352, 1, 1.0500022058672271`], 
     Hue[0.9999998718680897, 1, 1.0500010032461353`], 
     Hue[0.999999941724582, 1, 1.050000456284671], 
     Hue[0.9999999734958569, 1, 1.050000207522112], 
     Hue[0.9999999879456927, 1, 1.050000094382816], 
     Hue[0.9999999945175988, 1, 1.0500000429261076`], 
     Hue[0.9999999975065573, 1, 1.0500000195231594`], 
     Hue[0.999999998865961, 1, 1.0500000088792991`], 
     Hue[0.9999999994842295, 1, 1.050000004038381], 
     Hue[0.9999999997654232, 1, 1.0500000018366902`], 
     Hue[0.9999999998933125, 1, 1.0500000008353423`], 
     Hue[0.9999999999514776, 1, 1.0500000003799208`], 
     Hue[0.9999999999779315, 1, 1.0500000001727914`], 
     Hue[0.9999999999899631, 1, 1.050000000078587], 
     Hue[0.9999999999954351, 1, 1.0500000000357421`], 
     Hue[0.9999999999979239, 1, 1.0500000000162557`], 
     Hue[0.9999999999990558, 1, 1.0500000000073935`], 
     Hue[0.9999999999995706, 1, 1.0500000000033625`], 
     Hue[0.9999999999998047, 1, 1.0500000000015293`], 
     Hue[0.9999999999999112, 1, 1.0500000000006957`], 
     Hue[0.9999999999999596, 1, 1.0500000000003165`], 
     Hue[0.9999999999999816, 1, 1.050000000000144], 
     Hue[0.9999999999999917, 1, 1.0500000000000655`], 
     Hue[0.9999999999999962, 1, 1.0500000000000298`], 
     Hue[0.9999999999999982, 1, 1.0500000000000136`], 
     Hue[0.9999999999999992, 1, 1.0500000000000063`], 
     Hue[0.9999999999999997, 1, 1.050000000000003], 
     Hue[0.9999999999999999, 1, 1.0500000000000014`], 
     Hue[0.9999999999999999, 1, 1.0500000000000007`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.6833545882932159, 1, -17.474999625757572`], 
     Hue[0.6833545882932159, 1, -17.100757209075603`], 
     Hue[0.6833545882932159, 1, -16.726514792393633`], 
     Hue[0.6833545882932159, 1, -16.35227237571166], 
     Hue[0.6833545882932159, 1, -15.97802995902969], 
     Hue[0.683354588293216, 1, -15.603787542347721`], 
     Hue[0.6833545882932162, 1, -15.229545125665748`], 
     Hue[0.6833545882932164, 1, -14.855302708983777`], 
     Hue[0.6833545882932168, 1, -14.481060292301807`], 
     Hue[0.6833545882932179, 1, -14.106817875619832`], 
     Hue[0.6833545882932204, 1, -13.732575458937859`], 
     Hue[0.6833545882932257, 1, -13.358333042255879`], 
     Hue[0.6833545882932375, 1, -12.984090625573893`], 
     Hue[0.6833545882932631, 1, -12.609848208891888`], 
     Hue[0.6833545882933196, 1, -12.23560579220984], 
     Hue[0.6833545882934438, 1, -11.861363375527707`], 
     Hue[0.683354588293717, 1, -11.487120958845374`], 
     Hue[0.6833545882943175, 1, -11.112878542162603`], 
     Hue[0.683354588295638, 1, -10.73863612547888], 
     Hue[0.6833545882985412, 1, -10.36439370879305], 
     Hue[0.683354588304925, 1, -9.990151292102599], 
     Hue[0.6833545883189609, 1, -9.615908875401983], 
     Hue[0.683354588349822, 1, -9.241666458679022], 
     Hue[0.6833545884176772, 1, -8.867424041906917], 
     Hue[0.6833545885668721, 1, -8.493181625026768], 
     Hue[0.6833545888949114, 1, -8.118939207909058], 
     Hue[0.6833545896161803, 1, -7.7446967902690185`], 
     Hue[0.683354591202054, 1, -7.370454371480508], 
     Hue[0.6833545946889582, 1, -6.996211950166837], 
     Hue[0.6833546023557104, 1, -6.6219695233010185`], 
     Hue[0.6833546192128105, 1, -6.247727084227548], 
     Hue[0.683354656276985, 1, -5.873484618312784], 
     Hue[0.6833547377710307, 1, -5.499242093381391], 
     Hue[0.6833549169543588, 1, -5.124999438688794], 
     Hue[0.6833553109302963, 1, -4.750756498688017], 
     Hue[0.683356177179067, 1, -4.37651293137882], 
     Hue[0.6833580818387963, 1, -4.002267984820838], 
     Hue[0.6833622697378168, 1, -3.6280200058228242`], 
     Hue[0.6833714781313536, 1, -3.2537653600513172`], 
     Hue[0.683391726546506, 1, -2.8794960594194094`], 
     Hue[0.6834362553524334, 1, -2.5051945539518456`], 
     Hue[0.6835342010108076, 1, -2.1308223221208573`], 
     Hue[0.6837497449878213, 1, -1.7562949860352821`], 
     Hue[0.6842245757250076, 1, -1.381428581195909], 
     Hue[0.6852729747236361, 1, -1.0058262686160095`], 
     Hue[0.687599098251686, 1, -0.6286536519789583], 
     Hue[0.6928129389622515, 1, -0.2482729423768404], 
     Hue[0.7047286030708797, 1, 0.1378350088715593], 
     Hue[0.7326666689315915, 1, 0.528736064128534], 
     Hue[0.7953780659605623, 1, 0.886226646721138], 
     Hue[0.8879765223326507, 1, 1.0733478550621278`], 
     Hue[0.9506879193616229, 1, 1.0900996891514982`], 
     Hue[0.9786259852223356, 1, 1.0734410505764949`], 
     Hue[0.9905416493309641, 1, 1.0615755160100662`], 
     Hue[0.9957554900415299, 1, 1.0554372230899192`], 
     Hue[0.9980816135695798, 1, 1.0525070231348395`], 
     Hue[0.9991300125682083, 1, 1.051147127236911], 
     Hue[0.9996048433053947, 1, 1.0505231390795087`], 
     Hue[0.9998203872824083, 1, 1.0502382196759046`], 
     Hue[0.9999183329407826, 1, 1.050108404526888], 
     Hue[0.9999628617467099, 1, 1.0500493157412945`], 
     Hue[0.9999831101618624, 1, 1.0500224317913587`], 
     Hue[0.9999923185553992, 1, 1.0500102027018225`], 
     Hue[0.9999965064544196, 1, 1.0500046403857795`], 
     Hue[0.9999984111141489, 1, 1.050002110509768], 
     Hue[0.9999992773629196, 1, 1.0500009598825422`], 
     Hue[0.9999996713388571, 1, 1.0500004365637372`], 
     Hue[0.9999998505221852, 1, 1.0500001985531109`], 
     Hue[0.9999999320162309, 1, 1.0500000903036895`], 
     Hue[0.9999999690804054, 1, 1.0500000410708963`], 
     Hue[0.9999999859375055, 1, 1.0500000186793956`], 
     Hue[0.9999999936042577, 1, 1.0500000084955488`], 
     Hue[0.9999999970911619, 1, 1.0500000038638482`], 
     Hue[0.9999999986770356, 1, 1.050000001757311], 
     Hue[0.9999999993983045, 1, 1.05000000079924], 
     Hue[0.9999999997263438, 1, 1.0500000003635013`], 
     Hue[0.9999999998755388, 1, 1.0500000001653236`], 
     Hue[0.999999999943394, 1, 1.0500000000751906`], 
     Hue[0.9999999999742551, 1, 1.0500000000341974`], 
     Hue[0.999999999988291, 1, 1.0500000000155532`], 
     Hue[0.9999999999946746, 1, 1.0500000000070737`], 
     Hue[0.9999999999975779, 1, 1.0500000000032172`], 
     Hue[0.9999999999988984, 1, 1.0500000000014633`], 
     Hue[0.999999999999499, 1, 1.0500000000006655`], 
     Hue[0.9999999999997722, 1, 1.0500000000003027`], 
     Hue[0.9999999999998964, 1, 1.0500000000001377`], 
     Hue[0.9999999999999528, 1, 1.0500000000000627`], 
     Hue[0.9999999999999786, 1, 1.0500000000000285`], 
     Hue[0.9999999999999902, 1, 1.050000000000013], 
     Hue[0.9999999999999956, 1, 1.050000000000006], 
     Hue[0.999999999999998, 1, 1.0500000000000027`], 
     Hue[0.9999999999999991, 1, 1.0500000000000014`], 
     Hue[0.9999999999999996, 1, 1.0500000000000007`], 
     Hue[0.9999999999999998, 1, 1.0500000000000003`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.8087493894081474, 1, -17.474999625757572`], 
     Hue[0.8087493894081474, 1, -17.100757209075603`], 
     Hue[0.8087493894081474, 1, -16.726514792393633`], 
     Hue[0.8087493894081474, 1, -16.35227237571166], 
     Hue[0.8087493894081474, 1, -15.97802995902969], 
     Hue[0.8087493894081476, 1, -15.603787542347721`], 
     Hue[0.8087493894081476, 1, -15.229545125665748`], 
     Hue[0.8087493894081479, 1, -14.855302708983777`], 
     Hue[0.8087493894081483, 1, -14.481060292301807`], 
     Hue[0.8087493894081494, 1, -14.106817875619837`], 
     Hue[0.8087493894081519, 1, -13.73257545893787], 
     Hue[0.8087493894081574, 1, -13.358333042255904`], 
     Hue[0.8087493894081693, 1, -12.984090625573948`], 
     Hue[0.8087493894081955, 1, -12.609848208892007`], 
     Hue[0.8087493894082532, 1, -12.235605792210102`], 
     Hue[0.80874938940838, 1, -11.861363375528278`], 
     Hue[0.8087493894086588, 1, -11.487120958846628`], 
     Hue[0.8087493894092719, 1, -11.112878542165364`], 
     Hue[0.8087493894106199, 1, -10.738636125484952`], 
     Hue[0.8087493894135838, 1, -10.364393708806402`], 
     Hue[0.8087493894201004, 1, -9.990151292131953], 
     Hue[0.8087493894344289, 1, -9.615908875466527], 
     Hue[0.8087493894659332, 1, -9.241666458820932], 
     Hue[0.8087493895352025, 1, -8.86742404221894], 
     Hue[0.808749389687507, 1, -8.49318162571282], 
     Hue[0.808749390022383, 1, -8.118939209417501], 
     Hue[0.8087493907586841, 1, -7.7446967935856685`], 
     Hue[0.8087493923776096, 1, -7.370454378772922], 
     Hue[0.8087493959371853, 1, -6.996211966200865], 
     Hue[0.8087494037637221, 1, -6.621969558555477], 
     Hue[0.8087494209721424, 1, -6.247727161742492], 
     Hue[0.808749458808764, 1, -5.873484788747021], 
     Hue[0.808749542001159, 1, -5.499242468119842], 
     Hue[0.8087497249184452, 1, -5.125000262636566], 
     Hue[0.8087501271031357, 1, -4.750758310324847], 
     Hue[0.8087510113948987, 1, -4.376516914675576], 
     Hue[0.8087529556981241, 1, -4.002276743010101], 
     Hue[0.8087572306264112, 1, -3.628039262719547], 
     Hue[0.8087666297162142, 1, -3.253807700841656], 
     Hue[0.8087872942424309, 1, -2.8795891558682873`], 
     Hue[0.8088327225986873, 1, -2.505399250501145], 
     Hue[0.8089325718396521, 1, -2.1312724074884386`], 
     Hue[0.8091519421057511, 1, -1.7572846635484385`], 
     Hue[0.8096334488974098, 1, -1.3836048873536912`], 
     Hue[0.810688124940954, 1, -1.010612416270266], 
     Hue[0.8129874015563057, 1, -0.6391790866113949], 
     Hue[0.8179458586738362, 1, -0.2713927877742899], 
     Hue[0.828363679596515, 1, 0.08745197521287318], 
     Hue[0.8488689019994811, 1, 0.42352585617656613`], 
     Hue[0.883287480619358, 1, 0.7053115219739969], 
     Hue[0.9254619087887879, 1, 0.8924327303149845], 
     Hue[0.9598804874086655, 1, 0.9848894811995276], 
     Hue[0.980385709811632, 1, 1.0230580169178072`], 
     Hue[0.990803530734311, 1, 1.038455670612616], 
     Hue[0.9957619878518417, 1, 1.0449117884574823`], 
     Hue[0.9980612644671935, 1, 1.0477208754805822`], 
     Hue[0.9991159405107376, 1, 1.0489708210791289`], 
     Hue[0.9995974473023963, 1, 1.0495334615663527`], 
     Hue[0.9998168175684953, 1, 1.049788134308324], 
     Hue[0.9999166668094601, 1, 1.0499037079775881`], 
     Hue[0.9999620951657165, 1, 1.0499562192924172`], 
     Hue[0.9999827596919333, 1, 1.04998009100102], 
     Hue[0.9999921587817362, 1, 1.0499909458051002`], 
     Hue[0.9999964337100233, 1, 1.0499958821965172`], 
     Hue[0.9999983780132488, 1, 1.0499981272130132`], 
     Hue[0.9999992623050118, 1, 1.0499991482457132`], 
     Hue[0.9999996644897022, 1, 1.0499996126159648`], 
     Hue[0.9999998474069883, 1, 1.0499998238146608`], 
     Hue[0.9999999305993834, 1, 1.0499999198694516`], 
     Hue[0.999999968436005, 1, 1.0499999635559532`], 
     Hue[0.9999999856444254, 1, 1.0499999834249387`], 
     Hue[0.9999999934709621, 1, 1.049999992461521], 
     Hue[0.9999999970305379, 1, 1.0499999965714357`], 
     Hue[0.9999999986494633, 1, 1.0499999984406598`], 
     Hue[0.9999999993857644, 1, 1.049999999290799], 
     Hue[0.9999999997206405, 1, 1.0499999996774494`], 
     Hue[0.9999999998729449, 1, 1.0499999998533012`], 
     Hue[0.9999999999422142, 1, 1.04999999993328], 
     Hue[0.9999999999737186, 1, 1.0499999999696552`], 
     Hue[0.999999999988047, 1, 1.049999999986199], 
     Hue[0.9999999999945637, 1, 1.0499999999937233`], 
     Hue[0.9999999999975275, 1, 1.0499999999971452`], 
     Hue[0.9999999999988755, 1, 1.0499999999987017`], 
     Hue[0.9999999999994885, 1, 1.0499999999994094`], 
     Hue[0.9999999999997674, 1, 1.0499999999997316`], 
     Hue[0.9999999999998942, 1, 1.049999999999878], 
     Hue[0.9999999999999519, 1, 1.0499999999999445`], 
     Hue[0.9999999999999781, 1, 1.0499999999999747`], 
     Hue[0.99999999999999, 1, 1.0499999999999885`], 
     Hue[0.9999999999999954, 1, 1.0499999999999947`], 
     Hue[0.9999999999999979, 1, 1.0499999999999976`], 
     Hue[0.9999999999999991, 1, 1.049999999999999], 
     Hue[0.9999999999999996, 1, 1.0499999999999996`], 
     Hue[0.9999999999999998, 1, 1.0499999999999998`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.934144190523079, 1, -17.474999625757572`], 
     Hue[0.9341441905230791, 1, -17.100757209075603`], 
     Hue[0.934144190523079, 1, -16.726514792393633`], 
     Hue[0.9341441905230791, 1, -16.35227237571166], 
     Hue[0.9341441905230791, 1, -15.97802995902969], 
     Hue[0.9341441905230791, 1, -15.603787542347721`], 
     Hue[0.9341441905230791, 1, -15.229545125665748`], 
     Hue[0.9341441905230792, 1, -14.855302708983777`], 
     Hue[0.9341441905230794, 1, -14.48106029230181], 
     Hue[0.9341441905230798, 1, -14.106817875619843`], 
     Hue[0.934144190523081, 1, -13.732575458937879`], 
     Hue[0.9341441905230833, 1, -13.358333042255921`], 
     Hue[0.9341441905230885, 1, -12.984090625573987`], 
     Hue[0.9341441905230998, 1, -12.609848208892092`], 
     Hue[0.9341441905231246, 1, -12.23560579221029], 
     Hue[0.9341441905231793, 1, -11.861363375528692`], 
     Hue[0.9341441905232996, 1, -11.487120958847537`], 
     Hue[0.9341441905235638, 1, -11.11287854216736], 
     Hue[0.934144190524145, 1, -10.738636125489341`], 
     Hue[0.9341441905254227, 1, -10.364393708816054`], 
     Hue[0.9341441905282322, 1, -9.990151292153177], 
     Hue[0.9341441905344094, 1, -9.615908875513187], 
     Hue[0.9341441905479915, 1, -9.241666458923524], 
     Hue[0.9341441905778547, 1, -8.867424042444512], 
     Hue[0.9341441906435156, 1, -8.493181626208793], 
     Hue[0.9341441907878864, 1, -8.11893921050801], 
     Hue[0.9341441911053183, 1, -7.744696795983402], 
     Hue[0.9341441918032645, 1, -7.370454384044884], 
     Hue[0.9341441933378578, 1, -6.996211977792476], 
     Hue[0.9341441967120102, 1, -6.621969584042265], 
     Hue[0.9341442041308505, 1, -6.247727217780986], 
     Hue[0.9341442204428532, 1, -5.873484911960361], 
     Hue[0.9341442563084746, 1, -5.499242739032202], 
     Hue[0.9341443351670725, 1, -5.125000858298079], 
     Hue[0.9341445085550125, 1, -4.750759620017652], 
     Hue[0.9341448897848145, 1, -4.37651979431123], 
     Hue[0.9341457279906287, 1, -4.002283074438268], 
     Hue[0.9341475709060801, 1, -3.628053183292847], 
     Hue[0.9341516226331499, 1, -3.253838305914707], 
     Hue[0.9341605296248707, 1, -2.8796564361247228`], 
     Hue[0.9341801056897893, 1, -2.5055471236518994`], 
     Hue[0.9342231095679493, 1, -2.1315972609881966`], 
     Hue[0.9343174773846179, 1, -1.757997579479978], 
     Hue[0.9345240714841294, 1, -1.3851658943233829`], 
     Hue[0.9349740324091315, 1, -1.014013406240337], 
     Hue[0.9359431211869531, 1, -0.6465079270054019], 
     Hue[0.9379805775086667, 1, -0.28680796716901225`], 
     Hue[0.9420535177343086, 1, 0.05671055285649962], 
     Hue[0.9494213421738865, 1, 0.3688763506766626], 
     Hue[0.9605795414728034, 1, 0.6278832090571372], 
     Hue[0.9735646490502752, 1, 0.8150044173981241], 
     Hue[0.9847228483491922, 1, 0.9302399756996231], 
     Hue[0.9920906727887702, 1, 0.9923165945614332], 
     Hue[0.9961636130144123, 1, 1.0230404912178932`], 
     Hue[0.9982010693361258, 1, 1.037582948063475], 
     Hue[0.9991701581139475, 1, 1.0443198855105114`], 
     Hue[0.9996201190389495, 1, 1.047409814109437], 
     Hue[0.999826713138461, 1, 1.048820545634813], 
     Hue[0.9999210809551298, 1, 1.0494632808085658`], 
     Hue[0.9999640848332897, 1, 1.0497558348268343`], 
     Hue[0.9999836608982083, 1, 1.0498889390359818`], 
     Hue[0.9999925678899292, 1, 1.0499494859279694`], 
     Hue[0.9999966196169988, 1, 1.0499770252317993`], 
     Hue[0.9999984625324504, 1, 1.0499895507683497`], 
     Hue[0.9999993007382646, 1, 1.0499952475773588`], 
     Hue[0.9999996819680665, 1, 1.0499978385529085`], 
     Hue[0.9999998553560064, 1, 1.0499990169544515`], 
     Hue[0.9999999342146043, 1, 1.0499995529023], 
     Hue[0.9999999700802259, 1, 1.0499997966561123`], 
     Hue[0.9999999863922284, 1, 1.0499999075174575`], 
     Hue[0.9999999938110689, 1, 1.0499999579381496`], 
     Hue[0.9999999971852213, 1, 1.0499999808699114`], 
     Hue[0.9999999987198146, 1, 1.0499999912994726`], 
     Hue[0.9999999994177607, 1, 1.049999996042926], 
     Hue[0.9999999997351926, 1, 1.049999998200289], 
     Hue[0.9999999998795633, 1, 1.0499999991814761`], 
     Hue[0.9999999999452244, 1, 1.0499999996277285`], 
     Hue[0.9999999999750876, 1, 1.0499999998306877`], 
     Hue[0.9999999999886696, 1, 1.0499999999229954`], 
     Hue[0.9999999999948469, 1, 1.0499999999649776`], 
     Hue[0.9999999999976563, 1, 1.0499999999840717`], 
     Hue[0.9999999999989341, 1, 1.0499999999927556`], 
     Hue[0.9999999999995152, 1, 1.0499999999967051`], 
     Hue[0.9999999999997795, 1, 1.0499999999985015`], 
     Hue[0.9999999999998997, 1, 1.0499999999993186`], 
     Hue[0.9999999999999544, 1, 1.04999999999969], 
     Hue[0.9999999999999792, 1, 1.049999999999859], 
     Hue[0.9999999999999906, 1, 1.0499999999999359`], 
     Hue[0.9999999999999957, 1, 1.049999999999971], 
     Hue[0.999999999999998, 1, 1.0499999999999867`], 
     Hue[0.9999999999999991, 1, 1.049999999999994], 
     Hue[0.9999999999999996, 1, 1.0499999999999974`], 
     Hue[0.9999999999999998, 1, 1.0499999999999987`], 
     Hue[0.9999999999999999, 1, 1.0499999999999996`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.0595389916380107`, 1, -17.474999625757572`], 
     Hue[1.0595389916380107`, 1, -17.100757209075603`], 
     Hue[1.0595389916380107`, 1, -16.726514792393633`], 
     Hue[1.0595389916380107`, 1, -16.35227237571166], 
     Hue[1.0595389916380107`, 1, -15.97802995902969], 
     Hue[1.0595389916380107`, 1, -15.603787542347721`], 
     Hue[1.0595389916380105`, 1, -15.229545125665748`], 
     Hue[1.0595389916380105`, 1, -14.855302708983777`], 
     Hue[1.0595389916380102`, 1, -14.48106029230181], 
     Hue[1.0595389916380098`, 1, -14.106817875619843`], 
     Hue[1.059538991638009, 1, -13.732575458937879`], 
     Hue[1.0595389916380067`, 1, -13.358333042255923`], 
     Hue[1.059538991638002, 1, -12.98409062557399], 
     Hue[1.0595389916379918`, 1, -12.609848208892094`], 
     Hue[1.0595389916379692`, 1, -12.235605792210295`], 
     Hue[1.0595389916379194`, 1, -11.861363375528704`], 
     Hue[1.0595389916378102`, 1, -11.487120958847562`], 
     Hue[1.05953899163757, 1, -11.112878542167417`], 
     Hue[1.059538991637042, 1, -10.73863612548946], 
     Hue[1.0595389916358806`, 1, -10.36439370881632], 
     Hue[1.059538991633327, 1, -9.990151292153758], 
     Hue[1.059538991627713, 1, -9.615908875514469], 
     Hue[1.0595389916153688`, 1, -9.24166645892634], 
     Hue[1.0595389915882274`, 1, -8.867424042450706], 
     Hue[1.0595389915285511`, 1, -8.49318162622241], 
     Hue[1.059538991397339, 1, -8.118939210537953], 
     Hue[1.0595389911088395`, 1, -7.744696796049237], 
     Hue[1.0595389904745076`, 1, -7.370454384189636], 
     Hue[1.0595389890797844`, 1, -6.996211978110746], 
     Hue[1.0595389860131688`, 1, -6.621969584742054], 
     Hue[1.0595389792705177`, 1, -6.247727219319632], 
     Hue[1.0595389644452706`, 1, -5.873484915343422], 
     Hue[1.0595389318486172`, 1, -5.499242746470624], 
     Hue[1.0595388601775795`, 1, -5.125000874653103], 
     Hue[1.0595387025930783`, 1, -4.750759655977711], 
     Hue[1.0595383561105007`, 1, -4.376519873376733], 
     Hue[1.0595375943032521`, 1, -4.002283248277556], 
     Hue[1.0595359193620502`, 1, -3.6280535654977415`], 
     Hue[1.0595322369385942`, 1, -3.253839146180858], 
     Hue[1.0595241418192731`, 1, -2.879658283166144], 
     Hue[1.0595063502334634`, 1, -2.505551182498335], 
     Hue[1.0594672670056258`, 1, -2.131606174208037], 
     Hue[1.059381505470382, 1, -1.7580171238191296`], 
     Hue[1.0591937659818547`, 1, -1.385208610417177], 
     Hue[1.0587849333487709`, 1, -1.0141061035148347`], 
     Hue[1.0579047119824154`, 1, -0.6467059988718091], 
     Hue[1.0560553351407573`, 1, -0.28721742428901775`], 
     Hue[1.052363033150106, 1, 0.05592014834903403], 
     Hue[1.045697098744866, 1, 0.36753973296924913`], 
     Hue[1.0356243402699334`, 1, 0.6260759221583974], 
     Hue[1.0239146513680777`, 1, 0.8131971304993845], 
     Hue[1.013841892893145, 1, 0.9289033579922097], 
     Hue[1.007175958487905, 1, 0.9915261900539676], 
     Hue[1.0034836564972534`, 1, 1.0226310340978877`], 
     Hue[1.001634279655595, 1, 1.0373848761970679`], 
     Hue[1.0007540582892396`, 1, 1.044227188236014], 
     Hue[1.000345225656156, 1, 1.0473670980156429`], 
     Hue[1.0001574861676286`, 1, 1.0488010012956617`], 
     Hue[1.0000717246323847`, 1, 1.0494543675887253`], 
     Hue[1.0000326414045473`, 1, 1.0497517759803985`], 
     Hue[1.0000148498187373`, 1, 1.0498870919945602`], 
     Hue[1.0000067546994165`, 1, 1.0499486456618183`], 
     Hue[1.0000030722759603`, 1, 1.0499766430269055`], 
     Hue[1.0000013973347586`, 1, 1.0499893769290616`], 
     Hue[1.0000006355275097`, 1, 1.0499951685118565`], 
     Hue[1.0000002890449324`, 1, 1.0499978025928483`], 
     Hue[1.000000131460431, 1, 1.0499990005994275`], 
     Hue[1.0000000597893934`, 1, 1.0499995454638789`], 
     Hue[1.00000002719274, 1, 1.0499997932730514`], 
     Hue[1.000000012367493, 1, 1.049999905978812], 
     Hue[1.000000005624842, 1, 1.0499999572383603`], 
     Hue[1.000000002558226, 1, 1.0499999805516413`], 
     Hue[1.000000001163503, 1, 1.0499999911547206`], 
     Hue[1.0000000005291712`, 1, 1.0499999959770916`], 
     Hue[1.0000000002406715`, 1, 1.049999998170347], 
     Hue[1.0000000001094596`, 1, 1.0499999991678581`], 
     Hue[1.000000000049783, 1, 1.0499999996215348`], 
     Hue[1.0000000000226419`, 1, 1.0499999998278708`], 
     Hue[1.0000000000102978`, 1, 1.0499999999217142`], 
     Hue[1.0000000000046834`, 1, 1.049999999964395], 
     Hue[1.00000000000213, 1, 1.0499999999838066`], 
     Hue[1.0000000000009688`, 1, 1.049999999992635], 
     Hue[1.0000000000004405`, 1, 1.0499999999966503`], 
     Hue[1.0000000000002003`, 1, 1.0499999999984766`], 
     Hue[1.000000000000091, 1, 1.0499999999993073`], 
     Hue[1.0000000000000415`, 1, 1.049999999999685], 
     Hue[1.0000000000000189`, 1, 1.0499999999998566`], 
     Hue[1.0000000000000087`, 1, 1.0499999999999348`], 
     Hue[1.000000000000004, 1, 1.0499999999999705`], 
     Hue[1.0000000000000018`, 1, 1.0499999999999865`], 
     Hue[1.0000000000000009`, 1, 1.0499999999999938`], 
     Hue[1.0000000000000004`, 1, 1.0499999999999974`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999987`], 
     Hue[1., 1, 1.0499999999999996`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.1849337927529422`, 1, -17.474999625757572`], 
     Hue[1.1849337927529422`, 1, -17.100757209075603`], 
     Hue[1.1849337927529422`, 1, -16.726514792393633`], 
     Hue[1.1849337927529422`, 1, -16.35227237571166], 
     Hue[1.1849337927529422`, 1, -15.97802995902969], 
     Hue[1.1849337927529422`, 1, -15.603787542347721`], 
     Hue[1.184933792752942, 1, -15.229545125665748`], 
     Hue[1.1849337927529418`, 1, -14.855302708983777`], 
     Hue[1.1849337927529413`, 1, -14.481060292301807`], 
     Hue[1.1849337927529402`, 1, -14.10681787561984], 
     Hue[1.1849337927529378`, 1, -13.73257545893787], 
     Hue[1.1849337927529324`, 1, -13.358333042255904`], 
     Hue[1.1849337927529207`, 1, -12.984090625573952`], 
     Hue[1.184933792752895, 1, -12.609848208892013`], 
     Hue[1.184933792752838, 1, -12.235605792210114`], 
     Hue[1.1849337927527133`, 1, -11.861363375528304`], 
     Hue[1.184933792752439, 1, -11.48712095884669], 
     Hue[1.1849337927518357`, 1, -11.112878542165497`], 
     Hue[1.1849337927505097`, 1, -10.738636125485241`], 
     Hue[1.1849337927475936`, 1, -10.364393708807041`], 
     Hue[1.184933792741182, 1, -9.99015129213336], 
     Hue[1.1849337927270849`, 1, -9.615908875469616], 
     Hue[1.184933792696089, 1, -9.241666458827723], 
     Hue[1.1849337926279375`, 1, -8.86742404223387], 
     Hue[1.184933792478091, 1, -8.493181625745647], 
     Hue[1.1849337921486192`, 1, -8.118939209489682], 
     Hue[1.1849337914242006`, 1, -7.744696793744375], 
     Hue[1.1849337898314016`, 1, -7.370454379121875], 
     Hue[1.1849337863292708`, 1, -6.9962119669681195`], 
     Hue[1.1849337786290397`, 1, -6.6219695602424595`], 
     Hue[1.1849337616983313`, 1, -6.247727165451707], 
     Hue[1.1849337244723228`, 1, -5.873484796902574], 
     Hue[1.1849336426225021`, 1, -5.4992424860516715`], 
     Hue[1.1849334626571806`, 1, -5.125000302063737], 
     Hue[1.1849330669631035`, 1, -4.750758397014272], 
     Hue[1.1849321969426634`, 1, -4.3765171052811365`], 
     Hue[1.1849302840193106`, 1, -4.00227716209562], 
     Hue[1.184926078092239, 1, -3.6280401841542655`], 
     Hue[1.184916830743543, 1, -3.2538097267281847`], 
     Hue[1.1848964999814737`, 1, -2.8795936097701915`], 
     Hue[1.1848518060942528`, 1, -2.5054090411426504`], 
     Hue[1.184753574707976, 1, -2.1312939234367434`], 
     Hue[1.184537775915392, 1, -1.7573319179932614`], 
     Hue[1.1840641902367781`, 1, -1.383708528846913], 
     Hue[1.1830272561728568`, 1, -1.0108390408160484`], 
     Hue[1.180768508883216, 1, -0.6396712380921776], 
     Hue[1.1759059338432725`, 1, -0.2724446345482088], 
     Hue[1.1657256904212938`, 1, 0.08528950065069729], 
     Hue[1.1458159615250147`, 1, 0.4194929948585424], 
     Hue[1.1126783368024507`, 1, 0.6993283965988641], 
     Hue[1.072255455950493, 1, 0.8864496049398516], 
     Hue[1.0391178312279286`, 1, 0.9808566198815039], 
     Hue[1.0192081023316488`, 1, 1.0208955423556314`], 
     Hue[1.00902785890967, 1, 1.037403823838697], 
     Hue[1.0041652838697261`, 1, 1.0444196369766996`], 
     Hue[1.0019065365800854`, 1, 1.0474942509348002`], 
     Hue[1.0008696025161643`, 1, 1.0488671795859068`], 
     Hue[1.00039601683755, 1, 1.0494862071215294`], 
     Hue[1.0001802180449664`, 1, 1.049766618360019], 
     Hue[1.0000819866586894`, 1, 1.0498939173360833`], 
     Hue[1.0000372927714685`, 1, 1.0499517653905124`], 
     Hue[1.0000169620093993`, 1, 1.0499780651144914`], 
     Hue[1.0000077146607032`, 1, 1.0499900243703806`], 
     Hue[1.0000035087336316`, 1, 1.0499954631109973`], 
     Hue[1.0000015958102788`, 1, 1.0499979366074526`], 
     Hue[1.0000007257898387`, 1, 1.0499990615562877`], 
     Hue[1.0000003300957618`, 1, 1.0499995731887939`], 
     Hue[1.00000015013044, 1, 1.0499998058828306`], 
     Hue[1.0000000682806194`, 1, 1.049999911713899], 
     Hue[1.0000000310546109`, 1, 1.0499999598467376`], 
     Hue[1.0000000141239025`, 1, 1.0499999817379557`], 
     Hue[1.0000000064236714`, 1, 1.049999991694267], 
     Hue[1.0000000029215406`, 1, 1.049999996222482], 
     Hue[1.0000000013287416`, 1, 1.0499999982819526`], 
     Hue[1.000000000604323, 1, 1.0499999992186173`], 
     Hue[1.0000000002748513`, 1, 1.0499999996446205`], 
     Hue[1.0000000001250047`, 1, 1.0499999998383704`], 
     Hue[1.0000000000568532`, 1, 1.0499999999264895`], 
     Hue[1.0000000000258573`, 1, 1.0499999999665668`], 
     Hue[1.0000000000117601`, 1, 1.0499999999847944`], 
     Hue[1.0000000000053486`, 1, 1.0499999999930845`], 
     Hue[1.0000000000024325`, 1, 1.0499999999968548`], 
     Hue[1.0000000000011064`, 1, 1.0499999999985696`], 
     Hue[1.0000000000005032`, 1, 1.0499999999993495`], 
     Hue[1.000000000000229, 1, 1.049999999999704], 
     Hue[1.0000000000001041`, 1, 1.0499999999998655`], 
     Hue[1.0000000000000473`, 1, 1.0499999999999388`], 
     Hue[1.0000000000000215`, 1, 1.0499999999999723`], 
     Hue[1.0000000000000098`, 1, 1.0499999999999874`], 
     Hue[1.0000000000000044`, 1, 1.0499999999999943`], 
     Hue[1.000000000000002, 1, 1.0499999999999974`], 
     Hue[1.0000000000000009`, 1, 1.049999999999999], 
     Hue[1.0000000000000004`, 1, 1.0499999999999996`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.3103285938678737`, 1, -17.474999625757572`], 
     Hue[1.3103285938678737`, 1, -17.100757209075603`], 
     Hue[1.3103285938678737`, 1, -16.726514792393633`], 
     Hue[1.3103285938678737`, 1, -16.35227237571166], 
     Hue[1.3103285938678737`, 1, -15.97802995902969], 
     Hue[1.3103285938678737`, 1, -15.603787542347721`], 
     Hue[1.3103285938678737`, 1, -15.229545125665748`], 
     Hue[1.3103285938678733`, 1, -14.855302708983777`], 
     Hue[1.3103285938678728`, 1, -14.481060292301807`], 
     Hue[1.3103285938678717`, 1, -14.106817875619834`], 
     Hue[1.3103285938678693`, 1, -13.732575458937859`], 
     Hue[1.310328593867864, 1, -13.35833304225588], 
     Hue[1.310328593867852, 1, -12.984090625573897`], 
     Hue[1.310328593867826, 1, -12.609848208891894`], 
     Hue[1.3103285938677685`, 1, -12.235605792209855`], 
     Hue[1.310328593867642, 1, -11.861363375527734`], 
     Hue[1.3103285938673643`, 1, -11.487120958845432`], 
     Hue[1.3103285938667537`, 1, -11.112878542162735`], 
     Hue[1.3103285938654108`, 1, -10.738636125479168`], 
     Hue[1.3103285938624585`, 1, -10.364393708793687`], 
     Hue[1.3103285938559672`, 1, -9.990151292103999], 
     Hue[1.3103285938416946`, 1, -9.61590887540506], 
     Hue[1.3103285938103126`, 1, -9.241666458685783], 
     Hue[1.3103285937413127`, 1, -8.867424041921787], 
     Hue[1.3103285935896003`, 1, -8.49318162505946], 
     Hue[1.3103285932560262`, 1, -8.118939207980942], 
     Hue[1.3103285925225878`, 1, -7.744696790427072], 
     Hue[1.3103285909099565`, 1, -7.370454371828026], 
     Hue[1.3103285873642194`, 1, -6.996211950930934], 
     Hue[1.31032857956811, 1, -6.621969524981059], 
     Hue[1.310328562426589, 1, -6.247727087921498], 
     Hue[1.3103285247370506`, 1, -5.873484626434774], 
     Hue[1.3103284418680021`, 1, -5.499242111239442], 
     Hue[1.3103282596614276`, 1, -5.1249994779538195`], 
     Hue[1.3103278590382423`, 1, -4.75075658502129], 
     Hue[1.3103269781742126`, 1, -4.376513121203037], 
     Hue[1.3103250413806127`, 1, -4.002268402196803], 
     Hue[1.3103207828332903`, 1, -3.628020923539353], 
     Hue[1.310311419129124, 1, -3.2537673779590897`], 
     Hue[1.310290829352665, 1, -2.8795004967283235`], 
     Hue[1.3102455505882622`, 1, -2.5052043127031878`], 
     Hue[1.3101459588902666`, 1, -2.130843790157618], 
     Hue[1.3099268098575203`, 1, -1.7563422424925579`], 
     Hue[1.3094441214178763`, 1, -1.3815327461337186`], 
     Hue[1.3083787834422107`, 1, -1.0060565529285797`], 
     Hue[1.3060171048828988`, 1, -0.6291659657350512], 
     Hue[1.3007338388019472`, 1, -0.24942731116841976`], 
     Hue[1.2887138336071908`, 1, 0.13517529322092492`], 
     Hue[1.2608314542861778`, 1, 0.5225102227950682], 
     Hue[1.199613466668365, 1, 0.8736407687001033], 
     Hue[1.1107151271995117`, 1, 1.0607619770410928`], 
     Hue[1.0494971395816974`, 1, 1.083873847818032], 
     Hue[1.0216147602606838`, 1, 1.0707813349258601`], 
     Hue[1.009594755065927, 1, 1.0604211472184868`], 
     Hue[1.0043114889849751`, 1, 1.0549249093338264`], 
     Hue[1.0019498104256632`, 1, 1.0522767388222687`], 
     Hue[1.0008844724499977`, 1, 1.0510429622991013`], 
     Hue[1.0004017840103534`, 1, 1.0504758826222331`], 
     Hue[1.000182634977607, 1, 1.0502167516391445`], 
     Hue[1.0000830432796115`, 1, 1.050098645775546], 
     Hue[1.000037764515209, 1, 1.0500448784323804`], 
     Hue[1.0000171747387498`, 1, 1.0500204138835867`], 
     Hue[1.0000078110345836`, 1, 1.050009284985294], 
     Hue[1.000003552487261, 1, 1.050004223009814], 
     Hue[1.0000016156936613`, 1, 1.0500019206855518`], 
     Hue[1.0000007348296316`, 1, 1.0500008735492699`], 
     Hue[1.000000334206446, 1, 1.0500003972987113`], 
     Hue[1.0000001519998716`, 1, 1.0500001806950596`], 
     Hue[1.000000069130823, 1, 1.0500000821816988`], 
     Hue[1.0000000314412847`, 1, 1.0500000373769467`], 
     Hue[1.0000000142997638`, 1, 1.050000016999356], 
     Hue[1.0000000065036543`, 1, 1.0500000077314524`], 
     Hue[1.0000000029579175`, 1, 1.0500000035163306`], 
     Hue[1.000000001345286, 1, 1.0500000015992572`], 
     Hue[1.0000000006118475`, 1, 1.0500000007273558`], 
     Hue[1.0000000002782734`, 1, 1.0500000003308076`], 
     Hue[1.0000000001265612`, 1, 1.0500000001504541`], 
     Hue[1.000000000057561, 1, 1.0500000000684278`], 
     Hue[1.0000000000261793`, 1, 1.0500000000311216`], 
     Hue[1.0000000000119065`, 1, 1.0500000000141543`], 
     Hue[1.0000000000054152`, 1, 1.0500000000064376`], 
     Hue[1.000000000002463, 1, 1.050000000002928], 
     Hue[1.0000000000011202`, 1, 1.0500000000013316`], 
     Hue[1.0000000000005094`, 1, 1.0500000000006056`], 
     Hue[1.0000000000002316`, 1, 1.0500000000002756`], 
     Hue[1.0000000000001055`, 1, 1.0500000000001253`], 
     Hue[1.000000000000048, 1, 1.0500000000000569`], 
     Hue[1.0000000000000218`, 1, 1.050000000000026], 
     Hue[1.00000000000001, 1, 1.0500000000000118`], 
     Hue[1.0000000000000044`, 1, 1.0500000000000054`], 
     Hue[1.000000000000002, 1, 1.0500000000000025`], 
     Hue[1.0000000000000009`, 1, 1.0500000000000012`], 
     Hue[1.0000000000000004`, 1, 1.0500000000000005`], 
     Hue[1.0000000000000002`, 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.4357233949828054`, 1, -17.474999625757572`], 
     Hue[1.4357233949828054`, 1, -17.100757209075603`], 
     Hue[1.4357233949828054`, 1, -16.726514792393633`], 
     Hue[1.4357233949828054`, 1, -16.35227237571166], 
     Hue[1.4357233949828054`, 1, -15.97802995902969], 
     Hue[1.4357233949828054`, 1, -15.603787542347721`], 
     Hue[1.4357233949828054`, 1, -15.229545125665748`], 
     Hue[1.4357233949828052`, 1, -14.855302708983777`], 
     Hue[1.435723394982805, 1, -14.481060292301803`], 
     Hue[1.4357233949828045`, 1, -14.106817875619829`], 
     Hue[1.4357233949828037`, 1, -13.73257545893785], 
     Hue[1.4357233949828012`, 1, -13.358333042255865`], 
     Hue[1.435723394982796, 1, -12.984090625573858`], 
     Hue[1.4357233949827852`, 1, -12.60984820889181], 
     Hue[1.435723394982761, 1, -12.23560579220967], 
     Hue[1.4357233949827075`, 1, -11.861363375527324`], 
     Hue[1.43572339498259, 1, -11.487120958844534`], 
     Hue[1.4357233949823316`, 1, -11.112878542160757`], 
     Hue[1.4357233949817636`, 1, -10.738636125474821`], 
     Hue[1.4357233949805148`, 1, -10.364393708784126`], 
     Hue[1.435723394977769, 1, -9.990151292082981], 
     Hue[1.4357233949717316`, 1, -9.615908875358846], 
     Hue[1.4357233949584571`, 1, -9.24166645858417], 
     Hue[1.4357233949292703`, 1, -8.867424041698364], 
     Hue[1.435723394865096, 1, -8.493181624568217], 
     Hue[1.4357233947239945`, 1, -8.118939206900835], 
     Hue[1.4357233944137504`, 1, -7.744696788052207], 
     Hue[1.4357233937316087`, 1, -7.370454366606347], 
     Hue[1.4357233922317647`, 1, -6.996211939449885], 
     Hue[1.4357233889340162`, 1, -6.621969499737358], 
     Hue[1.4357233816831647`, 1, -6.247727032417471], 
     Hue[1.4357233657405133`, 1, -5.873484504396505], 
     Hue[1.435723330686941, 1, -5.499241842910354], 
     Hue[1.4357232536135618`, 1, -5.124998887970341], 
     Hue[1.435723084149591, 1, -4.750755287803876], 
     Hue[1.4357227115415327`, 1, -4.376510268953557], 
     Hue[1.4357218922636021`, 1, -4.002262130771572], 
     Hue[1.4357200908252994`, 1, -3.6280071338722415`], 
     Hue[1.435716129617834, 1, -3.2537370557630485`], 
     Hue[1.4357074183795144`, 1, -2.8794338145108815`], 
     Hue[1.4356882568925649`, 1, -2.505057638787222], 
     Hue[1.4356460880280548`, 1, -2.13052101415121], 
     Hue[1.4355531862016802`, 1, -1.755631190480526], 
     Hue[1.4353480267718877`, 1, -1.3799627650009854`], 
     Hue[1.4348925721241197`, 1, -1.0025726282764127`], 
     Hue[1.433869562537783, 1, -0.6213491752277025], 
     Hue[1.431510435702446, 1, -0.2314615488569225], 
     Hue[1.4257279212146643`, 1, 0.1786659776922811], 
     Hue[1.4092507913839674`, 1, 0.6394255433526332], 
     Hue[1.338772012779124, 1, 1.2284656137010275`], 
     Hue[1.096951382203687, 1, 1.4155868220420302`], 
     Hue[1.0264726035988392`, 1, 1.2007891683756016`], 
     Hue[1.0099954737681416`, 1, 1.1142720193972178`], 
     Hue[1.0042129592803597`, 1, 1.0783869095299845`], 
     Hue[1.0018538324450224`, 1, 1.0627416998411754`], 
     Hue[1.0008308228586857`, 1, 1.0557606634744359`], 
     Hue[1.0003753682109178`, 1, 1.0526129434318345`], 
     Hue[1.0001702087811253`, 1, 1.051186934634265], 
     Hue[1.0000773069547506`, 1, 1.0505395276455518`], 
     Hue[1.0000351380902406`, 1, 1.050245319691511], 
     Hue[1.000015976603291, 1, 1.0501115606498226`], 
     Hue[1.0000072653649714`, 1, 1.050050736079627], 
     Hue[1.0000033041575063`, 1, 1.0500230746524053`], 
     Hue[1.0000015027192033`, 1, 1.0500104944350448`], 
     Hue[1.0000006834412727`, 1, 1.0500047729350317`], 
     Hue[1.0000003108332145`, 1, 1.0500021707666833`], 
     Hue[1.0000001413692436`, 1, 1.050000987282189], 
     Hue[1.0000000642958644`, 1, 1.0500004490241486`], 
     Hue[1.0000000292422921`, 1, 1.0500002042199679`], 
     Hue[1.0000000132996407`, 1, 1.0500000928809736`], 
     Hue[1.0000000060487892`, 1, 1.0500000422430567`], 
     Hue[1.0000000027510407`, 1, 1.050000019212502], 
     Hue[1.0000000012511967`, 1, 1.0500000087380097`], 
     Hue[1.000000000569055, 1, 1.0500000039741213`], 
     Hue[1.000000000258811, 1, 1.0500000018074642`], 
     Hue[1.0000000001177094`, 1, 1.0500000008220503`], 
     Hue[1.0000000000535352`, 1, 1.0500000003738754`], 
     Hue[1.0000000000243483`, 1, 1.0500000001700418`], 
     Hue[1.0000000000110738`, 1, 1.0500000000773364`], 
     Hue[1.0000000000050364`, 1, 1.0500000000351732`], 
     Hue[1.0000000000022906`, 1, 1.0500000000159972`], 
     Hue[1.0000000000010418`, 1, 1.0500000000072756`], 
     Hue[1.0000000000004738`, 1, 1.0500000000033092`], 
     Hue[1.0000000000002156`, 1, 1.050000000001505], 
     Hue[1.000000000000098, 1, 1.0500000000006846`], 
     Hue[1.0000000000000446`, 1, 1.0500000000003114`], 
     Hue[1.0000000000000202`, 1, 1.0500000000001417`], 
     Hue[1.0000000000000093`, 1, 1.0500000000000644`], 
     Hue[1.0000000000000042`, 1, 1.0500000000000294`], 
     Hue[1.000000000000002, 1, 1.0500000000000134`], 
     Hue[1.0000000000000009`, 1, 1.0500000000000063`], 
     Hue[1.0000000000000004`, 1, 1.0500000000000027`], 
     Hue[1.0000000000000002`, 1, 1.0500000000000014`], 
     Hue[1., 1, 1.0500000000000007`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.5611181960977369, 1, -17.474999625757572`], 
     Hue[0.5611181960977369, 1, -17.100757209075603`], 
     Hue[0.5611181960977369, 1, -16.726514792393633`], 
     Hue[0.5611181960977369, 1, -16.35227237571166], 
     Hue[0.5611181960977369, 1, -15.97802995902969], 
     Hue[0.561118196097737, 1, -15.603787542347721`], 
     Hue[0.561118196097737, 1, -15.229545125665748`], 
     Hue[0.5611181960977372, 1, -14.855302708983777`], 
     Hue[0.5611181960977374, 1, -14.481060292301803`], 
     Hue[0.5611181960977378, 1, -14.106817875619829`], 
     Hue[0.5611181960977388, 1, -13.73257545893785], 
     Hue[0.561118196097741, 1, -13.358333042255865`], 
     Hue[0.5611181960977458, 1, -12.984090625573858`], 
     Hue[0.5611181960977564, 1, -12.609848208891808`], 
     Hue[0.5611181960977795, 1, -12.235605792209666`], 
     Hue[0.5611181960978304, 1, -11.86136337552732], 
     Hue[0.5611181960979424, 1, -11.487120958844521`], 
     Hue[0.5611181960981887, 1, -11.11287854216073], 
     Hue[0.5611181960987303, 1, -10.73863612547476], 
     Hue[0.5611181960999209, 1, -10.364393708783995`], 
     Hue[0.5611181961025387, 1, -9.990151292082688], 
     Hue[0.5611181961082945, 1, -9.615908875358205], 
     Hue[0.5611181961209499, 1, -9.241666458582761], 
     Hue[0.5611181961487759, 1, -8.867424041695267], 
     Hue[0.5611181962099576, 1, -8.493181624561409], 
     Hue[0.5611181963444796, 1, -8.118939206885862], 
     Hue[0.5611181966402565, 1, -7.744696788019289], 
     Hue[0.5611181972905898, 1, -7.370454366533967], 
     Hue[0.5611181987204952, 1, -6.996211939290741], 
     Hue[0.5611182018644678, 1, -6.621969499387445], 
     Hue[0.5611182087772076, 1, -6.24772703164811], 
     Hue[0.5611182239764441, 1, -5.873484502704888], 
     Hue[0.561118257395448, 1, -5.499241839190946], 
     Hue[0.5611183308748522, 1, -5.124998879792359], 
     Hue[0.5611184924366275, 1, -4.750755269822631], 
     Hue[0.5611188476697961, 1, -4.376510229417264], 
     Hue[0.5611196287445238, 1, -4.002262043839936], 
     Hue[0.5611213461817064, 1, -3.628006942723098], 
     Hue[0.5611251226806033, 1, -3.2537366354290187`], 
     Hue[0.5611334277322776, 1, -2.879432890073198], 
     Hue[0.5611516958216052, 1, -2.505055605050874], 
     Hue[0.5611918988782307, 1, -2.1305165369534373`], 
     Hue[0.5612804713129054, 1, -1.7556213193597057`], 
     Hue[0.5614760770893699, 1, -1.379940929838859], 
     Hue[0.5619103580063722, 1, -1.0025239754259119`], 
     Hue[0.5628859896287532, 1, -0.621238995542913], 
     Hue[0.5651368495470258, 1, -0.23120271696585215`], 
     Hue[0.5706603187970514, 1, 0.17932846558366067`], 
     Hue[0.5864585607591717, 1, 0.6415286982427686], 
     Hue[0.6555353914293939, 1, 1.240120676930572], 
     Hue[0.9055828046683375, 1, 1.4272418852715754`], 
     Hue[0.9746596353385644, 1, 1.2028923232657371`], 
     Hue[0.9904578773006854, 1, 1.1149345072885977`], 
     Hue[0.9959813465507111, 1, 1.078645741421055], 
     Hue[0.9982322064689837, 1, 1.0628518795259647`], 
     Hue[0.9992078380913647, 1, 1.055809316324937], 
     Hue[0.9996421190083672, 1, 1.0526347785939612`], 
     Hue[0.9998377247848317, 1, 1.0511968057550851`], 
     Hue[0.9999262972195062, 1, 1.0505440048433248`], 
     Hue[0.9999665002761318, 1, 1.0502473534278596`], 
     Hue[0.9999847683654595, 1, 1.050112485087506], 
     Hue[0.9999930734171336, 1, 1.0500511564136574`], 
     Hue[0.9999968499160307, 1, 1.0500232658015496`], 
     Hue[0.9999985673532131, 1, 1.0500105813666814`], 
     Hue[0.9999993484279409, 1, 1.0500048124713246`], 
     Hue[0.9999997036611095, 1, 1.0500021887479287`], 
     Hue[0.9999998652228848, 1, 1.0500009954601717`], 
     Hue[0.999999938702289, 1, 1.0500004527435565`], 
     Hue[0.999999972121293, 1, 1.0500002059115845`], 
     Hue[0.9999999873205293, 1, 1.0500000936503349`], 
     Hue[0.9999999942332692, 1, 1.0500000425929688`], 
     Hue[0.9999999973772419, 1, 1.050000019371645], 
     Hue[0.9999999988071473, 1, 1.0500000088103891`], 
     Hue[0.9999999994574804, 1, 1.05000000400704], 
     Hue[0.9999999997532575, 1, 1.050000001822436], 
     Hue[0.9999999998877794, 1, 1.0500000008288595`], 
     Hue[0.9999999999489612, 1, 1.0500000003769725`], 
     Hue[0.9999999999767871, 1, 1.0500000001714502`], 
     Hue[0.9999999999894426, 1, 1.050000000077977], 
     Hue[0.9999999999951984, 1, 1.0500000000354648`], 
     Hue[0.9999999999978162, 1, 1.0500000000161296`], 
     Hue[0.9999999999990068, 1, 1.050000000007336], 
     Hue[0.9999999999995483, 1, 1.0500000000033365`], 
     Hue[0.9999999999997945, 1, 1.0500000000015175`], 
     Hue[0.9999999999999065, 1, 1.0500000000006902`], 
     Hue[0.9999999999999575, 1, 1.050000000000314], 
     Hue[0.9999999999999807, 1, 1.0500000000001428`], 
     Hue[0.9999999999999912, 1, 1.050000000000065], 
     Hue[0.999999999999996, 1, 1.0500000000000296`], 
     Hue[0.9999999999999982, 1, 1.0500000000000136`], 
     Hue[0.9999999999999992, 1, 1.0500000000000063`], 
     Hue[0.9999999999999997, 1, 1.050000000000003], 
     Hue[0.9999999999999998, 1, 1.0500000000000014`], 
     Hue[0.9999999999999999, 1, 1.0500000000000007`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.6865129972126687, 1, -17.474999625757572`], 
     Hue[0.6865129972126687, 1, -17.100757209075603`], 
     Hue[0.6865129972126687, 1, -16.726514792393633`], 
     Hue[0.6865129972126687, 1, -16.35227237571166], 
     Hue[0.6865129972126687, 1, -15.97802995902969], 
     Hue[0.6865129972126687, 1, -15.603787542347721`], 
     Hue[0.6865129972126689, 1, -15.229545125665748`], 
     Hue[0.6865129972126691, 1, -14.855302708983777`], 
     Hue[0.6865129972126696, 1, -14.481060292301807`], 
     Hue[0.6865129972126707, 1, -14.106817875619832`], 
     Hue[0.6865129972126731, 1, -13.732575458937859`], 
     Hue[0.6865129972126784, 1, -13.35833304225588], 
     Hue[0.6865129972126903, 1, -12.984090625573895`], 
     Hue[0.6865129972127162, 1, -12.609848208891892`], 
     Hue[0.6865129972127733, 1, -12.235605792209848`], 
     Hue[0.6865129972128985, 1, -11.861363375527722`], 
     Hue[0.686512997213174, 1, -11.487120958845402`], 
     Hue[0.6865129972137798, 1, -11.112878542162669`], 
     Hue[0.6865129972151116, 1, -10.738636125479024`], 
     Hue[0.6865129972180399, 1, -10.364393708793369`], 
     Hue[0.6865129972244788, 1, -9.990151292103297], 
     Hue[0.6865129972386359, 1, -9.615908875403516], 
     Hue[0.6865129972697634, 1, -9.241666458682388], 
     Hue[0.6865129973382046, 1, -8.86742404191432], 
     Hue[0.6865129974886879, 1, -8.493181625043047], 
     Hue[0.6865129978195597, 1, -8.118939207944852], 
     Hue[0.6865129985470566, 1, -7.744696790347713], 
     Hue[0.6865130001466241, 1, -7.37045437165354], 
     Hue[0.6865130036636372, 1, -6.996211950547289], 
     Hue[0.6865130113965907, 1, -6.621969524137525], 
     Hue[0.6865130283992491, 1, -6.247727086066798], 
     Hue[0.6865130657834666, 1, -5.873484622356794], 
     Hue[0.6865131479811987, 1, -5.4992421022730715`], 
     Hue[0.6865133287117364, 1, -5.124999458239196], 
     Hue[0.6865137260895435, 1, -4.750756541674117], 
     Hue[0.6865145998179866, 1, -4.376513025893986], 
     Hue[0.6865165209229378, 1, -4.002268192636091], 
     Hue[0.6865207449779125, 1, -3.628020462762392], 
     Hue[0.6865300328559345, 1, -3.2537663647874755`], 
     Hue[0.6865504559748525, 1, -2.8794982688048787`], 
     Hue[0.6865953686118571, 1, -2.505199412970028], 
     Hue[0.6866941567823484, 1, -2.1308330114876], 
     Hue[0.6869115462879527, 1, -1.7563185166160193`], 
     Hue[0.6873904011089554, 1, -1.3814804515445307`], 
     Hue[0.6884474822686344, 1, -1.0059409571096813`], 
     Hue[0.6907918664038697, 1, -0.6289088756383676], 
     Hue[0.6960415519557478, 1, -0.24884841408664515`], 
     Hue[0.708012143207743, 1, 0.13650698989609844`], 
     Hue[0.7359285633058349, 1, 0.5256157626274821], 
     Hue[0.7978945541250174, 1, 0.8798766617961593], 
     Hue[0.8886184430876483, 1, 1.0669978701371488`], 
     Hue[0.9505844339068323, 1, 1.086979387650446], 
     Hue[0.9785008540049251, 1, 1.0721130316010339`], 
     Hue[0.9904714452569205, 1, 1.0610000443002612`], 
     Hue[0.9957211308087989, 1, 1.05518199943051], 
     Hue[0.9980655149440342, 1, 1.0523923346411672`], 
     Hue[0.9991225961037132, 1, 1.051095256888289], 
     Hue[0.999601450924716, 1, 1.0504996084987717`], 
     Hue[0.9998188404303203, 1, 1.050227530309162], 
     Hue[0.9999176286008117, 1, 1.0501035455087055`], 
     Hue[0.9999625412378161, 1, 1.050047106355825], 
     Hue[0.9999829643567342, 1, 1.0500214270552009`], 
     Hue[0.9999922522347562, 1, 1.0500097457622541`], 
     Hue[0.9999964762897309, 1, 1.0500044325705264`], 
     Hue[0.9999983973946821, 1, 1.0500020159946035`], 
     Hue[0.9999992711231251, 1, 1.050000916896443], 
     Hue[0.9999996685009322, 1, 1.050000417013335], 
     Hue[0.99999984923147, 1, 1.05000018966143], 
     Hue[0.9999999314292021, 1, 1.0500000862596788`], 
     Hue[0.9999999688134196, 1, 1.0500000392316464`], 
     Hue[0.999999985816078, 1, 1.0500000178428892`], 
     Hue[0.9999999935490315, 1, 1.0500000081150984`], 
     Hue[0.9999999970660446, 1, 1.0500000036908161`], 
     Hue[0.9999999986656121, 1, 1.0500000016786146`], 
     Hue[0.999999999393109, 1, 1.0500000007634482`], 
     Hue[0.9999999997239808, 1, 1.0500000003472227`], 
     Hue[0.9999999998744641, 1, 1.05000000015792], 
     Hue[0.9999999999429052, 1, 1.0500000000718235`], 
     Hue[0.9999999999740328, 1, 1.050000000032666], 
     Hue[0.9999999999881899, 1, 1.0500000000148568`], 
     Hue[0.9999999999946286, 1, 1.050000000006757], 
     Hue[0.9999999999975571, 1, 1.0500000000030731`], 
     Hue[0.9999999999988889, 1, 1.0500000000013978`], 
     Hue[0.9999999999994946, 1, 1.0500000000006358`], 
     Hue[0.9999999999997702, 1, 1.0500000000002891`], 
     Hue[0.9999999999998955, 1, 1.0500000000001315`], 
     Hue[0.9999999999999525, 1, 1.0500000000000598`], 
     Hue[0.9999999999999784, 1, 1.0500000000000274`], 
     Hue[0.9999999999999901, 1, 1.0500000000000125`], 
     Hue[0.9999999999999956, 1, 1.0500000000000058`], 
     Hue[0.999999999999998, 1, 1.0500000000000027`], 
     Hue[0.9999999999999991, 1, 1.0500000000000012`], 
     Hue[0.9999999999999996, 1, 1.0500000000000005`], 
     Hue[0.9999999999999998, 1, 1.0500000000000003`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.8119077983276003, 1, -17.474999625757572`], 
     Hue[0.8119077983276003, 1, -17.100757209075603`], 
     Hue[0.8119077983276003, 1, -16.726514792393633`], 
     Hue[0.8119077983276004, 1, -16.35227237571166], 
     Hue[0.8119077983276004, 1, -15.97802995902969], 
     Hue[0.8119077983276004, 1, -15.603787542347721`], 
     Hue[0.8119077983276005, 1, -15.229545125665748`], 
     Hue[0.8119077983276007, 1, -14.855302708983777`], 
     Hue[0.8119077983276013, 1, -14.481060292301807`], 
     Hue[0.8119077983276024, 1, -14.10681787561984], 
     Hue[0.8119077983276048, 1, -13.73257545893787], 
     Hue[0.8119077983276102, 1, -13.358333042255904`], 
     Hue[0.8119077983276219, 1, -12.98409062557395], 
     Hue[0.811907798327648, 1, -12.60984820889201], 
     Hue[0.8119077983277052, 1, -12.235605792210109`], 
     Hue[0.8119077983278311, 1, -11.861363375528292`], 
     Hue[0.8119077983281078, 1, -11.48712095884666], 
     Hue[0.811907798328716, 1, -11.112878542165431`], 
     Hue[0.8119077983300533, 1, -10.738636125485097`], 
     Hue[0.8119077983329939, 1, -10.364393708806723`], 
     Hue[0.8119077983394593, 1, -9.99015129213266], 
     Hue[0.8119077983536749, 1, -9.615908875468076], 
     Hue[0.8119077983849311, 1, -9.24166645882434], 
     Hue[0.811907798453655, 1, -8.867424042226434], 
     Hue[0.8119077986047603, 1, -8.493181625729301], 
     Hue[0.8119077989369996, 1, -8.118939209453737], 
     Hue[0.8119077996675033, 1, -7.744696793665345], 
     Hue[0.8119078012736817, 1, -7.370454378948108], 
     Hue[0.8119078048052304, 1, -6.996211966586052], 
     Hue[0.8119078125701432, 1, -6.621969559402399], 
     Hue[0.8119078296430694, 1, -6.247727163604642], 
     Hue[0.8119078671817759, 1, -5.873484792841381], 
     Hue[0.8119079497191356, 1, -5.499242477122221], 
     Hue[0.8119081311961727, 1, -5.125000282430326], 
     Hue[0.8119085302141235, 1, -4.7507583538458436`], 
     Hue[0.8119094075429707, 1, -4.3765170103659665`], 
     Hue[0.8119113365360691, 1, -4.002276953405153], 
     Hue[0.8119155777987925, 1, -3.6280397253110683`], 
     Hue[0.8119249028538198, 1, -3.2538087179066713`], 
     Hue[0.8119454045330967, 1, -2.8795913918865814`], 
     Hue[0.8119904745209937, 1, -2.50540416578138], 
     Hue[0.8120895342998387, 1, -2.131283209458398], 
     Hue[0.812307161487219, 1, -1.757308388036854], 
     Hue[0.8127848008326659, 1, -1.3836569245061259`], 
     Hue[0.8138308072780887, 1, -1.0107262164090913`], 
     Hue[0.8161102456364016, 1, -0.6394262906079926], 
     Hue[0.8210216176264236, 1, -0.2719214323587331], 
     Hue[0.8313221270855424, 1, 0.08636387946313451], 
     Hue[0.8515310480603818, 1, 0.4214926652486737], 
     Hue[0.8853073297018956, 1, 0.7022889532572367], 
     Hue[0.9266004686257032, 1, 0.8894101615982243], 
     Hue[0.9603767502672175, 1, 0.9828562902716353], 
     Hue[0.9805856712420573, 1, 1.0219699211680686`], 
     Hue[0.9908861807011765, 1, 1.0379270260281728`], 
     Hue[0.9957975526911986, 1, 1.0446645844608844`], 
     Hue[0.9980769910495116, 1, 1.0476070753417577`], 
     Hue[0.9991229974949344, 1, 1.048918783926694], 
     Hue[0.9996006368403814, 1, 1.0495097370779367`], 
     Hue[0.9998182640277616, 1, 1.0497773323383648`], 
     Hue[0.9999173238066066, 1, 1.049898792697353], 
     Hue[0.9999623937945036, 1, 1.0499539832741225`], 
     Hue[0.9999828954737806, 1, 1.0499790739360044`], 
     Hue[0.9999922205288079, 1, 1.0499904832135782`], 
     Hue[0.9999964617915312, 1, 1.0499956718014645`], 
     Hue[0.9999983907846296, 1, 1.049998031522622], 
     Hue[0.9999992681134768, 1, 1.0499991047247157`], 
     Hue[0.9999996671314276, 1, 1.0499995928222043`], 
     Hue[0.9999998486084647, 1, 1.0499998148122816`], 
     Hue[0.9999999311458244, 1, 1.0499999157750912`], 
     Hue[0.9999999686845309, 1, 1.0499999616938027`], 
     Hue[0.9999999857574571, 1, 1.0499999825780169`], 
     Hue[0.9999999935223699, 1, 1.049999992076334], 
     Hue[0.9999999970539186, 1, 1.0499999963962492`], 
     Hue[0.999999998660097, 1, 1.0499999983609836`], 
     Hue[0.9999999993906007, 1, 1.0499999992545612`], 
     Hue[0.99999999972284, 1, 1.0499999996609681`], 
     Hue[0.9999999998739453, 1, 1.0499999998458054`], 
     Hue[0.9999999999426692, 1, 1.049999999929871], 
     Hue[0.9999999999739255, 1, 1.049999999968105], 
     Hue[0.999999999988141, 1, 1.0499999999854939`], 
     Hue[0.9999999999946064, 1, 1.0499999999934024`], 
     Hue[0.999999999997547, 1, 1.0499999999969993`], 
     Hue[0.9999999999988843, 1, 1.0499999999986354`], 
     Hue[0.9999999999994926, 1, 1.0499999999993794`], 
     Hue[0.9999999999997692, 1, 1.0499999999997178`], 
     Hue[0.9999999999998951, 1, 1.0499999999998717`], 
     Hue[0.9999999999999523, 1, 1.0499999999999416`], 
     Hue[0.9999999999999782, 1, 1.0499999999999734`], 
     Hue[0.9999999999999901, 1, 1.0499999999999878`], 
     Hue[0.9999999999999956, 1, 1.0499999999999945`], 
     Hue[0.999999999999998, 1, 1.0499999999999976`], 
     Hue[0.9999999999999991, 1, 1.049999999999999], 
     Hue[0.9999999999999996, 1, 1.0499999999999996`], 
     Hue[0.9999999999999998, 1, 1.0499999999999998`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.9373025994425319, 1, -17.474999625757572`], 
     Hue[0.9373025994425319, 1, -17.100757209075603`], 
     Hue[0.9373025994425319, 1, -16.726514792393633`], 
     Hue[0.9373025994425319, 1, -16.35227237571166], 
     Hue[0.9373025994425319, 1, -15.97802995902969], 
     Hue[0.9373025994425319, 1, -15.603787542347721`], 
     Hue[0.937302599442532, 1, -15.229545125665748`], 
     Hue[0.9373025994425321, 1, -14.855302708983777`], 
     Hue[0.9373025994425324, 1, -14.48106029230181], 
     Hue[0.9373025994425328, 1, -14.106817875619843`], 
     Hue[0.9373025994425338, 1, -13.732575458937879`], 
     Hue[0.937302599442536, 1, -13.358333042255921`], 
     Hue[0.9373025994425409, 1, -12.984090625573987`], 
     Hue[0.9373025994425518, 1, -12.609848208892092`], 
     Hue[0.9373025994425754, 1, -12.235605792210292`], 
     Hue[0.9373025994426276, 1, -11.861363375528697`], 
     Hue[0.9373025994427424, 1, -11.48712095884755], 
     Hue[0.9373025994429948, 1, -11.112878542167389`], 
     Hue[0.9373025994435495, 1, -10.738636125489402`], 
     Hue[0.9373025994447692, 1, -10.36439370881619], 
     Hue[0.9373025994474512, 1, -9.990151292153474], 
     Hue[0.9373025994533482, 1, -9.615908875513842], 
     Hue[0.9373025994663137, 1, -9.241666458924966], 
     Hue[0.9373025994948216, 1, -8.867424042447682], 
     Hue[0.9373025995575026, 1, -8.493181626215764], 
     Hue[0.9373025996953211, 1, -8.118939210523338], 
     Hue[0.9373025999983465, 1, -7.744696796017105], 
     Hue[0.9373026006646168, 1, -7.370454384118987], 
     Hue[0.9373026021295635, 1, -6.996211977955409], 
     Hue[0.9373026053505817, 1, -6.621969584400513], 
     Hue[0.937302612432722, 1, -6.247727218568675], 
     Hue[0.9373026280044129, 1, -5.873484913692271], 
     Hue[0.9373026622422919, 1, -5.499242742840197], 
     Hue[0.9373027375219323, 1, -5.125000866670804], 
     Hue[0.9373029030407435, 1, -4.750759638426899], 
     Hue[0.9373032669685885, 1, -4.376519834787706], 
     Hue[0.9373040671326593, 1, -4.002283163432863], 
     Hue[0.9373058264073186, 1, -3.628053378957344], 
     Hue[0.9373096942438135, 1, -3.253838736077517], 
     Hue[0.9373181969718242, 1, -2.8796573816933977`], 
     Hue[0.9373368844684915, 1, -2.5055492015299166`], 
     Hue[0.9373779360645201, 1, -2.131601824027533], 
     Hue[0.9374680182845876, 1, -1.7580075851304755`], 
     Hue[0.9376652229821014, 1, -1.3851877631866703`], 
     Hue[0.9380946999301245, 1, -1.0140608658263084`], 
     Hue[0.9390195167057894, 1, -0.646609347748615], 
     Hue[0.9409632258337898, 1, -0.28701767117129684`], 
     Hue[0.9448462511338594, 1, 0.0563055877707227], 
     Hue[0.9518633339324021, 1, 0.3681911483300011], 
     Hue[0.9624782071929511, 1, 0.6269562759358118], 
     Hue[0.9748243922495805, 1, 0.8140774842767987], 
     Hue[0.9854392655101296, 1, 0.9295547733529617], 
     Hue[0.9924563483086722, 1, 0.9919116294756561], 
     Hue[0.996339373608742, 1, 1.0228307872156086`], 
     Hue[0.9982830827367424, 1, 1.0374815273202618`], 
     Hue[0.9992078995124074, 1, 1.04427242592454], 
     Hue[0.9996373764604305, 1, 1.0473879452461494`], 
     Hue[0.9998345811579443, 1, 1.0488105399843153`], 
     Hue[0.9999246633780118, 1, 1.0494587177692285`], 
     Hue[0.9999657149740405, 1, 1.0497537569488167`], 
     Hue[0.9999844024707079, 1, 1.049887993467307], 
     Hue[0.9999929051987184, 1, 1.049949055765159], 
     Hue[0.9999967730352133, 1, 1.0499768295673022`], 
     Hue[0.9999985323098726, 1, 1.049989461773755], 
     Hue[0.9999993324739435, 1, 1.0499952071008833`], 
     Hue[0.9999996964017884, 1, 1.0499978201436606`], 
     Hue[0.9999998619205996, 1, 1.0499990085817268`], 
     Hue[0.99999993720024, 1, 1.049999549094305], 
     Hue[0.999999971438119, 1, 1.049999794924202], 
     Hue[0.99999998700981, 1, 1.0499999067297696`], 
     Hue[0.9999999940919502, 1, 1.0499999575799022`], 
     Hue[0.9999999973129684, 1, 1.0499999807069775`], 
     Hue[0.9999999987779151, 1, 1.0499999912253688`], 
     Hue[0.9999999994441854, 1, 1.049999996009223], 
     Hue[0.9999999997472108, 1, 1.0499999981849606`], 
     Hue[0.9999999998850293, 1, 1.0499999991745046`], 
     Hue[0.9999999999477104, 1, 1.0499999996245577`], 
     Hue[0.9999999999762182, 1, 1.0499999998292457`], 
     Hue[0.9999999999891839, 1, 1.0499999999223395`], 
     Hue[0.9999999999950807, 1, 1.0499999999646794`], 
     Hue[0.9999999999977627, 1, 1.049999999983936], 
     Hue[0.9999999999989825, 1, 1.0499999999926939`], 
     Hue[0.9999999999995373, 1, 1.0499999999966771`], 
     Hue[0.9999999999997895, 1, 1.0499999999984888`], 
     Hue[0.9999999999999043, 1, 1.0499999999993126`], 
     Hue[0.9999999999999565, 1, 1.0499999999996874`], 
     Hue[0.9999999999999802, 1, 1.049999999999858], 
     Hue[0.999999999999991, 1, 1.0499999999999354`], 
     Hue[0.9999999999999959, 1, 1.0499999999999705`], 
     Hue[0.9999999999999981, 1, 1.0499999999999867`], 
     Hue[0.9999999999999991, 1, 1.0499999999999938`], 
     Hue[0.9999999999999997, 1, 1.0499999999999974`], 
     Hue[0.9999999999999998, 1, 1.0499999999999987`], 
     Hue[0.9999999999999999, 1, 1.0499999999999996`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.0626974005574636`, 1, -17.474999625757572`], 
     Hue[1.0626974005574636`, 1, -17.100757209075603`], 
     Hue[1.0626974005574636`, 1, -16.726514792393633`], 
     Hue[1.0626974005574636`, 1, -16.35227237571166], 
     Hue[1.0626974005574636`, 1, -15.97802995902969], 
     Hue[1.0626974005574636`, 1, -15.603787542347721`], 
     Hue[1.0626974005574634`, 1, -15.229545125665748`], 
     Hue[1.0626974005574634`, 1, -14.855302708983777`], 
     Hue[1.0626974005574632`, 1, -14.48106029230181], 
     Hue[1.0626974005574628`, 1, -14.106817875619843`], 
     Hue[1.0626974005574616`, 1, -13.732575458937879`], 
     Hue[1.0626974005574594`, 1, -13.358333042255921`], 
     Hue[1.0626974005574545`, 1, -12.984090625573987`], 
     Hue[1.0626974005574437`, 1, -12.609848208892092`], 
     Hue[1.0626974005574201`, 1, -12.235605792210292`], 
     Hue[1.0626974005573677`, 1, -11.861363375528697`], 
     Hue[1.0626974005572531`, 1, -11.48712095884755], 
     Hue[1.0626974005570007`, 1, -11.112878542167389`], 
     Hue[1.062697400556446, 1, -10.738636125489402`], 
     Hue[1.0626974005552263`, 1, -10.36439370881619], 
     Hue[1.0626974005525442`, 1, -9.990151292153474], 
     Hue[1.0626974005466474`, 1, -9.615908875513842], 
     Hue[1.0626974005336818`, 1, -9.241666458924966], 
     Hue[1.062697400505174, 1, -8.867424042447682], 
     Hue[1.062697400442493, 1, -8.493181626215764], 
     Hue[1.0626974003046743`, 1, -8.118939210523338], 
     Hue[1.062697400001649, 1, -7.744696796017105], 
     Hue[1.0626973993353788`, 1, -7.370454384118987], 
     Hue[1.062697397870432, 1, -6.996211977955409], 
     Hue[1.0626973946494138`, 1, -6.621969584400513], 
     Hue[1.0626973875672736`, 1, -6.247727218568675], 
     Hue[1.0626973719955826`, 1, -5.873484913692271], 
     Hue[1.0626973377577036`, 1, -5.499242742840197], 
     Hue[1.0626972624780633`, 1, -5.125000866670804], 
     Hue[1.062697096959252, 1, -4.750759638426899], 
     Hue[1.062696733031407, 1, -4.376519834787706], 
     Hue[1.0626959328673362`, 1, -4.002283163432862], 
     Hue[1.062694173592677, 1, -3.628053378957344], 
     Hue[1.062690305756182, 1, -3.253838736077517], 
     Hue[1.0626818030281713`, 1, -2.8796573816933977`], 
     Hue[1.062663115531504, 1, -2.5055492015299166`], 
     Hue[1.0626220639354753`, 1, -2.131601824027533], 
     Hue[1.062531981715408, 1, -1.7580075851304755`], 
     Hue[1.0623347770178941`, 1, -1.3851877631866703`], 
     Hue[1.061905300069871, 1, -1.0140608658263084`], 
     Hue[1.0609804832942062`, 1, -0.6466093477486152], 
     Hue[1.059036774166206, 1, -0.28701767117129706`], 
     Hue[1.0551537488661364`, 1, 0.05630558777072203], 
     Hue[1.0481366660675944`, 1, 0.3681911483300001], 
     Hue[1.0375217928070462`, 1, 0.6269562759358105], 
     Hue[1.0251756077504177`, 1, 0.8140774842767975], 
     Hue[1.0145607344898695`, 1, 0.9295547733529608], 
     Hue[1.0075436516913272`, 1, 0.9919116294756555], 
     Hue[1.0036606263912577`, 1, 1.0228307872156084`], 
     Hue[1.0017169172632574`, 1, 1.0374815273202618`], 
     Hue[1.0007921004875926`, 1, 1.04427242592454], 
     Hue[1.0003626235395695`, 1, 1.0473879452461494`], 
     Hue[1.0001654188420557`, 1, 1.0488105399843153`], 
     Hue[1.000075336621988, 1, 1.0494587177692285`], 
     Hue[1.0000342850259596`, 1, 1.0497537569488167`], 
     Hue[1.0000155975292921`, 1, 1.049887993467307], 
     Hue[1.0000070948012816`, 1, 1.049949055765159], 
     Hue[1.0000032269647867`, 1, 1.0499768295673022`], 
     Hue[1.0000014676901274`, 1, 1.049989461773755], 
     Hue[1.0000006675260564`, 1, 1.0499952071008833`], 
     Hue[1.0000003035982115`, 1, 1.0499978201436606`], 
     Hue[1.0000001380794004`, 1, 1.0499990085817268`], 
     Hue[1.0000000627997598`, 1, 1.049999549094305], 
     Hue[1.000000028561881, 1, 1.049999794924202], 
     Hue[1.00000001299019, 1, 1.0499999067297696`], 
     Hue[1.0000000059080498`, 1, 1.0499999575799022`], 
     Hue[1.0000000026870315`, 1, 1.0499999807069775`], 
     Hue[1.0000000012220849`, 1, 1.0499999912253688`], 
     Hue[1.0000000005558147`, 1, 1.049999996009223], 
     Hue[1.0000000002527891`, 1, 1.0499999981849606`], 
     Hue[1.0000000001149707`, 1, 1.0499999991745046`], 
     Hue[1.0000000000522897`, 1, 1.0499999996245577`], 
     Hue[1.0000000000237819`, 1, 1.0499999998292457`], 
     Hue[1.0000000000108162`, 1, 1.0499999999223395`], 
     Hue[1.0000000000049192`, 1, 1.0499999999646794`], 
     Hue[1.0000000000022373`, 1, 1.049999999983936], 
     Hue[1.0000000000010176`, 1, 1.0499999999926939`], 
     Hue[1.0000000000004627`, 1, 1.0499999999966771`], 
     Hue[1.0000000000002105`, 1, 1.0499999999984888`], 
     Hue[1.0000000000000957`, 1, 1.0499999999993126`], 
     Hue[1.0000000000000435`, 1, 1.0499999999996874`], 
     Hue[1.0000000000000198`, 1, 1.049999999999858], 
     Hue[1.000000000000009, 1, 1.0499999999999354`], 
     Hue[1.000000000000004, 1, 1.0499999999999705`], 
     Hue[1.0000000000000018`, 1, 1.0499999999999867`], 
     Hue[1.0000000000000009`, 1, 1.0499999999999938`], 
     Hue[1.0000000000000004`, 1, 1.0499999999999974`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999987`], 
     Hue[1., 1, 1.0499999999999996`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.1880922016723952`, 1, -17.474999625757572`], 
     Hue[1.1880922016723952`, 1, -17.100757209075603`], 
     Hue[1.1880922016723952`, 1, -16.726514792393633`], 
     Hue[1.1880922016723952`, 1, -16.35227237571166], 
     Hue[1.1880922016723952`, 1, -15.97802995902969], 
     Hue[1.1880922016723952`, 1, -15.603787542347721`], 
     Hue[1.188092201672395, 1, -15.229545125665748`], 
     Hue[1.1880922016723947`, 1, -14.855302708983777`], 
     Hue[1.1880922016723943`, 1, -14.481060292301807`], 
     Hue[1.1880922016723932`, 1, -14.106817875619837`], 
     Hue[1.1880922016723907`, 1, -13.73257545893787], 
     Hue[1.1880922016723854`, 1, -13.358333042255904`], 
     Hue[1.1880922016723734`, 1, -12.98409062557395], 
     Hue[1.1880922016723474`, 1, -12.60984820889201], 
     Hue[1.1880922016722901`, 1, -12.235605792210109`], 
     Hue[1.1880922016721644`, 1, -11.861363375528292`], 
     Hue[1.1880922016718878`, 1, -11.48712095884666], 
     Hue[1.1880922016712796`, 1, -11.112878542165431`], 
     Hue[1.1880922016699422`, 1, -10.738636125485097`], 
     Hue[1.1880922016670017`, 1, -10.364393708806723`], 
     Hue[1.1880922016605364`, 1, -9.99015129213266], 
     Hue[1.1880922016463207`, 1, -9.615908875468076], 
     Hue[1.1880922016150643`, 1, -9.24166645882434], 
     Hue[1.1880922015463404`, 1, -8.867424042226434], 
     Hue[1.1880922013952353`, 1, -8.493181625729301], 
     Hue[1.188092201062996, 1, -8.118939209453737], 
     Hue[1.1880922003324923`, 1, -7.744696793665345], 
     Hue[1.1880921987263138`, 1, -7.370454378948108], 
     Hue[1.1880921951947652`, 1, -6.996211966586052], 
     Hue[1.1880921874298522`, 1, -6.621969559402399], 
     Hue[1.188092170356926, 1, -6.247727163604642], 
     Hue[1.1880921328182197`, 1, -5.873484792841381], 
     Hue[1.1880920502808598`, 1, -5.499242477122221], 
     Hue[1.188091868803823, 1, -5.125000282430326], 
     Hue[1.188091469785872, 1, -4.7507583538458436`], 
     Hue[1.1880905924570249`, 1, -4.3765170103659665`], 
     Hue[1.1880886634639265`, 1, -4.002276953405153], 
     Hue[1.188084422201203, 1, -3.6280397253110683`], 
     Hue[1.1880750971461758`, 1, -3.2538087179066713`], 
     Hue[1.1880545954668988`, 1, -2.8795913918865814`], 
     Hue[1.1880095254790017`, 1, -2.50540416578138], 
     Hue[1.187910465700157, 1, -2.131283209458397], 
     Hue[1.1876928385127765`, 1, -1.757308388036854], 
     Hue[1.1872151991673296`, 1, -1.3836569245061259`], 
     Hue[1.186169192721907, 1, -1.0107262164090913`], 
     Hue[1.183889754363594, 1, -0.639426290607993], 
     Hue[1.178978382373572, 1, -0.271921432358734], 
     Hue[1.1686778729144534`, 1, 0.08636387946313306], 
     Hue[1.1484689519396143`, 1, 0.421492665248671], 
     Hue[1.1146926702981015`, 1, 0.7022889532572325], 
     Hue[1.0733995313742952`, 1, 0.8894101615982201], 
     Hue[1.0396232497327818`, 1, 0.9828562902716323], 
     Hue[1.0194143287579425`, 1, 1.021969921168067], 
     Hue[1.0091138192988234`, 1, 1.037927026028172], 
     Hue[1.0042024473088014`, 1, 1.0446645844608842`], 
     Hue[1.0019230089504885`, 1, 1.0476070753417575`], 
     Hue[1.0008770025050657`, 1, 1.0489187839266938`], 
     Hue[1.0003993631596186`, 1, 1.0495097370779367`], 
     Hue[1.0001817359722385`, 1, 1.0497773323383648`], 
     Hue[1.0000826761933934`, 1, 1.049898792697353], 
     Hue[1.0000376062054963`, 1, 1.0499539832741225`], 
     Hue[1.0000171045262194`, 1, 1.0499790739360042`], 
     Hue[1.0000077794711921`, 1, 1.0499904832135782`], 
     Hue[1.0000035382084689`, 1, 1.0499956718014645`], 
     Hue[1.0000016092153703`, 1, 1.049998031522622], 
     Hue[1.0000007318865232`, 1, 1.0499991047247157`], 
     Hue[1.0000003328685725`, 1, 1.0499995928222043`], 
     Hue[1.0000001513915353`, 1, 1.0499998148122816`], 
     Hue[1.0000000688541755`, 1, 1.0499999157750912`], 
     Hue[1.000000031315469, 1, 1.0499999616938027`], 
     Hue[1.000000014242543, 1, 1.0499999825780169`], 
     Hue[1.00000000647763, 1, 1.049999992076334], 
     Hue[1.0000000029460814`, 1, 1.0499999963962492`], 
     Hue[1.0000000013399029`, 1, 1.0499999983609836`], 
     Hue[1.0000000006093992`, 1, 1.0499999992545612`], 
     Hue[1.00000000027716, 1, 1.0499999996609681`], 
     Hue[1.0000000001260547`, 1, 1.0499999998458054`], 
     Hue[1.0000000000573308`, 1, 1.049999999929871], 
     Hue[1.0000000000260745`, 1, 1.049999999968105], 
     Hue[1.000000000011859, 1, 1.0499999999854939`], 
     Hue[1.0000000000053935`, 1, 1.0499999999934024`], 
     Hue[1.000000000002453, 1, 1.0499999999969993`], 
     Hue[1.0000000000011156`, 1, 1.0499999999986354`], 
     Hue[1.0000000000005074`, 1, 1.0499999999993794`], 
     Hue[1.0000000000002307`, 1, 1.0499999999997178`], 
     Hue[1.000000000000105, 1, 1.0499999999998717`], 
     Hue[1.0000000000000477`, 1, 1.0499999999999416`], 
     Hue[1.0000000000000218`, 1, 1.0499999999999734`], 
     Hue[1.0000000000000098`, 1, 1.0499999999999878`], 
     Hue[1.0000000000000044`, 1, 1.0499999999999945`], 
     Hue[1.000000000000002, 1, 1.0499999999999976`], 
     Hue[1.0000000000000009`, 1, 1.049999999999999], 
     Hue[1.0000000000000004`, 1, 1.0499999999999996`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.3134870027873269`, 1, -17.474999625757572`], 
     Hue[1.3134870027873269`, 1, -17.100757209075603`], 
     Hue[1.3134870027873269`, 1, -16.726514792393633`], 
     Hue[1.3134870027873269`, 1, -16.35227237571166], 
     Hue[1.3134870027873267`, 1, -15.97802995902969], 
     Hue[1.3134870027873267`, 1, -15.603787542347721`], 
     Hue[1.3134870027873267`, 1, -15.229545125665748`], 
     Hue[1.3134870027873264`, 1, -14.855302708983777`], 
     Hue[1.313487002787326, 1, -14.481060292301807`], 
     Hue[1.3134870027873249`, 1, -14.106817875619834`], 
     Hue[1.3134870027873222`, 1, -13.732575458937859`], 
     Hue[1.313487002787317, 1, -13.35833304225588], 
     Hue[1.3134870027873053`, 1, -12.984090625573895`], 
     Hue[1.3134870027872794`, 1, -12.609848208891892`], 
     Hue[1.3134870027872223`, 1, -12.235605792209848`], 
     Hue[1.313487002787097, 1, -11.861363375527722`], 
     Hue[1.3134870027868215`, 1, -11.487120958845402`], 
     Hue[1.3134870027862158`, 1, -11.112878542162669`], 
     Hue[1.313487002784884, 1, -10.738636125479024`], 
     Hue[1.3134870027819554`, 1, -10.364393708793369`], 
     Hue[1.3134870027755168`, 1, -9.990151292103297], 
     Hue[1.3134870027613597`, 1, -9.615908875403516], 
     Hue[1.313487002730232, 1, -9.241666458682388], 
     Hue[1.313487002661791, 1, -8.86742404191432], 
     Hue[1.3134870025113077`, 1, -8.493181625043047], 
     Hue[1.313487002180436, 1, -8.118939207944852], 
     Hue[1.313487001452939, 1, -7.744696790347713], 
     Hue[1.3134869998533714`, 1, -7.37045437165354], 
     Hue[1.3134869963363585`, 1, -6.996211950547289], 
     Hue[1.3134869886034048`, 1, -6.621969524137525], 
     Hue[1.3134869716007465`, 1, -6.247727086066798], 
     Hue[1.313486934216529, 1, -5.873484622356794], 
     Hue[1.3134868520187968`, 1, -5.499242102273072], 
     Hue[1.3134866712882591`, 1, -5.124999458239196], 
     Hue[1.313486273910452, 1, -4.750756541674117], 
     Hue[1.3134854001820089`, 1, -4.376513025893986], 
     Hue[1.3134834790770578`, 1, -4.002268192636091], 
     Hue[1.313479255022083, 1, -3.628020462762392], 
     Hue[1.313469967144061, 1, -3.2537663647874755`], 
     Hue[1.313449544025143, 1, -2.8794982688048787`], 
     Hue[1.3134046313881385`, 1, -2.505199412970028], 
     Hue[1.3133058432176472`, 1, -2.1308330114876], 
     Hue[1.3130884537120429`, 1, -1.7563185166160193`], 
     Hue[1.31260959889104, 1, -1.3814804515445311`], 
     Hue[1.311552517731361, 1, -1.0059409571096818`], 
     Hue[1.3092081335961259`, 1, -0.6289088756383681], 
     Hue[1.3039584480442477`, 1, -0.24884841408664604`], 
     Hue[1.2919878567922525`, 1, 0.13650698989609655`], 
     Hue[1.2640714366941606`, 1, 0.5256157626274776], 
     Hue[1.2021054458749791`, 1, 0.8798766617961503], 
     Hue[1.1113815569123509`, 1, 1.0669978701371399`], 
     Hue[1.0494155660931679`, 1, 1.0869793876504417`], 
     Hue[1.021499145995075, 1, 1.0721130316010319`], 
     Hue[1.0095285547430795`, 1, 1.0610000443002605`], 
     Hue[1.0042788691912012`, 1, 1.0551819994305096`], 
     Hue[1.001934485055966, 1, 1.0523923346411672`], 
     Hue[1.0008774038962869`, 1, 1.051095256888289], 
     Hue[1.000398549075284, 1, 1.0504996084987717`], 
     Hue[1.0001811595696797`, 1, 1.050227530309162], 
     Hue[1.0000823713991884`, 1, 1.0501035455087055`], 
     Hue[1.0000374587621839`, 1, 1.0500471063558248`], 
     Hue[1.0000170356432658`, 1, 1.0500214270552009`], 
     Hue[1.0000077477652438`, 1, 1.0500097457622541`], 
     Hue[1.0000035237102691`, 1, 1.0500044325705264`], 
     Hue[1.000001602605318, 1, 1.0500020159946035`], 
     Hue[1.0000007288768749`, 1, 1.050000916896443], 
     Hue[1.0000003314990678`, 1, 1.050000417013335], 
     Hue[1.00000015076853, 1, 1.05000018966143], 
     Hue[1.000000068570798, 1, 1.0500000862596788`], 
     Hue[1.0000000311865804`, 1, 1.0500000392316464`], 
     Hue[1.000000014183922, 1, 1.0500000178428892`], 
     Hue[1.0000000064509684`, 1, 1.0500000081150984`], 
     Hue[1.0000000029339555`, 1, 1.0500000036908161`], 
     Hue[1.000000001334388, 1, 1.0500000016786146`], 
     Hue[1.000000000606891, 1, 1.0500000007634482`], 
     Hue[1.0000000002760192`, 1, 1.0500000003472227`], 
     Hue[1.0000000001255358`, 1, 1.05000000015792], 
     Hue[1.0000000000570948`, 1, 1.0500000000718235`], 
     Hue[1.0000000000259672`, 1, 1.050000000032666], 
     Hue[1.00000000001181, 1, 1.0500000000148568`], 
     Hue[1.0000000000053713`, 1, 1.050000000006757], 
     Hue[1.000000000002443, 1, 1.0500000000030731`], 
     Hue[1.0000000000011111`, 1, 1.0500000000013978`], 
     Hue[1.0000000000005054`, 1, 1.0500000000006358`], 
     Hue[1.0000000000002298`, 1, 1.0500000000002891`], 
     Hue[1.0000000000001046`, 1, 1.0500000000001315`], 
     Hue[1.0000000000000475`, 1, 1.0500000000000598`], 
     Hue[1.0000000000000215`, 1, 1.0500000000000274`], 
     Hue[1.0000000000000098`, 1, 1.0500000000000125`], 
     Hue[1.0000000000000044`, 1, 1.0500000000000058`], 
     Hue[1.000000000000002, 1, 1.0500000000000027`], 
     Hue[1.0000000000000009`, 1, 1.0500000000000012`], 
     Hue[1.0000000000000004`, 1, 1.0500000000000005`], 
     Hue[1.0000000000000002`, 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.4388818039022584`, 1, -17.474999625757572`], 
     Hue[1.4388818039022584`, 1, -17.100757209075603`], 
     Hue[1.4388818039022584`, 1, -16.726514792393633`], 
     Hue[1.4388818039022584`, 1, -16.35227237571166], 
     Hue[1.4388818039022584`, 1, -15.97802995902969], 
     Hue[1.4388818039022584`, 1, -15.603787542347721`], 
     Hue[1.4388818039022584`, 1, -15.229545125665748`], 
     Hue[1.4388818039022584`, 1, -14.855302708983777`], 
     Hue[1.4388818039022582`, 1, -14.481060292301803`], 
     Hue[1.4388818039022575`, 1, -14.106817875619829`], 
     Hue[1.4388818039022566`, 1, -13.73257545893785], 
     Hue[1.4388818039022544`, 1, -13.358333042255865`], 
     Hue[1.4388818039022497`, 1, -12.984090625573858`], 
     Hue[1.4388818039022393`, 1, -12.609848208891808`], 
     Hue[1.438881803902216, 1, -12.235605792209666`], 
     Hue[1.4388818039021651`, 1, -11.86136337552732], 
     Hue[1.438881803902053, 1, -11.487120958844521`], 
     Hue[1.4388818039018068`, 1, -11.11287854216073], 
     Hue[1.4388818039012652`, 1, -10.73863612547476], 
     Hue[1.4388818039000746`, 1, -10.364393708783995`], 
     Hue[1.438881803897457, 1, -9.990151292082688], 
     Hue[1.438881803891701, 1, -9.615908875358206], 
     Hue[1.4388818038790456`, 1, -9.241666458582761], 
     Hue[1.4388818038512197`, 1, -8.867424041695267], 
     Hue[1.438881803790038, 1, -8.493181624561409], 
     Hue[1.438881803655516, 1, -8.118939206885862], 
     Hue[1.4388818033597388`, 1, -7.744696788019289], 
     Hue[1.4388818027094057`, 1, -7.370454366533967], 
     Hue[1.4388818012795004`, 1, -6.996211939290741], 
     Hue[1.4388817981355277`, 1, -6.621969499387445], 
     Hue[1.4388817912227878`, 1, -6.247727031648109], 
     Hue[1.4388817760235515`, 1, -5.873484502704888], 
     Hue[1.4388817426045475`, 1, -5.499241839190946], 
     Hue[1.4388816691251431`, 1, -5.124998879792359], 
     Hue[1.438881507563368, 1, -4.750755269822631], 
     Hue[1.4388811523301994`, 1, -4.376510229417264], 
     Hue[1.4388803712554716`, 1, -4.002262043839936], 
     Hue[1.4388786538182892`, 1, -3.628006942723098], 
     Hue[1.438874877319392, 1, -3.2537366354290187`], 
     Hue[1.4388665722677179`, 1, -2.879432890073198], 
     Hue[1.4388483041783902`, 1, -2.505055605050874], 
     Hue[1.4388081011217646`, 1, -2.1305165369534373`], 
     Hue[1.4387195286870902`, 1, -1.7556213193597057`], 
     Hue[1.4385239229106257`, 1, -1.3799409298388585`], 
     Hue[1.438089641993623, 1, -1.0025239754259119`], 
     Hue[1.437114010371242, 1, -0.621238995542913], 
     Hue[1.4348631504529694`, 1, -0.23120271696585237`], 
     Hue[1.4293396812029435`, 1, 0.17932846558365978`], 
     Hue[1.413541439240822, 1, 0.6415286982427657], 
     Hue[1.3444646085705978`, 1, 1.2401206769305553`], 
     Hue[1.0944171953316661`, 1, 1.4272418852715587`], 
     Hue[1.0253403646614374`, 1, 1.202892323265734], 
     Hue[1.0095421226993153`, 1, 1.1149345072885966`], 
     Hue[1.0040186534492892`, 1, 1.0786457414210546`], 
     Hue[1.0017677935310165`, 1, 1.0628518795259645`], 
     Hue[1.0007921619086353`, 1, 1.055809316324937], 
     Hue[1.0003578809916327`, 1, 1.0526347785939612`], 
     Hue[1.0001622752151684`, 1, 1.0511968057550851`], 
     Hue[1.0000737027804938`, 1, 1.0505440048433248`], 
     Hue[1.0000334997238682`, 1, 1.0502473534278596`], 
     Hue[1.0000152316345405`, 1, 1.050112485087506], 
     Hue[1.0000069265828664`, 1, 1.0500511564136574`], 
     Hue[1.0000031500839694`, 1, 1.0500232658015496`], 
     Hue[1.0000014326467868`, 1, 1.0500105813666814`], 
     Hue[1.000000651572059, 1, 1.0500048124713246`], 
     Hue[1.0000002963388905`, 1, 1.0500021887479287`], 
     Hue[1.0000001347771152`, 1, 1.0500009954601717`], 
     Hue[1.000000061297711, 1, 1.0500004527435565`], 
     Hue[1.0000000278787071`, 1, 1.0500002059115845`], 
     Hue[1.0000000126794706`, 1, 1.0500000936503349`], 
     Hue[1.0000000057667306`, 1, 1.0500000425929688`], 
     Hue[1.0000000026227582`, 1, 1.050000019371645], 
     Hue[1.0000000011928527`, 1, 1.0500000088103891`], 
     Hue[1.0000000005425196`, 1, 1.05000000400704], 
     Hue[1.0000000002467426`, 1, 1.050000001822436], 
     Hue[1.0000000001122207`, 1, 1.0500000008288595`], 
     Hue[1.000000000051039, 1, 1.0500000003769725`], 
     Hue[1.000000000023213, 1, 1.0500000001714502`], 
     Hue[1.0000000000105573`, 1, 1.050000000077977], 
     Hue[1.0000000000048017`, 1, 1.0500000000354648`], 
     Hue[1.0000000000021838`, 1, 1.0500000000161296`], 
     Hue[1.0000000000009932`, 1, 1.050000000007336], 
     Hue[1.0000000000004516`, 1, 1.0500000000033365`], 
     Hue[1.0000000000002054`, 1, 1.0500000000015175`], 
     Hue[1.0000000000000935`, 1, 1.0500000000006902`], 
     Hue[1.0000000000000424`, 1, 1.050000000000314], 
     Hue[1.0000000000000193`, 1, 1.0500000000001428`], 
     Hue[1.0000000000000089`, 1, 1.050000000000065], 
     Hue[1.000000000000004, 1, 1.0500000000000296`], 
     Hue[1.0000000000000018`, 1, 1.0500000000000136`], 
     Hue[1.0000000000000009`, 1, 1.0500000000000063`], 
     Hue[1.0000000000000004`, 1, 1.050000000000003], 
     Hue[1.0000000000000002`, 1, 1.0500000000000014`], 
     Hue[1., 1, 1.0500000000000007`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.5642766050171901, 1, -17.474999625757572`], 
     Hue[0.5642766050171901, 1, -17.100757209075603`], 
     Hue[0.5642766050171901, 1, -16.726514792393633`], 
     Hue[0.5642766050171901, 1, -16.35227237571166], 
     Hue[0.5642766050171901, 1, -15.97802995902969], 
     Hue[0.5642766050171901, 1, -15.603787542347721`], 
     Hue[0.5642766050171901, 1, -15.229545125665748`], 
     Hue[0.5642766050171902, 1, -14.855302708983777`], 
     Hue[0.5642766050171905, 1, -14.481060292301803`], 
     Hue[0.564276605017191, 1, -14.106817875619829`], 
     Hue[0.564276605017192, 1, -13.73257545893785], 
     Hue[0.5642766050171943, 1, -13.358333042255865`], 
     Hue[0.5642766050171992, 1, -12.984090625573858`], 
     Hue[0.5642766050172103, 1, -12.60984820889181], 
     Hue[0.5642766050172346, 1, -12.23560579220967], 
     Hue[0.564276605017288, 1, -11.861363375527324`], 
     Hue[0.5642766050174056, 1, -11.487120958844534`], 
     Hue[0.5642766050176639, 1, -11.112878542160757`], 
     Hue[0.5642766050182318, 1, -10.738636125474821`], 
     Hue[0.5642766050194807, 1, -10.364393708784126`], 
     Hue[0.5642766050222265, 1, -9.990151292082981], 
     Hue[0.5642766050282639, 1, -9.615908875358846], 
     Hue[0.5642766050415384, 1, -9.24166645858417], 
     Hue[0.5642766050707253, 1, -8.867424041698364], 
     Hue[0.5642766051348995, 1, -8.493181624568217], 
     Hue[0.5642766052760011, 1, -8.118939206900835], 
     Hue[0.564276605586245, 1, -7.744696788052207], 
     Hue[0.5642766062683868, 1, -7.370454366606347], 
     Hue[0.5642766077682309, 1, -6.996211939449885], 
     Hue[0.5642766110659794, 1, -6.621969499737358], 
     Hue[0.5642766183168308, 1, -6.247727032417471], 
     Hue[0.5642766342594823, 1, -5.873484504396505], 
     Hue[0.5642766693130545, 1, -5.499241842910354], 
     Hue[0.5642767463864338, 1, -5.124998887970341], 
     Hue[0.5642769158504046, 1, -4.750755287803876], 
     Hue[0.5642772884584627, 1, -4.376510268953557], 
     Hue[0.5642781077363934, 1, -4.002262130771572], 
     Hue[0.5642799091746962, 1, -3.6280071338722415`], 
     Hue[0.5642838703821615, 1, -3.2537370557630494`], 
     Hue[0.5642925816204811, 1, -2.8794338145108815`], 
     Hue[0.5643117431074307, 1, -2.505057638787222], 
     Hue[0.5643539119719406, 1, -2.13052101415121], 
     Hue[0.5644468137983154, 1, -1.755631190480526], 
     Hue[0.5646519732281079, 1, -1.379962765000985], 
     Hue[0.5651074278758756, 1, -1.0025726282764127`], 
     Hue[0.5661304374622123, 1, -0.6213491752277023], 
     Hue[0.5684895642975494, 1, -0.23146154885692227`], 
     Hue[0.5742720787853306, 1, 0.1786659776922821], 
     Hue[0.5907492086160268, 1, 0.6394255433526363], 
     Hue[0.661227987220868, 1, 1.228465613701044], 
     Hue[0.9030486177963165, 1, 1.4155868220420467`], 
     Hue[0.9735273964011624, 1, 1.2007891683756045`], 
     Hue[0.9900045262318591, 1, 1.1142720193972189`], 
     Hue[0.9957870407196405, 1, 1.078386909529985], 
     Hue[0.9981461675549778, 1, 1.0627416998411756`], 
     Hue[0.9991691771413144, 1, 1.055760663474436], 
     Hue[0.9996246317890822, 1, 1.0526129434318348`], 
     Hue[0.9998297912188747, 1, 1.051186934634265], 
     Hue[0.9999226930452494, 1, 1.0505395276455518`], 
     Hue[0.9999648619097593, 1, 1.050245319691511], 
     Hue[0.999984023396709, 1, 1.0501115606498226`], 
     Hue[0.9999927346350286, 1, 1.050050736079627], 
     Hue[0.9999966958424938, 1, 1.0500230746524053`], 
     Hue[0.9999984972807966, 1, 1.0500104944350448`], 
     Hue[0.9999993165587273, 1, 1.0500047729350317`], 
     Hue[0.9999996891667854, 1, 1.0500021707666833`], 
     Hue[0.9999998586307562, 1, 1.050000987282189], 
     Hue[0.9999999357041356, 1, 1.0500004490241486`], 
     Hue[0.9999999707577077, 1, 1.0500002042199679`], 
     Hue[0.9999999867003593, 1, 1.0500000928809736`], 
     Hue[0.9999999939512106, 1, 1.0500000422430567`], 
     Hue[0.9999999972489592, 1, 1.050000019212502], 
     Hue[0.9999999987488032, 1, 1.0500000087380097`], 
     Hue[0.9999999994309451, 1, 1.0500000039741213`], 
     Hue[0.9999999997411889, 1, 1.0500000018074642`], 
     Hue[0.9999999998822905, 1, 1.0500000008220503`], 
     Hue[0.9999999999464647, 1, 1.0500000003738754`], 
     Hue[0.9999999999756517, 1, 1.0500000001700418`], 
     Hue[0.9999999999889262, 1, 1.0500000000773364`], 
     Hue[0.9999999999949636, 1, 1.0500000000351732`], 
     Hue[0.9999999999977094, 1, 1.0500000000159972`], 
     Hue[0.9999999999989582, 1, 1.0500000000072756`], 
     Hue[0.9999999999995262, 1, 1.0500000000033092`], 
     Hue[0.9999999999997845, 1, 1.050000000001505], 
     Hue[0.999999999999902, 1, 1.0500000000006846`], 
     Hue[0.9999999999999554, 1, 1.0500000000003114`], 
     Hue[0.9999999999999797, 1, 1.0500000000001417`], 
     Hue[0.9999999999999908, 1, 1.0500000000000644`], 
     Hue[0.9999999999999958, 1, 1.0500000000000294`], 
     Hue[0.9999999999999981, 1, 1.0500000000000134`], 
     Hue[0.9999999999999991, 1, 1.0500000000000063`], 
     Hue[0.9999999999999996, 1, 1.0500000000000027`], 
     Hue[0.9999999999999998, 1, 1.0500000000000014`], 
     Hue[0.9999999999999999, 1, 1.0500000000000007`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.6896714061321216, 1, -17.474999625757572`], 
     Hue[0.6896714061321216, 1, -17.100757209075603`], 
     Hue[0.6896714061321216, 1, -16.726514792393633`], 
     Hue[0.6896714061321216, 1, -16.35227237571166], 
     Hue[0.6896714061321216, 1, -15.97802995902969], 
     Hue[0.6896714061321217, 1, -15.603787542347721`], 
     Hue[0.6896714061321219, 1, -15.229545125665748`], 
     Hue[0.6896714061321221, 1, -14.855302708983777`], 
     Hue[0.6896714061321225, 1, -14.481060292301807`], 
     Hue[0.6896714061321237, 1, -14.106817875619834`], 
     Hue[0.6896714061321262, 1, -13.732575458937859`], 
     Hue[0.6896714061321316, 1, -13.35833304225588], 
     Hue[0.6896714061321434, 1, -12.984090625573897`], 
     Hue[0.6896714061321696, 1, -12.609848208891894`], 
     Hue[0.6896714061322271, 1, -12.235605792209855`], 
     Hue[0.6896714061323533, 1, -11.861363375527734`], 
     Hue[0.6896714061326311, 1, -11.487120958845432`], 
     Hue[0.6896714061332418, 1, -11.112878542162735`], 
     Hue[0.6896714061345846, 1, -10.738636125479168`], 
     Hue[0.6896714061375369, 1, -10.364393708793687`], 
     Hue[0.6896714061440282, 1, -9.990151292103999], 
     Hue[0.6896714061583009, 1, -9.61590887540506], 
     Hue[0.6896714061896827, 1, -9.241666458685783], 
     Hue[0.6896714062586828, 1, -8.867424041921787], 
     Hue[0.6896714064103951, 1, -8.49318162505946], 
     Hue[0.6896714067439693, 1, -8.118939207980942], 
     Hue[0.6896714074774077, 1, -7.744696790427072], 
     Hue[0.6896714090900391, 1, -7.370454371828026], 
     Hue[0.689671412635776, 1, -6.9962119509309355`], 
     Hue[0.6896714204318855, 1, -6.621969524981059], 
     Hue[0.6896714375734064, 1, -6.247727087921498], 
     Hue[0.6896714752629447, 1, -5.873484626434774], 
     Hue[0.6896715581319932, 1, -5.499242111239442], 
     Hue[0.6896717403385677, 1, -5.1249994779538195`], 
     Hue[0.6896721409617532, 1, -4.75075658502129], 
     Hue[0.6896730218257829, 1, -4.376513121203037], 
     Hue[0.6896749586193828, 1, -4.002268402196804], 
     Hue[0.6896792171667052, 1, -3.628020923539353], 
     Hue[0.6896885808708715, 1, -3.2537673779590897`], 
     Hue[0.6897091706473306, 1, -2.8795004967283235`], 
     Hue[0.6897544494117331, 1, -2.5052043127031878`], 
     Hue[0.6898540411097288, 1, -2.130843790157618], 
     Hue[0.6900731901424751, 1, -1.7563422424925579`], 
     Hue[0.6905558785821193, 1, -1.3815327461337186`], 
     Hue[0.6916212165577849, 1, -1.0060565529285797`], 
     Hue[0.6939828951170965, 1, -0.6291659657350508], 
     Hue[0.6992661611980483, 1, -0.24942731116841887`], 
     Hue[0.7112861663928046, 1, 0.1351752932209268], 
     Hue[0.7391685457138175, 1, 0.5225102227950728], 
     Hue[0.8003865333316313, 1, 0.8736407687001122], 
     Hue[0.8892848728004874, 1, 1.0607619770411016`], 
     Hue[0.9505028604183027, 1, 1.0838738478180365`], 
     Hue[0.9783852397393165, 1, 1.0707813349258621`], 
     Hue[0.9904052449340731, 1, 1.0604211472184877`], 
     Hue[0.995688511015025, 1, 1.0549249093338269`], 
     Hue[0.9980501895743368, 1, 1.0522767388222691`], 
     Hue[0.9991155275500023, 1, 1.0510429622991013`], 
     Hue[0.9995982159896466, 1, 1.0504758826222331`], 
     Hue[0.9998173650223928, 1, 1.0502167516391445`], 
     Hue[0.9999169567203885, 1, 1.050098645775546], 
     Hue[0.999962235484791, 1, 1.0500448784323804`], 
     Hue[0.9999828252612502, 1, 1.0500204138835867`], 
     Hue[0.9999921889654165, 1, 1.050009284985294], 
     Hue[0.9999964475127389, 1, 1.050004223009814], 
     Hue[0.9999983843063388, 1, 1.0500019206855518`], 
     Hue[0.9999992651703684, 1, 1.0500008735492699`], 
     Hue[0.9999996657935539, 1, 1.0500003972987113`], 
     Hue[0.9999998480001284, 1, 1.0500001806950596`], 
     Hue[0.9999999308691769, 1, 1.0500000821816988`], 
     Hue[0.9999999685587152, 1, 1.0500000373769467`], 
     Hue[0.9999999857002363, 1, 1.050000016999356], 
     Hue[0.9999999934963457, 1, 1.0500000077314524`], 
     Hue[0.9999999970420826, 1, 1.0500000035163306`], 
     Hue[0.9999999986547139, 1, 1.0500000015992572`], 
     Hue[0.9999999993881524, 1, 1.0500000007273558`], 
     Hue[0.9999999997217265, 1, 1.0500000003308076`], 
     Hue[0.9999999998734388, 1, 1.0500000001504541`], 
     Hue[0.9999999999424389, 1, 1.0500000000684278`], 
     Hue[0.9999999999738207, 1, 1.0500000000311216`], 
     Hue[0.9999999999880934, 1, 1.0500000000141543`], 
     Hue[0.9999999999945848, 1, 1.0500000000064376`], 
     Hue[0.9999999999975371, 1, 1.050000000002928], 
     Hue[0.9999999999988799, 1, 1.0500000000013316`], 
     Hue[0.9999999999994905, 1, 1.0500000000006056`], 
     Hue[0.9999999999997683, 1, 1.0500000000002756`], 
     Hue[0.9999999999998946, 1, 1.0500000000001253`], 
     Hue[0.999999999999952, 1, 1.0500000000000569`], 
     Hue[0.9999999999999782, 1, 1.050000000000026], 
     Hue[0.9999999999999901, 1, 1.0500000000000118`], 
     Hue[0.9999999999999954, 1, 1.0500000000000054`], 
     Hue[0.999999999999998, 1, 1.0500000000000025`], 
     Hue[0.9999999999999991, 1, 1.0500000000000012`], 
     Hue[0.9999999999999996, 1, 1.0500000000000005`], 
     Hue[0.9999999999999998, 1, 1.0500000000000003`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.8150662072470534, 1, -17.474999625757572`], 
     Hue[0.8150662072470534, 1, -17.100757209075603`], 
     Hue[0.8150662072470534, 1, -16.726514792393633`], 
     Hue[0.8150662072470535, 1, -16.35227237571166], 
     Hue[0.8150662072470535, 1, -15.97802995902969], 
     Hue[0.8150662072470535, 1, -15.603787542347721`], 
     Hue[0.8150662072470536, 1, -15.229545125665748`], 
     Hue[0.8150662072470538, 1, -14.855302708983777`], 
     Hue[0.8150662072470544, 1, -14.481060292301807`], 
     Hue[0.8150662072470554, 1, -14.10681787561984], 
     Hue[0.8150662072470578, 1, -13.73257545893787], 
     Hue[0.8150662072470631, 1, -13.358333042255904`], 
     Hue[0.8150662072470749, 1, -12.984090625573952`], 
     Hue[0.8150662072471008, 1, -12.609848208892013`], 
     Hue[0.8150662072471575, 1, -12.235605792210114`], 
     Hue[0.8150662072472823, 1, -11.861363375528304`], 
     Hue[0.8150662072475565, 1, -11.48712095884669], 
     Hue[0.8150662072481598, 1, -11.112878542165497`], 
     Hue[0.815066207249486, 1, -10.738636125485241`], 
     Hue[0.815066207252402, 1, -10.364393708807041`], 
     Hue[0.8150662072588135, 1, -9.99015129213336], 
     Hue[0.8150662072729107, 1, -9.615908875469616], 
     Hue[0.8150662073039066, 1, -9.241666458827723], 
     Hue[0.815066207372058, 1, -8.86742404223387], 
     Hue[0.8150662075219046, 1, -8.493181625745647], 
     Hue[0.8150662078513764, 1, -8.118939209489682], 
     Hue[0.8150662085757949, 1, -7.744696793744375], 
     Hue[0.8150662101685939, 1, -7.370454379121875], 
     Hue[0.8150662136707247, 1, -6.9962119669681195`], 
     Hue[0.8150662213709559, 1, -6.6219695602424595`], 
     Hue[0.8150662383016644, 1, -6.247727165451707], 
     Hue[0.8150662755276727, 1, -5.873484796902574], 
     Hue[0.8150663573774937, 1, -5.4992424860516715`], 
     Hue[0.8150665373428152, 1, -5.125000302063737], 
     Hue[0.815066933036892, 1, -4.7507583970142715`], 
     Hue[0.8150678030573322, 1, -4.3765171052811365`], 
     Hue[0.8150697159806851, 1, -4.00227716209562], 
     Hue[0.8150739219077565, 1, -3.6280401841542655`], 
     Hue[0.8150831692564526, 1, -3.2538097267281847`], 
     Hue[0.8151035000185218, 1, -2.8795936097701915`], 
     Hue[0.8151481939057429, 1, -2.5054090411426504`], 
     Hue[0.8152464252920197, 1, -2.1312939234367434`], 
     Hue[0.8154622240846036, 1, -1.7573319179932614`], 
     Hue[0.8159358097632177, 1, -1.383708528846913], 
     Hue[0.8169727438271388, 1, -1.0108390408160484`], 
     Hue[0.8192314911167795, 1, -0.6396712380921772], 
     Hue[0.8240940661567233, 1, -0.2724446345482081], 
     Hue[0.834274309578702, 1, 0.08528950065069896], 
     Hue[0.8541840384749817, 1, 0.4194929948585452], 
     Hue[0.8873216631975466, 1, 0.6993283965988681], 
     Hue[0.9277445440495055, 1, 0.8864496049398556], 
     Hue[0.9608821687720709, 1, 0.9808566198815067], 
     Hue[0.9807918976683508, 1, 1.020895542355633], 
     Hue[0.9909721410903298, 1, 1.0374038238386978`], 
     Hue[0.9958347161302737, 1, 1.0444196369766998`], 
     Hue[0.9980934634199145, 1, 1.0474942509348004`], 
     Hue[0.9991303974838358, 1, 1.0488671795859068`], 
     Hue[0.9996039831624499, 1, 1.0494862071215294`], 
     Hue[0.9998197819550337, 1, 1.049766618360019], 
     Hue[0.9999180133413106, 1, 1.0498939173360833`], 
     Hue[0.9999627072285315, 1, 1.0499517653905124`], 
     Hue[0.9999830379906007, 1, 1.0499780651144914`], 
     Hue[0.9999922853392968, 1, 1.0499900243703806`], 
     Hue[0.9999964912663682, 1, 1.0499954631109973`], 
     Hue[0.9999984041897212, 1, 1.0499979366074526`], 
     Hue[0.9999992742101614, 1, 1.0499990615562877`], 
     Hue[0.9999996699042383, 1, 1.0499995731887939`], 
     Hue[0.9999998498695598, 1, 1.0499998058828306`], 
     Hue[0.9999999317193806, 1, 1.049999911713899], 
     Hue[0.9999999689453891, 1, 1.0499999598467376`], 
     Hue[0.9999999858760975, 1, 1.0499999817379557`], 
     Hue[0.9999999935763286, 1, 1.049999991694267], 
     Hue[0.9999999970784594, 1, 1.049999996222482], 
     Hue[0.9999999986712584, 1, 1.0499999982819526`], 
     Hue[0.999999999395677, 1, 1.0499999992186173`], 
     Hue[0.9999999997251487, 1, 1.0499999996446205`], 
     Hue[0.9999999998749953, 1, 1.0499999998383704`], 
     Hue[0.9999999999431468, 1, 1.0499999999264895`], 
     Hue[0.9999999999741427, 1, 1.0499999999665668`], 
     Hue[0.9999999999882399, 1, 1.0499999999847944`], 
     Hue[0.9999999999946514, 1, 1.0499999999930845`], 
     Hue[0.9999999999975674, 1, 1.0499999999968548`], 
     Hue[0.9999999999988937, 1, 1.0499999999985696`], 
     Hue[0.9999999999994968, 1, 1.0499999999993495`], 
     Hue[0.9999999999997712, 1, 1.049999999999704], 
     Hue[0.9999999999998959, 1, 1.0499999999998655`], 
     Hue[0.9999999999999527, 1, 1.0499999999999388`], 
     Hue[0.9999999999999785, 1, 1.0499999999999723`], 
     Hue[0.9999999999999902, 1, 1.0499999999999874`], 
     Hue[0.9999999999999956, 1, 1.0499999999999943`], 
     Hue[0.999999999999998, 1, 1.0499999999999974`], 
     Hue[0.9999999999999991, 1, 1.049999999999999], 
     Hue[0.9999999999999996, 1, 1.0499999999999996`], 
     Hue[0.9999999999999998, 1, 1.0499999999999998`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.9404610083619849, 1, -17.474999625757572`], 
     Hue[0.9404610083619849, 1, -17.100757209075603`], 
     Hue[0.9404610083619849, 1, -16.726514792393633`], 
     Hue[0.9404610083619849, 1, -16.35227237571166], 
     Hue[0.9404610083619849, 1, -15.97802995902969], 
     Hue[0.9404610083619849, 1, -15.603787542347721`], 
     Hue[0.940461008361985, 1, -15.229545125665748`], 
     Hue[0.940461008361985, 1, -14.855302708983777`], 
     Hue[0.9404610083619852, 1, -14.48106029230181], 
     Hue[0.9404610083619857, 1, -14.106817875619843`], 
     Hue[0.9404610083619867, 1, -13.732575458937879`], 
     Hue[0.9404610083619888, 1, -13.358333042255923`], 
     Hue[0.9404610083619934, 1, -12.98409062557399], 
     Hue[0.9404610083620037, 1, -12.609848208892094`], 
     Hue[0.9404610083620263, 1, -12.235605792210295`], 
     Hue[0.940461008362076, 1, -11.861363375528704`], 
     Hue[0.9404610083621853, 1, -11.487120958847562`], 
     Hue[0.9404610083624254, 1, -11.112878542167417`], 
     Hue[0.9404610083629537, 1, -10.73863612548946], 
     Hue[0.940461008364115, 1, -10.36439370881632], 
     Hue[0.9404610083666683, 1, -9.990151292153758], 
     Hue[0.9404610083722825, 1, -9.615908875514469], 
     Hue[0.9404610083846267, 1, -9.24166645892634], 
     Hue[0.9404610084117679, 1, -8.867424042450706], 
     Hue[0.9404610084714443, 1, -8.49318162622241], 
     Hue[0.9404610086026564, 1, -8.118939210537953], 
     Hue[0.940461008891156, 1, -7.744696796049237], 
     Hue[0.940461009525488, 1, -7.370454384189636], 
     Hue[0.940461010920211, 1, -6.996211978110746], 
     Hue[0.9404610139868267, 1, -6.621969584742054], 
     Hue[0.9404610207294778, 1, -6.247727219319632], 
     Hue[0.9404610355547248, 1, -5.873484915343422], 
     Hue[0.9404610681513782, 1, -5.499242746470624], 
     Hue[0.940461139822416, 1, -5.125000874653103], 
     Hue[0.9404612974069173, 1, -4.750759655977711], 
     Hue[0.9404616438894947, 1, -4.376519873376733], 
     Hue[0.9404624056967434, 1, -4.002283248277555], 
     Hue[0.9404640806379453, 1, -3.6280535654977415`], 
     Hue[0.9404677630614013, 1, -3.253839146180858], 
     Hue[0.9404758581807222, 1, -2.879658283166144], 
     Hue[0.940493649766532, 1, -2.505551182498335], 
     Hue[0.9405327329943696, 1, -2.131606174208037], 
     Hue[0.9406184945296134, 1, -1.7580171238191296`], 
     Hue[0.9408062340181409, 1, -1.385208610417177], 
     Hue[0.9412150666512246, 1, -1.0141061035148342`], 
     Hue[0.9420952880175801, 1, -0.6467059988718089], 
     Hue[0.9439446648592384, 1, -0.2872174242890173], 
     Hue[0.9476369668498901, 1, 0.05592014834903469], 
     Hue[0.9543029012551305, 1, 0.3675397329692499], 
     Hue[0.9643756597300639, 1, 0.6260759221583987], 
     Hue[0.9760853486319205, 1, 0.8131971304993857], 
     Hue[0.986158107106854, 1, 0.9289033579922106], 
     Hue[0.9928240415120946, 1, 0.991526190053968], 
     Hue[0.9965163435027464, 1, 1.0226310340978881`], 
     Hue[0.9983657203444047, 1, 1.037384876197068], 
     Hue[0.9992459417107603, 1, 1.0442271882360141`], 
     Hue[0.999654774343844, 1, 1.0473670980156429`], 
     Hue[0.9998425138323713, 1, 1.0488010012956617`], 
     Hue[0.9999282753676152, 1, 1.0494543675887253`], 
     Hue[0.9999673585954528, 1, 1.0497517759803985`], 
     Hue[0.9999851501812625, 1, 1.0498870919945602`], 
     Hue[0.9999932453005835, 1, 1.0499486456618183`], 
     Hue[0.9999969277240396, 1, 1.0499766430269055`], 
     Hue[0.9999986026652414, 1, 1.0499893769290616`], 
     Hue[0.9999993644724902, 1, 1.0499951685118565`], 
     Hue[0.9999997109550676, 1, 1.0499978025928483`], 
     Hue[0.9999998685395689, 1, 1.0499990005994275`], 
     Hue[0.9999999402106067, 1, 1.0499995454638789`], 
     Hue[0.9999999728072599, 1, 1.0499997932730514`], 
     Hue[0.9999999876325071, 1, 1.049999905978812], 
     Hue[0.9999999943751582, 1, 1.0499999572383603`], 
     Hue[0.9999999974417738, 1, 1.0499999805516413`], 
     Hue[0.9999999988364969, 1, 1.0499999911547206`], 
     Hue[0.9999999994708288, 1, 1.0499999959770916`], 
     Hue[0.9999999997593284, 1, 1.049999998170347], 
     Hue[0.9999999998905406, 1, 1.0499999991678581`], 
     Hue[0.9999999999502169, 1, 1.0499999996215348`], 
     Hue[0.9999999999773582, 1, 1.0499999998278708`], 
     Hue[0.9999999999897023, 1, 1.0499999999217142`], 
     Hue[0.9999999999953165, 1, 1.049999999964395], 
     Hue[0.9999999999978699, 1, 1.0499999999838066`], 
     Hue[0.9999999999990312, 1, 1.049999999992635], 
     Hue[0.9999999999995594, 1, 1.0499999999966503`], 
     Hue[0.9999999999997996, 1, 1.0499999999984766`], 
     Hue[0.9999999999999089, 1, 1.0499999999993073`], 
     Hue[0.9999999999999586, 1, 1.049999999999685], 
     Hue[0.9999999999999811, 1, 1.0499999999998566`], 
     Hue[0.9999999999999915, 1, 1.0499999999999348`], 
     Hue[0.9999999999999961, 1, 1.0499999999999705`], 
     Hue[0.9999999999999982, 1, 1.0499999999999865`], 
     Hue[0.9999999999999992, 1, 1.0499999999999938`], 
     Hue[0.9999999999999997, 1, 1.0499999999999974`], 
     Hue[0.9999999999999998, 1, 1.0499999999999987`], 
     Hue[0.9999999999999999, 1, 1.0499999999999996`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.0658558094769164`, 1, -17.474999625757572`], 
     Hue[1.0658558094769164`, 1, -17.100757209075603`], 
     Hue[1.0658558094769164`, 1, -16.726514792393633`], 
     Hue[1.0658558094769164`, 1, -16.35227237571166], 
     Hue[1.0658558094769164`, 1, -15.97802995902969], 
     Hue[1.0658558094769164`, 1, -15.603787542347721`], 
     Hue[1.0658558094769164`, 1, -15.229545125665748`], 
     Hue[1.0658558094769162`, 1, -14.855302708983777`], 
     Hue[1.0658558094769162`, 1, -14.48106029230181], 
     Hue[1.0658558094769155`, 1, -14.106817875619843`], 
     Hue[1.0658558094769146`, 1, -13.732575458937879`], 
     Hue[1.0658558094769122`, 1, -13.358333042255921`], 
     Hue[1.065855809476907, 1, -12.984090625573987`], 
     Hue[1.0658558094768957`, 1, -12.609848208892092`], 
     Hue[1.0658558094768709`, 1, -12.23560579221029], 
     Hue[1.0658558094768162`, 1, -11.861363375528692`], 
     Hue[1.065855809476696, 1, -11.487120958847537`], 
     Hue[1.0658558094764317`, 1, -11.11287854216736], 
     Hue[1.0658558094758506`, 1, -10.738636125489341`], 
     Hue[1.0658558094745727`, 1, -10.364393708816054`], 
     Hue[1.0658558094717634`, 1, -9.990151292153175], 
     Hue[1.0658558094655861`, 1, -9.615908875513187], 
     Hue[1.065855809452004, 1, -9.241666458923524], 
     Hue[1.0658558094221409`, 1, -8.867424042444512], 
     Hue[1.0658558093564798`, 1, -8.493181626208793], 
     Hue[1.065855809212109, 1, -8.11893921050801], 
     Hue[1.0658558088946772`, 1, -7.744696795983402], 
     Hue[1.065855808196731, 1, -7.370454384044884], 
     Hue[1.0658558066621378`, 1, -6.996211977792476], 
     Hue[1.0658558032879852`, 1, -6.621969584042265], 
     Hue[1.065855795869145, 1, -6.247727217780986], 
     Hue[1.0658557795571424`, 1, -5.873484911960361], 
     Hue[1.0658557436915208`, 1, -5.499242739032202], 
     Hue[1.065855664832923, 1, -5.125000858298079], 
     Hue[1.065855491444983, 1, -4.750759620017652], 
     Hue[1.065855110215181, 1, -4.37651979431123], 
     Hue[1.0658542720093669`, 1, -4.002283074438268], 
     Hue[1.0658524290939153`, 1, -3.628053183292847], 
     Hue[1.0658483773668457`, 1, -3.253838305914707], 
     Hue[1.0658394703751248`, 1, -2.879656436124722], 
     Hue[1.0658198943102062`, 1, -2.5055471236518994`], 
     Hue[1.0657768904320462`, 1, -2.1315972609881966`], 
     Hue[1.0656825226153774`, 1, -1.757997579479978], 
     Hue[1.0654759285158661`, 1, -1.3851658943233829`], 
     Hue[1.065025967590864, 1, -1.014013406240337], 
     Hue[1.0640568788130425`, 1, -0.6465079270054019], 
     Hue[1.062019422491329, 1, -0.28680796716901247`], 
     Hue[1.0579464822656874`, 1, 0.056710552856499175`], 
     Hue[1.05057865782611, 1, 0.3688763506766617], 
     Hue[1.0394204585271938`, 1, 0.627883209057136], 
     Hue[1.026435350949723, 1, 0.8150044173981228], 
     Hue[1.0152771516508068`, 1, 0.9302399756996222], 
     Hue[1.0079093272112294`, 1, 0.9923165945614325], 
     Hue[1.0038363869855875`, 1, 1.023040491217893], 
     Hue[1.001798930663874, 1, 1.037582948063475], 
     Hue[1.0008298418860524`, 1, 1.0443198855105114`], 
     Hue[1.0003798809610505`, 1, 1.047409814109437], 
     Hue[1.000173286861539, 1, 1.048820545634813], 
     Hue[1.0000789190448702`, 1, 1.0494632808085655`], 
     Hue[1.0000359151667102`, 1, 1.0497558348268343`], 
     Hue[1.0000163391017918`, 1, 1.0498889390359818`], 
     Hue[1.000007432110071, 1, 1.0499494859279694`], 
     Hue[1.000003380383001, 1, 1.0499770252317993`], 
     Hue[1.0000015374675497`, 1, 1.0499895507683497`], 
     Hue[1.0000006992617354`, 1, 1.0499952475773588`], 
     Hue[1.0000003180319335`, 1, 1.0499978385529085`], 
     Hue[1.0000001446439934`, 1, 1.0499990169544515`], 
     Hue[1.0000000657853956`, 1, 1.0499995529023], 
     Hue[1.0000000299197742`, 1, 1.0499997966561123`], 
     Hue[1.0000000136077716`, 1, 1.0499999075174575`], 
     Hue[1.0000000061889311`, 1, 1.0499999579381496`], 
     Hue[1.0000000028147789`, 1, 1.0499999808699114`], 
     Hue[1.0000000012801855`, 1, 1.0499999912994726`], 
     Hue[1.0000000005822391`, 1, 1.049999996042926], 
     Hue[1.0000000002648073`, 1, 1.049999998200289], 
     Hue[1.0000000001204365`, 1, 1.0499999991814761`], 
     Hue[1.0000000000547755`, 1, 1.0499999996277285`], 
     Hue[1.0000000000249125`, 1, 1.0499999998306877`], 
     Hue[1.0000000000113303`, 1, 1.0499999999229954`], 
     Hue[1.0000000000051532`, 1, 1.0499999999649776`], 
     Hue[1.0000000000023437`, 1, 1.0499999999840717`], 
     Hue[1.000000000001066, 1, 1.0499999999927556`], 
     Hue[1.0000000000004847`, 1, 1.0499999999967051`], 
     Hue[1.0000000000002205`, 1, 1.0499999999985015`], 
     Hue[1.0000000000001004`, 1, 1.0499999999993186`], 
     Hue[1.0000000000000455`, 1, 1.04999999999969], 
     Hue[1.0000000000000207`, 1, 1.049999999999859], 
     Hue[1.0000000000000093`, 1, 1.0499999999999359`], 
     Hue[1.0000000000000042`, 1, 1.049999999999971], 
     Hue[1.000000000000002, 1, 1.0499999999999867`], 
     Hue[1.0000000000000009`, 1, 1.049999999999994], 
     Hue[1.0000000000000004`, 1, 1.0499999999999974`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999987`], 
     Hue[1., 1, 1.0499999999999996`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.1912506105918481`, 1, -17.474999625757572`], 
     Hue[1.1912506105918481`, 1, -17.100757209075603`], 
     Hue[1.1912506105918481`, 1, -16.726514792393633`], 
     Hue[1.1912506105918481`, 1, -16.35227237571166], 
     Hue[1.1912506105918481`, 1, -15.97802995902969], 
     Hue[1.191250610591848, 1, -15.603787542347721`], 
     Hue[1.191250610591848, 1, -15.229545125665748`], 
     Hue[1.1912506105918477`, 1, -14.855302708983777`], 
     Hue[1.191250610591847, 1, -14.481060292301807`], 
     Hue[1.1912506105918461`, 1, -14.106817875619837`], 
     Hue[1.1912506105918435`, 1, -13.73257545893787], 
     Hue[1.1912506105918381`, 1, -13.358333042255904`], 
     Hue[1.1912506105918261`, 1, -12.984090625573948`], 
     Hue[1.1912506105918, 1, -12.609848208892007`], 
     Hue[1.1912506105917422`, 1, -12.235605792210102`], 
     Hue[1.1912506105916154`, 1, -11.861363375528278`], 
     Hue[1.1912506105913367`, 1, -11.487120958846628`], 
     Hue[1.1912506105907235`, 1, -11.112878542165364`], 
     Hue[1.1912506105893756`, 1, -10.738636125484952`], 
     Hue[1.1912506105864118`, 1, -10.364393708806402`], 
     Hue[1.191250610579895, 1, -9.990151292131953], 
     Hue[1.1912506105655667`, 1, -9.615908875466527], 
     Hue[1.1912506105340623`, 1, -9.241666458820932], 
     Hue[1.1912506104647929`, 1, -8.86742404221894], 
     Hue[1.1912506103124885`, 1, -8.49318162571282], 
     Hue[1.1912506099776126`, 1, -8.118939209417501], 
     Hue[1.1912506092413113`, 1, -7.7446967935856685`], 
     Hue[1.1912506076223859`, 1, -7.370454378772922], 
     Hue[1.1912506040628101`, 1, -6.996211966200865], 
     Hue[1.1912505962362734`, 1, -6.621969558555477], 
     Hue[1.191250579027853, 1, -6.247727161742491], 
     Hue[1.1912505411912315`, 1, -5.873484788747021], 
     Hue[1.1912504579988363`, 1, -5.499242468119841], 
     Hue[1.1912502750815503`, 1, -5.125000262636566], 
     Hue[1.19124987289686, 1, -4.750758310324847], 
     Hue[1.1912489886050968`, 1, -4.376516914675576], 
     Hue[1.1912470443018714`, 1, -4.002276743010101], 
     Hue[1.1912427693735843`, 1, -3.628039262719547], 
     Hue[1.1912333702837814`, 1, -3.253807700841656], 
     Hue[1.1912127057575645`, 1, -2.8795891558682873`], 
     Hue[1.1911672774013082`, 1, -2.505399250501145], 
     Hue[1.1910674281603433`, 1, -2.1312724074884386`], 
     Hue[1.1908480578942444`, 1, -1.7572846635484385`], 
     Hue[1.1903665511025856`, 1, -1.3836048873536912`], 
     Hue[1.1893118750590415`, 1, -1.0106124162702665`], 
     Hue[1.18701259844369, 1, -0.6391790866113953], 
     Hue[1.1820541413261594`, 1, -0.27139278777429077`], 
     Hue[1.1716363204034808`, 1, 0.08745197521287151], 
     Hue[1.1511310980005152`, 1, 0.423525856176563], 
     Hue[1.116712519380639, 1, 0.7053115219739927], 
     Hue[1.0745380912112106`, 1, 0.8924327303149802], 
     Hue[1.0401195125913338`, 1, 0.9848894811995247], 
     Hue[1.0196142901883678`, 1, 1.0230580169178056`], 
     Hue[1.009196469265689, 1, 1.0384556706126153`], 
     Hue[1.0042380121481582`, 1, 1.0449117884574821`], 
     Hue[1.0019387355328067`, 1, 1.0477208754805822`], 
     Hue[1.0008840594892625`, 1, 1.0489708210791289`], 
     Hue[1.0004025526976037`, 1, 1.0495334615663527`], 
     Hue[1.0001831824315046`, 1, 1.049788134308324], 
     Hue[1.0000833331905399`, 1, 1.0499037079775881`], 
     Hue[1.0000379048342833`, 1, 1.0499562192924172`], 
     Hue[1.0000172403080667`, 1, 1.04998009100102], 
     Hue[1.0000078412182638`, 1, 1.0499909458051002`], 
     Hue[1.0000035662899767`, 1, 1.0499958821965172`], 
     Hue[1.0000016219867514`, 1, 1.0499981272130132`], 
     Hue[1.0000007376949882`, 1, 1.0499991482457132`], 
     Hue[1.0000003355102978`, 1, 1.0499996126159648`], 
     Hue[1.0000001525930116`, 1, 1.0499998238146608`], 
     Hue[1.0000000694006166`, 1, 1.0499999198694516`], 
     Hue[1.000000031563995, 1, 1.0499999635559532`], 
     Hue[1.0000000143555747`, 1, 1.0499999834249387`], 
     Hue[1.0000000065290378`, 1, 1.049999992461521], 
     Hue[1.000000002969462, 1, 1.0499999965714357`], 
     Hue[1.0000000013505368`, 1, 1.0499999984406598`], 
     Hue[1.0000000006142356`, 1, 1.049999999290799], 
     Hue[1.0000000002793596`, 1, 1.0499999996774494`], 
     Hue[1.000000000127055, 1, 1.0499999998533012`], 
     Hue[1.0000000000577858`, 1, 1.04999999993328], 
     Hue[1.0000000000262814`, 1, 1.0499999999696552`], 
     Hue[1.000000000011953, 1, 1.049999999986199], 
     Hue[1.0000000000054363`, 1, 1.0499999999937233`], 
     Hue[1.0000000000024725`, 1, 1.0499999999971452`], 
     Hue[1.0000000000011244`, 1, 1.0499999999987017`], 
     Hue[1.0000000000005114`, 1, 1.0499999999994094`], 
     Hue[1.0000000000002327`, 1, 1.0499999999997316`], 
     Hue[1.0000000000001057`, 1, 1.049999999999878], 
     Hue[1.0000000000000482`, 1, 1.0499999999999445`], 
     Hue[1.000000000000022, 1, 1.0499999999999747`], 
     Hue[1.00000000000001, 1, 1.0499999999999885`], 
     Hue[1.0000000000000044`, 1, 1.0499999999999947`], 
     Hue[1.000000000000002, 1, 1.0499999999999976`], 
     Hue[1.0000000000000009`, 1, 1.049999999999999], 
     Hue[1.0000000000000004`, 1, 1.0499999999999996`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.3166454117067796`, 1, -17.474999625757572`], 
     Hue[1.3166454117067796`, 1, -17.100757209075603`], 
     Hue[1.3166454117067796`, 1, -16.726514792393633`], 
     Hue[1.3166454117067796`, 1, -16.35227237571166], 
     Hue[1.3166454117067794`, 1, -15.97802995902969], 
     Hue[1.3166454117067794`, 1, -15.603787542347721`], 
     Hue[1.3166454117067792`, 1, -15.229545125665748`], 
     Hue[1.3166454117067792`, 1, -14.855302708983777`], 
     Hue[1.3166454117067787`, 1, -14.481060292301807`], 
     Hue[1.3166454117067774`, 1, -14.106817875619832`], 
     Hue[1.3166454117067752`, 1, -13.732575458937859`], 
     Hue[1.3166454117067699`, 1, -13.358333042255879`], 
     Hue[1.316645411706758, 1, -12.984090625573893`], 
     Hue[1.3166454117067323`, 1, -12.609848208891888`], 
     Hue[1.316645411706676, 1, -12.23560579220984], 
     Hue[1.3166454117065516`, 1, -11.861363375527707`], 
     Hue[1.3166454117062785`, 1, -11.487120958845374`], 
     Hue[1.3166454117056778`, 1, -11.112878542162603`], 
     Hue[1.3166454117043576`, 1, -10.73863612547888], 
     Hue[1.316645411701454, 1, -10.36439370879305], 
     Hue[1.3166454116950705`, 1, -9.9901512921026], 
     Hue[1.3166454116810347`, 1, -9.615908875401983], 
     Hue[1.3166454116501736`, 1, -9.241666458679022], 
     Hue[1.3166454115823183`, 1, -8.867424041906917], 
     Hue[1.3166454114331234`, 1, -8.493181625026768], 
     Hue[1.316645411105084, 1, -8.118939207909058], 
     Hue[1.3166454103838152`, 1, -7.7446967902690185`], 
     Hue[1.3166454087979413`, 1, -7.370454371480508], 
     Hue[1.3166454053110372`, 1, -6.996211950166837], 
     Hue[1.316645397644285, 1, -6.6219695233010185`], 
     Hue[1.316645380787185, 1, -6.247727084227548], 
     Hue[1.3166453437230103`, 1, -5.873484618312784], 
     Hue[1.3166452622289646`, 1, -5.499242093381391], 
     Hue[1.3166450830456367`, 1, -5.124999438688794], 
     Hue[1.3166446890696992`, 1, -4.750756498688017], 
     Hue[1.3166438228209283`, 1, -4.37651293137882], 
     Hue[1.316641918161199, 1, -4.002267984820838], 
     Hue[1.3166377302621788`, 1, -3.6280200058228242`], 
     Hue[1.316628521868642, 1, -3.2537653600513172`], 
     Hue[1.3166082734534894`, 1, -2.8794960594194094`], 
     Hue[1.316563744647562, 1, -2.5051945539518456`], 
     Hue[1.3164657989891877`, 1, -2.1308223221208573`], 
     Hue[1.3162502550121742`, 1, -1.7562949860352821`], 
     Hue[1.315775424274988, 1, -1.381428581195909], 
     Hue[1.3147270252763592`, 1, -1.0058262686160095`], 
     Hue[1.3124009017483096`, 1, -0.6286536519789585], 
     Hue[1.3071870610377438`, 1, -0.24827294237684128`], 
     Hue[1.2952713969291154`, 1, 0.13783500887155742`], 
     Hue[1.2673333310684036`, 1, 0.5287360641285296], 
     Hue[1.2046219340394342`, 1, 0.8862266467211288], 
     Hue[1.1120234776673485`, 1, 1.0733478550621185`], 
     Hue[1.0493120806383773`, 1, 1.0900996891514938`], 
     Hue[1.0213740147776647`, 1, 1.0734410505764926`], 
     Hue[1.009458350669036, 1, 1.0615755160100653`], 
     Hue[1.0042445099584703`, 1, 1.055437223089919], 
     Hue[1.0019183864304202`, 1, 1.0525070231348392`], 
     Hue[1.0008699874317917`, 1, 1.051147127236911], 
     Hue[1.0003951566946054`, 1, 1.0505231390795087`], 
     Hue[1.0001796127175917`, 1, 1.0502382196759046`], 
     Hue[1.0000816670592174`, 1, 1.050108404526888], 
     Hue[1.00003713825329, 1, 1.0500493157412945`], 
     Hue[1.0000168898381376`, 1, 1.0500224317913587`], 
     Hue[1.0000076814446008`, 1, 1.0500102027018225`], 
     Hue[1.0000034935455804`, 1, 1.0500046403857795`], 
     Hue[1.0000015888858511`, 1, 1.050002110509768], 
     Hue[1.0000007226370804`, 1, 1.0500009598825422`], 
     Hue[1.0000003286611427`, 1, 1.0500004365637372`], 
     Hue[1.0000001494778148`, 1, 1.0500001985531109`], 
     Hue[1.000000067983769, 1, 1.0500000903036895`], 
     Hue[1.0000000309195944`, 1, 1.0500000410708963`], 
     Hue[1.0000000140624945`, 1, 1.0500000186793956`], 
     Hue[1.0000000063957422`, 1, 1.0500000084955488`], 
     Hue[1.000000002908838, 1, 1.0500000038638482`], 
     Hue[1.0000000013229644`, 1, 1.050000001757311], 
     Hue[1.0000000006016954`, 1, 1.05000000079924], 
     Hue[1.0000000002736562`, 1, 1.0500000003635013`], 
     Hue[1.000000000124461, 1, 1.0500000001653236`], 
     Hue[1.000000000056606, 1, 1.0500000000751906`], 
     Hue[1.000000000025745, 1, 1.0500000000341974`], 
     Hue[1.000000000011709, 1, 1.0500000000155532`], 
     Hue[1.0000000000053253`, 1, 1.0500000000070737`], 
     Hue[1.000000000002422, 1, 1.0500000000032172`], 
     Hue[1.0000000000011016`, 1, 1.0500000000014633`], 
     Hue[1.000000000000501, 1, 1.0500000000006655`], 
     Hue[1.0000000000002278`, 1, 1.0500000000003027`], 
     Hue[1.0000000000001037`, 1, 1.0500000000001377`], 
     Hue[1.000000000000047, 1, 1.0500000000000627`], 
     Hue[1.0000000000000215`, 1, 1.0500000000000285`], 
     Hue[1.0000000000000098`, 1, 1.050000000000013], 
     Hue[1.0000000000000044`, 1, 1.050000000000006], 
     Hue[1.000000000000002, 1, 1.0500000000000027`], 
     Hue[1.0000000000000009`, 1, 1.0500000000000014`], 
     Hue[1.0000000000000004`, 1, 1.0500000000000007`], 
     Hue[1.0000000000000002`, 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.4420402128217114`, 1, -17.474999625757572`], 
     Hue[1.4420402128217114`, 1, -17.100757209075603`], 
     Hue[1.4420402128217114`, 1, -16.726514792393633`], 
     Hue[1.4420402128217114`, 1, -16.35227237571166], 
     Hue[1.4420402128217114`, 1, -15.97802995902969], 
     Hue[1.4420402128217114`, 1, -15.603787542347721`], 
     Hue[1.4420402128217114`, 1, -15.229545125665748`], 
     Hue[1.4420402128217111`, 1, -14.855302708983777`], 
     Hue[1.442040212821711, 1, -14.481060292301803`], 
     Hue[1.4420402128217105`, 1, -14.106817875619829`], 
     Hue[1.4420402128217096`, 1, -13.73257545893785], 
     Hue[1.4420402128217074`, 1, -13.358333042255863`], 
     Hue[1.442040212821703, 1, -12.984090625573858`], 
     Hue[1.442040212821693, 1, -12.609848208891808`], 
     Hue[1.442040212821671, 1, -12.235605792209665`], 
     Hue[1.4420402128216225`, 1, -11.861363375527315`], 
     Hue[1.442040212821516, 1, -11.487120958844509`], 
     Hue[1.4420402128212817`, 1, -11.112878542160702`], 
     Hue[1.442040212820767, 1, -10.738636125474704`], 
     Hue[1.442040212819635, 1, -10.364393708783869`], 
     Hue[1.4420402128171463`, 1, -9.99015129208241], 
     Hue[1.4420402128116745`, 1, -9.615908875357595], 
     Hue[1.4420402127996428`, 1, -9.241666458581422], 
     Hue[1.4420402127731888`, 1, -8.86742404169232], 
     Hue[1.4420402127150238`, 1, -8.493181624554927], 
     Hue[1.4420402125871346`, 1, -8.118939206871609], 
     Hue[1.4420402123059406`, 1, -7.744696787987947], 
     Hue[1.4420402116876723`, 1, -7.370454366465059], 
     Hue[1.4420402103282686`, 1, -6.996211939139228], 
     Hue[1.4420402073393102`, 1, -6.621969499054308], 
     Hue[1.442040200767404, 1, -6.2477270309156285`], 
     Hue[1.442040186317568, 1, -5.873484501094361], 
     Hue[1.442040154546293, 1, -5.499241835649832], 
     Hue[1.442040084689801, 1, -5.124998872006396], 
     Hue[1.4420399310938465`, 1, -4.750755252703332], 
     Hue[1.4420395933754664`, 1, -4.376510191776175], 
     Hue[1.4420388508115634`, 1, -4.002261961075421], 
     Hue[1.4420372180519827`, 1, -3.628006760736726], 
     Hue[1.4420336277495602`, 1, -3.253736235243408], 
     Hue[1.4420257321584904`, 1, -2.879432009945968], 
     Hue[1.4420083646772226`, 1, -2.505053668787424], 
     Hue[1.4419701433398988`, 1, -2.130512274295959], 
     Hue[1.4418859355617575`, 1, -1.7556119210391745`], 
     Hue[1.4416999623443527`, 1, -1.379920139500354], 
     Hue[1.441287035420929, 1, -1.0024776455325985`], 
     Hue[1.4403592125841398`, 1, -0.6211340499071614], 
     Hue[1.4382177537451253`, 1, -0.2309560300290563], 
     Hue[1.432956990188384, 1, 0.17996091834616668`], 
     Hue[1.4178557268910428`, 1, 0.6435484926488195], 
     Hue[1.3503641440815821`, 1, 1.2517751546451321`], 
     Hue[1.0916760687401348`, 1, 1.4388963629861367`], 
     Hue[1.0241844859306695`, 1, 1.204912117671788], 
     Hue[1.0090832226333277`, 1, 1.1155669600511033`], 
     Hue[1.0038224590765863`, 1, 1.0788924283578507`], 
     Hue[1.0016810002375713`, 1, 1.0629568251617165`], 
     Hue[1.0007531774007823`, 1, 1.05585564621825], 
     Hue[1.0003402504773586`, 1, 1.052655568932466], 
     Hue[1.0001542772599539`, 1, 1.0512062040756167`], 
     Hue[1.0000700694818123`, 1, 1.0505482675008038`], 
     Hue[1.0000318481444888`, 1, 1.0502492896913094`], 
     Hue[1.000014480663221, 1, 1.0501133652147356`], 
     Hue[1.000006585072151, 1, 1.0500515565992687`], 
     Hue[1.0000029947697286`, 1, 1.050023447787921], 
     Hue[1.0000013620101478`, 1, 1.0500106641311968`], 
     Hue[1.0000006194462447`, 1, 1.0500048501124142`], 
     Hue[1.0000002817278648`, 1, 1.0500022058672271`], 
     Hue[1.0000001281319104`, 1, 1.0500010032461353`], 
     Hue[1.000000058275418, 1, 1.050000456284671], 
     Hue[1.000000026504143, 1, 1.050000207522112], 
     Hue[1.0000000120543073`, 1, 1.050000094382816], 
     Hue[1.0000000054824012`, 1, 1.0500000429261076`], 
     Hue[1.0000000024934426`, 1, 1.0500000195231594`], 
     Hue[1.0000000011340389`, 1, 1.0500000088792991`], 
     Hue[1.0000000005157705`, 1, 1.050000004038381], 
     Hue[1.0000000002345768`, 1, 1.0500000018366902`], 
     Hue[1.0000000001066875`, 1, 1.0500000008353423`], 
     Hue[1.0000000000485225`, 1, 1.0500000003799208`], 
     Hue[1.0000000000220683`, 1, 1.0500000001727914`], 
     Hue[1.0000000000100369`, 1, 1.050000000078587], 
     Hue[1.0000000000045648`, 1, 1.0500000000357421`], 
     Hue[1.0000000000020761`, 1, 1.0500000000162557`], 
     Hue[1.0000000000009444`, 1, 1.0500000000073935`], 
     Hue[1.0000000000004294`, 1, 1.0500000000033625`], 
     Hue[1.0000000000001954`, 1, 1.0500000000015293`], 
     Hue[1.0000000000000888`, 1, 1.0500000000006957`], 
     Hue[1.0000000000000404`, 1, 1.0500000000003165`], 
     Hue[1.0000000000000184`, 1, 1.050000000000144], 
     Hue[1.0000000000000084`, 1, 1.0500000000000655`], 
     Hue[1.0000000000000038`, 1, 1.0500000000000298`], 
     Hue[1.0000000000000018`, 1, 1.0500000000000136`], 
     Hue[1.0000000000000009`, 1, 1.0500000000000063`], 
     Hue[1.0000000000000004`, 1, 1.050000000000003], 
     Hue[1.0000000000000002`, 1, 1.0500000000000014`], 
     Hue[1., 1, 1.0500000000000007`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.5674350139366426, 1, -17.474999625757572`], 
     Hue[0.5674350139366426, 1, -17.100757209075603`], 
     Hue[0.5674350139366426, 1, -16.726514792393633`], 
     Hue[0.5674350139366426, 1, -16.35227237571166], 
     Hue[0.5674350139366426, 1, -15.97802995902969], 
     Hue[0.5674350139366426, 1, -15.603787542347721`], 
     Hue[0.5674350139366426, 1, -15.229545125665748`], 
     Hue[0.5674350139366429, 1, -14.855302708983777`], 
     Hue[0.5674350139366431, 1, -14.481060292301803`], 
     Hue[0.5674350139366435, 1, -14.106817875619829`], 
     Hue[0.5674350139366446, 1, -13.73257545893785], 
     Hue[0.5674350139366471, 1, -13.358333042255865`], 
     Hue[0.5674350139366522, 1, -12.984090625573858`], 
     Hue[0.5674350139366638, 1, -12.609848208891812`], 
     Hue[0.5674350139366893, 1, -12.23560579220967], 
     Hue[0.5674350139367452, 1, -11.86136337552733], 
     Hue[0.5674350139368681, 1, -11.487120958844546`], 
     Hue[0.5674350139371385, 1, -11.112878542160786`], 
     Hue[0.5674350139377327, 1, -10.738636125474883`], 
     Hue[0.5674350139390392, 1, -10.364393708784267`], 
     Hue[0.567435013941912, 1, -9.990151292083285], 
     Hue[0.5674350139482285, 1, -9.615908875359517], 
     Hue[0.5674350139621167, 1, -9.241666458585645], 
     Hue[0.5674350139926532, 1, -8.867424041701609], 
     Hue[0.5674350140597946, 1, -8.493181624575351], 
     Hue[0.5674350142074203, 1, -8.118939206916519], 
     Hue[0.5674350145320088, 1, -7.744696788086691], 
     Hue[0.5674350152456907, 1, -7.370454366682169], 
     Hue[0.5674350168148827, 1, -6.996211939616594], 
     Hue[0.5674350202651085, 1, -6.621969500103905], 
     Hue[0.5674350278512159, 1, -6.247727033223409], 
     Hue[0.5674350445310041, 1, -5.873484506168545], 
     Hue[0.5674350812053404, 1, -5.49924184680659], 
     Hue[0.5674351618423426, 1, -5.1249988965371225`], 
     Hue[0.5674353391417717, 1, -4.750755306639987], 
     Hue[0.5674357289779776, 1, -4.376510310369484], 
     Hue[0.5674365861364437, 1, -4.002262221836091], 
     Hue[0.5674384708662994, 1, -3.628007334108861], 
     Hue[0.5674426152216588, 1, -3.2537374960798626`], 
     Hue[0.56745172921257, 1, -2.879434782894454], 
     Hue[0.5674717765342201, 1, -2.505059769193079], 
     Hue[0.567515894517862, 1, -2.1305257041140475`], 
     Hue[0.5676130887507149, 1, -1.755641530455614], 
     Hue[0.5678277190907364, 1, -1.3799856361008216`], 
     Hue[0.5683041585009311, 1, -1.002623583501198], 
     Hue[0.5693740947522583, 1, -0.621464538300252], 
     Hue[0.5718403024476943, 1, -0.23173238399596108`], 
     Hue[0.5778780507419539, 1, 0.1779739698521592], 
     Hue[0.5950154955541864, 1, 0.6372421927421696], 
     Hue[0.666723801016345, 1, 1.2168403957848692`], 
     Hue[0.9007112129202922, 1, 1.403961604125871], 
     Hue[0.9724195183824552, 1, 1.198605817765138], 
     Hue[0.9895569631946884, 1, 1.113580011557096], 
     Hue[0.9955947114889482, 1, 1.0781160743909461`], 
     Hue[0.9980609191843843, 1, 1.0626263367686257`], 
     Hue[0.9991308554357116, 1, 1.055709708249651], 
     Hue[0.9996072948459063, 1, 1.0525900723319979`], 
     Hue[0.9998219251859277, 1, 1.0511765946591771`], 
     Hue[0.9999191194187806, 1, 1.0505348376827153`], 
     Hue[0.9999632374024225, 1, 1.050243189285654], 
     Hue[0.9999832847240726, 1, 1.0501105922662495`], 
     Hue[0.9999923987149838, 1, 1.0500502957628133`], 
     Hue[0.9999965430703432, 1, 1.0500228744157862`], 
     Hue[0.999998427800199, 1, 1.0500104033705262`], 
     Hue[0.9999992849586651, 1, 1.0500047315191054`], 
     Hue[0.999999674794871, 1, 1.0500021519305727`], 
     Hue[0.9999998520943002, 1, 1.0500009787154077`], 
     Hue[0.9999999327313023, 1, 1.0500004451279124`], 
     Hue[0.9999999694056384, 1, 1.050000202447928], 
     Hue[0.9999999860854267, 1, 1.0500000920750352`], 
     Hue[0.9999999936715341, 1, 1.0500000418765092`], 
     Hue[0.9999999971217599, 1, 1.0500000190457932`], 
     Hue[0.9999999986909519, 1, 1.0500000086621888`], 
     Hue[0.9999999994046338, 1, 1.0500000039396375`], 
     Hue[0.9999999997292224, 1, 1.0500000017917808`], 
     Hue[0.9999999998768481, 1, 1.050000000814917], 
     Hue[0.9999999999439895, 1, 1.0500000003706313`], 
     Hue[0.9999999999745259, 1, 1.0500000001685663`], 
     Hue[0.9999999999884142, 1, 1.0500000000766654`], 
     Hue[0.9999999999947307, 1, 1.0500000000348682`], 
     Hue[0.9999999999976035, 1, 1.0500000000158585`], 
     Hue[0.99999999999891, 1, 1.0500000000072125`], 
     Hue[0.9999999999995043, 1, 1.0500000000032803`], 
     Hue[0.9999999999997745, 1, 1.050000000001492], 
     Hue[0.9999999999998974, 1, 1.0500000000006786`], 
     Hue[0.9999999999999534, 1, 1.0500000000003087`], 
     Hue[0.9999999999999788, 1, 1.0500000000001404`], 
     Hue[0.9999999999999903, 1, 1.0500000000000638`], 
     Hue[0.9999999999999956, 1, 1.0500000000000291`], 
     Hue[0.999999999999998, 1, 1.0500000000000131`], 
     Hue[0.9999999999999991, 1, 1.050000000000006], 
     Hue[0.9999999999999996, 1, 1.0500000000000027`], 
     Hue[0.9999999999999998, 1, 1.0500000000000014`], 
     Hue[0.9999999999999999, 1, 1.0500000000000007`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.6928298150515741, 1, -17.474999625757572`], 
     Hue[0.6928298150515741, 1, -17.100757209075603`], 
     Hue[0.6928298150515741, 1, -16.726514792393633`], 
     Hue[0.6928298150515741, 1, -16.35227237571166], 
     Hue[0.6928298150515741, 1, -15.97802995902969], 
     Hue[0.6928298150515741, 1, -15.603787542347721`], 
     Hue[0.6928298150515743, 1, -15.229545125665748`], 
     Hue[0.6928298150515746, 1, -14.855302708983777`], 
     Hue[0.692829815051575, 1, -14.481060292301807`], 
     Hue[0.6928298150515761, 1, -14.106817875619834`], 
     Hue[0.6928298150515786, 1, -13.732575458937859`], 
     Hue[0.6928298150515841, 1, -13.35833304225588], 
     Hue[0.6928298150515961, 1, -12.984090625573897`], 
     Hue[0.6928298150516223, 1, -12.609848208891897`], 
     Hue[0.6928298150516803, 1, -12.23560579220986], 
     Hue[0.6928298150518075, 1, -11.861363375527748`], 
     Hue[0.6928298150520875, 1, -11.487120958845463`], 
     Hue[0.6928298150527028, 1, -11.1128785421628], 
     Hue[0.6928298150540559, 1, -10.738636125479315`], 
     Hue[0.6928298150570311, 1, -10.36439370879401], 
     Hue[0.6928298150635724, 1, -9.990151292104708], 
     Hue[0.6928298150779552, 1, -9.615908875406616], 
     Hue[0.6928298151095789, 1, -9.241666458689206], 
     Hue[0.6928298151791107, 1, -8.867424041929311], 
     Hue[0.6928298153319923, 1, -8.493181625076007], 
     Hue[0.6928298156681372, 1, -8.118939208017322], 
     Hue[0.6928298164072284, 1, -7.744696790507059], 
     Hue[0.6928298180322887, 1, -7.3704543720038975`], 
     Hue[0.692829821605353, 1, -6.996211951317625], 
     Hue[0.6928298294615483, 1, -6.621969525831286], 
     Hue[0.6928298467351814, 1, -6.247727089790917], 
     Hue[0.6928298847151984, 1, -5.873484630545118], 
     Hue[0.6928299682229287, 1, -5.499242120276971], 
     Hue[0.6928301518337856, 1, -5.1249994978249], 
     Hue[0.6928305555445806, 1, -4.750756628712468], 
     Hue[0.6928314431973013, 1, -4.3765132172684424`], 
     Hue[0.6928333949167995, 1, -4.002268613420444], 
     Hue[0.6928376862792855, 1, -3.6280213879722263`], 
     Hue[0.692847122121423, 1, -3.253768399167062], 
     Hue[0.6928678704437057, 1, -2.879502742311864], 
     Hue[0.6929134974883102, 1, -2.505209251219319], 
     Hue[0.6930138534159921, 1, -2.1308546538743167`], 
     Hue[0.6932346752972183, 1, -1.7563661542641584`], 
     Hue[0.6937210054574829, 1, -1.3815854440937125`], 
     Hue[0.6947941720342325, 1, -1.0061730092325496`], 
     Hue[0.6971721739772472, 1, -0.6294248148383648], 
     Hue[0.7024867536173796, 1, -0.25000937810130464`], 
     Hue[0.7145507018839625, 1, 0.1338405417409012], 
     Hue[0.7423870073768489, 1, 0.5194205967850185], 
     Hue[0.8028550675835241, 1, 0.8675168207069232], 
     Hue[0.8899747474680471, 1, 1.0546380290479125`], 
     Hue[0.9504428076747237, 1, 1.0807842218079822`], 
     Hue[0.978279113167611, 1, 1.0694465834458367`], 
     Hue[0.9903430614341943, 1, 1.059839080285602], 
     Hue[0.9956576410743269, 1, 1.054666060230513], 
     Hue[0.9980356430173415, 1, 1.052160282518299], 
     Hue[0.9991088095940911, 1, 1.0509902643391074`], 
     Hue[0.9995951397543558, 1, 1.0504519708506326`], 
     Hue[0.999815961635582, 1, 1.0502058879224458`], 
     Hue[0.9999163175632639, 1, 1.0500937072594148`], 
     Hue[0.9999619446078685, 1, 1.0500426328488401`], 
     Hue[0.9999826929301512, 1, 1.050019392675614], 
     Hue[0.9999921287722886, 1, 1.0500088205524207`], 
     Hue[0.9999964201347746, 1, 1.0500040117861733`], 
     Hue[0.9999983718542729, 1, 1.0500018246201472`], 
     Hue[0.9999992595069935, 1, 1.0500008298580925`], 
     Hue[0.9999996632177884, 1, 1.0500003774276303`], 
     Hue[0.9999998468286454, 1, 1.0500001716575305`], 
     Hue[0.9999999303363758, 1, 1.0500000780713554`], 
     Hue[0.9999999683163926, 1, 1.0500000355075276`], 
     Hue[0.9999999855900259, 1, 1.0500000161491283`], 
     Hue[0.999999993446221, 1, 1.0500000073447617`], 
     Hue[0.9999999970192854, 1, 1.0500000033404604`], 
     Hue[0.9999999986443456, 1, 1.0500000015192699`], 
     Hue[0.9999999993834369, 1, 1.0500000006909769`], 
     Hue[0.9999999997195819, 1, 1.0500000003142622`], 
     Hue[0.9999999998724635, 1, 1.0500000001429293`], 
     Hue[0.9999999999419953, 1, 1.0500000000650054`], 
     Hue[0.999999999973619, 1, 1.050000000029565], 
     Hue[0.9999999999880017, 1, 1.0500000000134464`], 
     Hue[0.999999999994543, 1, 1.0500000000061156`], 
     Hue[0.9999999999975181, 1, 1.0500000000027814`], 
     Hue[0.9999999999988712, 1, 1.050000000001265], 
     Hue[0.9999999999994866, 1, 1.0500000000005754`], 
     Hue[0.9999999999997665, 1, 1.0500000000002616`], 
     Hue[0.9999999999998939, 1, 1.050000000000119], 
     Hue[0.9999999999999517, 1, 1.0500000000000542`], 
     Hue[0.999999999999978, 1, 1.0500000000000247`], 
     Hue[0.99999999999999, 1, 1.0500000000000111`], 
     Hue[0.9999999999999954, 1, 1.0500000000000052`], 
     Hue[0.9999999999999979, 1, 1.0500000000000023`], 
     Hue[0.9999999999999991, 1, 1.0500000000000012`], 
     Hue[0.9999999999999996, 1, 1.0500000000000005`], 
     Hue[0.9999999999999998, 1, 1.0500000000000003`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.8182246161665059, 1, -17.474999625757572`], 
     Hue[0.8182246161665059, 1, -17.100757209075603`], 
     Hue[0.8182246161665059, 1, -16.726514792393633`], 
     Hue[0.8182246161665059, 1, -16.35227237571166], 
     Hue[0.8182246161665059, 1, -15.97802995902969], 
     Hue[0.8182246161665059, 1, -15.603787542347721`], 
     Hue[0.818224616166506, 1, -15.229545125665748`], 
     Hue[0.8182246161665063, 1, -14.855302708983777`], 
     Hue[0.8182246161665068, 1, -14.481060292301807`], 
     Hue[0.8182246161665079, 1, -14.10681787561984], 
     Hue[0.8182246161665103, 1, -13.732575458937871`], 
     Hue[0.8182246161665155, 1, -13.358333042255905`], 
     Hue[0.8182246161665272, 1, -12.984090625573952`], 
     Hue[0.8182246161665527, 1, -12.609848208892016`], 
     Hue[0.818224616166609, 1, -12.23560579221012], 
     Hue[0.8182246161667327, 1, -11.861363375528319`], 
     Hue[0.8182246161670046, 1, -11.487120958846718`], 
     Hue[0.8182246161676024, 1, -11.112878542165562`], 
     Hue[0.8182246161689171, 1, -10.738636125485385`], 
     Hue[0.8182246161718074, 1, -10.364393708807356`], 
     Hue[0.8182246161781626, 1, -9.990151292134053], 
     Hue[0.8182246161921358, 1, -9.615908875471138], 
     Hue[0.818224616222859, 1, -9.241666458831075], 
     Hue[0.8182246162904112, 1, -8.867424042241241], 
     Hue[0.8182246164389401, 1, -8.493181625761856], 
     Hue[0.8182246167655145, 1, -8.118939209525317], 
     Hue[0.8182246174835628, 1, -7.7446967938227305`], 
     Hue[0.818224619062355, 1, -7.370454379294155], 
     Hue[0.8182246225336889, 1, -6.996211967346917], 
     Hue[0.8182246301662057, 1, -6.621969561075329], 
     Hue[0.8182246469480292, 1, -6.247727167282959], 
     Hue[0.8182246838466796, 1, -5.873484800928998], 
     Hue[0.8182247649767287, 1, -5.499242494904678], 
     Hue[0.8182249433594637, 1, -5.125000321529066], 
     Hue[0.8182253355738411, 1, -4.750758439813131], 
     Hue[0.8182261979432619, 1, -4.376517199383707], 
     Hue[0.8182280940435802, 1, -4.002277368999323], 
     Hue[0.8182322629788326, 1, -3.628040639068467], 
     Hue[0.8182414289802712, 1, -3.2538107269090224`], 
     Hue[0.8182615808223073, 1, -2.879595808646222], 
     Hue[0.8183058810252964, 1, -2.505413874667524], 
     Hue[0.8184032454179166, 1, -2.131304545216417], 
     Hue[0.8186171312347176, 1, -1.757355244210373], 
     Hue[0.819086478694064, 1, -1.3837596803401426`], 
     Hue[0.8201139415027929, 1, -1.0109508464558183`], 
     Hue[0.822351154580103, 1, -0.6399138394612749], 
     Hue[0.8271632462715057, 1, -0.27296222229663236`], 
     Hue[0.8372203352163634, 1, 0.08422909597256767], 
     Hue[0.8568281011189045, 1, 0.41752692656710044`], 
     Hue[0.8893306617366802, 1, 0.6964291717300464], 
     Hue[0.9288939544298243, 1, 0.8835503800710338], 
     Hue[0.9613965150476004, 1, 0.9788905515900619], 
     Hue[0.9810042809501419, 1, 1.0198351376775014`], 
     Hue[0.9910613698949998, 1, 1.0368862360902735`], 
     Hue[0.9958734615864027, 1, 1.0441770356076023`], 
     Hue[0.9981106746637128, 1, 1.04738244529503], 
     Hue[0.9991381374724417, 1, 1.0488160280926775`], 
     Hue[0.9996074849317883, 1, 1.0494628809044177`], 
     Hue[0.9998213707485892, 1, 1.0497559965803447`], 
     Hue[0.9999187351412094, 1, 1.0498890838112098`], 
     Hue[0.9999630353441985, 1, 1.0499495665144822`], 
     Hue[0.9999831871862347, 1, 1.0499770649336535`], 
     Hue[0.9999923531876732, 1, 1.0499895694561796`], 
     Hue[0.9999965221229257, 1, 1.0499952562072943`], 
     Hue[0.999998418223244, 1, 1.0499978425048824`], 
     Hue[0.9999992805926646, 1, 1.049999018757429], 
     Hue[0.9999996728070422, 1, 1.0499995537234652`], 
     Hue[0.9999998511897771, 1, 1.0499997970298243`], 
     Hue[0.9999999323198262, 1, 1.0499999076874744`], 
     Hue[0.9999999692184767, 1, 1.0499999580154848`], 
     Hue[0.9999999860003002, 1, 1.0499999809050864`], 
     Hue[0.999999993632817, 1, 1.049999991315471], 
     Hue[0.9999999971041509, 1, 1.0499999960502022`], 
     Hue[0.9999999986829431, 1, 1.0499999982035984`], 
     Hue[0.9999999994009913, 1, 1.0499999991829811`], 
     Hue[0.9999999997275657, 1, 1.0499999996284128`], 
     Hue[0.9999999998760946, 1, 1.049999999830999], 
     Hue[0.9999999999436467, 1, 1.0499999999231369`], 
     Hue[0.9999999999743701, 1, 1.049999999965042], 
     Hue[0.9999999999883433, 1, 1.049999999984101], 
     Hue[0.9999999999946985, 1, 1.049999999992769], 
     Hue[0.9999999999975888, 1, 1.0499999999967113`], 
     Hue[0.9999999999989033, 1, 1.0499999999985044`], 
     Hue[0.9999999999995013, 1, 1.0499999999993197`], 
     Hue[0.9999999999997732, 1, 1.0499999999996907`], 
     Hue[0.9999999999998969, 1, 1.0499999999998593`], 
     Hue[0.999999999999953, 1, 1.049999999999936], 
     Hue[0.9999999999999787, 1, 1.049999999999971], 
     Hue[0.9999999999999903, 1, 1.0499999999999867`], 
     Hue[0.9999999999999956, 1, 1.049999999999994], 
     Hue[0.999999999999998, 1, 1.0499999999999974`], 
     Hue[0.9999999999999991, 1, 1.0499999999999987`], 
     Hue[0.9999999999999996, 1, 1.0499999999999996`], 
     Hue[0.9999999999999998, 1, 1.0499999999999998`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.9436194172814373, 1, -17.474999625757572`], 
     Hue[0.9436194172814373, 1, -17.100757209075603`], 
     Hue[0.9436194172814373, 1, -16.726514792393633`], 
     Hue[0.9436194172814373, 1, -16.35227237571166], 
     Hue[0.9436194172814373, 1, -15.97802995902969], 
     Hue[0.9436194172814373, 1, -15.603787542347721`], 
     Hue[0.9436194172814374, 1, -15.229545125665748`], 
     Hue[0.9436194172814375, 1, -14.855302708983777`], 
     Hue[0.9436194172814376, 1, -14.48106029230181], 
     Hue[0.943619417281438, 1, -14.106817875619843`], 
     Hue[0.9436194172814389, 1, -13.732575458937879`], 
     Hue[0.9436194172814409, 1, -13.358333042255923`], 
     Hue[0.9436194172814454, 1, -12.98409062557399], 
     Hue[0.9436194172814552, 1, -12.609848208892096`], 
     Hue[0.9436194172814767, 1, -12.235605792210297`], 
     Hue[0.9436194172815238, 1, -11.861363375528708`], 
     Hue[0.9436194172816275, 1, -11.487120958847573`], 
     Hue[0.9436194172818555, 1, -11.112878542167442`], 
     Hue[0.9436194172823569, 1, -10.738636125489517`], 
     Hue[0.9436194172834593, 1, -10.364393708816442`], 
     Hue[0.943619417285883, 1, -9.990151292154028], 
     Hue[0.9436194172912125, 1, -9.615908875515062], 
     Hue[0.9436194173029302, 1, -9.241666458927648], 
     Hue[0.9436194173286943, 1, -8.867424042453578], 
     Hue[0.9436194173853424, 1, -8.49318162622873], 
     Hue[0.9436194175098963, 1, -8.118939210551845], 
     Hue[0.9436194177837566, 1, -7.744696796079784], 
     Hue[0.9436194183859004, 1, -7.3704543842568], 
     Hue[0.9436194197098506, 1, -6.996211978258423], 
     Hue[0.9436194226208561, 1, -6.621969585066757], 
     Hue[0.9436194290213628, 1, -6.247727220033564], 
     Hue[0.9436194430943277, 1, -5.873484916913162], 
     Hue[0.9436194740369188, 1, -5.49924274992205], 
     Hue[0.9436195420711294, 1, -5.125000882241833], 
     Hue[0.9436196916592646, 1, -4.750759672663177], 
     Hue[0.9436200205601336, 1, -4.376519910063116], 
     Hue[0.9436207437105854, 1, -4.00228332893894], 
     Hue[0.9436223336588695, 1, -3.6280537428405975`], 
     Hue[0.943625829219811, 1, -3.2538395360633316`], 
     Hue[0.9436335135458425, 1, -2.879659140188462], 
     Hue[0.9436504022303329, 1, -2.5055530657794716`], 
     Hue[0.9436875017758373, 1, -2.1316103098283197`], 
     Hue[0.943768909223935, 1, -1.7580261918460118`], 
     Hue[0.9439471113488958, 1, -1.3852284280750207`], 
     Hue[0.9443351471006252, 1, -1.0141491027636163`], 
     Hue[0.9451704655277356, 1, -0.646797848139192], 
     Hue[0.9469249544888716, 1, -0.2874071728898895], 
     Hue[0.9504257678267101, 1, 0.0555542921983353], 
     Hue[0.9567401729870842, 1, 0.36692208809792215`], 
     Hue[0.9662719657707481, 1, 0.6252419894348795], 
     Hue[0.9773474515106887, 1, 0.8123631977758663], 
     Hue[0.9868792442943528, 1, 0.9282857131208826], 
     Hue[0.9931936494547271, 1, 0.9911603339032686], 
     Hue[0.9966944627925656, 1, 1.0224412854970157`], 
     Hue[0.9984489517537016, 1, 1.037293026929685], 
     Hue[0.9992842701808121, 1, 1.0441841889872323`], 
     Hue[0.9996723059325415, 1, 1.047347280357799], 
     Hue[0.9998505080575023, 1, 1.0487919332687796`], 
     Hue[0.9999319155056001, 1, 1.0494502319684424`], 
     Hue[0.9999690150511044, 1, 1.0497498926992619`], 
     Hue[0.9999859037355948, 1, 1.0498862349722422`], 
     Hue[0.9999935880616264, 1, 1.0499482557793445`], 
     Hue[0.9999970836225678, 1, 1.0499764656840487`], 
     Hue[0.9999986735708519, 1, 1.0499892962676771`], 
     Hue[0.9999993967213037, 1, 1.049995131825473], 
     Hue[0.9999997256221727, 1, 1.0499977859073826`], 
     Hue[0.9999998752103079, 1, 1.0499989930106972`], 
     Hue[0.9999999432445186, 1, 1.0499995420124517`], 
     Hue[0.9999999741871096, 1, 1.0499997917033113`], 
     Hue[0.9999999882600745, 1, 1.0499999052648803`], 
     Hue[0.9999999946605812, 1, 1.049999956913658], 
     Hue[0.9999999975715868, 1, 1.049999980403964], 
     Hue[0.9999999988955369, 1, 1.0499999910875557`], 
     Hue[0.9999999994976808, 1, 1.0499999959465445`], 
     Hue[0.999999999771541, 1, 1.0499999981564538`], 
     Hue[0.9999999998960949, 1, 1.0499999991615396`], 
     Hue[0.999999999952743, 1, 1.049999999618661], 
     Hue[0.9999999999785072, 1, 1.049999999826564], 
     Hue[0.9999999999902248, 1, 1.0499999999211198`], 
     Hue[0.9999999999955542, 1, 1.0499999999641247`], 
     Hue[0.999999999997978, 1, 1.0499999999836835`], 
     Hue[0.9999999999990804, 1, 1.049999999992579], 
     Hue[0.9999999999995818, 1, 1.049999999996625], 
     Hue[0.9999999999998098, 1, 1.049999999998465], 
     Hue[0.9999999999999135, 1, 1.049999999999302], 
     Hue[0.9999999999999607, 1, 1.0499999999996825`], 
     Hue[0.9999999999999821, 1, 1.0499999999998557`], 
     Hue[0.9999999999999919, 1, 1.0499999999999343`], 
     Hue[0.9999999999999963, 1, 1.0499999999999703`], 
     Hue[0.9999999999999983, 1, 1.0499999999999865`], 
     Hue[0.9999999999999992, 1, 1.0499999999999938`], 
     Hue[0.9999999999999997, 1, 1.0499999999999972`], 
     Hue[0.9999999999999999, 1, 1.0499999999999987`], 
     Hue[0.9999999999999999, 1, 1.0499999999999994`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.0690142183963691`, 1, -17.474999625757572`], 
     Hue[1.0690142183963691`, 1, -17.100757209075603`], 
     Hue[1.0690142183963691`, 1, -16.726514792393633`], 
     Hue[1.0690142183963691`, 1, -16.35227237571166], 
     Hue[1.0690142183963691`, 1, -15.97802995902969], 
     Hue[1.0690142183963691`, 1, -15.603787542347721`], 
     Hue[1.069014218396369, 1, -15.229545125665748`], 
     Hue[1.069014218396369, 1, -14.855302708983777`], 
     Hue[1.0690142183963687`, 1, -14.48106029230181], 
     Hue[1.069014218396368, 1, -14.106817875619843`], 
     Hue[1.069014218396367, 1, -13.732575458937879`], 
     Hue[1.0690142183963645`, 1, -13.358333042255921`], 
     Hue[1.0690142183963591`, 1, -12.984090625573987`], 
     Hue[1.0690142183963474`, 1, -12.60984820889209], 
     Hue[1.0690142183963214`, 1, -12.235605792210286`], 
     Hue[1.0690142183962643`, 1, -11.861363375528684`], 
     Hue[1.0690142183961386`, 1, -11.487120958847523`], 
     Hue[1.0690142183958624`, 1, -11.112878542167332`], 
     Hue[1.0690142183952551`, 1, -10.738636125489277`], 
     Hue[1.06901421839392, 1, -10.364393708815912`], 
     Hue[1.069014218390984, 1, -9.990151292152865], 
     Hue[1.0690142183845288`, 1, -9.6159088755125], 
     Hue[1.0690142183703357`, 1, -9.241666458922015], 
     Hue[1.0690142183391291`, 1, -8.867424042441195], 
     Hue[1.0690142182705138`, 1, -8.4931816262015], 
     Hue[1.0690142181196478`, 1, -8.118939210491972], 
     Hue[1.0690142177879345`, 1, -7.744696795948141], 
     Hue[1.0690142170585872`, 1, -7.3704543839673535`], 
     Hue[1.0690142154549516`, 1, -6.996211977622008], 
     Hue[1.0690142119289938`, 1, -6.621969583667455], 
     Hue[1.0690142041763748`, 1, -6.2477272169568785`], 
     Hue[1.0690141871304844`, 1, -5.873484910148372], 
     Hue[1.0690141496512444`, 1, -5.499242735048138], 
     Hue[1.0690140672447437`, 1, -5.125000849538226], 
     Hue[1.0690138860559546`, 1, -4.750759600757218], 
     Hue[1.0690134876743198`, 1, -4.3765197519632455`], 
     Hue[1.0690126117568208`, 1, -4.002282981328814], 
     Hue[1.069010685926175, 1, -3.628052978581281], 
     Hue[1.069006451903384, 1, -3.2538378558617183`], 
     Hue[1.0689971441520005`, 1, -2.8796554468319657`], 
     Hue[1.0689766872107163`, 1, -2.50554494968003], 
     Hue[1.0689317479021934`, 1, -2.131592486874764], 
     Hue[1.0688331312498316`, 1, -1.7579871107491736`], 
     Hue[1.0686172271807286`, 1, -1.385143012158559], 
     Hue[1.068146950338368, 1, -1.013963742122048], 
     Hue[1.0671339287737185`, 1, -0.6464017705127973], 
     Hue[1.0650033398477148`, 1, -0.28658836874713733`], 
     Hue[1.0607413364936853`, 1, 0.057134982667234824`], 
     Hue[1.0530232039801162`, 1, 0.3695953569574787], 
     Hue[1.0413204050669875`, 1, 0.6288568887093919], 
     Hue[1.027693813329382, 1, 0.8159780970503789], 
     Hue[1.0159910144162534`, 1, 0.9309589819804392], 
     Hue[1.008272881902684, 1, 0.9927410243721682], 
     Hue[1.0040108785486543`, 1, 1.0232600896397681`], 
     Hue[1.0018802896226504`, 1, 1.0376891045560799`], 
     Hue[1.000867268058001, 1, 1.0443695496288008`], 
     Hue[1.0003969912156403`, 1, 1.0474326962742604`], 
     Hue[1.0001810871465373`, 1, 1.0488310143656179`], 
     Hue[1.0000824704941755`, 1, 1.0494680549219988`], 
     Hue[1.0000375311856529`, 1, 1.0497580087987028`], 
     Hue[1.0000170742443684`, 1, 1.0498899283287384`], 
     Hue[1.000007766492985, 1, 1.0499499359809576`], 
     Hue[1.0000035324701941`, 1, 1.0499772299433654`], 
     Hue[1.000001606639548, 1, 1.0499896438778038`], 
     Hue[1.0000007307220493`, 1, 1.0499952899253437`], 
     Hue[1.0000003323404143`, 1, 1.049997857813342], 
     Hue[1.0000001511516254`, 1, 1.0499990257143041`], 
     Hue[1.0000000687451247`, 1, 1.0499995568863647`], 
     Hue[1.0000000312658848`, 1, 1.0499997984681007`], 
     Hue[1.0000000142199943`, 1, 1.0499999083415656`], 
     Hue[1.0000000064673753`, 1, 1.0499999583129611`], 
     Hue[1.0000000029414176`, 1, 1.0499999810403788`], 
     Hue[1.0000000013377819`, 1, 1.0499999913770028`], 
     Hue[1.0000000006084346`, 1, 1.0499999960781874`], 
     Hue[1.0000000002767213`, 1, 1.0499999982163262`], 
     Hue[1.000000000125855, 1, 1.04999999918877], 
     Hue[1.00000000005724, 1, 1.0499999996310456`], 
     Hue[1.0000000000260332`, 1, 1.0499999998321965`], 
     Hue[1.00000000001184, 1, 1.0499999999236815`], 
     Hue[1.000000000005385, 1, 1.0499999999652896`], 
     Hue[1.0000000000024492`, 1, 1.0499999999842136`], 
     Hue[1.000000000001114, 1, 1.0499999999928202`], 
     Hue[1.0000000000005067`, 1, 1.0499999999967347`], 
     Hue[1.0000000000002305`, 1, 1.049999999998515], 
     Hue[1.0000000000001048`, 1, 1.0499999999993246`], 
     Hue[1.0000000000000477`, 1, 1.0499999999996927`], 
     Hue[1.0000000000000218`, 1, 1.0499999999998604`], 
     Hue[1.0000000000000098`, 1, 1.0499999999999365`], 
     Hue[1.0000000000000044`, 1, 1.0499999999999712`], 
     Hue[1.000000000000002, 1, 1.049999999999987], 
     Hue[1.0000000000000009`, 1, 1.049999999999994], 
     Hue[1.0000000000000004`, 1, 1.0499999999999974`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999987`], 
     Hue[1., 1, 1.0499999999999996`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.1944090195113004`, 1, -17.474999625757572`], 
     Hue[1.1944090195113004`, 1, -17.100757209075603`], 
     Hue[1.1944090195113004`, 1, -16.726514792393633`], 
     Hue[1.1944090195113004`, 1, -16.35227237571166], 
     Hue[1.1944090195113004`, 1, -15.97802995902969], 
     Hue[1.1944090195113004`, 1, -15.603787542347721`], 
     Hue[1.1944090195113002`, 1, -15.229545125665748`], 
     Hue[1.1944090195113, 1, -14.855302708983777`], 
     Hue[1.1944090195112995`, 1, -14.481060292301807`], 
     Hue[1.1944090195112984`, 1, -14.106817875619837`], 
     Hue[1.194409019511296, 1, -13.73257545893787], 
     Hue[1.1944090195112904`, 1, -13.358333042255902`], 
     Hue[1.1944090195112784`, 1, -12.984090625573947`], 
     Hue[1.194409019511252, 1, -12.609848208892004`], 
     Hue[1.1944090195111938`, 1, -12.235605792210096`], 
     Hue[1.1944090195110662`, 1, -11.861363375528265`], 
     Hue[1.1944090195107853`, 1, -11.487120958846598`], 
     Hue[1.1944090195101675`, 1, -11.112878542165298`], 
     Hue[1.1944090195088095`, 1, -10.738636125484804`], 
     Hue[1.1944090195058235`, 1, -10.364393708806078`], 
     Hue[1.194409019499258, 1, -9.990151292131245], 
     Hue[1.1944090194848225`, 1, -9.615908875464964], 
     Hue[1.1944090194530825`, 1, -9.241666458817496], 
     Hue[1.194409019383295, 1, -8.867424042211386], 
     Hue[1.1944090192298513`, 1, -8.493181625696211], 
     Hue[1.1944090188924705`, 1, -8.118939209380985], 
     Hue[1.194409018150662, 1, -7.744696793505379], 
     Hue[1.194409016519627, 1, -7.370454378596384], 
     Hue[1.1944090129334262`, 1, -6.9962119658127095`], 
     Hue[1.1944090050483473`, 1, -6.621969557702026], 
     Hue[1.1944089877112096`, 1, -6.247727159865989], 
     Hue[1.194408949591573, 1, -5.8734847846211045`], 
     Hue[1.1944088657769045`, 1, -5.499242459048079], 
     Hue[1.194408681491403, 1, -5.12500024269025], 
     Hue[1.1944082762983543`, 1, -4.750758266468418], 
     Hue[1.1944073853919086`, 1, -4.376516818247645], 
     Hue[1.1944054265442055`, 1, -4.002276530993313], 
     Hue[1.1944011196337063`, 1, -3.6280387965618504`], 
     Hue[1.1943916502098675`, 1, -3.2538066759335607`], 
     Hue[1.194370830971249, 1, -2.8795869025953653`], 
     Hue[1.1943250621207535`, 1, -2.5053942972351955`], 
     Hue[1.1942244626622718`, 1, -2.1312615217690523`], 
     Hue[1.194003435335637, 1, -1.7572607538141958`], 
     Hue[1.1935182489162184`, 1, -1.3835524376068304`], 
     Hue[1.1924553098236332`, 1, -1.010497683869685], 
     Hue[1.190137057167739, 1, -0.6389297168168557], 
     Hue[1.1851332518591924`, 1, -0.27085887584298063`], 
     Hue[1.174601140732168, 1, 0.08855352326135024], 
     Hue[1.1538026317308223`, 1, 0.4255924776389348], 
     Hue[1.1187380711510646`, 1, 0.7083968037503994], 
     Hue[1.0756709483602374`, 1, 0.8955180120913869], 
     Hue[1.0406063877804792`, 1, 0.9869561026618964], 
     Hue[1.0198078787791331`, 1, 1.0241595649662842`], 
     Hue[1.0092757676521082`, 1, 1.0389895825439253`], 
     Hue[1.0042719623435614`, 1, 1.0451611582520215`], 
     Hue[1.0019537096876674`, 1, 1.0478356078811635`], 
     Hue[1.0008907705950822`, 1, 1.0490232708259892`], 
     Hue[1.0004055841756636`, 1, 1.0495573713005955`], 
     Hue[1.0001845568490286`, 1, 1.0497990200277103`], 
     Hue[1.000083957390547, 1, 1.0499086612435382`], 
     Hue[1.0000381885400513`, 1, 1.0499584725653386`], 
     Hue[1.000017369301433, 1, 1.0499811159091155`], 
     Hue[1.000007899877594, 1, 1.0499914119627962`], 
     Hue[1.000003592967095, 1, 1.0499960942133046`], 
     Hue[1.0000016341193918`, 1, 1.049998223640944], 
     Hue[1.0000007432129463`, 1, 1.0499991921021419`], 
     Hue[1.0000003380198976`, 1, 1.0499996325622805`], 
     Hue[1.0000001537343959`, 1, 1.049999832886423], 
     Hue[1.0000000699197273`, 1, 1.0499999239953681`], 
     Hue[1.0000000318000908`, 1, 1.0499999654324554`], 
     Hue[1.000000014462953, 1, 1.049999984278388], 
     Hue[1.0000000065778745`, 1, 1.0499999928496773`], 
     Hue[1.0000000029916734`, 1, 1.0499999967479723`], 
     Hue[1.0000000013606385`, 1, 1.04999999852095], 
     Hue[1.00000000061883, 1, 1.0499999993273155`], 
     Hue[1.000000000281449, 1, 1.0499999996940574`], 
     Hue[1.0000000001280054`, 1, 1.0499999998608547`], 
     Hue[1.0000000000582179`, 1, 1.0499999999367156`], 
     Hue[1.000000000026478, 1, 1.0499999999712177`], 
     Hue[1.0000000000120424`, 1, 1.0499999999869096`], 
     Hue[1.000000000005477, 1, 1.0499999999940464`], 
     Hue[1.000000000002491, 1, 1.0499999999972922`], 
     Hue[1.0000000000011329`, 1, 1.0499999999987686`], 
     Hue[1.0000000000005154`, 1, 1.04999999999944], 
     Hue[1.0000000000002343`, 1, 1.0499999999997454`], 
     Hue[1.0000000000001066`, 1, 1.0499999999998841`], 
     Hue[1.0000000000000484`, 1, 1.0499999999999472`], 
     Hue[1.000000000000022, 1, 1.049999999999976], 
     Hue[1.00000000000001, 1, 1.0499999999999892`], 
     Hue[1.0000000000000047`, 1, 1.0499999999999952`], 
     Hue[1.000000000000002, 1, 1.0499999999999978`], 
     Hue[1.0000000000000009`, 1, 1.049999999999999], 
     Hue[1.0000000000000004`, 1, 1.0499999999999996`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.319803820626232, 1, -17.474999625757572`], 
     Hue[1.319803820626232, 1, -17.100757209075603`], 
     Hue[1.319803820626232, 1, -16.726514792393633`], 
     Hue[1.319803820626232, 1, -16.35227237571166], 
     Hue[1.319803820626232, 1, -15.97802995902969], 
     Hue[1.319803820626232, 1, -15.603787542347721`], 
     Hue[1.3198038206262317`, 1, -15.229545125665748`], 
     Hue[1.3198038206262315`, 1, -14.855302708983777`], 
     Hue[1.319803820626231, 1, -14.481060292301807`], 
     Hue[1.31980382062623, 1, -14.106817875619832`], 
     Hue[1.3198038206262277`, 1, -13.732575458937857`], 
     Hue[1.3198038206262224`, 1, -13.358333042255879`], 
     Hue[1.3198038206262106`, 1, -12.984090625573891`], 
     Hue[1.3198038206261853`, 1, -12.609848208891885`], 
     Hue[1.3198038206261293`, 1, -12.235605792209837`], 
     Hue[1.319803820626006, 1, -11.861363375527693`], 
     Hue[1.3198038206257354`, 1, -11.487120958845344`], 
     Hue[1.3198038206251403`, 1, -11.112878542162537`], 
     Hue[1.3198038206238318`, 1, -10.738636125478736`], 
     Hue[1.3198038206209546`, 1, -10.364393708792736`], 
     Hue[1.3198038206146285`, 1, -9.99015129210191], 
     Hue[1.3198038206007194`, 1, -9.615908875400466], 
     Hue[1.319803820570137, 1, -9.241666458675684], 
     Hue[1.3198038205028944`, 1, -8.867424041899579], 
     Hue[1.3198038203550464`, 1, -8.493181625010632], 
     Hue[1.319803820029969, 1, -8.11893920787358], 
     Hue[1.3198038193152122`, 1, -7.744696790191013], 
     Hue[1.3198038177436566`, 1, -7.370454371308999], 
     Hue[1.3198038142882347`, 1, -6.996211949789733], 
     Hue[1.3198038066907027`, 1, -6.621969522471868], 
     Hue[1.3198037899857995`, 1, -6.247727082404472], 
     Hue[1.319803753256264, 1, -5.873484614304336], 
     Hue[1.3198036724979976`, 1, -5.499242084567902], 
     Hue[1.319803494932443, 1, -5.124999419310311], 
     Hue[1.3198031045135263`, 1, -4.750756456079921], 
     Hue[1.3198022460855685`, 1, -4.376512837694765], 
     Hue[1.3198003586211593`, 1, -4.002267778832887], 
     Hue[1.319796208527467, 1, -3.628019552900615], 
     Hue[1.3197870832454823`, 1, -3.253764364146397], 
     Hue[1.3197670175116525`, 1, -2.8794938694425136`], 
     Hue[1.3197228900899662`, 1, -2.5051897375647094`], 
     Hue[1.3196258255996365`, 1, -2.130811726279288], 
     Hue[1.319412212440966, 1, -1.7562716600764847`], 
     Hue[1.3189415947419674`, 1, -1.3813771558018872`], 
     Hue[1.317902300198119, 1, -1.0057125339872701`], 
     Hue[1.3155953981583286`, 1, -0.6284004017487979], 
     Hue[1.310419662787548, 1, -0.24770115186584762`], 
     Hue[1.2985644786433752`, 1, 0.1391587186838359], 
     Hue[1.2706175281659036`, 1, 0.5318699180624397], 
     Hue[1.2071640561907713`, 1, 0.8926929220662418], 
     Hue[1.1126397644354638`, 1, 1.0798141304072315`], 
     Hue[1.04918629246033, 1, 1.0932335430854039`], 
     Hue[1.0212393419828574`, 1, 1.0747647603887713`], 
     Hue[1.0093841578386844`, 1, 1.0621473065210592`], 
     Hue[1.0042084224679033`, 1, 1.0556904733200796`], 
     Hue[1.0019015204281132`, 1, 1.0526207577635787`], 
     Hue[1.0008622258842648`, 1, 1.0511985526309329`], 
     Hue[1.0003916081852662`, 1, 1.0505464650383065`], 
     Hue[1.0001779950265957`, 1, 1.050248815517474], 
     Hue[1.0000809305362657`, 1, 1.0501132209140236`], 
     Hue[1.0000368031145794`, 1, 1.0500515057181903`], 
     Hue[1.0000167373807496`, 1, 1.050023427696279], 
     Hue[1.0000076120987649`, 1, 1.0500106556240312`], 
     Hue[1.0000034620050726`, 1, 1.05000484637373], 
     Hue[1.0000015745406634`, 1, 1.050002204193824], 
     Hue[1.0000007161127056`, 1, 1.0500010024906383`], 
     Hue[1.0000003256937888`, 1, 1.050000455942219], 
     Hue[1.0000001481282343`, 1, 1.0500002073666006`], 
     Hue[1.0000000673699678`, 1, 1.0500000943121377`], 
     Hue[1.0000000306404324`, 1, 1.0500000428939726`], 
     Hue[1.0000000139355292`, 1, 1.0500000195085462`], 
     Hue[1.0000000063379972`, 1, 1.0500000088726535`], 
     Hue[1.0000000028825753`, 1, 1.0500000040353585`], 
     Hue[1.0000000013110197`, 1, 1.0500000018353155`], 
     Hue[1.000000000596263, 1, 1.0500000008347172`], 
     Hue[1.0000000002711855`, 1, 1.0500000003796366`], 
     Hue[1.0000000001233376`, 1, 1.050000000172662], 
     Hue[1.000000000056095, 1, 1.0500000000785281`], 
     Hue[1.0000000000255125`, 1, 1.0500000000357153`], 
     Hue[1.0000000000116034`, 1, 1.0500000000162437`], 
     Hue[1.0000000000052773`, 1, 1.0500000000073877`], 
     Hue[1.0000000000024, 1, 1.05000000000336], 
     Hue[1.0000000000010916`, 1, 1.0500000000015282`], 
     Hue[1.0000000000004965`, 1, 1.050000000000695], 
     Hue[1.0000000000002258`, 1, 1.0500000000003162`], 
     Hue[1.0000000000001028`, 1, 1.0500000000001437`], 
     Hue[1.0000000000000466`, 1, 1.0500000000000653`], 
     Hue[1.0000000000000213`, 1, 1.0500000000000298`], 
     Hue[1.0000000000000098`, 1, 1.0500000000000136`], 
     Hue[1.0000000000000044`, 1, 1.0500000000000063`], 
     Hue[1.000000000000002, 1, 1.050000000000003], 
     Hue[1.0000000000000009`, 1, 1.0500000000000014`], 
     Hue[1.0000000000000004`, 1, 1.0500000000000007`], 
     Hue[1.0000000000000002`, 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.4451986217411636`, 1, -17.474999625757572`], 
     Hue[1.4451986217411636`, 1, -17.100757209075603`], 
     Hue[1.4451986217411636`, 1, -16.726514792393633`], 
     Hue[1.4451986217411636`, 1, -16.35227237571166], 
     Hue[1.4451986217411636`, 1, -15.97802995902969], 
     Hue[1.4451986217411636`, 1, -15.603787542347721`], 
     Hue[1.4451986217411636`, 1, -15.229545125665748`], 
     Hue[1.4451986217411634`, 1, -14.855302708983777`], 
     Hue[1.4451986217411634`, 1, -14.481060292301803`], 
     Hue[1.445198621741163, 1, -14.106817875619829`], 
     Hue[1.445198621741162, 1, -13.73257545893785], 
     Hue[1.44519862174116, 1, -13.358333042255863`], 
     Hue[1.4451986217411559`, 1, -12.984090625573858`], 
     Hue[1.445198621741146, 1, -12.609848208891806`], 
     Hue[1.4451986217411255`, 1, -12.235605792209661`], 
     Hue[1.4451986217410795`, 1, -11.86136337552731], 
     Hue[1.4451986217409787`, 1, -11.487120958844498`], 
     Hue[1.4451986217407566`, 1, -11.11287854216068], 
     Hue[1.4451986217402688`, 1, -10.738636125474649`], 
     Hue[1.445198621739196, 1, -10.36439370878375], 
     Hue[1.4451986217368373`, 1, -9.990151292082148], 
     Hue[1.4451986217316513`, 1, -9.615908875357016], 
     Hue[1.4451986217202486`, 1, -9.241666458580147], 
     Hue[1.4451986216951769`, 1, -8.86742404168952], 
     Hue[1.4451986216400512`, 1, -8.493181624548772], 
     Hue[1.4451986215188448`, 1, -8.118939206858078], 
     Hue[1.445198621252345, 1, -7.744696787958197], 
     Hue[1.4451986206663852`, 1, -7.3704543663996445`], 
     Hue[1.4451986193780184`, 1, -6.996211938995402], 
     Hue[1.445198616545251, 1, -6.621969498738074], 
     Hue[1.4451986103167667`, 1, -6.247727030220315], 
     Hue[1.445198596622022, 1, -5.873484499565556], 
     Hue[1.4451985665109879`, 1, -5.499241832288405], 
     Hue[1.4451985003049175`, 1, -5.124998864615517], 
     Hue[1.4451983547352723`, 1, -4.750755236452722], 
     Hue[1.4451980346646822`, 1, -4.376510156045113], 
     Hue[1.4451973309040587`, 1, -4.0022618825106235`], 
     Hue[1.4451957834652083`, 1, -3.6280065879848156`], 
     Hue[1.4451923807738125`, 1, -3.2537358553639137`], 
     Hue[1.445184897755916, 1, -2.879431174476287], 
     Hue[1.445168437737797, 1, -2.5050518307617784`], 
     Hue[1.4451322132474669`, 1, -2.1305082278690293`], 
     Hue[1.445052403655804, 1, -1.7556029992764046`], 
     Hue[1.444876138031737, 1, -1.3799004024484482`], 
     Hue[1.4444847365729905`, 1, -1.0024336582082125`], 
     Hue[1.4436051326157, 1, -0.6210343866385777], 
     Hue[1.4415741561971873`, 1, -0.23072162350859315`], 
     Hue[1.436579602742588, 1, 0.18056284055633076`], 
     Hue[1.4221928741503098`, 1, 0.6454818195698667], 
     Hue[1.3564806875849782`, 1, 1.2633937991662016`], 
     Hue[1.088717934156191, 1, 1.450515007507207], 
     Hue[1.0230057475908547`, 1, 1.2068454445928354`], 
     Hue[1.0086190189985762`, 1, 1.1161688822612676`], 
     Hue[1.0036244655439766`, 1, 1.079126834878314], 
     Hue[1.0015934891254639`, 1, 1.0630564884303002`], 
     Hue[1.0007138851681734`, 1, 1.055899633542636], 
     Hue[1.000322483709427, 1, 1.0526753059843714`], 
     Hue[1.0001462180853598`, 1, 1.0512151258383864`], 
     Hue[1.0000664084936968`, 1, 1.0505523139277329`], 
     Hue[1.0000301840033667`, 1, 1.0502511277169548`], 
     Hue[1.0000137239852473`, 1, 1.050114200684417], 
     Hue[1.000006240967351, 1, 1.0500519364787628`], 
     Hue[1.0000028382759554`, 1, 1.0500236205398312`], 
     Hue[1.0000012908371052`, 1, 1.050010742695994], 
     Hue[1.0000005870764814`, 1, 1.0500048858434756`], 
     Hue[1.0000002670058914`, 1, 1.0500022221178371`], 
     Hue[1.000000121436246, 1, 1.0500010106370135`], 
     Hue[1.000000055230176, 1, 1.0500004596460975`], 
     Hue[1.0000000251191417`, 1, 1.0500002090509157`], 
     Hue[1.000000011424397, 1, 1.050000095078129], 
     Hue[1.0000000051959126`, 1, 1.0500000432423415`], 
     Hue[1.0000000023631452`, 1, 1.0500000196669852`], 
     Hue[1.0000000010747785`, 1, 1.0500000089447123`], 
     Hue[1.0000000004888185`, 1, 1.0500000040681314`], 
     Hue[1.0000000002223188`, 1, 1.050000001850221], 
     Hue[1.0000000001011125`, 1, 1.0500000008414963`], 
     Hue[1.0000000000459868`, 1, 1.0500000003827197`], 
     Hue[1.0000000000209153`, 1, 1.0500000001740641`], 
     Hue[1.0000000000095124`, 1, 1.050000000079166], 
     Hue[1.0000000000043263`, 1, 1.0500000000360055`], 
     Hue[1.0000000000019678`, 1, 1.0500000000163756`], 
     Hue[1.0000000000008948`, 1, 1.0500000000074479`], 
     Hue[1.000000000000407, 1, 1.0500000000033873`], 
     Hue[1.0000000000001852`, 1, 1.0500000000015406`], 
     Hue[1.0000000000000842`, 1, 1.0500000000007006`], 
     Hue[1.0000000000000382`, 1, 1.0500000000003187`], 
     Hue[1.0000000000000173`, 1, 1.050000000000145], 
     Hue[1.000000000000008, 1, 1.050000000000066], 
     Hue[1.0000000000000036`, 1, 1.05000000000003], 
     Hue[1.0000000000000016`, 1, 1.0500000000000138`], 
     Hue[1.0000000000000007`, 1, 1.0500000000000063`], 
     Hue[1.0000000000000004`, 1, 1.050000000000003], 
     Hue[1.0000000000000002`, 1, 1.0500000000000014`], 
     Hue[1., 1, 1.0500000000000007`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.570593422856095, 1, -17.474999625757572`], 
     Hue[0.570593422856095, 1, -17.100757209075603`], 
     Hue[0.570593422856095, 1, -16.726514792393633`], 
     Hue[0.570593422856095, 1, -16.35227237571166], 
     Hue[0.5705934228560952, 1, -15.97802995902969], 
     Hue[0.5705934228560952, 1, -15.603787542347721`], 
     Hue[0.5705934228560952, 1, -15.229545125665748`], 
     Hue[0.5705934228560953, 1, -14.855302708983777`], 
     Hue[0.5705934228560955, 1, -14.481060292301803`], 
     Hue[0.570593422856096, 1, -14.106817875619829`], 
     Hue[0.5705934228560972, 1, -13.73257545893785], 
     Hue[0.5705934228560996, 1, -13.358333042255865`], 
     Hue[0.5705934228561051, 1, -12.98409062557386], 
     Hue[0.5705934228561172, 1, -12.609848208891814`], 
     Hue[0.5705934228561438, 1, -12.235605792209673`], 
     Hue[0.5705934228562022, 1, -11.861363375527338`], 
     Hue[0.5705934228563304, 1, -11.48712095884456], 
     Hue[0.5705934228566125, 1, -11.112878542160816`], 
     Hue[0.5705934228572327, 1, -10.73863612547495], 
     Hue[0.5705934228585966, 1, -10.364393708784412`], 
     Hue[0.5705934228615952, 1, -9.990151292083604], 
     Hue[0.5705934228681884, 1, -9.615908875360217], 
     Hue[0.5705934228826849, 1, -9.241666458587188], 
     Hue[0.5705934229145588, 1, -8.867424041705], 
     Hue[0.570593422984641, 1, -8.493181624582805], 
     Hue[0.5705934231387326, 1, -8.118939206932907], 
     Hue[0.570593423477538, 1, -7.744696788122726], 
     Hue[0.5705934242224789, 1, -7.3704543667613995`], 
     Hue[0.5705934258604011, 1, -6.996211939790803], 
     Hue[0.5705934294617453, 1, -6.621969500486944], 
     Hue[0.5705934373801211, 1, -6.2477270340656075`], 
     Hue[0.5705934547904777, 1, -5.87348450802031], 
     Hue[0.5705934930711352, 1, -5.4992418508781205`], 
     Hue[0.5705935772400046, 1, -5.1249989054893295`], 
     Hue[0.5705937623050691, 1, -4.750755326323545], 
     Hue[0.5705941692158963, 1, -4.376510353648731], 
     Hue[0.5705950639173115, 1, -4.002262316997626], 
     Hue[0.5705970311963464, 1, -3.6280075433540775`], 
     Hue[0.5706013570667744, 1, -3.253737956205949], 
     Hue[0.5706108702174866, 1, -2.8794357948420277`], 
     Hue[0.5706317954614365, 1, -2.505061995426888], 
     Hue[0.5706778451048258, 1, -2.1305306049824635`], 
     Hue[0.5707792930537468, 1, -1.7556523351520477`], 
     Hue[0.5710033077592471, 1, -1.3800095338334863`], 
     Hue[0.571500534348218, 1, -1.002676819556678], 
     Hue[0.572616925749732, 1, -0.6215850317890388], 
     Hue[0.5751889773163095, 1, -0.2320150745697125], 
     Hue[0.5814780022264894, 1, 0.17725297610508428`], 
     Hue[0.5992567593644462, 1, 0.6349818572667122], 
     Hue[0.6720329238765048, 1, 1.2052710957555401`], 
     Hue[0.8985604989795848, 1, 1.3923923040965414`], 
     Hue[0.9713366634916478, 1, 1.1963454822896802`], 
     Hue[0.9891154206296053, 1, 1.112859017810021], 
     Hue[0.9954044455397855, 1, 1.0778333838171945`], 
     Hue[0.997976497106363, 1, 1.0625058432798389`], 
     Hue[0.999092888507877, 1, 1.0556564721941708`], 
     Hue[0.9995901150968479, 1, 1.0525661745993333`], 
     Hue[0.9998141298023483, 1, 1.0511657899627436`], 
     Hue[0.9999155777512693, 1, 1.0505299368142993`], 
     Hue[0.9999616273946587, 1, 1.0502409630518452`], 
     Hue[0.9999825526386086, 1, 1.0501095803186768`], 
     Hue[0.9999920657893206, 1, 1.050049835636727], 
     Hue[0.9999963916597486, 1, 1.0500226651705693`], 
     Hue[0.9999983589387835, 1, 1.0500103082089918`], 
     Hue[0.9999992536401987, 1, 1.0500046882398575`], 
     Hue[0.999999660551026, 1, 1.0500021322470143`], 
     Hue[0.9999998456160906, 1, 1.0500009697632016`], 
     Hue[0.99999992978496, 1, 1.0500004410563817`], 
     Hue[0.9999999680656173, 1, 1.0500002005961633`], 
     Hue[0.9999999854759739, 1, 1.050000091232837], 
     Hue[0.9999999933943498, 1, 1.0500000414934705`], 
     Hue[0.9999999969956941, 1, 1.050000018871584], 
     Hue[0.9999999986336161, 1, 1.050000008582957], 
     Hue[0.999999999378557, 1, 1.0500000039036022`], 
     Hue[0.9999999997173624, 1, 1.0500000017753917`], 
     Hue[0.999999999871454, 1, 1.0500000008074633`], 
     Hue[0.9999999999415362, 1, 1.0500000003672412`], 
     Hue[0.9999999999734102, 1, 1.0500000001670244`], 
     Hue[0.9999999999879067, 1, 1.0500000000759642`], 
     Hue[0.9999999999944998, 1, 1.0500000000345493`], 
     Hue[0.9999999999974984, 1, 1.0500000000157133`], 
     Hue[0.9999999999988622, 1, 1.0500000000071466`], 
     Hue[0.9999999999994825, 1, 1.0500000000032503`], 
     Hue[0.9999999999997646, 1, 1.0500000000014784`], 
     Hue[0.999999999999893, 1, 1.0500000000006724`], 
     Hue[0.9999999999999514, 1, 1.0500000000003058`], 
     Hue[0.9999999999999779, 1, 1.0500000000001393`], 
     Hue[0.9999999999999899, 1, 1.0500000000000633`], 
     Hue[0.9999999999999954, 1, 1.050000000000029], 
     Hue[0.9999999999999979, 1, 1.0500000000000131`], 
     Hue[0.999999999999999, 1, 1.050000000000006], 
     Hue[0.9999999999999996, 1, 1.0500000000000027`], 
     Hue[0.9999999999999998, 1, 1.0500000000000014`], 
     Hue[0.9999999999999999, 1, 1.0500000000000007`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.6959882239710269, 1, -17.474999625757572`], 
     Hue[0.6959882239710269, 1, -17.100757209075603`], 
     Hue[0.6959882239710269, 1, -16.726514792393633`], 
     Hue[0.6959882239710269, 1, -16.35227237571166], 
     Hue[0.6959882239710269, 1, -15.97802995902969], 
     Hue[0.6959882239710269, 1, -15.603787542347721`], 
     Hue[0.695988223971027, 1, -15.229545125665748`], 
     Hue[0.6959882239710272, 1, -14.855302708983777`], 
     Hue[0.6959882239710278, 1, -14.481060292301807`], 
     Hue[0.6959882239710289, 1, -14.106817875619834`], 
     Hue[0.6959882239710313, 1, -13.732575458937859`], 
     Hue[0.6959882239710369, 1, -13.358333042255882`], 
     Hue[0.6959882239710489, 1, -12.984090625573899`], 
     Hue[0.6959882239710755, 1, -12.6098482088919], 
     Hue[0.6959882239711338, 1, -12.235605792209867`], 
     Hue[0.695988223971262, 1, -11.86136337552776], 
     Hue[0.6959882239715439, 1, -11.487120958845493`], 
     Hue[0.6959882239721638, 1, -11.112878542162868`], 
     Hue[0.6959882239735267, 1, -10.738636125479463`], 
     Hue[0.6959882239765234, 1, -10.364393708794333`], 
     Hue[0.6959882239831121, 1, -9.990151292105422], 
     Hue[0.6959882239975992, 1, -9.615908875408186], 
     Hue[0.6959882240294524, 1, -9.241666458692654], 
     Hue[0.6959882240994886, 1, -8.867424041936893], 
     Hue[0.6959882242534793, 1, -8.493181625092676], 
     Hue[0.6959882245920628, 1, -8.118939208053973], 
     Hue[0.6959882253365156, 1, -7.744696790587644], 
     Hue[0.6959882269733646, 1, -7.370454372181082], 
     Hue[0.6959882305723495, 1, -6.996211951707209], 
     Hue[0.6959882384855367, 1, -6.621969526687875], 
     Hue[0.6959882558844795, 1, -6.247727091674318], 
     Hue[0.6959882941400182, 1, -5.873484634686206], 
     Hue[0.6959883782535448, 1, -5.499242129382099], 
     Hue[0.6959885631963767, 1, -5.124999517844613], 
     Hue[0.6959889698357962, 1, -4.750756672730442], 
     Hue[0.6959898639276392, 1, -4.376513314052367], 
     Hue[0.6959918298044089, 1, -4.002268826223828], 
     Hue[0.6959961522919578, 1, -3.628021855878096], 
     Hue[0.696005656555514, 1, -3.253769428009134], 
     Hue[0.6960265552496097, 1, -2.879505004670688], 
     Hue[0.6960725125907566, 1, -2.505214226571244], 
     Hue[0.6961735931527001, 1, -2.1308655983481035`], 
     Hue[0.6963960005612562, 1, -1.756390242459272], 
     Hue[0.6968857791896714, 1, -1.381638524407675], 
     Hue[0.6979663434647526, 1, -1.00629027890145], 
     Hue[0.70035969333705, 1, -0.6296853151303119], 
     Hue[0.7057033180454415, 1, -0.25059435980413736`], 
     Hue[0.7178057834079163, 1, 0.13250334954645526`], 
     Hue[0.7455843393456597, 1, 0.5163479815725143], 
     Hue[0.8053011637798616, 1, 0.861502723419088], 
     Hue[0.8906870601911624, 1, 1.0486239317600772`], 
     Hue[0.9504038846253656, 1, 1.077711606595478], 
     Hue[0.9781824405631099, 1, 1.0681093912513904`], 
     Hue[0.9902849059255849, 1, 1.0592540985827692`], 
     Hue[0.9956285306339767, 1, 1.0544055599385658`], 
     Hue[0.9980218805062742, 1, 1.0520430128493987`], 
     Hue[0.9991024447813553, 1, 1.0509371840251447`], 
     Hue[0.9995922234097706, 1, 1.0504278826555191`], 
     Hue[0.9998146308183268, 1, 1.0501949434486588`], 
     Hue[0.9999157113802701, 1, 1.050088731907489], 
     Hue[0.9999616687214172, 1, 1.050040370490016], 
     Hue[0.9999825674155127, 1, 1.050018363833542], 
     Hue[0.999992071679069, 1, 1.0500083526465513`], 
     Hue[0.999996394166618, 1, 1.050003798982789], 
     Hue[0.9999983600433876, 1, 1.0500017278362215`], 
     Hue[0.9999992541352306, 1, 1.0500007858401175`], 
     Hue[0.9999996607746501, 1, 1.0500003574079173`], 
     Hue[0.9999998457174821, 1, 1.050000162552402], 
     Hue[0.9999999298310086, 1, 1.0500000739302668`], 
     Hue[0.9999999680865472, 1, 1.0500000336241258`], 
     Hue[0.9999999854854902, 1, 1.050000015292541], 
     Hue[0.9999999933986773, 1, 1.0500000069551785`], 
     Hue[0.9999999969976622, 1, 1.0500000031632746`], 
     Hue[0.9999999986345112, 1, 1.0500000014386843`], 
     Hue[0.999999999378964, 1, 1.050000000654326], 
     Hue[0.9999999997175476, 1, 1.050000000297593], 
     Hue[0.9999999998715382, 1, 1.050000000135348], 
     Hue[0.9999999999415745, 1, 1.0500000000615575`], 
     Hue[0.9999999999734276, 1, 1.0500000000279968`], 
     Hue[0.9999999999879147, 1, 1.0500000000127332`], 
     Hue[0.9999999999945035, 1, 1.0500000000057912`], 
     Hue[0.9999999999975001, 1, 1.050000000002634], 
     Hue[0.999999999998863, 1, 1.050000000001198], 
     Hue[0.9999999999994829, 1, 1.050000000000545], 
     Hue[0.9999999999997649, 1, 1.0500000000002478`], 
     Hue[0.9999999999998931, 1, 1.0500000000001128`], 
     Hue[0.9999999999999514, 1, 1.0500000000000513`], 
     Hue[0.9999999999999779, 1, 1.0500000000000234`], 
     Hue[0.9999999999999899, 1, 1.0500000000000107`], 
     Hue[0.9999999999999954, 1, 1.050000000000005], 
     Hue[0.9999999999999979, 1, 1.0500000000000023`], 
     Hue[0.999999999999999, 1, 1.0500000000000012`], 
     Hue[0.9999999999999996, 1, 1.0500000000000005`], 
     Hue[0.9999999999999998, 1, 1.0500000000000003`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.821383025085958, 1, -17.474999625757572`], 
     Hue[0.821383025085958, 1, -17.100757209075603`], 
     Hue[0.821383025085958, 1, -16.726514792393633`], 
     Hue[0.821383025085958, 1, -16.35227237571166], 
     Hue[0.8213830250859581, 1, -15.97802995902969], 
     Hue[0.8213830250859581, 1, -15.603787542347721`], 
     Hue[0.8213830250859582, 1, -15.229545125665748`], 
     Hue[0.8213830250859584, 1, -14.855302708983777`], 
     Hue[0.8213830250859588, 1, -14.481060292301807`], 
     Hue[0.82138302508596, 1, -14.10681787561984], 
     Hue[0.8213830250859624, 1, -13.732575458937871`], 
     Hue[0.8213830250859676, 1, -13.358333042255905`], 
     Hue[0.8213830250859792, 1, -12.984090625573954`], 
     Hue[0.8213830250860045, 1, -12.609848208892018`], 
     Hue[0.8213830250860602, 1, -12.235605792210126`], 
     Hue[0.8213830250861827, 1, -11.861363375528333`], 
     Hue[0.8213830250864521, 1, -11.487120958846749`], 
     Hue[0.8213830250870444, 1, -11.112878542165628`], 
     Hue[0.8213830250883468, 1, -10.738636125485527`], 
     Hue[0.8213830250912104, 1, -10.364393708807668`], 
     Hue[0.8213830250975067, 1, -9.99015129213474], 
     Hue[0.8213830251113504, 1, -9.615908875472652], 
     Hue[0.8213830251417891, 1, -9.241666458834397], 
     Hue[0.8213830252087153, 1, -8.867424042248546], 
     Hue[0.8213830253558679, 1, -8.493181625777916], 
     Hue[0.8213830256794165, 1, -8.118939209560633], 
     Hue[0.8213830263908115, 1, -7.744696793900377], 
     Hue[0.8213830279549753, 1, -7.370454379464879], 
     Hue[0.8213830313941453, 1, -6.996211967722293], 
     Hue[0.8213830389559421, 1, -6.621969561900679], 
     Hue[0.8213830555822716, 1, -6.247727169097678], 
     Hue[0.8213830921390334, 1, -5.87348480491907], 
     Hue[0.8213831725173613, 1, -5.4992425036777535`], 
     Hue[0.8213833492472618, 1, -5.125000340818647], 
     Hue[0.821383737827485, 1, -4.750758482225566], 
     Hue[0.8213845922062867, 1, -4.3765172926366205`], 
     Hue[0.8213864707369074, 1, -4.002277574034786], 
     Hue[0.8213906010387471, 1, -3.6280410898745465`], 
     Hue[0.8213996820840634, 1, -3.2538117180554202`], 
     Hue[0.8214196470738302, 1, -2.879597987649282], 
     Hue[0.8214635361646895, 1, -2.5054186644551404`], 
     Hue[0.8215599953069946, 1, -2.131315070627128], 
     Hue[0.8217718843347912, 1, -1.7573783575633308`], 
     Hue[0.8222368107602107, 1, -1.383810359138652], 
     Hue[0.8232544074917008, 1, -1.0110615907425842`], 
     Hue[0.8254692531383, 1, -0.6401540062485549], 
     Hue[0.8302292008011833, 1, -0.2734740265725857], 
     Hue[0.8401603123903487, 1, 0.08318291532396516], 
     Hue[0.8594634598051014, 1, 0.4155945339936824], 
     Hue[0.8913344997826842, 1, 0.6935906185428158], 
     Hue[0.9300485253032724, 1, 0.8807118268838032], 
     Hue[0.9619195652808556, 1, 0.976958159016644], 
     Hue[0.9812227126956089, 1, 1.018788957028899], 
     Hue[0.9911538242847744, 1, 1.0363744318143202`], 
     Hue[0.9959137719476578, 1, 1.043936868820322], 
     Hue[0.9981286175942571, 1, 1.0472717010082644`], 
     Hue[0.9991462143257472, 1, 1.048765349294168], 
     Hue[0.9996111407511666, 1, 1.0494397675514602`], 
     Hue[0.9998230297789634, 1, 1.0497454711696343`], 
     Hue[0.9999194889212685, 1, 1.049884294023593], 
     Hue[0.9999633780121279, 1, 1.049947387511423], 
     Hue[0.9999833430018945, 1, 1.0499760737872557`], 
     Hue[0.999992424047211, 1, 1.0499891186501007`], 
     Hue[0.9999965543490505, 1, 1.049995051171831], 
     Hue[0.9999984328796714, 1, 1.049997749251968], 
     Hue[0.999999287258473, 1, 1.0499989763449942`], 
     Hue[0.9999996758386963, 1, 1.0499995344338837`], 
     Hue[0.9999998525685967, 1, 1.049999788256749], 
     Hue[0.9999999329469246, 1, 1.049999903697403], 
     Hue[0.9999999695036863, 1, 1.049999956200766], 
     Hue[0.9999999861300158, 1, 1.0499999800797366`], 
     Hue[0.9999999936918128, 1, 1.0499999909400948`], 
     Hue[0.9999999971309826, 1, 1.0499999958794781`], 
     Hue[0.9999999986951464, 1, 1.0499999981259516`], 
     Hue[0.9999999994065415, 1, 1.0499999991476667`], 
     Hue[0.99999999973009, 1, 1.0499999996123517`], 
     Hue[0.9999999998772426, 1, 1.0499999998236942`], 
     Hue[0.9999999999441689, 1, 1.0499999999198146`], 
     Hue[0.9999999999746075, 1, 1.049999999963531], 
     Hue[0.9999999999884512, 1, 1.0499999999834135`], 
     Hue[0.9999999999947475, 1, 1.0499999999924565`], 
     Hue[0.9999999999976111, 1, 1.0499999999965692`], 
     Hue[0.9999999999989135, 1, 1.0499999999984395`], 
     Hue[0.9999999999995058, 1, 1.0499999999992904`], 
     Hue[0.9999999999997753, 1, 1.0499999999996772`], 
     Hue[0.9999999999998977, 1, 1.0499999999998533`], 
     Hue[0.9999999999999535, 1, 1.0499999999999332`], 
     Hue[0.9999999999999789, 1, 1.0499999999999696`], 
     Hue[0.9999999999999903, 1, 1.0499999999999863`], 
     Hue[0.9999999999999957, 1, 1.0499999999999936`], 
     Hue[0.999999999999998, 1, 1.0499999999999972`], 
     Hue[0.9999999999999991, 1, 1.0499999999999987`], 
     Hue[0.9999999999999996, 1, 1.0499999999999994`], 
     Hue[0.9999999999999998, 1, 1.0499999999999998`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.9467778262008897, 1, -17.474999625757572`], 
     Hue[0.9467778262008897, 1, -17.100757209075603`], 
     Hue[0.9467778262008897, 1, -16.726514792393633`], 
     Hue[0.9467778262008897, 1, -16.35227237571166], 
     Hue[0.9467778262008897, 1, -15.97802995902969], 
     Hue[0.9467778262008898, 1, -15.603787542347721`], 
     Hue[0.9467778262008898, 1, -15.229545125665748`], 
     Hue[0.9467778262008899, 1, -14.855302708983777`], 
     Hue[0.94677782620089, 1, -14.48106029230181], 
     Hue[0.9467778262008905, 1, -14.106817875619843`], 
     Hue[0.9467778262008913, 1, -13.732575458937879`], 
     Hue[0.9467778262008932, 1, -13.358333042255923`], 
     Hue[0.9467778262008975, 1, -12.98409062557399], 
     Hue[0.9467778262009067, 1, -12.609848208892096`], 
     Hue[0.946777826200927, 1, -12.2356057922103], 
     Hue[0.9467778262009716, 1, -11.861363375528713`], 
     Hue[0.9467778262010698, 1, -11.487120958847584`], 
     Hue[0.9467778262012855, 1, -11.112878542167465`], 
     Hue[0.9467778262017599, 1, -10.73863612548957], 
     Hue[0.9467778262028028, 1, -10.364393708816559`], 
     Hue[0.9467778262050961, 1, -9.990151292154286], 
     Hue[0.9467778262101385, 1, -9.615908875515625], 
     Hue[0.9467778262212252, 1, -9.241666458928888], 
     Hue[0.9467778262456019, 1, -8.867424042456303], 
     Hue[0.9467778262991996, 1, -8.493181626234719], 
     Hue[0.9467778264170463, 1, -8.118939210565012], 
     Hue[0.9467778266761593, 1, -7.744696796108735], 
     Hue[0.9467778272458779, 1, -7.370454384320456], 
     Hue[0.9467778284985339, 1, -6.9962119783983825`], 
     Hue[0.9467778312527827, 1, -6.621969585374491], 
     Hue[0.9467778373086244, 1, -6.247727220710188], 
     Hue[0.9467778506237653, 1, -5.873484918400873], 
     Hue[0.9467778799001088, 1, -5.49924275319312], 
     Hue[0.9467779442707004, 1, -5.1250008894340064`], 
     Hue[0.9467780858035618, 1, -4.750759688476725], 
     Hue[0.9467783969932051, 1, -4.376519944832409], 
     Hue[0.9467790812021069, 1, -4.002283405385255], 
     Hue[0.9467805855314779, 1, -3.6280539109160976`], 
     Hue[0.9467838928539865, 1, -3.2538399055715015`], 
     Hue[0.9467911633637579, 1, -2.8796599524233333`], 
     Hue[0.9468071425113396, 1, -2.5055548506340104`], 
     Hue[0.9468422438381958, 1, -2.1316142292709994`], 
     Hue[0.9469192654952998, 1, -1.758034785694172], 
     Hue[0.9470878617801922, 1, -1.3852472086143959`], 
     Hue[0.9474549559030712, 1, -1.0141898478578055`], 
     Hue[0.9482450798034904, 1, -0.6468848649544414], 
     Hue[0.9499041547887297, 1, -0.2875868661660268], 
     Hue[0.953212756815461, 1, 0.055208073644612776`], 
     Hue[0.9591752769187816, 1, 0.3663381977321507], 
     Hue[0.9681671911084124, 1, 0.6244543282663138], 
     Hue[0.9786106350924769, 1, 0.8115755366073005], 
     Hue[0.9876025492821079, 1, 0.9277018227551113], 
     Hue[0.9935650693854285, 1, 0.9908141153495461], 
     Hue[0.9968736714121599, 1, 1.0222615922208786`], 
     Hue[0.9985327463973993, 1, 1.0372060101144356`], 
     Hue[0.9993228702978185, 1, 1.044143443893043], 
     Hue[0.9996899644206975, 1, 1.0473284998184242`], 
     Hue[0.99985856070559, 1, 1.0487833394206194`], 
     Hue[0.999935582362694, 1, 1.0494463125257634`], 
     Hue[0.9999706836895502, 1, 1.0497481078447228`], 
     Hue[0.9999866628371318, 1, 1.0498854227373708`], 
     Hue[0.9999939333469033, 1, 1.049947886271175], 
     Hue[0.9999972406694119, 1, 1.0499762976085492`], 
     Hue[0.9999987449987828, 1, 1.0499892198213627`], 
     Hue[0.9999994292076846, 1, 1.04999509705618], 
     Hue[0.9999997403973279, 1, 1.0499977700938345`], 
     Hue[0.9999998819301893, 1, 1.049998985818524], 
     Hue[0.999999946300781, 1, 1.0499995387413823`], 
     Hue[0.9999999755771245, 1, 1.0499997902155995`], 
     Hue[0.9999999888922653, 1, 1.049999904588256], 
     Hue[0.999999994948107, 1, 1.0499999566059233`], 
     Hue[0.9999999977023559, 1, 1.0499999802640037`], 
     Hue[0.9999999989550118, 1, 1.0499999910239006`], 
     Hue[0.9999999995247305, 1, 1.0499999959175934`], 
     Hue[0.9999999997838434, 1, 1.0499999981432868`], 
     Hue[0.9999999999016901, 1, 1.049999999155551], 
     Hue[0.9999999999552879, 1, 1.0499999996159373`], 
     Hue[0.9999999999796645, 1, 1.049999999825325], 
     Hue[0.9999999999907513, 1, 1.0499999999205565`], 
     Hue[0.9999999999957936, 1, 1.0499999999638683`], 
     Hue[0.9999999999980869, 1, 1.0499999999835672`], 
     Hue[0.9999999999991299, 1, 1.0499999999925262`], 
     Hue[0.9999999999996043, 1, 1.049999999996601], 
     Hue[0.99999999999982, 1, 1.049999999998454], 
     Hue[0.9999999999999182, 1, 1.049999999999297], 
     Hue[0.9999999999999628, 1, 1.0499999999996803`], 
     Hue[0.999999999999983, 1, 1.0499999999998546`], 
     Hue[0.9999999999999923, 1, 1.0499999999999339`], 
     Hue[0.9999999999999964, 1, 1.04999999999997], 
     Hue[0.9999999999999984, 1, 1.0499999999999863`], 
     Hue[0.9999999999999992, 1, 1.0499999999999938`], 
     Hue[0.9999999999999997, 1, 1.0499999999999972`], 
     Hue[0.9999999999999999, 1, 1.0499999999999987`], 
     Hue[0.9999999999999999, 1, 1.0499999999999994`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.0721726273158214`, 1, -17.474999625757572`], 
     Hue[1.0721726273158214`, 1, -17.100757209075603`], 
     Hue[1.0721726273158214`, 1, -16.726514792393633`], 
     Hue[1.0721726273158214`, 1, -16.35227237571166], 
     Hue[1.0721726273158214`, 1, -15.97802995902969], 
     Hue[1.0721726273158214`, 1, -15.603787542347721`], 
     Hue[1.0721726273158214`, 1, -15.229545125665748`], 
     Hue[1.0721726273158212`, 1, -14.855302708983777`], 
     Hue[1.072172627315821, 1, -14.48106029230181], 
     Hue[1.0721726273158205`, 1, -14.106817875619841`], 
     Hue[1.0721726273158194`, 1, -13.732575458937879`], 
     Hue[1.0721726273158168`, 1, -13.358333042255921`], 
     Hue[1.0721726273158112`, 1, -12.984090625573986`], 
     Hue[1.0721726273157988`, 1, -12.609848208892089`], 
     Hue[1.0721726273157717`, 1, -12.235605792210283`], 
     Hue[1.0721726273157122`, 1, -11.86136337552868], 
     Hue[1.0721726273155812`, 1, -11.487120958847509`], 
     Hue[1.0721726273152932`, 1, -11.112878542167302`], 
     Hue[1.0721726273146601`, 1, -10.73863612548921], 
     Hue[1.072172627313268, 1, -10.364393708815763`], 
     Hue[1.0721726273102068`, 1, -9.99015129215254], 
     Hue[1.0721726273034762`, 1, -9.615908875511783], 
     Hue[1.0721726272886776`, 1, -9.241666458920442], 
     Hue[1.0721726272561396`, 1, -8.867424042437733], 
     Hue[1.0721726271845973`, 1, -8.493181626193884], 
     Hue[1.0721726270272953`, 1, -8.118939210475233], 
     Hue[1.072172626681431, 1, -7.744696795911335], 
     Hue[1.07217262592097, 1, -7.370454383886428], 
     Hue[1.0721726242489236`, 1, -6.996211977444074], 
     Hue[1.072172620572549, 1, -6.6219695832762255`], 
     Hue[1.0721726124892044`, 1, -6.247727216096675], 
     Hue[1.072172594716139, 1, -5.873484908257019], 
     Hue[1.0721725556380397`, 1, -5.499242730889573], 
     Hue[1.0721724697160882`, 1, -5.125000840394695], 
     Hue[1.072172280797802, 1, -4.750759580653183], 
     Hue[1.0721718654212125`, 1, -4.376519707760427], 
     Hue[1.0721709521369376`, 1, -4.002282884141163], 
     Hue[1.072168944149342, 1, -3.6280527649032397`], 
     Hue[1.072164529497446, 1, -3.2538373860956735`], 
     Hue[1.0721548246481416`, 1, -2.8796544142041727`], 
     Hue[1.072133494868654, 1, -2.5055426804678067`], 
     Hue[1.07208663774074, 1, -2.1315875035546394`], 
     Hue[1.0719838106724295`, 1, -1.7579761829997695`], 
     Hue[1.0717586796632517`, 1, -1.3851191254119588`], 
     Hue[1.0712682626324155`, 1, -1.0139118916545284`], 
     Hue[1.070211663231588, 1, -0.6462909137713417], 
     Hue[1.0679885857843618`, 1, -0.28635893521190536`], 
     Hue[1.0635384149026643`, 1, 0.05757881287752531], 
     Hue[1.055470435664852, 1, 0.3703481845074297], 
     Hue[1.0432217010714198`, 1, 0.6298774910888809], 
     Hue[1.028950926244402, 1, 0.8169986994298679], 
     Hue[1.0167021916509698`, 1, 0.9317118095303901], 
     Hue[1.0086342124131573`, 1, 0.9931848545824584], 
     Hue[1.0041840415314598`, 1, 1.0234895231750003`], 
     Hue[1.0019609640842337`, 1, 1.0377999612975353`], 
     Hue[1.0009043646834062`, 1, 1.0444214000963201`], 
     Hue[1.0004139476525697`, 1, 1.0474565830208606`], 
     Hue[1.0001888166433919`, 1, 1.0488419421150212`], 
     Hue[1.0000859895750813`, 1, 1.0494730382421231`], 
     Hue[1.0000391324471676`, 1, 1.0497602780109263`], 
     Hue[1.0000178026676798`, 1, 1.0498909609565312`], 
     Hue[1.0000080978183754`, 1, 1.0499504057470028`], 
     Hue[1.0000036831664794`, 1, 1.0499774436214073`], 
     Hue[1.0000016751788838`, 1, 1.0499897410654548`], 
     Hue[1.000000761894609, 1, 1.0499953341281618`], 
     Hue[1.0000003465180194`, 1, 1.0499978779173769`], 
     Hue[1.0000001575997333`, 1, 1.0499990348578354`], 
     Hue[1.0000000716777817`, 1, 1.04999956104493], 
     Hue[1.0000000325996825`, 1, 1.0499998003594535`], 
     Hue[1.000000014826617, 1, 1.0499999092017696`], 
     Hue[1.0000000067432726`, 1, 1.049999958704189], 
     Hue[1.000000003066898, 1, 1.0499999812183127`], 
     Hue[1.0000000013948513`, 1, 1.0499999914579285`], 
     Hue[1.0000000006343903`, 1, 1.049999996114993], 
     Hue[1.000000000288526, 1, 1.0499999982330657`], 
     Hue[1.0000000001312241`, 1, 1.0499999991963833`], 
     Hue[1.0000000000596818`, 1, 1.0499999996345084`], 
     Hue[1.0000000000271438`, 1, 1.0499999998337712`], 
     Hue[1.0000000000123452`, 1, 1.0499999999243979`], 
     Hue[1.0000000000056146`, 1, 1.0499999999656155`], 
     Hue[1.0000000000025535`, 1, 1.0499999999843617`], 
     Hue[1.0000000000011615`, 1, 1.0499999999928875`], 
     Hue[1.0000000000005282`, 1, 1.0499999999967653`], 
     Hue[1.0000000000002403`, 1, 1.0499999999985288`], 
     Hue[1.0000000000001092`, 1, 1.049999999999331], 
     Hue[1.0000000000000497`, 1, 1.0499999999996958`], 
     Hue[1.0000000000000226`, 1, 1.0499999999998617`], 
     Hue[1.0000000000000102`, 1, 1.049999999999937], 
     Hue[1.0000000000000047`, 1, 1.0499999999999714`], 
     Hue[1.0000000000000022`, 1, 1.0499999999999872`], 
     Hue[1.0000000000000009`, 1, 1.049999999999994], 
     Hue[1.0000000000000004`, 1, 1.0499999999999974`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999987`], 
     Hue[1., 1, 1.0499999999999996`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.1975674284307531`, 1, -17.474999625757572`], 
     Hue[1.1975674284307531`, 1, -17.100757209075603`], 
     Hue[1.1975674284307531`, 1, -16.726514792393633`], 
     Hue[1.1975674284307531`, 1, -16.35227237571166], 
     Hue[1.1975674284307531`, 1, -15.97802995902969], 
     Hue[1.1975674284307531`, 1, -15.603787542347721`], 
     Hue[1.197567428430753, 1, -15.229545125665748`], 
     Hue[1.1975674284307527`, 1, -14.855302708983777`], 
     Hue[1.1975674284307523`, 1, -14.481060292301807`], 
     Hue[1.1975674284307511`, 1, -14.106817875619837`], 
     Hue[1.1975674284307487`, 1, -13.73257545893787], 
     Hue[1.1975674284307432`, 1, -13.358333042255902`], 
     Hue[1.197567428430731, 1, -12.984090625573945`], 
     Hue[1.1975674284307043`, 1, -12.609848208892002`], 
     Hue[1.197567428430646, 1, -12.23560579221009], 
     Hue[1.1975674284305171`, 1, -11.861363375528251`], 
     Hue[1.1975674284302342`, 1, -11.487120958846567`], 
     Hue[1.1975674284296123`, 1, -11.11287854216523], 
     Hue[1.1975674284282447`, 1, -10.738636125484657`], 
     Hue[1.1975674284252378`, 1, -10.364393708805753`], 
     Hue[1.1975674284186262`, 1, -9.990151292130529], 
     Hue[1.197567428404089, 1, -9.61590887546339], 
     Hue[1.1975674283721258`, 1, -9.241666458814036], 
     Hue[1.1975674283018478`, 1, -8.867424042203778], 
     Hue[1.1975674281473252`, 1, -8.493181625679483], 
     Hue[1.1975674278075723`, 1, -8.118939209344202], 
     Hue[1.1975674270605485`, 1, -7.744696793424505], 
     Hue[1.1975674254180466`, 1, -7.370454378418567], 
     Hue[1.1975674218066326`, 1, -6.996211965421739], 
     Hue[1.1975674138661174`, 1, -6.621969556842387], 
     Hue[1.1975673964070896`, 1, -6.2477271579758735`], 
     Hue[1.19756735801945, 1, -5.873484780465257], 
     Hue[1.1975672736155143`, 1, -5.499242449910506], 
     Hue[1.1975670880343698`, 1, -5.125000222599234], 
     Hue[1.197566679992529, 1, -4.750758222293829], 
     Hue[1.1975657828222395`, 1, -4.376516721120148], 
     Hue[1.1975638102014363`, 1, -4.002276317438279], 
     Hue[1.1975594730046784`, 1, -3.6280383270215353`], 
     Hue[1.1975499369752713`, 1, -3.2538056435859017`], 
     Hue[1.1975289712198613`, 1, -2.879584632954691], 
     Hue[1.1974828798840362`, 1, -2.505389307931842], 
     Hue[1.1973815697514614`, 1, -2.1312505565759015`], 
     Hue[1.197158972051291, 1, -1.7572366681956353`], 
     Hue[1.1966702953492963`, 1, -1.3834995956565568`], 
     Hue[1.1955995033764621`, 1, -1.0103820630972982`], 
     Hue[1.1932631460324454`, 1, -0.6386782730257854], 
     Hue[1.188215754256846, 1, -0.27031987460050844`], 
     Hue[1.1775724414000137`, 1, 0.0896682513885273], 
     Hue[1.1564837893848545`, 1, 0.42769243066526275`], 
     Hue[1.1207695195015646`, 1, 0.7115455209123644], 
     Hue[1.0767979089291901`, 1, 0.8986667292533521], 
     Hue[1.0410836390458995`, 1, 0.9890560556882242], 
     Hue[1.01999498703074, 1, 1.0252742930934615`], 
     Hue[1.0093516741739075`, 1, 1.0395285837863977`], 
     Hue[1.004304282398308, 1, 1.0454126020430918`], 
     Hue[1.0019679250542912`, 1, 1.0479512286535504`], 
     Hue[1.0008971330814571`, 1, 1.0490761127762631`], 
     Hue[1.0004084563794622`, 1, 1.049581456919156], 
     Hue[1.0001858586792918`, 1, 1.0498099852208609`], 
     Hue[1.000084548546717, 1, 1.0499136505468911`], 
     Hue[1.000038457210892, 1, 1.049960742206013], 
     Hue[1.0000174914554818`, 1, 1.0499821482567746`], 
     Hue[1.000007955426075, 1, 1.0499918815031115`], 
     Hue[1.0000036182293168`, 1, 1.049996307768338], 
     Hue[1.000001645608514, 1, 1.049998320768441], 
     Hue[1.000000748438224, 1, 1.0499992362767308`], 
     Hue[1.0000003403963833`, 1, 1.0499996526532962`], 
     Hue[1.0000001548152389`, 1, 1.0499998420239958`], 
     Hue[1.0000000704113032`, 1, 1.0499999281512158`], 
     Hue[1.0000000320236637`, 1, 1.0499999673225706`], 
     Hue[1.0000000145646357`, 1, 1.0499999851380286`], 
     Hue[1.0000000066241206`, 1, 1.0499999932406492`], 
     Hue[1.0000000030127065`, 1, 1.0499999969257896`], 
     Hue[1.0000000013702046`, 1, 1.0499999986018231`], 
     Hue[1.0000000006231808`, 1, 1.0499999993640972`], 
     Hue[1.000000000283428, 1, 1.049999999710786], 
     Hue[1.0000000001289053`, 1, 1.049999999868463], 
     Hue[1.0000000000586273`, 1, 1.049999999940176], 
     Hue[1.0000000000266642`, 1, 1.0499999999727916`], 
     Hue[1.0000000000121272`, 1, 1.0499999999876253`], 
     Hue[1.0000000000055156`, 1, 1.0499999999943719`], 
     Hue[1.0000000000025084`, 1, 1.0499999999974403`], 
     Hue[1.0000000000011409`, 1, 1.0499999999988359`], 
     Hue[1.000000000000519, 1, 1.0499999999994705`], 
     Hue[1.000000000000236, 1, 1.0499999999997593`], 
     Hue[1.0000000000001072`, 1, 1.0499999999998906`], 
     Hue[1.0000000000000488`, 1, 1.0499999999999503`], 
     Hue[1.0000000000000222`, 1, 1.0499999999999774`], 
     Hue[1.00000000000001, 1, 1.0499999999999896`], 
     Hue[1.0000000000000047`, 1, 1.0499999999999954`], 
     Hue[1.000000000000002, 1, 1.0499999999999978`], 
     Hue[1.0000000000000009`, 1, 1.0499999999999992`], 
     Hue[1.0000000000000004`, 1, 1.0499999999999996`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.3229622295456849`, 1, -17.474999625757572`], 
     Hue[1.3229622295456849`, 1, -17.100757209075603`], 
     Hue[1.3229622295456849`, 1, -16.726514792393633`], 
     Hue[1.3229622295456849`, 1, -16.35227237571166], 
     Hue[1.3229622295456849`, 1, -15.97802995902969], 
     Hue[1.3229622295456849`, 1, -15.603787542347721`], 
     Hue[1.3229622295456847`, 1, -15.229545125665748`], 
     Hue[1.3229622295456847`, 1, -14.855302708983777`], 
     Hue[1.322962229545684, 1, -14.481060292301807`], 
     Hue[1.3229622295456829`, 1, -14.106817875619832`], 
     Hue[1.3229622295456807`, 1, -13.732575458937857`], 
     Hue[1.3229622295456753`, 1, -13.358333042255879`], 
     Hue[1.3229622295456638`, 1, -12.984090625573891`], 
     Hue[1.3229622295456387`, 1, -12.609848208891883`], 
     Hue[1.3229622295455832`, 1, -12.23560579220983], 
     Hue[1.3229622295454613`, 1, -11.86136337552768], 
     Hue[1.3229622295451933`, 1, -11.487120958845313`], 
     Hue[1.3229622295446037`, 1, -11.112878542162473`], 
     Hue[1.3229622295433077`, 1, -10.738636125478594`], 
     Hue[1.3229622295404577`, 1, -10.364393708792427`], 
     Hue[1.322962229534192, 1, -9.990151292101226], 
     Hue[1.322962229520415, 1, -9.615908875398963], 
     Hue[1.322962229490123, 1, -9.241666458672377], 
     Hue[1.3229622294235197`, 1, -8.867424041892308], 
     Hue[1.322962229277077, 1, -8.493181624994648], 
     Hue[1.3229622289550893`, 1, -8.118939207838434], 
     Hue[1.322962228247126, 1, -7.744696790113731], 
     Hue[1.322962226690508, 1, -7.370454371139076], 
     Hue[1.3229622232679286`, 1, -6.996211949416122], 
     Hue[1.322962215742609, 1, -6.621969521650402], 
     Hue[1.322962199196481, 1, -6.247727080598288], 
     Hue[1.322962162816049, 1, -5.873484610333028], 
     Hue[1.322962082825365, 1, -5.499242075836074], 
     Hue[1.3229619069475105`, 1, -5.124999400111382], 
     Hue[1.3229615202393654`, 1, -4.750756413866608], 
     Hue[1.3229606699702812`, 1, -4.3765127448787124`], 
     Hue[1.3229588004445199`, 1, -4.002267574753364], 
     Hue[1.322954689790647, 1, -3.6280191041741547`], 
     Hue[1.3229456512145774`, 1, -3.253763377465021], 
     Hue[1.322925776067813, 1, -2.879491699737166], 
     Hue[1.3228820674260762`, 1, -2.505184965707995], 
     Hue[1.3227859224156773`, 1, -2.130801228148414], 
     Hue[1.3225743246191786`, 1, -1.7562485479873955`], 
     Hue[1.3221081073244523`, 1, -1.381326195912169], 
     Hue[1.321078336296868, 1, -1.0055997994422816`], 
     Hue[1.3187916108783209`, 1, -0.6281492314495083], 
     Hue[1.3136562363570878`, 1, -0.24713329854929866`], 
     Hue[1.3018671217641642`, 1, 0.14047747956051448`], 
     Hue[1.2739244175895355`, 1, 0.5350160562122273], 
     Hue[1.209733002610299, 1, 0.8992777374653046], 
     Hue[1.113229226935389, 1, 1.0863989458062944`], 
     Hue[1.049037811956151, 1, 1.0963796812351914`], 
     Hue[1.0210951077815213`, 1, 1.07608352126545], 
     Hue[1.0093059931885975`, 1, 1.062715159837608], 
     Hue[1.0041706186673642`, 1, 1.0559416436193692`], 
     Hue[1.001883893248817, 1, 1.0527334923085674`], 
     Hue[1.0008541222212326`, 1, 1.0512495125206511`], 
     Hue[1.0003879049265065`, 1, 1.0505695771273955`], 
     Hue[1.0001763071300078`, 1, 1.0502593136483482`], 
     Hue[1.000080162119609, 1, 1.050117992770738], 
     Hue[1.000036453477872, 1, 1.050053675423538], 
     Hue[1.0000165783311075`, 1, 1.0500244143776554`], 
     Hue[1.000007539755038, 1, 1.0500111043504927`], 
     Hue[1.0000034291011652`, 1, 1.0500050504532532`], 
     Hue[1.0000015595754037`, 1, 1.0500022970098766`], 
     Hue[1.0000007093063195`, 1, 1.0500010447039525`], 
     Hue[1.0000003225981744`, 1, 1.050000475141149], 
     Hue[1.00000014672032, 1, 1.0500002160984283`], 
     Hue[1.0000000667296358`, 1, 1.0500000982834454`], 
     Hue[1.0000000303492038`, 1, 1.0500000447001567`], 
     Hue[1.000000013803076, 1, 1.0500000203300142`], 
     Hue[1.0000000062777565`, 1, 1.050000009246264], 
     Hue[1.0000000028551772`, 1, 1.0500000042052797`], 
     Hue[1.0000000012985588`, 1, 1.0500000019125972`], 
     Hue[1.0000000005905956`, 1, 1.0500000008698656`], 
     Hue[1.000000000268608, 1, 1.0500000003956222`], 
     Hue[1.0000000001221652`, 1, 1.0500000001799323`], 
     Hue[1.0000000000555618`, 1, 1.0500000000818348`], 
     Hue[1.00000000002527, 1, 1.0500000000372192`], 
     Hue[1.000000000011493, 1, 1.0500000000169276`], 
     Hue[1.0000000000052272`, 1, 1.050000000007699], 
     Hue[1.0000000000023774`, 1, 1.0500000000035017`], 
     Hue[1.0000000000010811`, 1, 1.0500000000015925`], 
     Hue[1.0000000000004918`, 1, 1.0500000000007244`], 
     Hue[1.0000000000002236`, 1, 1.0500000000003293`], 
     Hue[1.0000000000001017`, 1, 1.05000000000015], 
     Hue[1.0000000000000462`, 1, 1.0500000000000682`], 
     Hue[1.000000000000021, 1, 1.0500000000000311`], 
     Hue[1.0000000000000095`, 1, 1.0500000000000143`], 
     Hue[1.0000000000000044`, 1, 1.0500000000000065`], 
     Hue[1.000000000000002, 1, 1.050000000000003], 
     Hue[1.0000000000000009`, 1, 1.0500000000000014`], 
     Hue[1.0000000000000004`, 1, 1.0500000000000007`], 
     Hue[1.0000000000000002`, 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.4483570306606162`, 1, -17.474999625757572`], 
     Hue[1.4483570306606162`, 1, -17.100757209075603`], 
     Hue[1.4483570306606162`, 1, -16.726514792393633`], 
     Hue[1.4483570306606162`, 1, -16.35227237571166], 
     Hue[1.4483570306606162`, 1, -15.97802995902969], 
     Hue[1.4483570306606162`, 1, -15.603787542347721`], 
     Hue[1.448357030660616, 1, -15.229545125665748`], 
     Hue[1.448357030660616, 1, -14.855302708983777`], 
     Hue[1.4483570306606157`, 1, -14.481060292301803`], 
     Hue[1.4483570306606155`, 1, -14.106817875619829`], 
     Hue[1.4483570306606146`, 1, -13.73257545893785], 
     Hue[1.4483570306606126`, 1, -13.358333042255863`], 
     Hue[1.4483570306606086`, 1, -12.984090625573858`], 
     Hue[1.4483570306605997`, 1, -12.609848208891805`], 
     Hue[1.44835703066058, 1, -12.23560579220966], 
     Hue[1.4483570306605364`, 1, -11.861363375527304`], 
     Hue[1.4483570306604414`, 1, -11.487120958844487`], 
     Hue[1.4483570306602318`, 1, -11.112878542160656`], 
     Hue[1.4483570306597708`, 1, -10.738636125474597`], 
     Hue[1.4483570306587576`, 1, -10.364393708783636`], 
     Hue[1.44835703065653, 1, -9.9901512920819], 
     Hue[1.448357030651632, 1, -9.615908875356467], 
     Hue[1.4483570306408624`, 1, -9.241666458578944], 
     Hue[1.4483570306171831`, 1, -8.867424041686872], 
     Hue[1.4483570305651186`, 1, -8.49318162454295], 
     Hue[1.448357030450643, 1, -8.118939206845276], 
     Hue[1.4483570301989421`, 1, -7.744696787930049], 
     Hue[1.4483570296455213`, 1, -7.370454366337753], 
     Hue[1.448357028428699, 1, -6.996211938859321], 
     Hue[1.4483570257532383`, 1, -6.621969498438868], 
     Hue[1.4483570198706284`, 1, -6.247727029562445], 
     Hue[1.448357006936368, 1, -5.873484498119079], 
     Hue[1.4483569784974324`, 1, -5.499241829107989], 
     Hue[1.448356915967857, 1, -5.124998857622635], 
     Hue[1.4483567784818479`, 1, -4.750755221077201], 
     Hue[1.4483564761850993`, 1, -4.376510122238152], 
     Hue[1.4483558115049273`, 1, -4.002261808176488], 
     Hue[1.4483543499963305`, 1, -3.6280064245354176`], 
     Hue[1.4483511362566008`, 1, -3.2537354959402327`], 
     Hue[1.448344068761827, 1, -2.879430383993639], 
     Hue[1.448328522703871, 1, -2.505050091700051], 
     Hue[1.448294309398423, 1, -2.1305043992772505`], 
     Hue[1.4482189297745065`, 1, -1.7555945576387517`], 
     Hue[1.4480524428741643`, 1, -1.3798817267194072`], 
     Hue[1.44768272947737, 1, -1.0023920320833273`], 
     Hue[1.4468517335266982`, 1, -0.6209400516806487], 
     Hue[1.4449322671609108`, 1, -0.23049962649007627`], 
     Hue[1.4402072672597255`, 1, 0.1811337574207913], 
     Hue[1.4265520419332396`, 1, 0.6473256417292923], 
     Hue[1.3628240199012385`, 1, 1.2749360986739795`], 
     Hue[1.085533010759383, 1, 1.4620573070149858`], 
     Hue[1.0218049887273772`, 1, 1.208689266752261], 
     Hue[1.008149763400891, 1, 1.116739799125728], 
     Hue[1.0034247634997053`, 1, 1.0793488318968307`], 
     Hue[1.001505297133918, 1, 1.0631508233882292`], 
     Hue[1.0006743011832462`, 1, 1.0559412596675217`], 
     Hue[1.0003045877864518`, 1, 1.0526939817134129`], 
     Hue[1.0001381008861097`, 1, 1.051223567476039], 
     Hue[1.000062721262193, 1, 1.050556142519512], 
     Hue[1.000028507956745, 1, 1.050252866778682], 
     Hue[1.0000129618987892`, 1, 1.050114991167065], 
     Hue[1.000005894404015, 1, 1.0500522959024434`], 
     Hue[1.0000026806642857`, 1, 1.0500237839892295`], 
     Hue[1.0000012191556886`, 1, 1.050010817030129], 
     Hue[1.0000005544755168`, 1, 1.0500049196504373`], 
     Hue[1.000000252178768, 1, 1.0500022374933584`], 
     Hue[1.000000114692759, 1, 1.050001017629896], 
     Hue[1.0000000521631838`, 1, 1.0500004628265127`], 
     Hue[1.0000000237242481`, 1, 1.0500002104973942`], 
     Hue[1.0000000107899876`, 1, 1.0500000957359994`], 
     Hue[1.0000000049073778`, 1, 1.0500000435415464`], 
     Hue[1.000000002231917, 1, 1.0500000198030661`], 
     Hue[1.000000001015095, 1, 1.0500000090066033`], 
     Hue[1.0000000004616738`, 1, 1.05000000409628], 
     Hue[1.0000000002099731`, 1, 1.0500000018630231`], 
     Hue[1.0000000000954976`, 1, 1.050000000847319], 
     Hue[1.000000000043433, 1, 1.0500000003853678`], 
     Hue[1.0000000000197538`, 1, 1.0500000001752685`], 
     Hue[1.0000000000089841`, 1, 1.0500000000797136`], 
     Hue[1.000000000004086, 1, 1.0500000000362546`], 
     Hue[1.0000000000018583`, 1, 1.0500000000164889`], 
     Hue[1.000000000000845, 1, 1.0500000000074994`], 
     Hue[1.0000000000003844`, 1, 1.0500000000034109`], 
     Hue[1.0000000000001747`, 1, 1.0500000000015512`], 
     Hue[1.0000000000000795`, 1, 1.0500000000007055`], 
     Hue[1.0000000000000362`, 1, 1.050000000000321], 
     Hue[1.0000000000000164`, 1, 1.050000000000146], 
     Hue[1.0000000000000075`, 1, 1.0500000000000664`], 
     Hue[1.0000000000000033`, 1, 1.0500000000000302`], 
     Hue[1.0000000000000016`, 1, 1.0500000000000138`], 
     Hue[1.0000000000000007`, 1, 1.0500000000000063`], 
     Hue[1.0000000000000002`, 1, 1.050000000000003], 
     Hue[1.0000000000000002`, 1, 1.0500000000000014`], 
     Hue[1., 1, 1.0500000000000007`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.5737518317755478, 1, -17.474999625757572`], 
     Hue[0.5737518317755478, 1, -17.100757209075603`], 
     Hue[0.5737518317755478, 1, -16.726514792393633`], 
     Hue[0.5737518317755478, 1, -16.35227237571166], 
     Hue[0.5737518317755478, 1, -15.97802995902969], 
     Hue[0.5737518317755478, 1, -15.603787542347721`], 
     Hue[0.5737518317755479, 1, -15.229545125665748`], 
     Hue[0.573751831775548, 1, -14.855302708983777`], 
     Hue[0.5737518317755482, 1, -14.481060292301803`], 
     Hue[0.5737518317755488, 1, -14.10681787561983], 
     Hue[0.5737518317755499, 1, -13.73257545893785], 
     Hue[0.5737518317755526, 1, -13.358333042255865`], 
     Hue[0.5737518317755583, 1, -12.98409062557386], 
     Hue[0.5737518317755708, 1, -12.609848208891814`], 
     Hue[0.5737518317755985, 1, -12.235605792209677`], 
     Hue[0.5737518317756592, 1, -11.861363375527343`], 
     Hue[0.5737518317757929, 1, -11.487120958844573`], 
     Hue[0.5737518317760868, 1, -11.112878542160846`], 
     Hue[0.5737518317767327, 1, -10.738636125475018`], 
     Hue[0.5737518317781533, 1, -10.364393708784563`], 
     Hue[0.5737518317812765, 1, -9.990151292083937], 
     Hue[0.5737518317881438, 1, -9.61590887536095], 
     Hue[0.573751831803243, 1, -9.241666458588796], 
     Hue[0.5737518318364419, 1, -8.867424041708533], 
     Hue[0.5737518319094371, 1, -8.493181624590578], 
     Hue[0.573751832069934, 1, -8.118939206949996], 
     Hue[0.5737518324228229, 1, -7.7446967881603], 
     Hue[0.5737518331987295, 1, -7.370454366844013], 
     Hue[0.5737518349047364, 1, -6.996211939972443], 
     Hue[0.5737518386557809, 1, -6.621969500886324], 
     Hue[0.5737518469033072, 1, -6.2477270349437335`], 
     Hue[0.5737518650373756, 1, -5.873484509951071], 
     Hue[0.573751904909279, 1, -5.499241855123342], 
     Hue[0.5737519925768693, 1, -5.1249989148234345`], 
     Hue[0.573752185334688, 1, -4.750755346846799], 
     Hue[0.5737526091598859, 1, -4.376510398774258], 
     Hue[0.573753541051878, 1, -4.002262416218695], 
     Hue[0.5737555901052047, 1, -3.628007761525466], 
     Hue[0.573760095786368, 1, -3.2537384359599937`], 
     Hue[0.5737700043467739, 1, -2.8794368499545344`], 
     Hue[0.5737917992542882, 1, -2.505064316609263], 
     Hue[0.5738397623344191, 1, -2.1305357148134707`], 
     Hue[0.573945423619705, 1, -1.7556636002517292`], 
     Hue[0.5741787323816123, 1, -1.3800344484792724`], 
     Hue[0.5746965400445675, 1, -1.0027323139495212`], 
     Hue[0.5758588951379412, 1, -0.6217106004465545], 
     Hue[0.5785355036525499, 1, -0.23230946680009734`], 
     Hue[0.5850717075762143, 1, 0.17650354844106142`], 
     Hue[0.603472396328739, 1, 0.6326477825613318], 
     Hue[0.6771652602021232, 1, 1.193779879875815], 
     Hue[0.896586571573419, 1, 1.3809010882168153`], 
     Hue[0.9702794354468078, 1, 1.1940114075842998`], 
     Hue[0.9886801241993332, 1, 1.112109590145998], 
     Hue[0.9952163281229977, 1, 1.0775389915868097`], 
     Hue[0.9978929366376065, 1, 1.0623802746223234`], 
     Hue[0.9990552917309803, 1, 1.0556009778013278`], 
     Hue[0.9995730993939353, 1, 1.0525412599535477`], 
     Hue[0.9998064081558428, 1, 1.0511545248630618`], 
     Hue[0.9999120694411285, 1, 1.0505248269832914`], 
     Hue[0.9999600325212595, 1, 1.0502386418694705`], 
     Hue[0.9999818274287737, 1, 1.0501085252061697`], 
     Hue[0.9999917359891798, 1, 1.0500493558826827`], 
     Hue[0.999996241670343, 1, 1.0500224469991803`], 
     Hue[0.9999982907236697, 1, 1.050010208987922], 
     Hue[0.999999222615662, 1, 1.0500046431143317`], 
     Hue[0.9999996464408598, 1, 1.0500021117237603`], 
     Hue[0.9999998391986785, 1, 1.050000960429096], 
     Hue[0.9999999268662687, 1, 1.0500004368111604`], 
     Hue[0.9999999667381722, 1, 1.0500001986654024`], 
     Hue[0.9999999848722406, 1, 1.050000090354711], 
     Hue[0.9999999931197667, 1, 1.0500000410940913`], 
     Hue[0.9999999968708114, 1, 1.0500000186899427`], 
     Hue[0.9999999985768184, 1, 1.0500000085003451`], 
     Hue[0.9999999993527249, 1, 1.0500000038660295`], 
     Hue[0.9999999997056137, 1, 1.0500000017583033`], 
     Hue[0.9999999998661107, 1, 1.0500000007996912`], 
     Hue[0.9999999999391059, 1, 1.0500000003637064`], 
     Hue[0.9999999999723049, 1, 1.0500000001654168`], 
     Hue[0.9999999999874041, 1, 1.050000000075233], 
     Hue[0.9999999999942712, 1, 1.0500000000342167`], 
     Hue[0.9999999999973945, 1, 1.050000000015562], 
     Hue[0.999999999998815, 1, 1.0500000000070777`], 
     Hue[0.9999999999994611, 1, 1.050000000003219], 
     Hue[0.9999999999997549, 1, 1.050000000001464], 
     Hue[0.9999999999998885, 1, 1.050000000000666], 
     Hue[0.9999999999999493, 1, 1.050000000000303], 
     Hue[0.9999999999999769, 1, 1.0500000000001377`], 
     Hue[0.9999999999999896, 1, 1.0500000000000627`], 
     Hue[0.9999999999999952, 1, 1.0500000000000285`], 
     Hue[0.9999999999999978, 1, 1.050000000000013], 
     Hue[0.999999999999999, 1, 1.050000000000006], 
     Hue[0.9999999999999996, 1, 1.0500000000000027`], 
     Hue[0.9999999999999998, 1, 1.0500000000000014`], 
     Hue[0.9999999999999999, 1, 1.0500000000000007`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.6991466328904795, 1, -17.474999625757572`], 
     Hue[0.6991466328904795, 1, -17.100757209075603`], 
     Hue[0.6991466328904795, 1, -16.726514792393633`], 
     Hue[0.6991466328904795, 1, -16.35227237571166], 
     Hue[0.6991466328904796, 1, -15.97802995902969], 
     Hue[0.6991466328904796, 1, -15.603787542347721`], 
     Hue[0.6991466328904797, 1, -15.229545125665748`], 
     Hue[0.69914663289048, 1, -14.855302708983777`], 
     Hue[0.6991466328904805, 1, -14.481060292301807`], 
     Hue[0.6991466328904816, 1, -14.106817875619834`], 
     Hue[0.6991466328904841, 1, -13.732575458937859`], 
     Hue[0.6991466328904896, 1, -13.358333042255882`], 
     Hue[0.6991466328905018, 1, -12.9840906255739], 
     Hue[0.6991466328905285, 1, -12.609848208891902`], 
     Hue[0.6991466328905872, 1, -12.235605792209872`], 
     Hue[0.6991466328907163, 1, -11.861363375527775`], 
     Hue[0.6991466328910001, 1, -11.487120958845523`], 
     Hue[0.6991466328916243, 1, -11.112878542162935`], 
     Hue[0.6991466328929964, 1, -10.73863612547961], 
     Hue[0.6991466328960134, 1, -10.36439370879466], 
     Hue[0.6991466329026472, 1, -9.990151292106138], 
     Hue[0.6991466329172329, 1, -9.615908875409765], 
     Hue[0.6991466329493028, 1, -9.241666458696127], 
     Hue[0.6991466330198159, 1, -8.867424041944528], 
     Hue[0.699146633174855, 1, -8.493181625109463], 
     Hue[0.6991466335157437, 1, -8.118939208090882], 
     Hue[0.699146634265265, 1, -7.7446967906687965`], 
     Hue[0.6991466359132583, 1, -7.3704543723595135`], 
     Hue[0.6991466395367463, 1, -6.996211952099531], 
     Hue[0.6991466475038092, 1, -6.621969527550483], 
     Hue[0.69914666502121, 1, -6.247727093570962], 
     Hue[0.699146703537205, 1, -5.873484638856408], 
     Hue[0.6991467882234033, 1, -5.499242138551242], 
     Hue[0.6991469744253785, 1, -5.124999538005074], 
     Hue[0.6991473838332843, 1, -4.750756717057881], 
     Hue[0.6991482840121455, 1, -4.376513411516699], 
     Hue[0.6991502632719857, 1, -4.002269040523148], 
     Hue[0.6991546151822459, 1, -3.628022327072676], 
     Hue[0.6991641841237548, 1, -3.253770464080045], 
     Hue[0.6991852249565829, 1, -2.8795072829133987`], 
     Hue[0.6992314944812561, 1, -2.5052192367973865`], 
     Hue[0.6993332598001398, 1, -2.1308766192580935`], 
     Hue[0.6995571648073394, 1, -1.7564144975393547`], 
     Hue[0.7000501973757887, 1, -1.3816919659203777`], 
     Hue[0.7011377259409877, 1, -1.0064083145556262`], 
     Hue[0.7035454443155158, 1, -0.6299473584564519], 
     Hue[0.7089158451967481, 1, -0.2511820017656097], 
     Hue[0.7210514489976483, 1, 0.13116432171091763`], 
     Hue[0.748760931917728, 1, 0.5132934208541683], 
     Hue[0.8077257753566345, 1, 0.8555964349284975], 
     Hue[0.8914208575338423, 1, 1.0427176432694865`], 
     Hue[0.9503857009727501, 1, 1.074657045877132], 
     Hue[0.9780951838928307, 1, 1.066770363415853], 
     Hue[0.9902307876937312, 1, 1.0586664566212967`], 
     Hue[0.9956011885749637, 1, 1.0541435166124258`], 
     Hue[0.9980089069494918, 1, 1.0519249771952226`], 
     Hue[0.999096435514691, 1, 1.0508837425124424`], 
     Hue[0.9995894680831401, 1, 1.0504036275754363`], 
     Hue[0.9998133730903398, 1, 1.0501839225386689`], 
     Hue[0.9999151384092234, 1, 1.050083721681347], 
     Hue[0.9999614079338967, 1, 1.0500380922473056`], 
     Hue[0.9999824487667247, 1, 1.0500173277626312`], 
     Hue[0.9999920177082336, 1, 1.0500078814519702`], 
     Hue[0.9999963696184938, 1, 1.0500035846834694`], 
     Hue[0.999998348878334, 1, 1.05000163037189], 
     Hue[0.9999992490571952, 1, 1.0500007415126795`], 
     Hue[0.999999658465101, 1, 1.0500003372474558`], 
     Hue[0.9999998446670764, 1, 1.0500001533832595`], 
     Hue[0.9999999293532745, 1, 1.050000069760064], 
     Hue[0.9999999678692695, 1, 1.0500000317274822`], 
     Hue[0.9999999853866703, 1, 1.0500000144299315`], 
     Hue[0.9999999933537332, 1, 1.0500000065628563`], 
     Hue[0.9999999969772212, 1, 1.050000002984843], 
     Hue[0.9999999986252145, 1, 1.0500000013575321`], 
     Hue[0.9999999993747358, 1, 1.0500000006174173`], 
     Hue[0.9999999997156245, 1, 1.0500000002808065`], 
     Hue[0.9999999998706636, 1, 1.0500000001277132`], 
     Hue[0.9999999999411767, 1, 1.0500000000580851`], 
     Hue[0.9999999999732466, 1, 1.0500000000264176`], 
     Hue[0.9999999999878324, 1, 1.050000000012015], 
     Hue[0.9999999999944661, 1, 1.0500000000054646`], 
     Hue[0.9999999999974831, 1, 1.0500000000024854`], 
     Hue[0.9999999999988552, 1, 1.0500000000011305`], 
     Hue[0.9999999999994794, 1, 1.050000000000514], 
     Hue[0.9999999999997632, 1, 1.0500000000002339`], 
     Hue[0.9999999999998923, 1, 1.0500000000001064`], 
     Hue[0.999999999999951, 1, 1.0500000000000485`], 
     Hue[0.9999999999999777, 1, 1.050000000000022], 
     Hue[0.9999999999999899, 1, 1.05000000000001], 
     Hue[0.9999999999999953, 1, 1.0500000000000045`], 
     Hue[0.9999999999999979, 1, 1.050000000000002], 
     Hue[0.999999999999999, 1, 1.050000000000001], 
     Hue[0.9999999999999996, 1, 1.0500000000000005`], 
     Hue[0.9999999999999998, 1, 1.0500000000000003`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.8245414340054112, 1, -17.474999625757572`], 
     Hue[0.8245414340054112, 1, -17.100757209075603`], 
     Hue[0.8245414340054112, 1, -16.726514792393633`], 
     Hue[0.8245414340054112, 1, -16.35227237571166], 
     Hue[0.8245414340054114, 1, -15.97802995902969], 
     Hue[0.8245414340054114, 1, -15.603787542347721`], 
     Hue[0.8245414340054115, 1, -15.229545125665748`], 
     Hue[0.8245414340054117, 1, -14.855302708983777`], 
     Hue[0.8245414340054121, 1, -14.481060292301807`], 
     Hue[0.8245414340054132, 1, -14.10681787561984], 
     Hue[0.8245414340054156, 1, -13.732575458937871`], 
     Hue[0.8245414340054208, 1, -13.358333042255907`], 
     Hue[0.8245414340054322, 1, -12.984090625573955`], 
     Hue[0.8245414340054573, 1, -12.60984820889202], 
     Hue[0.8245414340055125, 1, -12.235605792210134`], 
     Hue[0.8245414340056338, 1, -11.861363375528345`], 
     Hue[0.8245414340059005, 1, -11.487120958846777`], 
     Hue[0.8245414340064872, 1, -11.112878542165692`], 
     Hue[0.8245414340077768, 1, -10.738636125485668`], 
     Hue[0.8245414340106125, 1, -10.36439370880798], 
     Hue[0.8245414340168474, 1, -9.99015129213542], 
     Hue[0.8245414340305562, 1, -9.615908875474148], 
     Hue[0.8245414340606982, 1, -9.241666458837688], 
     Hue[0.8245414341269722, 1, -8.867424042255783], 
     Hue[0.8245414342726907, 1, -8.493181625793826], 
     Hue[0.8245414345930859, 1, -8.11893920959561], 
     Hue[0.8245414352975476, 1, -7.744696793977286], 
     Hue[0.824541436846467, 1, -7.370454379633979], 
     Hue[0.8245414402521184, 1, -6.996211968094099], 
     Hue[0.8245414477402176, 1, -6.621969562718183], 
     Hue[0.8245414642045058, 1, -6.247727170895149], 
     Hue[0.8245415004049824, 1, -5.873484808871217], 
     Hue[0.8245415799999357, 1, -5.499242512367442], 
     Hue[0.8245417550074047, 1, -5.125000359924885], 
     Hue[0.82454213980045, 1, -4.750758524234875], 
     Hue[0.8245429858521802, 1, -4.376517385003156], 
     Hue[0.8245448460733606, 1, -4.002277777121272], 
     Hue[0.8245489361154128, 1, -3.6280415363949965`], 
     Hue[0.8245579286292242, 1, -3.253812699777174], 
     Hue[0.8245776989081918, 1, -2.879600145921825], 
     Hue[0.8246211596215169, 1, -2.5054234086219545`], 
     Hue[0.8247166756162086, 1, -2.131325495536971], 
     Hue[0.8249264848418936, 1, -1.7574012490131994`], 
     Hue[0.8253868092253015, 1, -1.383860545591373], 
     Hue[0.826394149249042, 1, -1.0111712315544914`], 
     Hue[0.828585804423341, 1, -0.6403916511466703], 
     Hue[0.8332919733752442, 1, -0.27397988137025586`], 
     Hue[0.8430943497013166, 1, 0.08215120143775911], 
     Hue[0.8620903343694868, 1, 0.4136958832937411], 
     Hue[0.8933333459197472, 1, 0.6908120965387392], 
     Hue[0.9312080880856627, 1, 0.8779333048797267], 
     Hue[0.9624510996359236, 1, 0.9750595083167024], 
     Hue[0.9814470843040942, 1, 1.017757243142693], 
     Hue[0.9912494606301668, 1, 1.03586857701665], 
     Hue[0.9959556295820703, 1, 1.043699223922207], 
     Hue[0.9981472847563693, 1, 1.0471620601963572`], 
     Hue[0.9991546247801097, 1, 1.0487151628414468`], 
     Hue[0.9996149491635177, 1, 1.0494168761015918`], 
     Hue[0.9998247583892026, 1, 1.0497350462597916`], 
     Hue[0.9999202743838943, 1, 1.0498795498567786`], 
     Hue[0.9999637350972195, 1, 1.0499452292388798`], 
     Hue[0.9999835053761872, 1, 1.0499750920655022`], 
     Hue[0.9999924978899984, 1, 1.0499886721296499`], 
     Hue[0.9999965879320506, 1, 1.0499948480853463`], 
     Hue[0.9999984481532311, 1, 1.0499976568854326`], 
     Hue[0.9999992942049613, 1, 1.0499989343356846`], 
     Hue[0.9999996789980066, 1, 1.049999515327646], 
     Hue[0.9999998540054755, 1, 1.0499997795670597`], 
     Hue[0.9999999336004288, 1, 1.0499998997452562`], 
     Hue[0.9999999698009054, 1, 1.0499999544032954`], 
     Hue[0.9999999862651936, 1, 1.0499999792622317`], 
     Hue[0.9999999937532928, 1, 1.0499999905682866`], 
     Hue[0.9999999971589443, 1, 1.0499999957103765`], 
     Hue[0.9999999987078636, 1, 1.0499999980490426`], 
     Hue[0.9999999994123253, 1, 1.049999999112688], 
     Hue[0.9999999997327206, 1, 1.0499999995964429`], 
     Hue[0.999999999878439, 1, 1.0499999998164589`], 
     Hue[0.999999999944713, 1, 1.049999999916524], 
     Hue[0.999999999974855, 1, 1.0499999999620344`], 
     Hue[0.9999999999885638, 1, 1.049999999982733], 
     Hue[0.9999999999947987, 1, 1.0499999999921468`], 
     Hue[0.9999999999976344, 1, 1.0499999999964285`], 
     Hue[0.9999999999989241, 1, 1.0499999999983756`], 
     Hue[0.9999999999995107, 1, 1.0499999999992613`], 
     Hue[0.9999999999997774, 1, 1.049999999999664], 
     Hue[0.9999999999998987, 1, 1.0499999999998473`], 
     Hue[0.9999999999999539, 1, 1.0499999999999305`], 
     Hue[0.999999999999979, 1, 1.0499999999999683`], 
     Hue[0.9999999999999905, 1, 1.0499999999999856`], 
     Hue[0.9999999999999957, 1, 1.0499999999999936`], 
     Hue[0.999999999999998, 1, 1.0499999999999972`], 
     Hue[0.9999999999999991, 1, 1.0499999999999987`], 
     Hue[0.9999999999999996, 1, 1.0499999999999994`], 
     Hue[0.9999999999999998, 1, 1.0499999999999998`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.9499362351203424, 1, -17.474999625757572`], 
     Hue[0.9499362351203424, 1, -17.100757209075603`], 
     Hue[0.9499362351203424, 1, -16.726514792393633`], 
     Hue[0.9499362351203424, 1, -16.35227237571166], 
     Hue[0.9499362351203424, 1, -15.97802995902969], 
     Hue[0.9499362351203424, 1, -15.603787542347721`], 
     Hue[0.9499362351203425, 1, -15.229545125665748`], 
     Hue[0.9499362351203425, 1, -14.855302708983777`], 
     Hue[0.9499362351203428, 1, -14.48106029230181], 
     Hue[0.9499362351203431, 1, -14.106817875619843`], 
     Hue[0.949936235120344, 1, -13.732575458937879`], 
     Hue[0.9499362351203458, 1, -13.358333042255923`], 
     Hue[0.9499362351203497, 1, -12.98409062557399], 
     Hue[0.9499362351203584, 1, -12.609848208892098`], 
     Hue[0.9499362351203775, 1, -12.235605792210302`], 
     Hue[0.9499362351204196, 1, -11.861363375528716`], 
     Hue[0.9499362351205121, 1, -11.487120958847594`], 
     Hue[0.9499362351207155, 1, -11.112878542167488`], 
     Hue[0.9499362351211627, 1, -10.738636125489622`], 
     Hue[0.9499362351221459, 1, -10.364393708816667`], 
     Hue[0.9499362351243078, 1, -9.990151292154527], 
     Hue[0.9499362351290612, 1, -9.615908875516158], 
     Hue[0.9499362351395125, 1, -9.241666458930057], 
     Hue[0.9499362351624923, 1, -8.867424042458875], 
     Hue[0.9499362352130184, 1, -8.493181626240373], 
     Hue[0.9499362353241115, 1, -8.118939210577448], 
     Hue[0.9499362355683751, 1, -7.744696796136078], 
     Hue[0.9499362361054441, 1, -7.370454384380577], 
     Hue[0.9499362372863126, 1, -6.996211978530572], 
     Hue[0.9499362398827202, 1, -6.621969585665138], 
     Hue[0.9499362455915121, 1, -6.247727221349239], 
     Hue[0.9499362581435853, 1, -5.87348491980597], 
     Hue[0.9499362857421519, 1, -5.499242756282543], 
     Hue[0.9499363464237753, 1, -5.12500089622679], 
     Hue[0.9499364798456278, 1, -4.750759703412129], 
     Hue[0.9499367732015025, 1, -4.376519977670919], 
     Hue[0.9499374181994356, 1, -4.002283477586398], 
     Hue[0.9499388363176086, 1, -3.62805406965807], 
     Hue[0.9499419540998647, 1, -3.2538402545599467`], 
     Hue[0.9499488079332197, 1, -2.8796607195513557`], 
     Hue[0.9499638712657644, 1, -2.5055565363612935`], 
     Hue[0.9499969606210943, 1, -2.131617931003313], 
     Hue[0.9500695664937631, 1, -1.7580429020309392`], 
     Hue[0.9502284921645057, 1, -1.3852649448861472`], 
     Hue[0.9505745077748172, 1, -1.0142283239143859`], 
     Hue[0.9513191615651356, 1, -0.6469670203650502], 
     Hue[0.9528823259771594, 1, -0.2877564561259469], 
     Hue[0.9559980363819947, 1, 0.05488154378154941], 
     Hue[0.9616083398458218, 1, 0.3657880464575437], 
     Hue[0.9700614006986077, 1, 0.6237127978451467], 
     Hue[0.9798748344217344, 1, 0.8108340061861334], 
     Hue[0.9883278952745204, 1, 0.9271516714805041], 
     Hue[0.9939381987383475, 1, 0.9904875854864826], 
     Hue[0.9970539091431829, 1, 1.0220920022609585`], 
     Hue[0.9986170735552068, 1, 1.0371238547038268`], 
     Hue[0.9993617273455252, 1, 1.0441049678364627`], 
     Hue[0.9997077429558368, 1, 1.0473107635466727`], 
     Hue[0.9998666686265794, 1, 1.0487752230838518`], 
     Hue[0.9999392744992482, 1, 1.0494426107934491`], 
     Hue[0.999972363854578, 1, 1.04974642211744], 
     Hue[0.9999874271871227, 1, 1.049884655609348], 
     Hue[0.9999942810204777, 1, 1.0499475372827296`], 
     Hue[0.9999973988027339, 1, 1.0499761388665767`], 
     Hue[0.9999988169209069, 1, 1.0499891476202188`], 
     Hue[0.9999994619188399, 1, 1.049995064217669], 
     Hue[0.9999997552747146, 1, 1.049997755158431], 
     Hue[0.9999998886965671, 1, 1.04999897902574], 
     Hue[0.9999999493781905, 1, 1.0499995356519591`], 
     Hue[0.9999999769767572, 1, 1.0499997888105022`], 
     Hue[0.9999999895288304, 1, 1.0499999039492054`], 
     Hue[0.9999999952376223, 1, 1.0499999563152775`], 
     Hue[0.9999999978340299, 1, 1.0499999801318154`], 
     Hue[0.9999999990148983, 1, 1.0499999909637803`], 
     Hue[0.9999999995519674, 1, 1.0499999958902502`], 
     Hue[0.9999999997962309, 1, 1.0499999981308508`], 
     Hue[0.9999999999073241, 1, 1.049999999149895], 
     Hue[0.9999999999578502, 1, 1.049999999613365], 
     Hue[0.9999999999808299, 1, 1.0499999998241552`], 
     Hue[0.9999999999912813, 1, 1.0499999999200242`], 
     Hue[0.9999999999960346, 1, 1.0499999999636265`], 
     Hue[0.9999999999981966, 1, 1.049999999983457], 
     Hue[0.9999999999991798, 1, 1.049999999992476], 
     Hue[0.999999999999627, 1, 1.0499999999965781`], 
     Hue[0.9999999999998304, 1, 1.0499999999984437`], 
     Hue[0.9999999999999228, 1, 1.0499999999992922`], 
     Hue[0.9999999999999649, 1, 1.049999999999678], 
     Hue[0.999999999999984, 1, 1.0499999999998537`], 
     Hue[0.9999999999999928, 1, 1.0499999999999334`], 
     Hue[0.9999999999999967, 1, 1.0499999999999698`], 
     Hue[0.9999999999999984, 1, 1.0499999999999863`], 
     Hue[0.9999999999999993, 1, 1.0499999999999938`], 
     Hue[0.9999999999999997, 1, 1.0499999999999972`], 
     Hue[0.9999999999999999, 1, 1.0499999999999987`], 
     Hue[0.9999999999999999, 1, 1.0499999999999994`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.0753310362352742`, 1, -17.474999625757572`], 
     Hue[1.0753310362352742`, 1, -17.100757209075603`], 
     Hue[1.0753310362352742`, 1, -16.726514792393633`], 
     Hue[1.0753310362352742`, 1, -16.35227237571166], 
     Hue[1.0753310362352742`, 1, -15.97802995902969], 
     Hue[1.0753310362352742`, 1, -15.603787542347721`], 
     Hue[1.0753310362352742`, 1, -15.229545125665748`], 
     Hue[1.075331036235274, 1, -14.855302708983777`], 
     Hue[1.0753310362352737`, 1, -14.48106029230181], 
     Hue[1.0753310362352733`, 1, -14.106817875619841`], 
     Hue[1.075331036235272, 1, -13.732575458937879`], 
     Hue[1.0753310362352693`, 1, -13.358333042255921`], 
     Hue[1.0753310362352635`, 1, -12.984090625573986`], 
     Hue[1.0753310362352506`, 1, -12.609848208892087`], 
     Hue[1.0753310362352224`, 1, -12.235605792210281`], 
     Hue[1.0753310362351605`, 1, -11.861363375528672`], 
     Hue[1.0753310362350241`, 1, -11.487120958847495`], 
     Hue[1.0753310362347246`, 1, -11.11287854216727], 
     Hue[1.0753310362340658`, 1, -10.738636125489139`], 
     Hue[1.0753310362326172`, 1, -10.36439370881561], 
     Hue[1.075331036229432, 1, -9.990151292152198], 
     Hue[1.0753310362224286`, 1, -9.615908875511037], 
     Hue[1.0753310362070305`, 1, -9.2416664589188], 
     Hue[1.075331036173174, 1, -8.867424042434127], 
     Hue[1.0753310360987327`, 1, -8.493181626185955], 
     Hue[1.0753310359350567`, 1, -8.118939210457798], 
     Hue[1.075331035575178, 1, -7.744696795873], 
     Hue[1.0753310347839025`, 1, -7.370454383802138], 
     Hue[1.0753310330441035`, 1, -6.996211977258745], 
     Hue[1.07533102921876, 1, -6.6219695828687355`], 
     Hue[1.0753310208078732`, 1, -6.247727215200714], 
     Hue[1.0753310023146316`, 1, -5.873484906287047], 
     Hue[1.0753309616530626`, 1, -5.499242726558144], 
     Hue[1.0753308722494963`, 1, -5.125000830871087], 
     Hue[1.0753306756761087`, 1, -4.7507595597134635`], 
     Hue[1.075330243468135, 1, -4.376519661720182], 
     Hue[1.0753292931767071`, 1, -4.002282782913582], 
     Hue[1.0753272038227553`, 1, -3.6280525423428456`], 
     Hue[1.0753226102794782`, 1, -3.2538368968014515`], 
     Hue[1.0753125121502518`, 1, -2.8796533386474366`], 
     Hue[1.0752903179138635`, 1, -2.505540316906142], 
     Hue[1.0752415613299338`, 1, -2.131582312977181], 
     Hue[1.0751345639097742`, 1, -1.7579648004721429`], 
     Hue[1.0749002925575337`, 1, -1.385094243188867], 
     Hue[1.0743899186814603`, 1, -1.013857873833713], 
     Hue[1.0732901120537082`, 1, -0.6461753939062671], 
     Hue[1.0709752196571194`, 1, -0.28611972871963465`], 
     Hue[1.0663378210592684`, 1, 0.05804197571891889], 
     Hue[1.0579204852526174`, 1, 0.3711348509788738], 
     Hue[1.0451244162539186`, 1, 0.6309452015199752], 
     Hue[1.0302066199813562`, 1, 0.8180664098609622], 
     Hue[1.0174105509826572`, 1, 0.9324984760018343], 
     Hue[1.008993215176006, 1, 0.9936480174238523], 
     Hue[1.0043558165781548`, 1, 1.023728729667271], 
     Hue[1.0020409241815662`, 1, 1.03791548116261], 
     Hue[1.000941117553814, 1, 1.0444754179171358`], 
     Hue[1.0004307436777404`, 1, 1.0474814652439524`], 
     Hue[1.0001964723255, 1, 1.0488533246426481`], 
     Hue[1.0000894749053406`, 1, 1.0494782288195814`], 
     Hue[1.0000407183214108`, 1, 1.0497626415725918`], 
     Hue[1.0000185240850223`, 1, 1.0498920365132678`], 
     Hue[1.000008425955796, 1, 1.0499508950412244`], 
     Hue[1.000003832412519, 1, 1.0499776661818014`], 
     Hue[1.000001743058567, 1, 1.049989842293035], 
     Hue[1.000000792767139, 1, 1.049995380168407], 
     Hue[1.0000003605591654`, 1, 1.0499978988570962`], 
     Hue[1.0000001639857778`, 1, 1.0499990443814444`], 
     Hue[1.0000000745822115`, 1, 1.049999565376358], 
     Hue[1.0000000339206425`, 1, 1.049999802329426], 
     Hue[1.000000015427401, 1, 1.0499999100977302`], 
     Hue[1.0000000070165143`, 1, 1.0499999591116798`], 
     Hue[1.0000000031911707`, 1, 1.0499999814036431`], 
     Hue[1.0000000014513717`, 1, 1.0499999915422182`], 
     Hue[1.0000000006600962`, 1, 1.0499999961533288`], 
     Hue[1.0000000003002174`, 1, 1.049999998250501], 
     Hue[1.0000000001365414`, 1, 1.049999999204313], 
     Hue[1.0000000000621, 1, 1.0499999996381149`], 
     Hue[1.0000000000282436`, 1, 1.0499999998354115`], 
     Hue[1.0000000000128455`, 1, 1.0499999999251437`], 
     Hue[1.0000000000058422`, 1, 1.0499999999659548`], 
     Hue[1.0000000000026572`, 1, 1.049999999984516], 
     Hue[1.0000000000012084`, 1, 1.0499999999929577`], 
     Hue[1.0000000000005496`, 1, 1.0499999999967973`], 
     Hue[1.00000000000025, 1, 1.0499999999985434`], 
     Hue[1.0000000000001137`, 1, 1.0499999999993375`], 
     Hue[1.0000000000000517`, 1, 1.0499999999996987`], 
     Hue[1.0000000000000235`, 1, 1.049999999999863], 
     Hue[1.0000000000000107`, 1, 1.0499999999999376`], 
     Hue[1.0000000000000049`, 1, 1.0499999999999716`], 
     Hue[1.0000000000000022`, 1, 1.0499999999999872`], 
     Hue[1.000000000000001, 1, 1.049999999999994], 
     Hue[1.0000000000000004`, 1, 1.0499999999999974`], 
     Hue[1.0000000000000002`, 1, 1.049999999999999], 
     Hue[1., 1, 1.0499999999999996`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.2007258373502059`, 1, -17.474999625757572`], 
     Hue[1.2007258373502059`, 1, -17.100757209075603`], 
     Hue[1.2007258373502059`, 1, -16.726514792393633`], 
     Hue[1.2007258373502059`, 1, -16.35227237571166], 
     Hue[1.2007258373502059`, 1, -15.97802995902969], 
     Hue[1.2007258373502059`, 1, -15.603787542347721`], 
     Hue[1.2007258373502057`, 1, -15.229545125665748`], 
     Hue[1.2007258373502054`, 1, -14.855302708983777`], 
     Hue[1.200725837350205, 1, -14.481060292301807`], 
     Hue[1.2007258373502039`, 1, -14.106817875619837`], 
     Hue[1.2007258373502012`, 1, -13.73257545893787], 
     Hue[1.2007258373501957`, 1, -13.358333042255902`], 
     Hue[1.2007258373501837`, 1, -12.984090625573945`], 
     Hue[1.2007258373501568`, 1, -12.609848208891998`], 
     Hue[1.200725837350098, 1, -12.235605792210082`], 
     Hue[1.2007258373499683`, 1, -11.861363375528235`], 
     Hue[1.2007258373496836`, 1, -11.487120958846536`], 
     Hue[1.2007258373490575`, 1, -11.112878542165163`], 
     Hue[1.2007258373476808`, 1, -10.738636125484506`], 
     Hue[1.200725837344654, 1, -10.364393708805425`], 
     Hue[1.200725837337999, 1, -9.990151292129807], 
     Hue[1.200725837323366, 1, -9.615908875461805], 
     Hue[1.2007258372911924`, 1, -9.241666458810553], 
     Hue[1.2007258372204512`, 1, -8.867424042196118], 
     Hue[1.2007258370649108`, 1, -8.493181625662642], 
     Hue[1.2007258367229199`, 1, -8.11893920930717], 
     Hue[1.200725835970975, 1, -7.74469679334308], 
     Hue[1.2007258343176526`, 1, -7.370454378239539], 
     Hue[1.2007258306824478`, 1, -6.996211965028105], 
     Hue[1.200725822689623, 1, -6.621969555976894], 
     Hue[1.2007258051155807`, 1, -6.24772715607289], 
     Hue[1.200725766475055, 1, -5.873484776281114], 
     Hue[1.2007256815150913`, 1, -5.499242440710721], 
     Hue[1.2007254947113866`, 1, -5.12500020237143], 
     Hue[1.200725083981442, 1, -4.750758177818477], 
     Hue[1.2007241809006135`, 1, -4.376516623331334], 
     Hue[1.200722195283514, 1, -4.002276102429096], 
     Hue[1.2007178295083831`, 1, -3.6280378542834892`], 
     Hue[1.2007082306281367`, 1, -3.253804604205129], 
     Hue[1.200687126609394, 1, -2.879582347839605], 
     Hue[1.200640730924871, 1, -2.5053842845536964`], 
     Hue[1.2005387499449909`, 1, -2.1312395162164597`], 
     Hue[1.200314669193527, 1, -1.7572124161259939`], 
     Hue[1.1998226930090516`, 1, -1.3834463820600622`], 
     Hue[1.1987444617965173`, 1, -1.0102655982477031`], 
     Hue[1.1963908799779446`, 1, -0.638424848100954], 
     Hue[1.1913016879035514`, 1, -0.2697759650539131], 
     Hue[1.1805503295118447`, 1, 0.09079587965308122], 
     Hue[1.1591748115305351`, 1, 0.4298256067678148], 
     Hue[1.122807065454081, 1, 0.7147584177240006], 
     Hue[1.0779187718961265`, 1, 0.9018796260649882], 
     Hue[1.0415510258196718`, 1, 0.9911892317907762], 
     Hue[1.0201755078383616`, 1, 1.0264019213580153`], 
     Hue[1.0094241494466547`, 1, 1.0400724933329928`], 
     Hue[1.0043349573722615`, 1, 1.0456660269679234`], 
     Hue[1.0019813755536886`, 1, 1.0480676935031457`], 
     Hue[1.0009031443411542`, 1, 1.0491293263727577`], 
     Hue[1.000411168156679, 1, 1.0496057089887973`], 
     Hue[1.000187087405215, 1, 1.0498210255803027`], 
     Hue[1.0000851064253349`, 1, 1.049918673925037], 
     Hue[1.000038710740812, 1, 1.0499630273210987`], 
     Hue[1.0000176067220692`, 1, 1.0499831876375474`], 
     Hue[1.0000080078418228`, 1, 1.0499923542411576`], 
     Hue[1.0000036420666918`, 1, 1.049996522777522], 
     Hue[1.0000016564495924`, 1, 1.0499984185572553`], 
     Hue[1.0000007533687638`, 1, 1.0499992807520837`], 
     Hue[1.0000003426388195`, 1, 1.0499996728811003`], 
     Hue[1.0000001558351148`, 1, 1.0499998512237807`], 
     Hue[1.0000000708751509`, 1, 1.0499999323353577`], 
     Hue[1.0000000322346254`, 1, 1.0499999692255544`], 
     Hue[1.000000014660583, 1, 1.049999986003522], 
     Hue[1.0000000066677581`, 1, 1.049999993634283], 
     Hue[1.0000000030325533`, 1, 1.0499999971048177`], 
     Hue[1.0000000013792312`, 1, 1.0499999986832464`], 
     Hue[1.000000000627286, 1, 1.0499999994011293`], 
     Hue[1.0000000002852951`, 1, 1.0499999997276286`], 
     Hue[1.0000000001297547`, 1, 1.0499999998761231`], 
     Hue[1.0000000000590135`, 1, 1.0499999999436598`], 
     Hue[1.0000000000268399`, 1, 1.049999999974376], 
     Hue[1.000000000012207, 1, 1.049999999988346], 
     Hue[1.0000000000055518`, 1, 1.0499999999946996`], 
     Hue[1.000000000002525, 1, 1.0499999999975893`], 
     Hue[1.0000000000011484`, 1, 1.0499999999989036`], 
     Hue[1.0000000000005222`, 1, 1.0499999999995013`], 
     Hue[1.0000000000002376`, 1, 1.0499999999997733`], 
     Hue[1.0000000000001081`, 1, 1.0499999999998968`], 
     Hue[1.000000000000049, 1, 1.0499999999999532`], 
     Hue[1.0000000000000224`, 1, 1.0499999999999787`], 
     Hue[1.0000000000000102`, 1, 1.0499999999999903`], 
     Hue[1.0000000000000047`, 1, 1.0499999999999956`], 
     Hue[1.000000000000002, 1, 1.049999999999998], 
     Hue[1.0000000000000009`, 1, 1.0499999999999992`], 
     Hue[1.0000000000000004`, 1, 1.0499999999999996`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.3261206384651372`, 1, -17.474999625757572`], 
     Hue[1.3261206384651372`, 1, -17.100757209075603`], 
     Hue[1.326120638465137, 1, -16.726514792393633`], 
     Hue[1.3261206384651372`, 1, -16.35227237571166], 
     Hue[1.326120638465137, 1, -15.97802995902969], 
     Hue[1.326120638465137, 1, -15.603787542347721`], 
     Hue[1.326120638465137, 1, -15.229545125665748`], 
     Hue[1.3261206384651367`, 1, -14.855302708983777`], 
     Hue[1.3261206384651363`, 1, -14.481060292301807`], 
     Hue[1.3261206384651352`, 1, -14.106817875619832`], 
     Hue[1.3261206384651327`, 1, -13.732575458937857`], 
     Hue[1.3261206384651276`, 1, -13.358333042255877`], 
     Hue[1.3261206384651163`, 1, -12.984090625573891`], 
     Hue[1.3261206384650914`, 1, -12.609848208891881`], 
     Hue[1.3261206384650364`, 1, -12.235605792209824`], 
     Hue[1.3261206384649156`, 1, -11.861363375527667`], 
     Hue[1.3261206384646502`, 1, -11.487120958845285`], 
     Hue[1.3261206384640667`, 1, -11.112878542162411`], 
     Hue[1.3261206384627835`, 1, -10.738636125478456`], 
     Hue[1.3261206384599622`, 1, -10.364393708792118`], 
     Hue[1.326120638453759, 1, -9.990151292100549], 
     Hue[1.3261206384401196`, 1, -9.615908875397473], 
     Hue[1.3261206384101305`, 1, -9.241666458669103], 
     Hue[1.3261206383441924`, 1, -8.867424041885108], 
     Hue[1.3261206381992126`, 1, -8.493181624978817], 
     Hue[1.3261206378804413`, 1, -8.118939207803628], 
     Hue[1.3261206371795504`, 1, -7.744696790037202], 
     Hue[1.3261206356384823`, 1, -7.370454370970813], 
     Hue[1.3261206322500938`, 1, -6.996211949046153], 
     Hue[1.3261206247999502`, 1, -6.621969520836939], 
     Hue[1.3261206084191135`, 1, -6.247727078809707], 
     Hue[1.3261205724021117`, 1, -5.8734846064004245`], 
     Hue[1.3261204932105108`, 1, -5.499242067189347], 
     Hue[1.3261203190896187`, 1, -5.124999381099564], 
     Hue[1.3261199362445344`, 1, -4.7507563720647], 
     Hue[1.3261190944691719`, 1, -4.376512652967215], 
     Hue[1.3261172436183226`, 1, -4.00226737266264], 
     Hue[1.326113174023234, 1, -3.6280186598201745`], 
     Hue[1.3261042257133226`, 1, -3.2537624003958667`], 
     Hue[1.3260845489844322`, 1, -2.879489551158377], 
     Hue[1.3260412763540188`, 1, -2.5051802402636296`], 
     Hue[1.3259460887761718`, 1, -2.1307908318757116`], 
     Hue[1.3257365901057934`, 1, -1.7562256589336778`], 
     Hue[1.3252749589161659`, 1, -1.3812757219035678`], 
     Hue[1.3242551270538503`, 1, -1.0054881108585654`], 
     Hue[1.3219895271943625`, 1, -0.6279002470403383], 
     Hue[1.3168967628506705`, 1, -0.2465696384510092], 
     Hue[1.305179341159688, 1, 0.14179064370446215`], 
     Hue[1.2772543870406554`, 1, 0.5381731494940653], 
     Hue[1.212330033387359, 1, 0.9059833923476305], 
     Hue[1.1137906050777813`, 1, 1.0931046006886205`], 
     Hue[1.048866251424483, 1, 1.0995367745170297`], 
     Hue[1.02094129730545, 1, 1.0773966854093977`], 
     Hue[1.009223875614467, 1, 1.0632788199358976`], 
     Hue[1.0041311112707747`, 1, 1.0561906280285391`], 
     Hue[1.0018655114112869`, 1, 1.0528451808922836`], 
     Hue[1.0008456795489713`, 1, 1.051299986529252], 
     Hue[1.0003840483593438`, 1, 1.0505924661811135`], 
     Hue[1.0001745496889654`, 1, 1.0502697099210505`], 
     Hue[1.0000793621111181`, 1, 1.0501227182151036`], 
     Hue[1.0000360894807048`, 1, 1.0500558240023272`], 
     Hue[1.0000164127518145`, 1, 1.0500253914468096`], 
     Hue[1.000007464441903, 1, 1.0500115487044723`], 
     Hue[1.0000033948468143`, 1, 1.050005252543977], 
     Hue[1.000001543995965, 1, 1.0500023889213739`], 
     Hue[1.0000007022206026`, 1, 1.05000108650586], 
     Hue[1.0000003193755185`, 1, 1.0500004941529664`], 
     Hue[1.0000001452546263`, 1, 1.0500002247451552`], 
     Hue[1.0000000660630253`, 1, 1.0500001022160486`], 
     Hue[1.0000000300460237`, 1, 1.0500000464887378`], 
     Hue[1.000000013665187, 1, 1.050000021143476], 
     Hue[1.0000000062150434`, 1, 1.0500000096162334`], 
     Hue[1.0000000028266547`, 1, 1.0500000043735451`], 
     Hue[1.0000000012855867`, 1, 1.0500000019891256`], 
     Hue[1.0000000005846958`, 1, 1.0500000009046713`], 
     Hue[1.0000000002659246`, 1, 1.0500000004114523`], 
     Hue[1.0000000001209448`, 1, 1.0500000001871321`], 
     Hue[1.0000000000550067`, 1, 1.0500000000851093`], 
     Hue[1.0000000000250175`, 1, 1.0500000000387084`], 
     Hue[1.0000000000113782`, 1, 1.050000000017605], 
     Hue[1.000000000005175, 1, 1.050000000008007], 
     Hue[1.0000000000023537`, 1, 1.0500000000036416`], 
     Hue[1.0000000000010705`, 1, 1.0500000000016563`], 
     Hue[1.000000000000487, 1, 1.0500000000007532`], 
     Hue[1.0000000000002214`, 1, 1.0500000000003427`], 
     Hue[1.0000000000001008`, 1, 1.050000000000156], 
     Hue[1.0000000000000457`, 1, 1.0500000000000709`], 
     Hue[1.0000000000000209`, 1, 1.0500000000000322`], 
     Hue[1.0000000000000095`, 1, 1.0500000000000147`], 
     Hue[1.0000000000000042`, 1, 1.0500000000000067`], 
     Hue[1.000000000000002, 1, 1.0500000000000032`], 
     Hue[1.0000000000000009`, 1, 1.0500000000000014`], 
     Hue[1.0000000000000004`, 1, 1.0500000000000007`], 
     Hue[1.0000000000000002`, 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.451515439580069, 1, -17.474999625757572`], 
     Hue[1.451515439580069, 1, -17.100757209075603`], 
     Hue[1.451515439580069, 1, -16.726514792393633`], 
     Hue[1.451515439580069, 1, -16.35227237571166], 
     Hue[1.451515439580069, 1, -15.97802995902969], 
     Hue[1.451515439580069, 1, -15.603787542347721`], 
     Hue[1.451515439580069, 1, -15.229545125665748`], 
     Hue[1.4515154395800687`, 1, -14.855302708983777`], 
     Hue[1.4515154395800685`, 1, -14.481060292301803`], 
     Hue[1.451515439580068, 1, -14.106817875619829`], 
     Hue[1.4515154395800673`, 1, -13.73257545893785], 
     Hue[1.4515154395800656`, 1, -13.358333042255863`], 
     Hue[1.4515154395800618`, 1, -12.984090625573856`], 
     Hue[1.4515154395800534`, 1, -12.609848208891805`], 
     Hue[1.4515154395800347`, 1, -12.235605792209657`], 
     Hue[1.4515154395799938`, 1, -11.861363375527299`], 
     Hue[1.4515154395799044`, 1, -11.487120958844477`], 
     Hue[1.4515154395797072`, 1, -11.112878542160635`], 
     Hue[1.4515154395792735`, 1, -10.738636125474548`], 
     Hue[1.4515154395783205`, 1, -10.36439370878353], 
     Hue[1.4515154395762246`, 1, -9.990151292081665], 
     Hue[1.4515154395716163`, 1, -9.61590887535595], 
     Hue[1.4515154395614842`, 1, -9.241666458577809], 
     Hue[1.4515154395392065`, 1, -8.867424041684377], 
     Hue[1.4515154394902237`, 1, -8.493181624537462], 
     Hue[1.4515154393825238`, 1, -8.118939206833208], 
     Hue[1.4515154391457215`, 1, -7.744696787903513], 
     Hue[1.4515154386250573`, 1, -7.37045436627941], 
     Hue[1.4515154374802586`, 1, -6.9962119387310375`], 
     Hue[1.4515154349631583`, 1, -6.621969498156811], 
     Hue[1.4515154294287398`, 1, -6.247727028942276], 
     Hue[1.451515417260057, 1, -5.873484496755496], 
     Hue[1.4515153905044196`, 1, -5.499241826109839], 
     Hue[1.4515153316759635`, 1, -5.124998851030502], 
     Hue[1.451515202327735, 1, -4.750755206582824], 
     Hue[1.451514917923879, 1, -4.376510090368604], 
     Hue[1.45151429258594, 1, -4.002261738102292], 
     Hue[1.4515129175832728`, 1, -3.628006270452918], 
     Hue[1.451509894061407, 1, -3.2537351571140025`], 
     Hue[1.4515032448759175`, 1, -2.879429638809772], 
     Hue[1.4514886189144844`, 1, -2.5050484522892775`], 
     Hue[1.4514564303362423`, 1, -2.130500790038914], 
     Hue[1.4513855106995879`, 1, -1.755586599501963], 
     Hue[1.4512288697186972`, 1, -1.3798641199191912`], 
     Hue[1.4508809980293371`, 1, -1.002352784797828], 
     Hue[1.450098978018147, 1, -0.6208510885721548], 
     Hue[1.4482919947797745`, 1, -0.23029016155583415`], 
     Hue[1.4438397261890485`, 1, 0.18167321562513494`], 
     Hue[1.4309323327287804`, 1, 0.6490770037493812], 
     Hue[1.3694033890412873`, 1, 1.2863558659719343`], 
     Hue[1.082112050538787, 1, 1.4734770743129415`], 
     Hue[1.0205831068512892`, 1, 1.21044062877235], 
     Hue[1.0076757133910204`, 1, 1.1172792573300716`], 
     Hue[1.0032234448002944`, 1, 1.0795582968310728`], 
     Hue[1.0014164615619217`, 1, 1.0632397864967231`], 
     Hue[1.0006344415507316`, 1, 1.0559805069530208`], 
     Hue[1.0002865698613714`, 1, 1.052711588513629], 
     Hue[1.000129928880481, 1, 1.0512315256128284`], 
     Hue[1.0000590092438264`, 1, 1.0505597517578482`], 
     Hue[1.0000268206655845`, 1, 1.0502545061894566`], 
     Hue[1.0000121947041511`, 1, 1.0501157363509317`], 
     Hue[1.0000055455186618`, 1, 1.0500526347286736`], 
     Hue[1.000002521996796, 1, 1.050023938071729], 
     Hue[1.0000011469941288`, 1, 1.050010887104325], 
     Hue[1.0000005216561898`, 1, 1.0500049515199852`], 
     Hue[1.000000237252334, 1, 1.0500022519877363`], 
     Hue[1.0000001079041052`, 1, 1.0500010242220288`], 
     Hue[1.0000000490756493`, 1, 1.0500004658246638`], 
     Hue[1.0000000223200118`, 1, 1.0500002118609775`], 
     Hue[1.000000010151329, 1, 1.0500000963561682`], 
     Hue[1.0000000046169106`, 1, 1.0500000438236046`], 
     Hue[1.00000000209981, 1, 1.0500000199313486`], 
     Hue[1.0000000009550116`, 1, 1.0500000090649473`], 
     Hue[1.0000000004343474`, 1, 1.0500000041228152`], 
     Hue[1.0000000001975449`, 1, 1.0500000018750917`], 
     Hue[1.000000000089845, 1, 1.0500000008528076`], 
     Hue[1.0000000000408624`, 1, 1.0500000003878642`], 
     Hue[1.0000000000185845`, 1, 1.050000000176404], 
     Hue[1.0000000000084523`, 1, 1.05000000008023], 
     Hue[1.0000000000038443`, 1, 1.0500000000364893`], 
     Hue[1.0000000000017484`, 1, 1.0500000000165957`], 
     Hue[1.0000000000007951`, 1, 1.0500000000075478`], 
     Hue[1.0000000000003617`, 1, 1.0500000000034329`], 
     Hue[1.0000000000001645`, 1, 1.0500000000015612`], 
     Hue[1.0000000000000748`, 1, 1.0500000000007101`], 
     Hue[1.000000000000034, 1, 1.050000000000323], 
     Hue[1.0000000000000155`, 1, 1.050000000000147], 
     Hue[1.000000000000007, 1, 1.0500000000000669`], 
     Hue[1.000000000000003, 1, 1.0500000000000305`], 
     Hue[1.0000000000000016`, 1, 1.0500000000000138`], 
     Hue[1.0000000000000007`, 1, 1.0500000000000063`], 
     Hue[1.0000000000000002`, 1, 1.050000000000003], 
     Hue[1.0000000000000002`, 1, 1.0500000000000014`], 
     Hue[1., 1, 1.0500000000000007`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.5769102406950004, 1, -17.474999625757572`], 
     Hue[0.5769102406950004, 1, -17.100757209075603`], 
     Hue[0.5769102406950004, 1, -16.726514792393633`], 
     Hue[0.5769102406950004, 1, -16.35227237571166], 
     Hue[0.5769102406950006, 1, -15.97802995902969], 
     Hue[0.5769102406950006, 1, -15.603787542347721`], 
     Hue[0.5769102406950006, 1, -15.229545125665748`], 
     Hue[0.5769102406950006, 1, -14.855302708983777`], 
     Hue[0.576910240695001, 1, -14.481060292301803`], 
     Hue[0.5769102406950015, 1, -14.10681787561983], 
     Hue[0.5769102406950027, 1, -13.73257545893785], 
     Hue[0.5769102406950054, 1, -13.358333042255865`], 
     Hue[0.5769102406950113, 1, -12.98409062557386], 
     Hue[0.5769102406950244, 1, -12.609848208891814`], 
     Hue[0.5769102406950533, 1, -12.235605792209679`], 
     Hue[0.5769102406951163, 1, -11.86136337552735], 
     Hue[0.5769102406952553, 1, -11.487120958844589`], 
     Hue[0.5769102406955607, 1, -11.11287854216088], 
     Hue[0.5769102406962323, 1, -10.73863612547509], 
     Hue[0.5769102406977089, 1, -10.364393708784721`], 
     Hue[0.5769102407009556, 1, -9.990151292084283], 
     Hue[0.5769102407080942, 1, -9.61590887536171], 
     Hue[0.57691024072379, 1, -9.241666458590469], 
     Hue[0.5769102407583007, 1, -8.867424041712212], 
     Hue[0.5769102408341806, 1, -8.493181624598664], 
     Hue[0.5769102410010194, 1, -8.118939206967775], 
     Hue[0.5769102413678528, 1, -7.744696788199392], 
     Hue[0.5769102421744194, 1, -7.3704543669299705`], 
     Hue[0.5769102439478395, 1, -6.9962119401614435`], 
     Hue[0.5769102478471073, 1, -6.621969501301886], 
     Hue[0.5769102564205357, 1, -6.247727035857442], 
     Hue[0.5769102752711748, 1, -5.873484511960067], 
     Hue[0.5769103167186224, 1, -5.499241859540582], 
     Hue[0.576910407850409, 1, -5.124998924535763], 
     Hue[0.5769106082250715, 1, -4.750755368201667], 
     Hue[0.5769110487977278, 1, -4.3765104457282895`], 
     Hue[0.576912017513278, 1, -4.002262519460222], 
     Hue[0.576914147533801, 1, -3.6280079885370853`], 
     Hue[0.5769188312505311, 1, -3.2537389351529473`], 
     Hue[0.5769291313146903, 1, -2.8794379478158936`], 
     Hue[0.5769517872839796, 1, -2.5050667318233373`], 
     Hue[0.5770016448215408, 1, -2.130541031581366], 
     Hue[0.5771114773907787, 1, -1.7556753212531866`], 
     Hue[0.5773539861746191, 1, -1.3800603699079728`], 
     Hue[0.5778921603836901, 1, -1.0027900432480539`], 
     Hue[0.5790999680499413, 1, -0.6218411867848874], 
     Hue[0.5818797976866306, 1, -0.2326154010909005], 
     Hue[0.5886589480731228, 1, 0.175726255869465], 
     Hue[0.607661860533288, 1, 0.6302432381489005], 
     Hue[0.6821304382125474, 1, 1.18238544103446], 
     Hue[0.8947798024824478, 1, 1.3695066493754595`], 
     Hue[0.9692483801617112, 1, 1.1916068631718684`], 
     Hue[0.9882512926218773, 1, 1.1113322975744018`], 
     Hue[0.9950304430083698, 1, 1.0772330572960067`], 
     Hue[0.9978102726450591, 1, 1.06224968828399], 
     Hue[0.9990180803113105, 1, 1.0555432485027947`], 
     Hue[0.9995562545203813, 1, 1.052515338524847], 
     Hue[0.9997987633042218, 1, 1.0511428038616046`], 
     Hue[0.9999085958734597, 1, 1.050519510215396], 
     Hue[0.9999584534110209, 1, 1.050236226655396], 
     Hue[0.9999811093803103, 1, 1.05010742734481], 
     Hue[0.9999914094444694, 1, 1.050048856689729], 
     Hue[0.9999960931611995, 1, 1.050022219987561], 
     Hue[0.9999982231817224, 1, 1.050010105746395], 
     Hue[0.9999991918972727, 1, 1.0500045961602997`], 
     Hue[0.9999996324699291, 1, 1.050002090368893], 
     Hue[0.9999998328445915, 1, 1.0500009507167674`], 
     Hue[0.999999923976378, 1, 1.05000043239392], 
     Hue[0.9999999654238257, 1, 1.0500001966564059`], 
     Hue[0.9999999842744648, 1, 1.0500000894410026`], 
     Hue[0.9999999928478932, 1, 1.050000040678529], 
     Hue[0.999999996747161, 1, 1.0500000185009415`], 
     Hue[0.9999999985205811, 1, 1.050000008414386], 
     Hue[0.9999999993271477, 1, 1.0500000038269344`], 
     Hue[0.999999999693981, 1, 1.0500000017405224`], 
     Hue[0.99999999986082, 1, 1.0500000007916044`], 
     Hue[0.9999999999366997, 1, 1.0500000003600285`], 
     Hue[0.9999999999712105, 1, 1.050000000163744], 
     Hue[0.9999999999869063, 1, 1.0500000000744723`], 
     Hue[0.9999999999940449, 1, 1.0500000000338707`], 
     Hue[0.9999999999972916, 1, 1.0500000000154048`], 
     Hue[0.9999999999987682, 1, 1.0500000000070062`], 
     Hue[0.9999999999994398, 1, 1.0500000000031866`], 
     Hue[0.9999999999997452, 1, 1.0500000000014493`], 
     Hue[0.9999999999998841, 1, 1.0500000000006593`], 
     Hue[0.9999999999999473, 1, 1.0500000000002998`], 
     Hue[0.999999999999976, 1, 1.0500000000001364`], 
     Hue[0.9999999999999891, 1, 1.050000000000062], 
     Hue[0.999999999999995, 1, 1.0500000000000282`], 
     Hue[0.9999999999999978, 1, 1.050000000000013], 
     Hue[0.999999999999999, 1, 1.050000000000006], 
     Hue[0.9999999999999996, 1, 1.0500000000000027`], 
     Hue[0.9999999999999998, 1, 1.0500000000000014`], 
     Hue[0.9999999999999999, 1, 1.0500000000000005`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.7023050418099317, 1, -17.474999625757572`], 
     Hue[0.7023050418099317, 1, -17.100757209075603`], 
     Hue[0.7023050418099317, 1, -16.726514792393633`], 
     Hue[0.7023050418099317, 1, -16.35227237571166], 
     Hue[0.7023050418099317, 1, -15.97802995902969], 
     Hue[0.7023050418099317, 1, -15.603787542347721`], 
     Hue[0.7023050418099319, 1, -15.229545125665748`], 
     Hue[0.7023050418099321, 1, -14.855302708983777`], 
     Hue[0.7023050418099326, 1, -14.481060292301807`], 
     Hue[0.7023050418099337, 1, -14.106817875619834`], 
     Hue[0.7023050418099364, 1, -13.732575458937859`], 
     Hue[0.7023050418099419, 1, -13.358333042255882`], 
     Hue[0.7023050418099541, 1, -12.984090625573902`], 
     Hue[0.702305041809981, 1, -12.609848208891906`], 
     Hue[0.70230504181004, 1, -12.23560579220988], 
     Hue[0.70230504181017, 1, -11.861363375527791`], 
     Hue[0.7023050418104556, 1, -11.487120958845555`], 
     Hue[0.7023050418110837, 1, -11.112878542163003`], 
     Hue[0.7023050418124646, 1, -10.738636125479761`], 
     Hue[0.7023050418155008, 1, -10.36439370879499], 
     Hue[0.7023050418221768, 1, -9.990151292106862], 
     Hue[0.7023050418368554, 1, -9.615908875411353], 
     Hue[0.7023050418691296, 1, -9.241666458699621], 
     Hue[0.7023050419400918, 1, -8.867424041952212], 
     Hue[0.7023050420961182, 1, -8.49318162512636], 
     Hue[0.7023050424391779, 1, -8.118939208128033], 
     Hue[0.7023050431934725, 1, -7.744696790750482], 
     Hue[0.702305044851961, 1, -7.370454372539119], 
     Hue[0.7023050484985252, 1, -6.996211952494437], 
     Hue[0.7023050565163262, 1, -6.621969528418776], 
     Hue[0.7023050741452865, 1, -6.2477270954801005`], 
     Hue[0.7023051129065703, 1, -5.873484643054083], 
     Hue[0.70230519813209, 1, -5.499242147780788], 
     Hue[0.7023053855198811, 1, -5.124999558298345], 
     Hue[0.702305797535045, 1, -4.750756761677325], 
     Hue[0.7023067034464231, 1, -4.376513509623053], 
     Hue[0.7023086953098641, 1, -4.002269256234007], 
     Hue[0.7023130749289036, 1, -3.628022801370391], 
     Hue[0.7023227047794599, 1, -3.2537715069716917`], 
     Hue[0.7023438794621177, 1, -2.8795095761423655`], 
     Hue[0.7023904429351002, 1, -2.505224279922542], 
     Hue[0.7024928528675219, 1, -2.130887712253826], 
     Hue[0.7027181669723074, 1, -1.7564389099027082`], 
     Hue[0.7032142577561981, 1, -1.3817457473469206`], 
     Hue[0.7043083148805387, 1, -1.00652706857638], 
     Hue[0.7067294187969749, 1, -0.6302108363763796], 
     Hue[0.7121243276470158, 1, -0.2517720501708498], 
     Hue[0.7242877408312005, 1, 0.1298240541001927], 
     Hue[0.7519171741041535, 1, 0.5102579069371466], 
     Hue[0.810129805667723, 1, 0.8497959657232458], 
     Hue[0.892175236142206, 1, 1.0369171740642347`], 
     Hue[0.9503878677057768, 1, 1.0716215319601101`], 
     Hue[0.9780173009787305, 1, 1.0654300958051277`], 
     Hue[0.9901807141629155, 1, 1.0580764082160568`], 
     Hue[0.9955756230129567, 1, 1.053880038692498], 
     Hue[0.9979967269293929, 1, 1.0518062231744683`], 
     Hue[0.9990907840537335, 1, 1.0508299610858995`], 
     Hue[0.9995868748376243, 1, 1.050379215212083], 
     Hue[0.9998121889424098, 1, 1.0501728295429358`], 
     Hue[0.9999145988748315, 1, 1.0500786785561915`], 
     Hue[0.9999611623478138, 1, 1.0500357990183382`], 
     Hue[0.9999823370304718, 1, 1.0500162848709842`], 
     Hue[0.9999919668810281, 1, 1.0500074071542556`], 
     Hue[0.9999963465000676, 1, 1.0500033689726105`], 
     Hue[0.9999983383635086, 1, 1.0500015322655352`], 
     Hue[0.9999992442748867, 1, 1.0500006968932347`], 
     Hue[0.9999996562900506, 1, 1.0500003169541856`], 
     Hue[0.9999998436778416, 1, 1.0500001441537141`], 
     Hue[0.9999999289033614, 1, 1.0500000655623898`], 
     Hue[0.999999967664645, 1, 1.0500000298183443`], 
     Hue[0.9999999852936055, 1, 1.0500000135616394`], 
     Hue[0.9999999933114064, 1, 1.0500000061679498`], 
     Hue[0.9999999969579707, 1, 1.0500000028052363`], 
     Hue[0.9999999986164592, 1, 1.0500000012758453`], 
     Hue[0.9999999993707538, 1, 1.0500000005802654`], 
     Hue[0.9999999997138135, 1, 1.0500000002639098`], 
     Hue[0.9999999998698399, 1, 1.0500000001200285`], 
     Hue[0.9999999999408021, 1, 1.05000000005459], 
     Hue[0.9999999999730763, 1, 1.050000000024828], 
     Hue[0.9999999999877549, 1, 1.050000000011292], 
     Hue[0.9999999999944308, 1, 1.0500000000051357`], 
     Hue[0.9999999999974671, 1, 1.0500000000023357`], 
     Hue[0.999999999998848, 1, 1.0500000000010623`], 
     Hue[0.9999999999994761, 1, 1.0500000000004832`], 
     Hue[0.9999999999997617, 1, 1.0500000000002199`], 
     Hue[0.9999999999998916, 1, 1.0500000000001], 
     Hue[0.9999999999999507, 1, 1.0500000000000456`], 
     Hue[0.9999999999999776, 1, 1.0500000000000207`], 
     Hue[0.9999999999999898, 1, 1.0500000000000094`], 
     Hue[0.9999999999999953, 1, 1.0500000000000043`], 
     Hue[0.9999999999999979, 1, 1.050000000000002], 
     Hue[0.999999999999999, 1, 1.050000000000001], 
     Hue[0.9999999999999996, 1, 1.0500000000000005`], 
     Hue[0.9999999999999998, 1, 1.0500000000000003`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.8276998429248634, 1, -17.474999625757572`], 
     Hue[0.8276998429248634, 1, -17.100757209075603`], 
     Hue[0.8276998429248634, 1, -16.726514792393633`], 
     Hue[0.8276998429248634, 1, -16.35227237571166], 
     Hue[0.8276998429248634, 1, -15.97802995902969], 
     Hue[0.8276998429248634, 1, -15.603787542347721`], 
     Hue[0.8276998429248636, 1, -15.229545125665748`], 
     Hue[0.8276998429248639, 1, -14.855302708983777`], 
     Hue[0.8276998429248643, 1, -14.481060292301807`], 
     Hue[0.8276998429248654, 1, -14.10681787561984], 
     Hue[0.8276998429248676, 1, -13.732575458937871`], 
     Hue[0.8276998429248729, 1, -13.358333042255907`], 
     Hue[0.8276998429248841, 1, -12.984090625573955`], 
     Hue[0.827699842924909, 1, -12.609848208892023`], 
     Hue[0.8276998429249636, 1, -12.235605792210139`], 
     Hue[0.8276998429250837, 1, -11.86136337552836], 
     Hue[0.8276998429253477, 1, -11.487120958846806`], 
     Hue[0.8276998429259282, 1, -11.112878542165754`], 
     Hue[0.8276998429272048, 1, -10.738636125485808`], 
     Hue[0.8276998429300114, 1, -10.364393708808285`], 
     Hue[0.8276998429361825, 1, -9.990151292136094], 
     Hue[0.8276998429497511, 1, -9.615908875475629], 
     Hue[0.8276998429795845, 1, -9.241666458840946], 
     Hue[0.8276998430451801, 1, -8.867424042262945], 
     Hue[0.827699843189407, 1, -8.493181625809575], 
     Hue[0.8276998435065227, 1, -8.11893920963024], 
     Hue[0.8276998442037737, 1, -7.744696794053426], 
     Hue[0.8276998457368386, 1, -7.370454379801392], 
     Hue[0.8276998491076306, 1, -6.996211968462194], 
     Hue[0.8276998565190832, 1, -6.621969563527522], 
     Hue[0.8276998728148461, 1, -6.247727172674663], 
     Hue[0.8276999086447818, 1, -5.873484812783882], 
     Hue[0.8276999874250156, 1, -5.4992425209703235`], 
     Hue[0.8277001606411344, 1, -5.125000378840255], 
     Hue[0.8277005414954695, 1, -4.750758565824515], 
     Hue[0.8277013788869552, 1, -4.3765174764469394`], 
     Hue[0.827703220066164, 1, -4.002277978178806], 
     Hue[0.8277072682379137, 1, -3.628041978454002], 
     Hue[0.8277161686797255, 1, -3.2538136716877943`], 
     Hue[0.8277357364661599, 1, -2.8796022826144876`], 
     Hue[0.8277787517058101, 1, -2.5054281053024736`], 
     Hue[0.8278732870297344, 1, -2.1313358158540368`], 
     Hue[0.8280809342723262, 1, -1.7574239096104287`], 
     Hue[0.8285364774802025, 1, -1.3839102202505822`], 
     Hue[0.8295331744950138, 1, -1.0112797272478657`], 
     Hue[0.8317008265779626, 1, -0.640626688030401], 
     Hue[0.8363516083980963, 1, -0.27447962371876833`], 
     Hue[0.8460225559185807, 1, 0.0811341900232978], 
     Hue[0.8647089407571815, 1, 0.4118310336143657], 
     Hue[0.895327363125742, 1, 0.6880929842971024], 
     Hue[0.9323724797991202, 1, 0.8752141926380897], 
     Hue[0.962990902167681, 1, 0.9731946586373268], 
     Hue[0.9816772870062823, 1, 1.0167402317282317`], 
     Hue[0.9913482345267668, 1, 1.0353688346681376`], 
     Hue[0.9959990163469007, 1, 1.0434641870384762`], 
     Hue[0.9981666684298495, 1, 1.047053564502983], 
     Hue[0.9991633654446609, 1, 1.0486654881822373`], 
     Hue[0.9996189086525371, 1, 1.0493942155043625`], 
     Hue[0.9998265558951289, 1, 1.0497247259427251`], 
     Hue[0.9999210912190534, 1, 1.0498748531762598`], 
     Hue[0.9999641064587034, 1, 1.049943092546217], 
     Hue[0.9999836742451379, 1, 1.0499741201548816`], 
     Hue[0.9999925746869497, 1, 1.0499882300706447`], 
     Hue[0.9999966228586993, 1, 1.0499946470278119`], 
     Hue[0.9999984640379082, 1, 1.0499975654416493`], 
     Hue[0.999999301429394, 1, 1.0499988927460444`], 
     Hue[0.999999682283729, 1, 1.0499994964122759`], 
     Hue[0.9999998554998478, 1, 1.0499997709641784`], 
     Hue[0.9999999342800816, 1, 1.0499998958325905`], 
     Hue[0.9999999701100173, 1, 1.0499999526237813`], 
     Hue[0.9999999864057803, 1, 1.0499999784528933`], 
     Hue[0.9999999938172328, 1, 1.0499999902001924`], 
     Hue[0.9999999971880248, 1, 1.0499999955429642`], 
     Hue[0.9999999987210897, 1, 1.0499999979729022`], 
     Hue[0.9999999994183407, 1, 1.0499999990780586`], 
     Hue[0.9999999997354564, 1, 1.0499999995806932`], 
     Hue[0.9999999998796834, 1, 1.0499999998092957`], 
     Hue[0.999999999945279, 1, 1.049999999913266], 
     Hue[0.9999999999751124, 1, 1.0499999999605527`], 
     Hue[0.9999999999886809, 1, 1.049999999982059], 
     Hue[0.999999999994852, 1, 1.0499999999918403`], 
     Hue[0.9999999999976587, 1, 1.049999999996289], 
     Hue[0.9999999999989351, 1, 1.0499999999983123`], 
     Hue[0.9999999999995157, 1, 1.0499999999992324`], 
     Hue[0.9999999999997797, 1, 1.049999999999651], 
     Hue[0.9999999999998999, 1, 1.0499999999998413`], 
     Hue[0.9999999999999545, 1, 1.0499999999999279`], 
     Hue[0.9999999999999792, 1, 1.0499999999999672`], 
     Hue[0.9999999999999906, 1, 1.0499999999999852`], 
     Hue[0.9999999999999957, 1, 1.0499999999999934`], 
     Hue[0.999999999999998, 1, 1.049999999999997], 
     Hue[0.9999999999999991, 1, 1.0499999999999987`], 
     Hue[0.9999999999999996, 1, 1.0499999999999994`], 
     Hue[0.9999999999999998, 1, 1.0499999999999998`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.9530946440397952, 1, -17.474999625757572`], 
     Hue[0.9530946440397952, 1, -17.100757209075603`], 
     Hue[0.9530946440397952, 1, -16.726514792393633`], 
     Hue[0.9530946440397952, 1, -16.35227237571166], 
     Hue[0.9530946440397952, 1, -15.97802995902969], 
     Hue[0.9530946440397952, 1, -15.603787542347721`], 
     Hue[0.9530946440397952, 1, -15.229545125665748`], 
     Hue[0.9530946440397953, 1, -14.855302708983777`], 
     Hue[0.9530946440397954, 1, -14.48106029230181], 
     Hue[0.9530946440397958, 1, -14.106817875619843`], 
     Hue[0.9530946440397966, 1, -13.732575458937879`], 
     Hue[0.9530946440397983, 1, -13.358333042255923`], 
     Hue[0.9530946440398019, 1, -12.984090625573991`], 
     Hue[0.9530946440398101, 1, -12.609848208892098`], 
     Hue[0.9530946440398281, 1, -12.235605792210304`], 
     Hue[0.9530946440398675, 1, -11.861363375528722`], 
     Hue[0.9530946440399545, 1, -11.487120958847605`], 
     Hue[0.9530946440401453, 1, -11.11287854216751], 
     Hue[0.9530946440405652, 1, -10.738636125489666`], 
     Hue[0.9530946440414882, 1, -10.36439370881677], 
     Hue[0.9530946440435178, 1, -9.990151292154755], 
     Hue[0.9530946440479804, 1, -9.61590887551666], 
     Hue[0.9530946440577923, 1, -9.241666458931157], 
     Hue[0.953094644079366, 1, -8.867424042461296], 
     Hue[0.9530946441268006, 1, -8.493181626245695], 
     Hue[0.9530946442310965, 1, -8.118939210589149], 
     Hue[0.9530946444604145, 1, -7.744696796161803], 
     Hue[0.9530946449646225, 1, -7.3704543844371395`], 
     Hue[0.9530946460732382, 1, -6.996211978654935], 
     Hue[0.9530946485107822, 1, -6.62196958593858], 
     Hue[0.9530946538702761, 1, -6.2477272219504645`], 
     Hue[0.9530946656543385, 1, -5.8734849211279005`], 
     Hue[0.9530946915642601, 1, -5.499242759189103], 
     Hue[0.9530947485330187, 1, -5.12500090261751], 
     Hue[0.9530948737913207, 1, -4.750759717463506], 
     Hue[0.9530951491979069, 1, -4.376520008565718], 
     Hue[0.9530957547308927, 1, -4.002283545513943], 
     Hue[0.9530970860795268, 1, -3.628054219004021], 
     Hue[0.9531000130943212, 1, -3.253840582891325], 
     Hue[0.9531064475550393, 1, -2.87966144127087], 
     Hue[0.9531205891543301, 1, -2.505558122299587], 
     Hue[0.9531516535739971, 1, -2.131621413577709], 
     Hue[0.9532198153904796, 1, -1.7580505377091538`], 
     Hue[0.9533690093984201, 1, -1.3852816301402082`], 
     Hue[0.9536938175185731, 1, -1.0142645168863063`], 
     Hue[0.9543927416772814, 1, -0.6470442870663982], 
     Hue[0.9558595284151461, 1, -0.2879158975869023], 
     Hue[0.9587817089151532, 1, 0.0545747505164178], 
     Hue[0.964039487627873, 1, 0.365271619482171], 
     Hue[0.9719546587130017, 1, 0.6230172659616222], 
     Hue[0.9811399853267931, 1, 0.8101384743026093], 
     Hue[0.989055156411922, 1, 0.9266352445051315], 
     Hue[0.9943129351246417, 1, 0.9901807922213511], 
     Hue[0.997235115624649, 1, 1.0219325608000032`], 
     Hue[0.9987019023625137, 1, 1.0370465880024786`], 
     Hue[0.9994008265212221, 1, 1.0440687748645423`], 
     Hue[0.9997256346413751, 1, 1.0472940782926115`], 
     Hue[0.9998748286493155, 1, 1.0487675874056375`], 
     Hue[0.999942990465798, 1, 1.049439128219053], 
     Hue[0.9999740548854651, 1, 1.0497448361791457`], 
     Hue[0.9999881964847559, 1, 1.0498839338898345`], 
     Hue[0.9999946309454739, 1, 1.049947208951351], 
     Hue[0.9999975579602683, 1, 1.049975989520626], 
     Hue[0.9999988893089025, 1, 1.049989079692675], 
     Hue[0.9999994948418882, 1, 1.049995033322871], 
     Hue[0.9999997702484744, 1, 1.0499977411070536`], 
     Hue[0.9999998955067765, 1, 1.0499989726350212`], 
     Hue[0.9999999524755351, 1, 1.0499995327453988`], 
     Hue[0.9999999783854566, 1, 1.0499997874885723`], 
     Hue[0.999999990169519, 1, 1.04999990334798], 
     Hue[0.999999995529013, 1, 1.0499999560418352`], 
     Hue[0.9999999979665568, 1, 1.0499999800074515`], 
     Hue[0.9999999990751727, 1, 1.0499999909072184`], 
     Hue[0.9999999995793807, 1, 1.0499999958645254`], 
     Hue[0.9999999998086987, 1, 1.049999998119151], 
     Hue[0.9999999999129946, 1, 1.0499999991445739`], 
     Hue[0.9999999999604292, 1, 1.0499999996109448`], 
     Hue[0.9999999999820028, 1, 1.0499999998230545`], 
     Hue[0.9999999999918148, 1, 1.0499999999195235`], 
     Hue[0.9999999999962773, 1, 1.0499999999633987`], 
     Hue[0.9999999999983069, 1, 1.0499999999833534`], 
     Hue[0.99999999999923, 1, 1.049999999992429], 
     Hue[0.9999999999996497, 1, 1.0499999999965568`], 
     Hue[0.9999999999998407, 1, 1.049999999998434], 
     Hue[0.9999999999999275, 1, 1.0499999999992877`], 
     Hue[0.999999999999967, 1, 1.049999999999676], 
     Hue[0.999999999999985, 1, 1.0499999999998526`], 
     Hue[0.9999999999999932, 1, 1.049999999999933], 
     Hue[0.9999999999999969, 1, 1.0499999999999696`], 
     Hue[0.9999999999999986, 1, 1.0499999999999863`], 
     Hue[0.9999999999999993, 1, 1.0499999999999936`], 
     Hue[0.9999999999999997, 1, 1.0499999999999972`], 
     Hue[0.9999999999999999, 1, 1.0499999999999987`], 
     Hue[0.9999999999999999, 1, 1.0499999999999994`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.0784894451547262`, 1, -17.474999625757572`], 
     Hue[1.0784894451547262`, 1, -17.100757209075603`], 
     Hue[1.0784894451547262`, 1, -16.726514792393633`], 
     Hue[1.0784894451547262`, 1, -16.35227237571166], 
     Hue[1.0784894451547262`, 1, -15.97802995902969], 
     Hue[1.0784894451547262`, 1, -15.603787542347721`], 
     Hue[1.0784894451547262`, 1, -15.229545125665748`], 
     Hue[1.078489445154726, 1, -14.855302708983777`], 
     Hue[1.0784894451547258`, 1, -14.48106029230181], 
     Hue[1.0784894451547253`, 1, -14.106817875619841`], 
     Hue[1.078489445154724, 1, -13.732575458937879`], 
     Hue[1.0784894451547213`, 1, -13.358333042255921`], 
     Hue[1.0784894451547151`, 1, -12.984090625573986`], 
     Hue[1.0784894451547018`, 1, -12.609848208892085`], 
     Hue[1.0784894451546727`, 1, -12.235605792210277`], 
     Hue[1.0784894451546083`, 1, -11.861363375528667`], 
     Hue[1.0784894451544667`, 1, -11.487120958847479`], 
     Hue[1.0784894451541556`, 1, -11.112878542167236`], 
     Hue[1.0784894451534712`, 1, -10.738636125489066`], 
     Hue[1.0784894451519669`, 1, -10.364393708815447`], 
     Hue[1.0784894451486589`, 1, -9.990151292151847], 
     Hue[1.0784894451413858`, 1, -9.615908875510263], 
     Hue[1.078489445125394, 1, -9.241666458917095], 
     Hue[1.0784894450902323`, 1, -8.867424042430377], 
     Hue[1.0784894450129214`, 1, -8.493181626177714], 
     Hue[1.0784894448429359`, 1, -8.118939210439674], 
     Hue[1.0784894444691842`, 1, -7.744696795833149], 
     Hue[1.078489443647406, 1, -7.3704543837145176`], 
     Hue[1.0784894418405397`, 1, -6.99621197706609], 
     Hue[1.0784894378677337`, 1, -6.621969582445143], 
     Hue[1.0784894291326168`, 1, -6.247727214269349], 
     Hue[1.078489409926482, 1, -5.8734849042392305`], 
     Hue[1.0784893676974556`, 1, -5.499242722055559], 
     Hue[1.0784892748474821`, 1, -5.12500082097115], 
     Hue[1.0784890706964034`, 1, -4.750759537946306], 
     Hue[1.0784886218272445`, 1, -4.37651961386064], 
     Hue[1.078487634902859, 1, -4.002282677685932], 
     Hue[1.0784854650051818`, 1, -3.6280523109877203`], 
     Hue[1.078480694378672, 1, -3.25383638817162], 
     Hue[1.0784702069422827`, 1, -2.8796522205847364`], 
     Hue[1.0784471569701644`, 1, -2.505537859923016], 
     Hue[1.0783965200389058`, 1, -2.13157691717295], 
     Hue[1.0782853939602473`, 1, -1.7579529675837635`], 
     Hue[1.0780420723985344`, 1, -1.3850683749769745`], 
     Hue[1.0775119325774, 1, -1.0138017084630218`], 
     Hue[1.0763693049099545`, 1, -0.6460552496619649], 
     Hue[1.073963300617879, 1, -0.285870814285784], 
     Hue[1.0691396587502326`, 1, 0.058524399920407366`], 
     Hue[1.0603734864150018`, 1, 0.37195537426769787`], 
     Hue[1.0470286214581874`, 1, 0.6320602145805532], 
     Hue[1.0314608236965395`, 1, 0.8191814229215403], 
     Hue[1.0181159587397248`, 1, 0.9333189992906585], 
     Hue[1.009349786404494, 1, 0.9941304416253408], 
     Hue[1.0045261445368474`, 1, 1.0239776441011215`], 
     Hue[1.002120140244772, 1, 1.038035625406912], 
     Hue[1.0009775125773264`, 1, 1.0445315832878268`], 
     Hue[1.0004473727561918`, 1, 1.0475073334558453`], 
     Hue[1.0002040511944792`, 1, 1.0488651575310273`], 
     Hue[1.0000929251158206`, 1, 1.0494836246238117`], 
     Hue[1.0000422881845619`, 1, 1.0497650985557174`], 
     Hue[1.0000192382124435`, 1, 1.049893154575968], 
     Hue[1.0000087507760544`, 1, 1.0499514036710558`], 
     Hue[1.0000039801495444`, 1, 1.049977897536927], 
     Hue[1.0000018102518675`, 1, 1.049989947520685], 
     Hue[1.0000008233274817`, 1, 1.0499954280279495`], 
     Hue[1.0000003744583228`, 1, 1.0499979206242538`], 
     Hue[1.000000170307244, 1, 1.0499990542813806`], 
     Hue[1.0000000774572706`, 1, 1.0499995698789433`], 
     Hue[1.0000000352282443`, 1, 1.0499998043772423`], 
     Hue[1.0000000160221094`, 1, 1.049999911029095], 
     Hue[1.0000000072869928`, 1, 1.0499999595352725`], 
     Hue[1.0000000033141865`, 1, 1.0499999815962966`], 
     Hue[1.0000000015073203`, 1, 1.0499999916298388`], 
     Hue[1.000000000685542, 1, 1.0499999961931794`], 
     Hue[1.0000000003117904`, 1, 1.0499999982686254`], 
     Hue[1.000000000141805, 1, 1.0499999992125562`], 
     Hue[1.0000000000644942`, 1, 1.0499999996418639`], 
     Hue[1.0000000000293325`, 1, 1.0499999998371166`], 
     Hue[1.0000000000133407`, 1, 1.0499999999259193`], 
     Hue[1.0000000000060674`, 1, 1.0499999999663074`], 
     Hue[1.0000000000027596`, 1, 1.0499999999846763`], 
     Hue[1.000000000001255, 1, 1.0499999999930307`], 
     Hue[1.0000000000005709`, 1, 1.0499999999968304`], 
     Hue[1.0000000000002596`, 1, 1.0499999999985585`], 
     Hue[1.0000000000001181`, 1, 1.0499999999993443`], 
     Hue[1.0000000000000537`, 1, 1.0499999999997018`], 
     Hue[1.0000000000000244`, 1, 1.0499999999998644`], 
     Hue[1.000000000000011, 1, 1.0499999999999383`], 
     Hue[1.000000000000005, 1, 1.049999999999972], 
     Hue[1.0000000000000022`, 1, 1.0499999999999874`], 
     Hue[1.000000000000001, 1, 1.0499999999999943`], 
     Hue[1.0000000000000004`, 1, 1.0499999999999974`], 
     Hue[1.0000000000000002`, 1, 1.049999999999999], 
     Hue[1., 1, 1.0499999999999996`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.203884246269658, 1, -17.474999625757572`], 
     Hue[1.203884246269658, 1, -17.100757209075603`], 
     Hue[1.203884246269658, 1, -16.726514792393633`], 
     Hue[1.203884246269658, 1, -16.35227237571166], 
     Hue[1.203884246269658, 1, -15.97802995902969], 
     Hue[1.203884246269658, 1, -15.603787542347721`], 
     Hue[1.2038842462696577`, 1, -15.229545125665748`], 
     Hue[1.2038842462696575`, 1, -14.855302708983777`], 
     Hue[1.203884246269657, 1, -14.481060292301807`], 
     Hue[1.203884246269656, 1, -14.106817875619837`], 
     Hue[1.2038842462696535`, 1, -13.732575458937868`], 
     Hue[1.2038842462696477`, 1, -13.358333042255902`], 
     Hue[1.2038842462696355`, 1, -12.984090625573943`], 
     Hue[1.2038842462696087`, 1, -12.609848208891995`], 
     Hue[1.2038842462695494`, 1, -12.235605792210075`], 
     Hue[1.203884246269419, 1, -11.861363375528223`], 
     Hue[1.2038842462691326`, 1, -11.487120958846505`], 
     Hue[1.2038842462685027`, 1, -11.112878542165094`], 
     Hue[1.2038842462671175`, 1, -10.738636125484359`], 
     Hue[1.203884246264072, 1, -10.364393708805094`], 
     Hue[1.203884246257376, 1, -9.990151292129083], 
     Hue[1.2038842462426531`, 1, -9.61590887546021], 
     Hue[1.2038842462102815`, 1, -9.241666458807046], 
     Hue[1.2038842461391053`, 1, -8.867424042188409], 
     Hue[1.2038842459826082`, 1, -8.493181625645692], 
     Hue[1.2038842456385137`, 1, -8.118939209269902], 
     Hue[1.2038842448819436`, 1, -7.744696793261139], 
     Hue[1.2038842432184522`, 1, -7.37045437805937], 
     Hue[1.203884239560888, 1, -6.996211964631963], 
     Hue[1.2038842315189013`, 1, -6.6219695551058875`], 
     Hue[1.2038842138367651`, 1, -6.247727154157787], 
     Hue[1.2038841749585707`, 1, -5.873484772070326], 
     Hue[1.2038840894760363`, 1, -5.499242431452347], 
     Hue[1.2038839015233356`, 1, -5.125000182014804], 
     Hue[1.203883488267034, 1, -4.750758133059874], 
     Hue[1.2038825796313004`, 1, -4.37651652491971], 
     Hue[1.2038805817998273`, 1, -4.002275886050429], 
     Hue[1.2038761891654706`, 1, -3.62803737853386], 
     Hue[1.2038665312138959`, 1, -3.2538035582004667`], 
     Hue[1.2038452972398836`, 1, -2.879580048149567], 
     Hue[1.2037986154638958`, 1, -2.5053792290768966`], 
     Hue[1.2036960037312883`, 1, -2.13122840502833], 
     Hue[1.2034705278521622`, 1, -1.7571880071066033`], 
     Hue[1.202975444367699, 1, -1.3833928175330283`], 
     Hue[1.201890190877885, 1, -1.01014833400471], 
     Hue[1.1995202733788446`, 1, -0.6381695359401798], 
     Hue[1.1943910912578612`, 1, -0.26922733116336905`], 
     Hue[1.183534911724703, 1, 0.09193612025299214], 
     Hue[1.1618759431301486`, 1, 0.43199188736555116`], 
     Hue[1.1248509175180967`, 1, 0.7180362610230355], 
     Hue[1.0790333287515628`, 1, 0.9051574693640232], 
     Hue[1.0420083031395104`, 1, 0.9933555123885129], 
     Hue[1.0203493345449557`, 1, 1.0275421619579264`], 
     Hue[1.009493155011797, 1, 1.0406211272235368`], 
     Hue[1.0043639728908136`, 1, 1.0459213391286977`], 
     Hue[1.0019940553917732`, 1, 1.0481849577461386`], 
     Hue[1.0009088019019592`, 1, 1.0491828908997916`], 
     Hue[1.000413718417496, 1, 1.049630118008188], 
     Hue[1.0001882425383697`, 1, 1.0498321367684322`], 
     Hue[1.0000856308057622`, 1, 1.0499237294018369`], 
     Hue[1.0000389490297745`, 1, 1.049965327011137], 
     Hue[1.000017715055762, 1, 1.0499842336422087`], 
     Hue[1.0000080571041876`, 1, 1.049992829990786], 
     Hue[1.000003664469831, 1, 1.0499967391561886`], 
     Hue[1.0000016666383578`, 1, 1.0499985169688788`], 
     Hue[1.000000758002624, 1, 1.0499993255106865`], 
     Hue[1.0000003447463226`, 1, 1.049999693237727], 
     Hue[1.0000001567936219`, 1, 1.0499998604821548`], 
     Hue[1.0000000713110873`, 1, 1.0499999365461465`], 
     Hue[1.0000000324328928`, 1, 1.0499999711406574`], 
     Hue[1.0000000147507566`, 1, 1.0499999868745271`], 
     Hue[1.00000000670877, 1, 1.0499999940304237`], 
     Hue[1.0000000030512057`, 1, 1.0499999972849858`], 
     Hue[1.0000000013877144`, 1, 1.0499999987651885`], 
     Hue[1.0000000006311442`, 1, 1.0499999994383973`], 
     Hue[1.00000000028705, 1, 1.0499999997445784`], 
     Hue[1.0000000001305527`, 1, 1.049999999883832], 
     Hue[1.0000000000593765`, 1, 1.0499999999471659`], 
     Hue[1.0000000000270048`, 1, 1.0499999999759706`], 
     Hue[1.0000000000122822`, 1, 1.0499999999890712`], 
     Hue[1.000000000005586, 1, 1.0499999999950296`], 
     Hue[1.0000000000025406`, 1, 1.0499999999977394`], 
     Hue[1.0000000000011555`, 1, 1.049999999998972], 
     Hue[1.0000000000005256`, 1, 1.0499999999995324`], 
     Hue[1.000000000000239, 1, 1.0499999999997873`], 
     Hue[1.0000000000001088`, 1, 1.0499999999999032`], 
     Hue[1.0000000000000495`, 1, 1.049999999999956], 
     Hue[1.0000000000000224`, 1, 1.04999999999998], 
     Hue[1.0000000000000102`, 1, 1.049999999999991], 
     Hue[1.0000000000000047`, 1, 1.0499999999999958`], 
     Hue[1.0000000000000022`, 1, 1.049999999999998], 
     Hue[1.0000000000000009`, 1, 1.0499999999999992`], 
     Hue[1.0000000000000004`, 1, 1.0499999999999996`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.3292790473845892`, 1, -17.474999625757572`], 
     Hue[1.3292790473845892`, 1, -17.100757209075603`], 
     Hue[1.3292790473845892`, 1, -16.726514792393633`], 
     Hue[1.3292790473845892`, 1, -16.35227237571166], 
     Hue[1.3292790473845892`, 1, -15.97802995902969], 
     Hue[1.3292790473845892`, 1, -15.603787542347721`], 
     Hue[1.329279047384589, 1, -15.229545125665748`], 
     Hue[1.3292790473845888`, 1, -14.855302708983777`], 
     Hue[1.3292790473845884`, 1, -14.481060292301807`], 
     Hue[1.3292790473845872`, 1, -14.106817875619832`], 
     Hue[1.329279047384585, 1, -13.732575458937857`], 
     Hue[1.32927904738458, 1, -13.358333042255877`], 
     Hue[1.3292790473845686`, 1, -12.98409062557389], 
     Hue[1.329279047384544, 1, -12.609848208891878`], 
     Hue[1.3292790473844895`, 1, -12.235605792209817`], 
     Hue[1.32927904738437, 1, -11.861363375527654`], 
     Hue[1.3292790473841074`, 1, -11.487120958845257`], 
     Hue[1.32927904738353, 1, -11.112878542162347`], 
     Hue[1.3292790473822604`, 1, -10.738636125478317`], 
     Hue[1.3292790473794687`, 1, -10.364393708791814`], 
     Hue[1.3292790473733302`, 1, -9.990151292099878], 
     Hue[1.329279047359834, 1, -9.615908875396], 
     Hue[1.3292790473301592`, 1, -9.241666458665863], 
     Hue[1.3292790472649125`, 1, -8.867424041877983], 
     Hue[1.3292790471214526`, 1, -8.49318162496315], 
     Hue[1.3292790468060236`, 1, -8.118939207769179], 
     Hue[1.329279046112481, 1, -7.7446967899614565`], 
     Hue[1.3292790445875702`, 1, -7.370454370804269], 
     Hue[1.3292790412347064`, 1, -6.996211948679972], 
     Hue[1.3292790338626728`, 1, -6.621969520031803], 
     Hue[1.3292790176535783`, 1, -6.247727077039434], 
     Hue[1.3292789820141904`, 1, -5.873484602508074], 
     Hue[1.329278903652859, 1, -5.4992420586311255`], 
     Hue[1.329278731357499, 1, -5.124999362282346], 
     Hue[1.329278352526244, 1, -4.750756330690661], 
     Hue[1.3292775195761064`, 1, -4.37651256199647], 
     Hue[1.3292756881290806`, 1, -4.002267172640306], 
     Hue[1.3292716611955768`, 1, -3.6280182200136917`], 
     Hue[1.3292628066765422`, 1, -3.253761433323832], 
     Hue[1.3292433361183114`, 1, -2.8794874245528534`], 
     Hue[1.3292005165594463`, 1, -2.5051755630953485`], 
     Hue[1.3291063239924177`, 1, -2.130780541568959], 
     Hue[1.3288990073985567`, 1, -1.7562030019951764`], 
     Hue[1.3284421462731681`, 1, -1.3812257539715025`], 
     Hue[1.3274326656331858`, 1, -1.0053775137519831`], 
     Hue[1.3251891336275905`, 1, -0.6276535538858343], 
     Hue[1.3201412213972459`, 1, -0.24601042747901114`], 
     Hue[1.3085011465728424`, 1, 0.1430975556033045], 
     Hue[1.2806078215114822`, 1, 0.5413398060951977], 
     Hue[1.2149564833314834`, 1, 0.9128122341903115], 
     Hue[1.1143225640531091`, 1, 1.0999334425313017`], 
     Hue[1.0486712258731086`, 1, 1.1027034311181623`], 
     Hue[1.0207779008117475`, 1, 1.0787035973082402`], 
     Hue[1.0091378259873436`, 1, 1.0638380309078956`], 
     Hue[1.0040899137569987`, 1, 1.0564373211830433`], 
     Hue[1.0018463817514036`, 1, 1.0529557779988659`], 
     Hue[1.0008369011114209`, 1, 1.0513499544613174`], 
     Hue[1.0003800399860325`, 1, 1.0506151231196146`], 
     Hue[1.0001727233921716`, 1, 1.0502800002278037`], 
     Hue[1.000078530825143, 1, 1.050127395383385], 
     Hue[1.0000357112662779`, 1, 1.0500579506078505`], 
     Hue[1.000016240708047, 1, 1.0500263585188447`], 
     Hue[1.0000073861890124`, 1, 1.0500119885109553`], 
     Hue[1.0000033592555087`, 1, 1.0500054525663114`], 
     Hue[1.0000015278084826`, 1, 1.050002479892119], 
     Hue[1.0000006948583453`, 1, 1.0500011278798993`], 
     Hue[1.0000003160270903`, 1, 1.0500005129701842`], 
     Hue[1.0000001437317303`, 1, 1.0500002333033764`], 
     Hue[1.0000000653703989`, 1, 1.0500001061083986`], 
     Hue[1.000000029731011, 1, 1.0500000482590113`], 
     Hue[1.0000000135219165`, 1, 1.0500000219486112`], 
     Hue[1.0000000061498828`, 1, 1.0500000099824158`], 
     Hue[1.000000002797019, 1, 1.050000004540088], 
     Hue[1.0000000012721082`, 1, 1.0500000020648708`], 
     Hue[1.0000000005785656`, 1, 1.0500000009391208`], 
     Hue[1.0000000002631366`, 1, 1.0500000004271202`], 
     Hue[1.0000000001196767`, 1, 1.050000000194258], 
     Hue[1.00000000005443, 1, 1.0500000000883503`], 
     Hue[1.0000000000247553`, 1, 1.0500000000401823`], 
     Hue[1.000000000011259, 1, 1.0500000000182754`], 
     Hue[1.0000000000051206`, 1, 1.0500000000083118`], 
     Hue[1.0000000000023288`, 1, 1.0500000000037804`], 
     Hue[1.0000000000010592`, 1, 1.0500000000017193`], 
     Hue[1.0000000000004818`, 1, 1.050000000000782], 
     Hue[1.0000000000002192`, 1, 1.0500000000003558`], 
     Hue[1.0000000000000997`, 1, 1.050000000000162], 
     Hue[1.0000000000000453`, 1, 1.0500000000000738`], 
     Hue[1.0000000000000207`, 1, 1.0500000000000336`], 
     Hue[1.0000000000000093`, 1, 1.0500000000000154`], 
     Hue[1.0000000000000042`, 1, 1.050000000000007], 
     Hue[1.000000000000002, 1, 1.0500000000000032`], 
     Hue[1.0000000000000009`, 1, 1.0500000000000016`], 
     Hue[1.0000000000000004`, 1, 1.0500000000000007`], 
     Hue[1.0000000000000002`, 1, 1.0500000000000003`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.4546738484995214`, 1, -17.474999625757572`], 
     Hue[1.4546738484995214`, 1, -17.100757209075603`], 
     Hue[1.4546738484995214`, 1, -16.726514792393633`], 
     Hue[1.4546738484995214`, 1, -16.35227237571166], 
     Hue[1.4546738484995214`, 1, -15.97802995902969], 
     Hue[1.4546738484995214`, 1, -15.603787542347721`], 
     Hue[1.4546738484995214`, 1, -15.229545125665748`], 
     Hue[1.4546738484995214`, 1, -14.855302708983777`], 
     Hue[1.4546738484995212`, 1, -14.481060292301803`], 
     Hue[1.454673848499521, 1, -14.106817875619829`], 
     Hue[1.45467384849952, 1, -13.73257545893785], 
     Hue[1.4546738484995185`, 1, -13.358333042255863`], 
     Hue[1.454673848499515, 1, -12.984090625573856`], 
     Hue[1.454673848499507, 1, -12.609848208891803`], 
     Hue[1.4546738484994897`, 1, -12.235605792209654`], 
     Hue[1.4546738484994515`, 1, -11.861363375527295`], 
     Hue[1.4546738484993673`, 1, -11.487120958844468`], 
     Hue[1.4546738484991828`, 1, -11.112878542160614`], 
     Hue[1.4546738484987767`, 1, -10.738636125474503`], 
     Hue[1.4546738484978838`, 1, -10.364393708783428`], 
     Hue[1.4546738484959207`, 1, -9.990151292081444], 
     Hue[1.4546738484916042`, 1, -9.615908875355467], 
     Hue[1.4546738484821136`, 1, -9.241666458576741], 
     Hue[1.454673848461246, 1, -8.867424041682032], 
     Hue[1.4546738484153643`, 1, -8.493181624532308], 
     Hue[1.4546738483144828`, 1, -8.118939206821876], 
     Hue[1.4546738480926715`, 1, -7.744696787878602], 
     Hue[1.4546738476049694`, 1, -7.370454366224636], 
     Hue[1.4546738465326454`, 1, -6.996211938610604], 
     Hue[1.4546738441748963`, 1, -6.621969497892011], 
     Hue[1.4546738389908485`, 1, -6.247727028360053], 
     Hue[1.454673827592536, 1, -5.873484495475345], 
     Hue[1.454673802530733, 1, -5.499241823295132], 
     Hue[1.4546737474265636`, 1, -5.1249988448417145`], 
     Hue[1.4546736262670543`, 1, -4.750755192975298], 
     Hue[1.4546733598680968`, 1, -4.3765100604490215`], 
     Hue[1.4546727741186767`, 1, -4.002261672315635], 
     Hue[1.4546714861635426`, 1, -3.628006125798014], 
     Hue[1.454668654050797, 1, -3.253734839018742], 
     Hue[1.4546624257958656`, 1, -2.879428939218572], 
     Hue[1.454648725704219, 1, -2.505046913177135], 
     Hue[1.4546185745945008`, 1, -2.1304974015853926`], 
     Hue[1.4545521431905177`, 1, -1.7555791280487643`], 
     Hue[1.4544054113610583`, 1, -1.379847589220056], 
     Hue[1.4540795259990482`, 1, -1.0023159329918838`], 
     Hue[1.4533468284502966`, 1, -0.620767538418586], 
     Hue[1.4516532460489375`, 1, -0.23009334466367481`], 
     Hue[1.4474767162831026`, 1, 0.18218078415507322`], 
     Hue[1.4353327914073555`, 1, 0.6507330444541654], 
     Hue[1.37622721298006, 1, 1.2976008959287428`], 
     Hue[1.0784466355194668`, 1, 1.4847221042697512`], 
     Hue[1.0193410570921668`, 1, 1.2120966694771345`], 
     Hue[1.0071971322164193`, 1, 1.11778682586001], 
     Hue[1.0030206024505839`, 1, 1.0797551137232324`], 
     Hue[1.001327020049225, 1, 1.0633233366502917`], 
     Hue[1.0005943225004732`, 1, 1.0560173587589647`], 
     Hue[1.0002684371384631`, 1, 1.052728119212764], 
     Hue[1.0001217053090037`, 1, 1.0512389970660267`], 
     Hue[1.0000552739050208`, 1, 1.0505631402113695`], 
     Hue[1.0000251227953023`, 1, 1.0502560453015988`], 
     Hue[1.000011422703656, 1, 1.050116435942132], 
     Hue[1.0000051944487245`, 1, 1.050052952823934], 
     Hue[1.000002362335979, 1, 1.050024082726633], 
     Hue[1.0000010743808447`, 1, 1.0500109528909825`], 
     Hue[1.0000004886314249`, 1, 1.0500049814395678`], 
     Hue[1.000000222232467, 1, 1.0500022655952623`], 
     Hue[1.0000001010729578`, 1, 1.0500010304108154`], 
     Hue[1.0000000459687886`, 1, 1.0500004686393702`], 
     Hue[1.0000000209069857`, 1, 1.0500002131411286`], 
     Hue[1.000000009508673, 1, 1.0500000969383916`], 
     Hue[1.000000004324625, 1, 1.0500000440884047`], 
     Hue[1.0000000019668762`, 1, 1.0500000200517818`], 
     Hue[1.000000000894552, 1, 1.0500000091197212`], 
     Hue[1.0000000004068499`, 1, 1.050000004147727], 
     Hue[1.0000000001850389`, 1, 1.0500000018864217`], 
     Hue[1.0000000000841571`, 1, 1.0500000008579606`], 
     Hue[1.0000000000382754`, 1, 1.050000000390208], 
     Hue[1.000000000017408, 1, 1.0500000001774699`], 
     Hue[1.0000000000079172`, 1, 1.0500000000807148`], 
     Hue[1.000000000003601, 1, 1.0500000000367098`], 
     Hue[1.0000000000016378`, 1, 1.050000000016696], 
     Hue[1.0000000000007447`, 1, 1.0500000000075935`], 
     Hue[1.0000000000003388`, 1, 1.0500000000034535`], 
     Hue[1.000000000000154, 1, 1.0500000000015708`], 
     Hue[1.0000000000000702`, 1, 1.0500000000007144`], 
     Hue[1.000000000000032, 1, 1.050000000000325], 
     Hue[1.0000000000000144`, 1, 1.0500000000001477`], 
     Hue[1.0000000000000067`, 1, 1.0500000000000673`], 
     Hue[1.000000000000003, 1, 1.0500000000000307`], 
     Hue[1.0000000000000013`, 1, 1.050000000000014], 
     Hue[1.0000000000000007`, 1, 1.0500000000000063`], 
     Hue[1.0000000000000002`, 1, 1.050000000000003], 
     Hue[1.0000000000000002`, 1, 1.0500000000000014`], 
     Hue[1., 1, 1.0500000000000007`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.5800686496144527, 1, -17.474999625757572`], 
     Hue[0.5800686496144527, 1, -17.100757209075603`], 
     Hue[0.5800686496144527, 1, -16.726514792393633`], 
     Hue[0.5800686496144527, 1, -16.35227237571166], 
     Hue[0.5800686496144527, 1, -15.97802995902969], 
     Hue[0.5800686496144527, 1, -15.603787542347721`], 
     Hue[0.5800686496144527, 1, -15.229545125665748`], 
     Hue[0.5800686496144529, 1, -14.855302708983777`], 
     Hue[0.5800686496144531, 1, -14.481060292301803`], 
     Hue[0.5800686496144537, 1, -14.10681787561983], 
     Hue[0.5800686496144549, 1, -13.732575458937852`], 
     Hue[0.5800686496144578, 1, -13.358333042255866`], 
     Hue[0.580068649614464, 1, -12.984090625573861`], 
     Hue[0.5800686496144776, 1, -12.609848208891815`], 
     Hue[0.5800686496145073, 1, -12.235605792209682`], 
     Hue[0.5800686496145728, 1, -11.861363375527358`], 
     Hue[0.5800686496147169, 1, -11.487120958844603`], 
     Hue[0.5800686496150339, 1, -11.112878542160914`], 
     Hue[0.5800686496157308, 1, -10.738636125475164`], 
     Hue[0.580068649617263, 1, -10.364393708784883`], 
     Hue[0.5800686496206318, 1, -9.990151292084642], 
     Hue[0.580068649628039, 1, -9.6159088753625], 
     Hue[0.5800686496443253, 1, -9.241666458592205], 
     Hue[0.5800686496801342, 1, -8.867424041716031], 
     Hue[0.5800686497588685, 1, -8.493181624607063], 
     Hue[0.5800686499319838, 1, -8.118939206986242], 
     Hue[0.5800686503126171, 1, -7.744696788239994], 
     Hue[0.5800686511495261, 1, -7.370454367019245], 
     Hue[0.580068652989661, 1, -6.996211940357733], 
     Hue[0.5800686570356164, 1, -6.621969501733467], 
     Hue[0.5800686659315709, 1, -6.247727036806372], 
     Hue[0.5800686854913569, 1, -5.873484514046508], 
     Hue[0.5800687284980266, 1, -5.499241864128102], 
     Hue[0.580068823058121, 1, -5.124998934622491], 
     Hue[0.5800690309707168, 1, -4.750755390379738], 
     Hue[0.5800694881173244, 1, -4.376510494492335], 
     Hue[0.5800704932749114, 1, -4.002262626681543], 
     Hue[0.5800727034236446, 1, -3.6280082242995118`], 
     Hue[0.5800775633306384, 1, -3.2537394535881035`], 
     Hue[0.5800882508383208, 1, -2.8794390879931724`], 
     Hue[0.5801117589279592, 1, -2.505069240115133], 
     Hue[0.5801634911949525, 1, -2.1305465531785472`], 
     Hue[0.5802774513402831, 1, -1.7556874934734485`], 
     Hue[0.5805290624266717, 1, -1.380087287583389], 
     Hue[0.5810873803328043, 1, -1.0028499830941107`], 
     Hue[0.5823401100854353, 1, -0.6219767311125848], 
     Hue[0.5852217771785753, 1, -0.23293271217873857`], 
     Hue[0.5922395120942454, 1, 0.17492168347785253`], 
     Hue[0.61182466294135, 1, 0.627771507020156], 
     Hue[0.686937745659181, 1, 1.1711034047581488`], 
     Hue[0.8931309039552664, 1, 1.3582246130991475`], 
     Hue[0.9682439866731015, 1, 1.1891351320431238`], 
     Hue[0.9878291375202068, 1, 1.1105277251827892`], 
     Hue[0.9948468724358773, 1, 1.0769157462081684`], 
     Hue[0.9977285395290173, 1, 1.0621141439562929`], 
     Hue[0.9989812692816483, 1, 1.055483308656738], 
     Hue[0.9995395871877809, 1, 1.0524884208494314`], 
     Hue[0.9997911982741695, 1, 1.0511306316413425`], 
     Hue[0.9999051584195002, 1, 1.0505139886182149`], 
     Hue[0.9999568906864934, 1, 1.0502337183636006`], 
     Hue[0.9999803987761318, 1, 1.0501062871675324`], 
     Hue[0.9999910862838143, 1, 1.0500483382545724`], 
     Hue[0.999995946190808, 1, 1.050021984225135], 
     Hue[0.9999981563395411, 1, 1.050009998525074], 
     Hue[0.9999991614971282, 1, 1.0500045473962543`], 
     Hue[0.9999996186437358, 1, 1.050002068190822], 
     Hue[0.9999998265563316, 1, 1.0500009406300395`], 
     Hue[0.9999999211164261, 1, 1.0500004278064003`], 
     Hue[0.9999999641230957, 1, 1.0500001945699649`], 
     Hue[0.9999999836828817, 1, 1.050000088492072], 
     Hue[0.9999999925788362, 1, 1.0500000402469474`], 
     Hue[0.9999999966247917, 1, 1.0500000183046545`], 
     Hue[0.9999999984649265, 1, 1.0500000083251129`], 
     Hue[0.9999999993018355, 1, 1.0500000037863324`], 
     Hue[0.9999999996824688, 1, 1.0500000017220563`], 
     Hue[0.9999999998555841, 1, 1.0500000007832058`], 
     Hue[0.9999999999343184, 1, 1.0500000003562087`], 
     Hue[0.9999999999701275, 1, 1.050000000162007], 
     Hue[0.9999999999864138, 1, 1.0500000000736822`], 
     Hue[0.9999999999938208, 1, 1.0500000000335112`], 
     Hue[0.9999999999971897, 1, 1.0500000000152412`], 
     Hue[0.9999999999987218, 1, 1.0500000000069318`], 
     Hue[0.9999999999994187, 1, 1.0500000000031526`], 
     Hue[0.9999999999997357, 1, 1.050000000001434], 
     Hue[0.9999999999998798, 1, 1.0500000000006522`], 
     Hue[0.9999999999999453, 1, 1.0500000000002967`], 
     Hue[0.9999999999999751, 1, 1.050000000000135], 
     Hue[0.9999999999999887, 1, 1.0500000000000613`], 
     Hue[0.9999999999999949, 1, 1.050000000000028], 
     Hue[0.9999999999999977, 1, 1.0500000000000127`], 
     Hue[0.9999999999999989, 1, 1.0500000000000058`], 
     Hue[0.9999999999999996, 1, 1.0500000000000027`], 
     Hue[0.9999999999999998, 1, 1.0500000000000014`], 
     Hue[0.9999999999999999, 1, 1.0500000000000005`], 
     Hue[1., 1, 1.0500000000000003`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.7054634507293838, 1, -17.474999625757572`], 
     Hue[0.7054634507293838, 1, -17.100757209075603`], 
     Hue[0.7054634507293838, 1, -16.726514792393633`], 
     Hue[0.7054634507293838, 1, -16.35227237571166], 
     Hue[0.7054634507293839, 1, -15.97802995902969], 
     Hue[0.705463450729384, 1, -15.603787542347721`], 
     Hue[0.705463450729384, 1, -15.229545125665748`], 
     Hue[0.7054634507293842, 1, -14.855302708983777`], 
     Hue[0.7054634507293848, 1, -14.481060292301807`], 
     Hue[0.705463450729386, 1, -14.106817875619834`], 
     Hue[0.7054634507293884, 1, -13.73257545893786], 
     Hue[0.7054634507293941, 1, -13.358333042255884`], 
     Hue[0.7054634507294064, 1, -12.984090625573904`], 
     Hue[0.7054634507294334, 1, -12.60984820889191], 
     Hue[0.7054634507294928, 1, -12.235605792209887`], 
     Hue[0.7054634507296236, 1, -11.861363375527803`], 
     Hue[0.7054634507299109, 1, -11.487120958845585`], 
     Hue[0.7054634507305426, 1, -11.112878542163072`], 
     Hue[0.7054634507319317, 1, -10.73863612547991], 
     Hue[0.7054634507349861, 1, -10.36439370879532], 
     Hue[0.7054634507417017, 1, -9.990151292107589], 
     Hue[0.7054634507564673, 1, -9.615908875412952], 
     Hue[0.705463450788933, 1, -9.241666458703138], 
     Hue[0.7054634508603164, 1, -8.867424041959945], 
     Hue[0.7054634510172687, 1, -8.49318162514336], 
     Hue[0.7054634513623642, 1, -8.118939208165415], 
     Hue[0.7054634521211351, 1, -7.7446967908326725`], 
     Hue[0.7054634537894657, 1, -7.3704543727198315`], 
     Hue[0.7054634574576701, 1, -6.996211952891772], 
     Hue[0.705463465523052, 1, -6.621969529292408], 
     Hue[0.7054634832566293, 1, -6.24772709740098], 
     Hue[0.7054635222479372, 1, -5.873484647277577], 
     Hue[0.7054636079792163, 1, -5.499242157067102], 
     Hue[0.7054637964790283, 1, -5.124999578716433], 
     Hue[0.7054642109391952, 1, -4.7507568065712045`], 
     Hue[0.7054651222263322, 1, -4.376513608332796], 
     Hue[0.705467125908942, 1, -4.002269473271453], 
     Hue[0.7054715315119238, 1, -3.6280232785844406`], 
     Hue[0.7054812184786685, 1, -3.253772556273291], 
     Hue[0.7055025186696999, 1, -2.8795118834540823`], 
     Hue[0.7055493577407772, 1, -2.505229353958664], 
     Hue[0.7056523718931689, 1, -2.1308988729569993`], 
     Hue[0.7058790060574727, 1, -1.756463469888337], 
     Hue[0.7063779582152425, 1, -1.3817998472814874`], 
     Hue[0.7074781060279056, 1, -1.0066464931264345`], 
     Hue[0.7099116094297264, 1, -0.6304756402137464], 
     Hue[0.7153287598106604, 1, -0.25236425202436985`], 
     Hue[0.7275147050720341, 1, 0.12848313320401938`], 
     Hue[0.7550534531434265, 1, 0.5072423826112371], 
     Hue[0.8125141111260783, 1, 0.844099378382268], 
     Hue[0.8929493396033029, 1, 1.031220586723257], 
     Hue[0.9504099975859559, 1, 1.0686060076342008`], 
     Hue[0.9779487456573491, 1, 1.0640891749089545`], 
     Hue[0.9901346909187231, 1, 1.0574842063625367`], 
     Hue[0.9955518412996573, 1, 1.053615234855131], 
     Hue[0.997985344701478, 1, 1.051686798624414], 
     Hue[0.9990854925141412, 1, 1.0507758611513323`], 
     Hue[0.9995844446719112, 1, 1.0503546552264542`], 
     Hue[0.999811078836215, 1, 1.0501616688397635`], 
     Hue[0.9999140929886067, 1, 1.0500736045200696`], 
     Hue[0.9999609320596838, 1, 1.0500334917066223`], 
     Hue[0.9999822322507154, 1, 1.050015235569385], 
     Hue[0.99999191921746, 1, 1.0500069299402062`], 
     Hue[0.9999963248204418, 1, 1.0500031519351638`], 
     Hue[0.9999983285030517, 1, 1.050001433555793], 
     Hue[0.9999992397901886, 1, 1.0500006519993554`], 
     Hue[0.9999996542503554, 1, 1.050000296536098], 
     Hue[0.9999998427501675, 1, 1.0500001348674004`], 
     Hue[0.9999999284814467, 1, 1.0500000613388962`], 
     Hue[0.9999999674727545, 1, 1.050000027897464], 
     Hue[0.9999999852063319, 1, 1.0500000126880067`], 
     Hue[0.9999999932717137, 1, 1.050000005770614], 
     Hue[0.999999996939918, 1, 1.0500000026245246`], 
     Hue[0.9999999986082486, 1, 1.050000001193656], 
     Hue[0.9999999993670197, 1, 1.0500000005428851`], 
     Hue[0.9999999997121152, 1, 1.0500000002469088`], 
     Hue[0.9999999998690675, 1, 1.0500000001122962`], 
     Hue[0.9999999999404507, 1, 1.0500000000510734`], 
     Hue[0.9999999999729166, 1, 1.0500000000232286`], 
     Hue[0.9999999999876822, 1, 1.0500000000105645`], 
     Hue[0.9999999999943977, 1, 1.0500000000048049`], 
     Hue[0.999999999997452, 1, 1.0500000000021854`], 
     Hue[0.9999999999988411, 1, 1.050000000000994], 
     Hue[0.999999999999473, 1, 1.0500000000004521`], 
     Hue[0.9999999999997603, 1, 1.0500000000002057`], 
     Hue[0.999999999999891, 1, 1.0500000000000935`], 
     Hue[0.9999999999999504, 1, 1.0500000000000425`], 
     Hue[0.9999999999999775, 1, 1.0500000000000194`], 
     Hue[0.9999999999999898, 1, 1.050000000000009], 
     Hue[0.9999999999999953, 1, 1.050000000000004], 
     Hue[0.9999999999999979, 1, 1.050000000000002], 
     Hue[0.999999999999999, 1, 1.050000000000001], 
     Hue[0.9999999999999996, 1, 1.0500000000000005`], 
     Hue[0.9999999999999998, 1, 1.0500000000000003`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.8308582518443162, 1, -17.474999625757572`], 
     Hue[0.8308582518443162, 1, -17.100757209075603`], 
     Hue[0.8308582518443162, 1, -16.726514792393633`], 
     Hue[0.8308582518443162, 1, -16.35227237571166], 
     Hue[0.8308582518443162, 1, -15.97802995902969], 
     Hue[0.8308582518443162, 1, -15.603787542347721`], 
     Hue[0.8308582518443163, 1, -15.229545125665748`], 
     Hue[0.8308582518443165, 1, -14.855302708983777`], 
     Hue[0.830858251844317, 1, -14.481060292301807`], 
     Hue[0.830858251844318, 1, -14.10681787561984], 
     Hue[0.8308582518443204, 1, -13.732575458937871`], 
     Hue[0.8308582518443255, 1, -13.358333042255907`], 
     Hue[0.8308582518443366, 1, -12.984090625573957`], 
     Hue[0.8308582518443612, 1, -12.609848208892025`], 
     Hue[0.8308582518444152, 1, -12.235605792210144`], 
     Hue[0.830858251844534, 1, -11.861363375528372`], 
     Hue[0.8308582518447952, 1, -11.487120958846834`], 
     Hue[0.8308582518453695, 1, -11.112878542165816`], 
     Hue[0.8308582518466323, 1, -10.738636125485947`], 
     Hue[0.8308582518494089, 1, -10.364393708808588`], 
     Hue[0.8308582518555137, 1, -9.990151292136762], 
     Hue[0.8308582518689366, 1, -9.615908875477094], 
     Hue[0.8308582518984498, 1, -9.24166645884417], 
     Hue[0.8308582519633412, 1, -8.867424042270033], 
     Hue[0.8308582521060197, 1, -8.49318162582516], 
     Hue[0.8308582524197311, 1, -8.118939209664507], 
     Hue[0.8308582531094968, 1, -7.744696794128768], 
     Hue[0.8308582546261035, 1, -7.370454379967049], 
     Hue[0.8308582579607084, 1, -6.996211968826429], 
     Hue[0.8308582652925958, 1, -6.621969564328374], 
     Hue[0.8308582814134162, 1, -6.2477271744355205`], 
     Hue[0.8308583168587009, 1, -5.873484816655527], 
     Hue[0.8308583947931911, 1, -5.49924252948301], 
     Hue[0.8308585661497465, 1, -5.125000397557309], 
     Hue[0.8308589429153902, 1, -4.750758606978108], 
     Hue[0.8308597713168693, 1, -4.376517566931961], 
     Hue[0.8308615927290749, 1, -4.002278177128217], 
     Hue[0.8308655974365007, 1, -3.628042415877502], 
     Hue[0.8308744023021, 1, -3.2538146334046614`], 
     Hue[0.8308937598941208, 1, -2.879604396886421], 
     Hue[0.8309363127399213, 1, -2.5054327526499858`], 
     Hue[0.831029830258701, 1, -2.1313460275280027`], 
     Hue[0.8312352342010093, 1, -1.7574463304982737`], 
     Hue[0.8316858190415537, 1, -1.3839593638790635`], 
     Hue[0.8326714912112609, 1, -1.011387036671178], 
     Hue[0.8348143382463602, 1, -0.6408590319787144], 
     Hue[0.8394081510253443, 1, -0.2749730936899737], 
     Hue[0.8489450399423015, 1, 0.08013210990446051], 
     Hue[0.867319491109177, 1, 0.4100000375285796], 
     Hue[0.8973167090311219, 1, 0.6854326789621026], 
     Hue[0.933541542813193, 1, 0.8725538873030898], 
     Hue[0.9635387607351382, 1, 0.9713636625515408], 
     Hue[0.9819132119020142, 1, 1.0157381516093944`], 
     Hue[0.9914501008189716, 1, 1.034875364696932], 
     Hue[0.9960439135979559, 1, 1.0432318430901628`], 
     Hue[0.9981867606330551, 1, 1.0469462550796709`], 
     Hue[0.9991724328027624, 1, 1.0486163445537566`], 
     Hue[0.9996230176433069, 1, 1.0493717946165175`], 
     Hue[0.9998284215856151, 1, 1.0497145142687596`], 
     Hue[0.9999219391043949, 1, 1.0498702058287475`], 
     Hue[0.9999644919501952, 1, 1.0499409782742832`], 
     Hue[0.9999838495422162, 1, 1.0499731584380148`], 
     Hue[0.9999926544078155, 1, 1.0499877926471453`], 
     Hue[0.9999966591152413, 1, 1.0499944480783998`], 
     Hue[0.9999984805274469, 1, 1.0499974749566279`], 
     Hue[0.999999308928926, 1, 1.0499988515924512`], 
     Hue[0.9999996856945695, 1, 1.0499994776952222`], 
     Hue[0.999999857051125, 1, 1.0499997624514927`], 
     Hue[0.9999999349856152, 1, 1.0499998919609466`], 
     Hue[0.9999999704308998, 1, 1.049999950862924], 
     Hue[0.9999999865517204, 1, 1.0499999776520406`], 
     Hue[0.9999999938836076, 1, 1.0499999898359578`], 
     Hue[0.9999999972182125, 1, 1.0499999953773071`], 
     Hue[0.9999999987348194, 1, 1.0499999978975598`], 
     Hue[0.9999999994245851, 1, 1.0499999990437923`], 
     Hue[0.9999999997382963, 1, 1.0499999995651086`], 
     Hue[0.999999999880975, 1, 1.0499999998022078`], 
     Hue[0.9999999999458664, 1, 1.0499999999100424`], 
     Hue[0.9999999999753796, 1, 1.0499999999590865`], 
     Hue[0.9999999999888024, 1, 1.0499999999813923`], 
     Hue[0.9999999999949073, 1, 1.049999999991537], 
     Hue[0.9999999999976837, 1, 1.049999999996151], 
     Hue[0.9999999999989465, 1, 1.0499999999982494`], 
     Hue[0.9999999999995209, 1, 1.0499999999992038`], 
     Hue[0.9999999999997821, 1, 1.049999999999638], 
     Hue[0.9999999999999009, 1, 1.0499999999998355`], 
     Hue[0.9999999999999549, 1, 1.0499999999999252`], 
     Hue[0.9999999999999795, 1, 1.049999999999966], 
     Hue[0.9999999999999907, 1, 1.0499999999999845`], 
     Hue[0.9999999999999958, 1, 1.049999999999993], 
     Hue[0.9999999999999981, 1, 1.049999999999997], 
     Hue[0.9999999999999991, 1, 1.0499999999999985`], 
     Hue[0.9999999999999996, 1, 1.0499999999999994`], 
     Hue[0.9999999999999998, 1, 1.0499999999999998`], 
     Hue[0.9999999999999999, 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.9562530529592472, 1, -17.474999625757572`], 
     Hue[0.9562530529592472, 1, -17.100757209075603`], 
     Hue[0.9562530529592472, 1, -16.726514792393633`], 
     Hue[0.9562530529592473, 1, -16.35227237571166], 
     Hue[0.9562530529592473, 1, -15.97802995902969], 
     Hue[0.9562530529592473, 1, -15.603787542347721`], 
     Hue[0.9562530529592473, 1, -15.229545125665748`], 
     Hue[0.9562530529592475, 1, -14.855302708983777`], 
     Hue[0.9562530529592476, 1, -14.48106029230181], 
     Hue[0.9562530529592479, 1, -14.106817875619843`], 
     Hue[0.9562530529592486, 1, -13.732575458937879`], 
     Hue[0.9562530529592502, 1, -13.358333042255923`], 
     Hue[0.9562530529592537, 1, -12.984090625573991`], 
     Hue[0.9562530529592613, 1, -12.6098482088921], 
     Hue[0.9562530529592781, 1, -12.235605792210306`], 
     Hue[0.956253052959315, 1, -11.861363375528727`], 
     Hue[0.9562530529593961, 1, -11.487120958847612`], 
     Hue[0.9562530529595745, 1, -11.112878542167529`], 
     Hue[0.9562530529599669, 1, -10.738636125489712`], 
     Hue[0.9562530529608294, 1, -10.364393708816868`], 
     Hue[0.9562530529627259, 1, -9.99015129215497], 
     Hue[0.9562530529668959, 1, -9.615908875517126], 
     Hue[0.9562530529760644, 1, -9.241666458932189], 
     Hue[0.9562530529962235, 1, -8.867424042463561], 
     Hue[0.956253053040548, 1, -8.49318162625068], 
     Hue[0.9562530531380055, 1, -8.118939210600107], 
     Hue[0.9562530533522877, 1, -7.7446967961859], 
     Hue[0.956253053823436, 1, -7.370454384490119], 
     Hue[0.9562530548593626, 1, -6.9962119787714245`], 
     Hue[0.956253057137083, 1, -6.621969586194711], 
     Hue[0.9562530621451684, 1, -6.247727222513627], 
     Hue[0.9562530731565794, 1, -5.873484922366142], 
     Hue[0.9562530973676523, 1, -5.499242761911656], 
     Hue[0.9562531506011116, 1, -5.125000908603647], 
     Hue[0.956253267646537, 1, -4.750759730625323], 
     Hue[0.9562535249953829, 1, -4.376520037504638], 
     Hue[0.9562540908249826, 1, -4.00228360914114], 
     Hue[0.9562553348799007, 1, -3.628054358895154], 
     Hue[0.9562580699751168, 1, -3.2538408904364235`], 
     Hue[0.9562640825319705, 1, -2.8796621172980714`], 
     Hue[0.95627729684201, 1, -2.5055596078263465`], 
     Hue[0.9563063241556211, 1, -2.1316246756323984`], 
     Hue[0.9563700153764894, 1, -1.7580576897683284`], 
     Hue[0.9565094204200744, 1, -1.3852972580279002`], 
     Hue[0.9568129000184376, 1, -1.0142984135663762`], 
     Hue[0.9574658511401465, 1, -0.647116639405551], 
     Hue[0.9588358225968425, 1, -0.28806514816754825`], 
     Hue[0.961563876635427, 1, 0.05428773861328018], 
     Hue[0.9664688452471016, 1, 0.3647889026858231], 
     Hue[0.9738470285920817, 1, 0.6223676089161846], 
     Hue[0.9824060243671653, 1, 0.8094888172571716], 
     Hue[0.9897842077121455, 1, 0.9261525277087836], 
     Hue[0.9946891763238203, 1, 0.9898937803182134], 
     Hue[0.9974172303624047, 1, 1.0217833102193572`], 
     Hue[0.9987872018191007, 1, 1.036974235663326], 
     Hue[0.9994401529408098, 1, 1.0440348781844728`], 
     Hue[0.999743632539173, 1, 1.0472784504049195`], 
     Hue[0.999883037582758, 1, 1.0487604353464623`], 
     Hue[0.9999467288036261, 1, 1.049435866164364], 
     Hue[0.9999757561172373, 1, 1.049743350652387], 
     Hue[0.9999889704272767, 1, 1.0498832578626325`], 
     Hue[0.9999949829841306, 1, 1.049946901406252], 
     Hue[0.9999977180793467, 1, 1.0499758496294924`], 
     Hue[0.9999989621342646, 1, 1.0499890160654777`], 
     Hue[0.9999995279638645, 1, 1.0499950043839517`], 
     Hue[0.9999997853127103, 1, 1.049997727945236], 
     Hue[0.9999999023581357, 1, 1.049998966648883], 
     Hue[0.999999955591595, 1, 1.0499995300228457`], 
     Hue[0.999999979802668, 1, 1.0499997862503305`], 
     Hue[0.999999990814079, 1, 1.049999902784817], 
     Hue[0.9999999958221644, 1, 1.0499999557857038`], 
     Hue[0.9999999980998846, 1, 1.0499999798909605`], 
     Hue[0.9999999991358113, 1, 1.0499999908542375`], 
     Hue[0.9999999996069596, 1, 1.0499999958404291`], 
     Hue[0.9999999998212419, 1, 1.0499999981081918`], 
     Hue[0.9999999999186993, 1, 1.0499999991395894`], 
     Hue[0.9999999999630237, 1, 1.049999999608678], 
     Hue[0.9999999999831829, 1, 1.0499999998220235`], 
     Hue[0.9999999999923515, 1, 1.0499999999190548`], 
     Hue[0.9999999999965213, 1, 1.0499999999631855`], 
     Hue[0.9999999999984179, 1, 1.0499999999832565`], 
     Hue[0.9999999999992805, 1, 1.049999999992385], 
     Hue[0.9999999999996727, 1, 1.0499999999965366`], 
     Hue[0.9999999999998511, 1, 1.0499999999984249`], 
     Hue[0.9999999999999323, 1, 1.0499999999992837`], 
     Hue[0.9999999999999692, 1, 1.0499999999996743`], 
     Hue[0.999999999999986, 1, 1.049999999999852], 
     Hue[0.9999999999999937, 1, 1.0499999999999325`], 
     Hue[0.9999999999999971, 1, 1.0499999999999694`], 
     Hue[0.9999999999999987, 1, 1.049999999999986], 
     Hue[0.9999999999999994, 1, 1.0499999999999936`], 
     Hue[0.9999999999999998, 1, 1.0499999999999972`], 
     Hue[0.9999999999999999, 1, 1.0499999999999987`], 
     Hue[0.9999999999999999, 1, 1.0499999999999994`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.0816478540741785`, 1, -17.474999625757572`], 
     Hue[1.0816478540741785`, 1, -17.100757209075603`], 
     Hue[1.0816478540741785`, 1, -16.726514792393633`], 
     Hue[1.0816478540741785`, 1, -16.35227237571166], 
     Hue[1.0816478540741785`, 1, -15.97802995902969], 
     Hue[1.0816478540741785`, 1, -15.603787542347721`], 
     Hue[1.0816478540741783`, 1, -15.229545125665748`], 
     Hue[1.0816478540741783`, 1, -14.855302708983777`], 
     Hue[1.081647854074178, 1, -14.48106029230181], 
     Hue[1.0816478540741774`, 1, -14.106817875619841`], 
     Hue[1.081647854074176, 1, -13.732575458937879`], 
     Hue[1.0816478540741732`, 1, -13.35833304225592], 
     Hue[1.081647854074167, 1, -12.984090625573984`], 
     Hue[1.0816478540741532`, 1, -12.609848208892084`], 
     Hue[1.0816478540741228`, 1, -12.235605792210276`], 
     Hue[1.081647854074056, 1, -11.861363375528658`], 
     Hue[1.0816478540739094`, 1, -11.487120958847465`], 
     Hue[1.0816478540735868`, 1, -11.112878542167202`], 
     Hue[1.0816478540728773`, 1, -10.73863612548899], 
     Hue[1.0816478540713177`, 1, -10.364393708815282`], 
     Hue[1.0816478540678882`, 1, -9.99015129215148], 
     Hue[1.0816478540603478`, 1, -9.615908875509458], 
     Hue[1.0816478540437688`, 1, -9.241666458915326], 
     Hue[1.0816478540073158`, 1, -8.867424042426487], 
     Hue[1.081647853927166, 1, -8.493181626169159], 
     Hue[1.0816478537509377`, 1, -8.118939210420868], 
     Hue[1.0816478533634604`, 1, -7.744696795791799], 
     Hue[1.081647852511503, 1, -7.370454383623602], 
     Hue[1.0816478506382812`, 1, -6.9962119768661895`], 
     Hue[1.081647846519577, 1, -6.621969582005615], 
     Hue[1.08164783746367, 1, -6.247727213302947], 
     Hue[1.0816478175522053`, 1, -5.873484902114377], 
     Hue[1.0816477737723518`, 1, -5.49924271738359], 
     Hue[1.0816476775125357`, 1, -5.125000810698785], 
     Hue[1.08164746586416, 1, -4.750759515360282], 
     Hue[1.0816470005105758`, 1, -4.376519564200645], 
     Hue[1.081645977341853, 1, -4.002282568499646], 
     Hue[1.0816437277547961`, 1, -3.6280520709289465`], 
     Hue[1.0816387819229154`, 1, -3.2538358604063573`], 
     Hue[1.0816279093053243`, 1, -2.8796510604557746`], 
     Hue[1.0816040126551107`, 1, -2.505535310483121], 
     Hue[1.0815515152231414`, 1, -2.131571318252936], 
     Hue[1.0814363037928552`, 1, -1.7579406889275602`], 
     Hue[1.081184025659628, 1, -1.3850415306431165`], 
     Hue[1.0806343182906224`, 1, -1.013743416147755], 
     Hue[1.079449271264104, 1, -0.6459305213961417], 
     Hue[1.0769528876035064`, 1, -0.285612259794211], 
     Hue[1.0719440319878202`, 1, 0.05902601064617208], 
     Hue[1.0628295741858553`, 1, 0.37280977243477664`], 
     Hue[1.0489343887219584`, 1, 0.6332227342342469], 
     Hue[1.0327134653522207`, 1, 0.8203439425752339], 
     Hue[1.0188182798883234`, 1, 0.9341733974577373], 
     Hue[1.0097038220863586`, 1, 0.9946320523511054], 
     Hue[1.0046949664706721`, 1, 1.0242361985926947`], 
     Hue[1.0021985828100746`, 1, 1.0381603536727353`], 
     Hue[1.0010135357835561`, 1, 1.0445898756030934`], 
     Hue[1.0004638284145506`, 1, 1.0475341777897034`], 
     Hue[1.0002115502813231`, 1, 1.0488774361872308`], 
     Hue[1.000096338851037, 1, 1.049489223543826], 
     Hue[1.0000438414190678`, 1, 1.0497676479956124`], 
     Hue[1.0000199447688543`, 1, 1.0498943147049296`], 
     Hue[1.0000090721512631`, 1, 1.0499519314363188`], 
     Hue[1.0000041263193824`, 1, 1.0499781375957005`], 
     Hue[1.0000018767323253`, 1, 1.0499900567069715`], 
     Hue[1.0000008535636027`, 1, 1.0499954776879434`], 
     Hue[1.0000003882100186`, 1, 1.0499979432102782`], 
     Hue[1.0000001765616429`, 1, 1.0499990645537456`], 
     Hue[1.0000000803018267`, 1, 1.0499995745509128`], 
     Hue[1.0000000365219732`, 1, 1.049999806502096], 
     Hue[1.0000000166105085`, 1, 1.0499999119954968`], 
     Hue[1.0000000075546016`, 1, 1.0499999599748004`], 
     Hue[1.0000000034358973`, 1, 1.0499999817961978`], 
     Hue[1.0000000015626755`, 1, 1.0499999917207556`], 
     Hue[1.0000000007107182`, 1, 1.049999996234529], 
     Hue[1.0000000003232408`, 1, 1.0499999982874317`], 
     Hue[1.0000000001470126`, 1, 1.0499999992211093`], 
     Hue[1.0000000000668625`, 1, 1.0499999996457539`], 
     Hue[1.0000000000304097`, 1, 1.0499999998388858`], 
     Hue[1.0000000000138305`, 1, 1.049999999926724], 
     Hue[1.0000000000062903`, 1, 1.0499999999666734`], 
     Hue[1.0000000000028608`, 1, 1.0499999999848428`], 
     Hue[1.0000000000013012`, 1, 1.0499999999931064`], 
     Hue[1.0000000000005917`, 1, 1.0499999999968648`], 
     Hue[1.0000000000002691`, 1, 1.049999999998574], 
     Hue[1.0000000000001223`, 1, 1.0499999999993515`], 
     Hue[1.0000000000000557`, 1, 1.049999999999705], 
     Hue[1.0000000000000253`, 1, 1.049999999999866], 
     Hue[1.0000000000000115`, 1, 1.049999999999939], 
     Hue[1.0000000000000053`, 1, 1.0499999999999723`], 
     Hue[1.0000000000000024`, 1, 1.0499999999999874`], 
     Hue[1.000000000000001, 1, 1.0499999999999943`], 
     Hue[1.0000000000000004`, 1, 1.0499999999999974`], 
     Hue[1.0000000000000002`, 1, 1.049999999999999], 
     Hue[1., 1, 1.0499999999999996`], 
     Hue[1., 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1.207042655189114, 1, -17.474999625757572`], 
     Hue[1.207042655189114, 1, -17.100757209075603`], 
     Hue[1.207042655189114, 1, -16.726514792393633`], 
     Hue[1.207042655189114, 1, -16.35227237571166], 
     Hue[1.207042655189114, 1, -15.97802995902969], 
     Hue[1.207042655189114, 1, -15.603787542347721`], 
     Hue[1.207042655189114, 1, -15.229545125665748`], 
     Hue[1.2070426551891138`, 1, -14.855302708983777`], 
     Hue[1.2070426551891131`, 1, -14.481060292301807`], 
     Hue[1.207042655189112, 1, -14.106817875619837`], 
     Hue[1.2070426551891096`, 1, -13.732575458937868`], 
     Hue[1.2070426551891038`, 1, -13.358333042255902`], 
     Hue[1.2070426551890916`, 1, -12.984090625573941`], 
     Hue[1.2070426551890645`, 1, -12.609848208891991`], 
     Hue[1.2070426551890048`, 1, -12.235605792210071`], 
     Hue[1.2070426551888738`, 1, -11.861363375528208`], 
     Hue[1.2070426551885856`, 1, -11.487120958846475`], 
     Hue[1.207042655187952, 1, -11.112878542165026`], 
     Hue[1.2070426551865592`, 1, -10.738636125484206`], 
     Hue[1.2070426551834963`, 1, -10.364393708804764`], 
     Hue[1.207042655176762, 1, -9.990151292128353], 
     Hue[1.2070426551619549`, 1, -9.615908875458608], 
     Hue[1.207042655129398, 1, -9.24166645880352], 
     Hue[1.2070426550578148`, 1, -8.867424042180653], 
     Hue[1.2070426549004225`, 1, -8.49318162562864], 
     Hue[1.20704265455436, 1, -8.118939209232414], 
     Hue[1.2070426537934629`, 1, -7.744696793178712], 
     Hue[1.2070426521204574`, 1, -7.370454377878134], 
     Hue[1.2070426484419743`, 1, -6.9962119642334715`], 
     Hue[1.2070426403539927`, 1, -6.621969554229714], 
     Hue[1.207042622570726, 1, -6.247727152231319], 
     Hue[1.207042583470173, 1, -5.873484767834549], 
     Hue[1.2070424974987315`, 1, -5.49924242213903], 
     Hue[1.2070423084710513`, 1, -5.125000161537371], 
     Hue[1.2070418928511346`, 1, -4.7507580880356475`], 
     Hue[1.2070409790183168`, 1, -4.376516425924033], 
     Hue[1.207038969759204, 1, -4.002275668387488], 
     Hue[1.2070345519953531`, 1, -3.6280368999599855`], 
     Hue[1.2070248387752576`, 1, -3.2538025059837548`], 
     Hue[1.2070034832053749`, 1, -2.8795777347897973`], 
     Hue[1.2069565337085892`, 1, -2.505374143490335], 
     Hue[1.2068533315699377`, 1, -2.1312172273775554`], 
     Hue[1.2066265490540535`, 1, -1.7571634507032254`], 
     Hue[1.2061285517613034`, 1, -1.3833389229418522`], 
     Hue[1.2050366961267251`, 1, -1.0100303154256751`], 
     Hue[1.2026513400353551`, 1, -0.6379124314492823], 
     Hue[1.1974840018259547`, 1, -0.26867415982197085`], 
     Hue[1.1865262941919243`, 1, 0.0930886773867925], 
     Hue[1.1645874336191513`, 1, 0.4341911431808394], 
     Hue[1.1269012920689254`, 1, 0.7213798408786523], 
     Hue[1.0801413631201904`, 1, 0.9085010492196399], 
     Hue[1.042455221569964, 1, 0.9955547682038012], 
     Hue[1.0205163609971903`, 1, 1.0286947190917266`], 
     Hue[1.0095586533631598`, 1, 1.0411742985649353`], 
     Hue[1.0043913151537591`, 1, 1.0461784436195949`], 
     Hue[1.002005959062389, 1, 1.0483029763251737`], 
     Hue[1.0009141034278108`, 1, 1.0492367854909674`], 
     Hue[1.0004161061350607`, 1, 1.0496546744115656`], 
     Hue[1.0001893236191763`, 1, 1.049843314419207], 
     Hue[1.000086121480525, 1, 1.049928814988398], 
     Hue[1.0000391719837394`, 1, 1.049967640370907], 
     Hue[1.0000178164138567`, 1, 1.0499852858589214`], 
     Hue[1.000008103193761, 1, 1.049993308564661], 
     Hue[1.00000368542991, 1, 1.0499969568191303`], 
     Hue[1.0000016761707973`, 1, 1.0499986159645565`], 
     Hue[1.0000007623379796`, 1, 1.0499993705349129`], 
     Hue[1.000000346718063, 1, 1.0499997137151598`], 
     Hue[1.0000001576903828`, 1, 1.049999869795472], 
     Hue[1.0000000717189412`, 1, 1.049999940781924], 
     Hue[1.000000032618388, 1, 1.0499999730671252`], 
     Hue[1.0000000148351214`, 1, 1.0499999877507011`], 
     Hue[1.0000000067471397`, 1, 1.0499999944289151`], 
     Hue[1.0000000030686567`, 1, 1.049999997466223], 
     Hue[1.0000000013956512`, 1, 1.0499999988476167`], 
     Hue[1.000000000634754, 1, 1.0499999994758862`], 
     Hue[1.0000000002886915`, 1, 1.0499999997616287`], 
     Hue[1.0000000001312994`, 1, 1.0499999998915868`], 
     Hue[1.000000000059716, 1, 1.0499999999506926`], 
     Hue[1.0000000000271594`, 1, 1.0499999999775746`], 
     Hue[1.0000000000123523`, 1, 1.0499999999898009`], 
     Hue[1.000000000005618, 1, 1.0499999999953613`], 
     Hue[1.000000000002555, 1, 1.0499999999978904`], 
     Hue[1.0000000000011622`, 1, 1.0499999999990406`], 
     Hue[1.0000000000005285`, 1, 1.0499999999995635`], 
     Hue[1.0000000000002405`, 1, 1.0499999999998015`], 
     Hue[1.0000000000001092`, 1, 1.0499999999999097`], 
     Hue[1.0000000000000497`, 1, 1.049999999999959], 
     Hue[1.0000000000000226`, 1, 1.0499999999999814`], 
     Hue[1.0000000000000102`, 1, 1.0499999999999916`], 
     Hue[1.0000000000000047`, 1, 1.049999999999996], 
     Hue[1.0000000000000022`, 1, 1.0499999999999983`], 
     Hue[1.0000000000000009`, 1, 1.0499999999999992`], 
     Hue[1.0000000000000004`, 1, 1.0499999999999998`], 
     Hue[1.0000000000000002`, 1, 1.0499999999999998`], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[1., 1, 1.05], 
     Hue[0.7929573448108859, 1, -17.264488266373966`], 
     Hue[0.918352145925817, 1, -17.264488266373966`], 
     Hue[0.7929573448108859, 1, -17.07736705803298], 
     Hue[0.7929573448108859, 1, -16.90742299186392], 
     Hue[0.918352145925817, 1, -17.07736705803298], 
     Hue[0.918352145925817, 1, -16.90742299186392], 
     Hue[0.7929573448108859, 1, -16.70312464135101], 
     Hue[0.7929573448108859, 1, -16.53318057518195], 
     Hue[0.918352145925817, 1, -16.70312464135101], 
     Hue[0.918352145925817, 1, -16.53318057518195], 
     Hue[0.7929573448108859, 1, -16.32888222466904], 
     Hue[0.7929573448108859, 1, -16.15893815849998], 
     Hue[0.918352145925817, 1, -16.32888222466904], 
     Hue[0.918352145925817, 1, -16.15893815849998], 
     Hue[0.7929573448108859, 1, -15.954639807987068`], 
     Hue[0.7929573448108859, 1, -15.784695741818005`], 
     Hue[0.918352145925817, 1, -15.954639807987068`], 
     Hue[0.918352145925817, 1, -15.784695741818005`], 
     Hue[0.792957344810886, 1, -15.580397391305098`], 
     Hue[0.792957344810886, 1, -15.407712291810729`], 
     Hue[0.918352145925817, 1, -15.580397391305098`], 
     Hue[0.918352145925817, 1, -15.407712291810729`], 
     Hue[0.7929573448108861, 1, -15.206154974623129`], 
     Hue[0.7929573448108862, 1, -15.033469875128759`], 
     Hue[0.9183521459258172, 1, -15.206154974623129`], 
     Hue[0.9183521459258172, 1, -15.033469875128759`], 
     Hue[0.7929573448108863, 1, -14.831912557941154`], 
     Hue[0.7929573448108864, 1, -14.657856941784134`], 
     Hue[0.9183521459258173, 1, -14.831912557941154`], 
     Hue[0.9183521459258174, 1, -14.657856941784138`], 
     Hue[0.7929573448108869, 1, -14.457670141259184`], 
     Hue[0.7929573448108873, 1, -14.283614525102161`], 
     Hue[0.9183521459258175, 1, -14.457670141259188`], 
     Hue[0.9183521459258177, 1, -14.283614525102164`], 
     Hue[0.7929573448108881, 1, -14.083427724577215`], 
     Hue[0.7929573448108891, 1, -13.908172906340374`], 
     Hue[0.9183521459258182, 1, -14.08342772457722], 
     Hue[0.9183521459258186, 1, -13.90817290634038], 
     Hue[0.7929573448108908, 1, -13.709185307895245`], 
     Hue[0.7929573448108933, 1, -13.511830908473113`], 
     Hue[0.9183521459258195, 1, -13.709185307895256`], 
     Hue[0.9183521459258208, 1, -13.511830908473128`], 
     Hue[0.7929573448108966, 1, -13.33494289121328], 
     Hue[0.7929573448109022, 1, -13.137588491791151`], 
     Hue[0.9183521459258225, 1, -13.3349428912133], 
     Hue[0.9183521459258254, 1, -13.137588491791181`], 
     Hue[0.7929573448109096, 1, -12.96070047453132], 
     Hue[0.7929573448109218, 1, -12.763346075109196`], 
     Hue[0.9183521459258291, 1, -12.960700474531365`], 
     Hue[0.9183521459258354, 1, -12.763346075109263`], 
     Hue[0.792957344810938, 1, -12.586458057849372`], 
     Hue[0.792957344810965, 1, -12.38910365842726], 
     Hue[0.9183521459258436, 1, -12.586458057849468`], 
     Hue[0.9183521459258573, 1, -12.389103658427409`], 
     Hue[0.7929573448110007, 1, -12.212215641167454`], 
     Hue[0.7929573448110598, 1, -12.014861241745368`], 
     Hue[0.9183521459258754, 1, -12.212215641167669`], 
     Hue[0.9183521459259056, 1, -12.014861241745693`], 
     Hue[0.7929573448111383, 1, -11.837973224485596`], 
     Hue[0.7929573448112683, 1, -11.640618825063568`], 
     Hue[0.9183521459259456, 1, -11.837973224486069`], 
     Hue[0.9183521459260118, 1, -11.640618825064285`], 
     Hue[0.7929573448114411, 1, -11.463730807803874`], 
     Hue[0.7929573448117271, 1, -11.266376408381976`], 
     Hue[0.9183521459260997, 1, -11.463730807804914`], 
     Hue[0.9183521459262454, 1, -11.26637640838355], 
     Hue[0.7929573448121066, 1, -11.089488391122453`], 
     Hue[0.7929573448127354, 1, -10.892133991700838`], 
     Hue[0.9183521459264387, 1, -11.089488391124739`], 
     Hue[0.9183521459267588, 1, -10.892133991704302`], 
     Hue[0.7929573448135698, 1, -10.71524597444169], 
     Hue[0.7929573448149525, 1, -10.517891575020698`], 
     Hue[0.9183521459271838, 1, -10.715245974446715`], 
     Hue[0.9183521459278879, 1, -10.517891575028312`], 
     Hue[0.7929573448167874, 1, -10.341003557762374`], 
     Hue[0.7929573448198273, 1, -10.14364915834275], 
     Hue[0.9183521459288223, 1, -10.341003557773425`], 
     Hue[0.9183521459303703, 1, -10.14364915835949], 
     Hue[0.7929573448241851, 1, -9.9550660655652], 
     Hue[0.7929573448307584, 1, -9.764290146129232], 
     Hue[0.9183521459325895, 1, -9.9550660655901], 
     Hue[0.918352145935937, 1, -9.76429014616644], 
     Hue[0.7929573448401273, 1, -9.580823648896395], 
     Hue[0.7929573448545802, 1, -9.39004772946693], 
     Hue[0.9183521459407078, 1, -9.580823648951144], 
     Hue[0.9183521459480679, 1, -9.39004772954874], 
     Hue[0.7929573448751798, 1, -9.206581232243364], 
     Hue[0.7929573449069579, 1, -9.015805312828206], 
     Hue[0.918352145958558, 1, -9.206581232363744], 
     Hue[0.9183521459747406, 1, -9.015805313008084], 
     Hue[0.7929573449522507, 1, -8.83233881562503], 
     Hue[0.7929573450221221, 1, -8.641562896241327], 
     Hue[0.9183521459978052, 1, -8.832338815889708], 
     Hue[0.9183521460333864, 1, -8.641562896636826], 
     Hue[0.7929573451217085, 1, -8.458096399082981], 
     Hue[0.7929573452753368, 1, -8.267320479768435], 
     Hue[0.9183521460840997, 1, -8.458096399664937], 
     Hue[0.918352146162333, 1, -8.267320480638029], 
     Hue[0.7929573454943002, 1, -8.083853982708657], 
     Hue[0.792957345832087, 1, -7.893078063546171], 
     Hue[0.9183521462738373, 1, -8.083853983988218], 
     Hue[0.9183521464458511, 1, -7.893078065458174], 
     Hue[0.7929573463135277, 1, -7.709611566703118], 
     Hue[0.7929573470562289, 1, -7.518835647874972], 
     Hue[0.9183521466910187, 1, -7.709611569516526], 
     Hue[0.9183521470692302, 1, -7.51883565207894], 
     Hue[0.7929573481147858, 1, -7.335369151508439], 
     Hue[0.7929573497477831, 1, -7.144593233415404], 
     Hue[0.9183521476082871, 1, -7.3353691576943545`], 
     Hue[0.9183521484398709, 1, -7.144593242658792], 
     Hue[0.7929573520752612, 1, -6.961126738096618], 
     Hue[0.7929573556657775, 1, -6.770350821619895], 
     Hue[0.9183521496251101, 1, -6.9611267516977575`], 
     Hue[0.9183521514535361, 1, -6.770350841943586], 
     Hue[0.7929573607832673, 1, -6.586884328604811], 
     Hue[0.7929573686778338, 1, -6.39610841568193], 
     Hue[0.9183521540595542, 1, -6.586884358510011], 
     Hue[0.9183521580797639, 1, -6.39610846036818], 
     Hue[0.7929573803648058, 1, -6.206794390330587], 
     Hue[0.7929573975711949, 1, -6.019307725086818], 
     Hue[0.9183521640312083, 1, -6.206794456898431], 
     Hue[0.9183521727933461, 1, -6.01930782387029], 
     Hue[0.7929574229842606, 1, -5.832552008839367], 
     Hue[0.792957460816414, 1, -5.645065360626262], 
     Hue[0.9183521857346287, 1, -5.832552155203867], 
     Hue[0.9183522050001701, 1, -5.645065577824093], 
     Hue[0.7929575166928048, 1, -5.458309669532378], 
     Hue[0.7929575998753663, 1, -5.270823058765196], 
     Hue[0.9183522334544986, 1, -5.458309991347803], 
     Hue[0.9183522758141176, 1, -5.270823536323543], 
     Hue[0.792957722732248, 1, -5.084067422977441], 
     Hue[0.7929579056278684, 1, -4.8965808945442815`], 
     Hue[0.9183523383773086, 1, -5.084068130560773], 
     Hue[0.918352431514296, 1, -4.896581944562557], 
     Hue[0.7929581757563131, 1, -4.709825380361038], 
     Hue[0.792958605231091, 1, -4.5119231288984025`], 
     Hue[0.91835256907311, 1, -4.709826936138722], 
     Hue[0.9183527877760246, 1, -4.511925488775212], 
     Hue[0.7929591831107661, 1, -4.332660026594159], 
     Hue[0.7929600633267064, 1, -4.146818693969353], 
     Hue[0.9183530820505057, 1, -4.332663468420146], 
     Hue[0.918353530281533, 1, -4.1468237837872435`], 
     Hue[0.7929613867158539, 1, -3.95841942955031], 
     Hue[0.7929634533941161, 1, -3.7622545178949913`], 
     Hue[0.9183542041831266, 1, -3.958426997063958], 
     Hue[0.9183552565713584, 1, -3.7622659546419417`], 
     Hue[0.79296625917624, 1, -3.5827191522351685`], 
     Hue[0.7929707925524317, 1, -3.3874242720197056`], 
     Hue[0.9183566852965918, 1, -3.582735841819665], 
     Hue[0.9183589936588681, 1, -3.3874494483985744`], 
     Hue[0.7929769748897584, 1, -3.2077546443396106`], 
     Hue[0.7929869303895217, 1, -3.01289824201419], 
     Hue[0.9183621415272528, 1, -3.2077913937778755`], 
     Hue[0.9183672102590901, 1, -3.012953625995012], 
     Hue[0.7930005686208814, 1, -2.8328236235946864`], 
     Hue[0.7930224308229996, 1, -2.638397506078788], 
     Hue[0.9183752650173473, 1, -2.809497430597288], 
     Hue[0.9183852823198008, 1, -2.638510045925372], 
     Hue[0.793057174164815, 1, -2.435215034628241], 
     Hue[0.7931004345720146, 1, -2.2642103811589074`], 
     Hue[0.9184029627979239, 1, -2.4354018398673976`], 
     Hue[0.9184249715561256, 1, -2.264478071437253], 
     Hue[0.7931767965933579, 1, -2.0610717753015493`], 
     Hue[0.7932718660960876, 1, -1.8901103069328367`], 
     Hue[0.9184638024991909, 1, -2.0614821444349998`], 
     Hue[0.9185121138336417, 1, -1.8906981358164991`], 
     Hue[0.7934396377579931, 1, -1.6870482484135982`], 
     Hue[0.7936484350243493, 1, -1.5161826474584863`], 
     Hue[0.9185972821815014, 1, -1.6879487769212946`], 
     Hue[0.9187031206232098, 1, -1.5174715063753001`], 
     Hue[0.7940166985160431, 1, -1.313291300700379], 
     Hue[0.7944746423464804, 1, -1.142640881028549], 
     Hue[0.9188893713123538, 1, -1.3152628195712939`], 
     Hue[0.9191356187187034, 1, -1.136037493677055], 
     Hue[0.7952250239239654, 1, -0.9517823716418234], 
     Hue[0.7963157926287906, 1, -0.7652585938101457], 
     Hue[0.9195107541311032, 1, -0.9502015284635259], 
     Hue[0.9200655854251313, 1, -0.7643469452084228], 
     Hue[0.7979186302712398, 1, -0.5799619401899554], 
     Hue[0.8003616634480243, 1, -0.3898670517275895], 
     Hue[0.9208831910677889, 1, -0.5790462486788923], 
     Hue[0.9221556632661447, 1, -0.3856068213316941], 
     Hue[0.8039376910167902, 1, -0.20290189414236837`], 
     Hue[0.8092119286686172, 1, -0.017023767852071714`], 
     Hue[0.9239392533604879, 1, -0.2030048349871163], 
     Hue[0.9266498422874198, 1, -0.015252267918329121`], 
     Hue[0.8172576702964525, 1, 0.17295981744174693`], 
     Hue[0.8290394745053534, 1, 0.35850211194666914`], 
     Hue[0.9306340208075652, 1, 0.17076106323803764`], 
     Hue[0.9366394348869866, 1, 0.3592757164850413], 
     Hue[0.8470976636821219, 1, 0.5461276685703053], 
     Hue[0.9455365228024409, 1, 0.5463167043336311], 
     Hue[0.8754818518713068, 1, 0.734065648189032], 
     Hue[0.9589833666763473, 1, 0.7343574564123183], 
     Hue[0.924533795542217, 1, 0.9217318012278398], 
     Hue[0.9794536384048675, 1, 0.9216020435240968], 
     Hue[1.043746947040748, 1, -17.264488266373966`], 
     Hue[1.043746947040748, 1, -17.07736705803298], 
     Hue[1.043746947040748, 1, -16.90742299186392], 
     Hue[1.043746947040748, 1, -16.70312464135101], 
     Hue[1.043746947040748, 1, -16.53318057518195], 
     Hue[1.043746947040748, 1, -16.32888222466904], 
     Hue[1.043746947040748, 1, -16.15893815849998], 
     Hue[1.043746947040748, 1, -15.954639807987068`], 
     Hue[1.043746947040748, 1, -15.784695741818005`], 
     Hue[1.043746947040748, 1, -15.580397391305098`], 
     Hue[1.043746947040748, 1, -15.407712291810729`], 
     Hue[1.043746947040748, 1, -15.206154974623129`], 
     Hue[1.043746947040748, 1, -15.033469875128759`], 
     Hue[1.043746947040748, 1, -14.831912557941154`], 
     Hue[1.043746947040748, 1, -14.657856941784138`], 
     Hue[1.0437469470407479`, 1, -14.457670141259188`], 
     Hue[1.0437469470407477`, 1, -14.283614525102164`], 
     Hue[1.0437469470407477`, 1, -14.08342772457722], 
     Hue[1.0437469470407472`, 1, -13.908172906340381`], 
     Hue[1.0437469470407468`, 1, -13.709185307895257`], 
     Hue[1.043746947040746, 1, -13.51183090847313], 
     Hue[1.0437469470407452`, 1, -13.334942891213304`], 
     Hue[1.0437469470407437`, 1, -13.137588491791186`], 
     Hue[1.0437469470407414`, 1, -12.960700474531372`], 
     Hue[1.0437469470407381`, 1, -12.763346075109274`], 
     Hue[1.0437469470407335`, 1, -12.586458057849484`], 
     Hue[1.043746947040726, 1, -12.38910365842743], 
     Hue[1.043746947040716, 1, -12.2122156411677], 
     Hue[1.0437469470406993`, 1, -12.014861241745743`], 
     Hue[1.043746947040677, 1, -11.83797322448614], 
     Hue[1.0437469470406404`, 1, -11.640618825064394`], 
     Hue[1.0437469470405918`, 1, -11.46373080780507], 
     Hue[1.0437469470405112`, 1, -11.266376408383788`], 
     Hue[1.0437469470404044`, 1, -11.089488391125084`], 
     Hue[1.0437469470402274`, 1, -10.892133991704824`], 
     Hue[1.0437469470399923`, 1, -10.715245974447473`], 
     Hue[1.043746947039603, 1, -10.51789157502946], 
     Hue[1.0437469470390863`, 1, -10.34100355777509], 
     Hue[1.0437469470382301`, 1, -10.143649158362019`], 
     Hue[1.0437469470370029`, 1, -9.955066065593856], 
     Hue[1.0437469470351517`, 1, -9.764290146172051], 
     Hue[1.0437469470325134`, 1, -9.5808236489594], 
     Hue[1.043746947028443, 1, -9.390047729561077], 
     Hue[1.043746947022642, 1, -9.206581232381899], 
     Hue[1.0437469470136926`, 1, -9.015805313035212], 
     Hue[1.0437469470009373`, 1, -8.832338815929628], 
     Hue[1.0437469469812604`, 1, -8.641562896696476], 
     Hue[1.043746946953215, 1, -8.458096399752705], 
     Hue[1.0437469469099505`, 1, -8.26732048076918], 
     Hue[1.0437469468482865`, 1, -8.083853984181198], 
     Hue[1.0437469467531597`, 1, -7.893078065746537], 
     Hue[1.0437469466175773`, 1, -7.709611569940837], 
     Hue[1.0437469464084195`, 1, -7.518835652712975], 
     Hue[1.0437469461103108`, 1, -7.335369158627299], 
     Hue[1.0437469456504296`, 1, -7.1445932440528575`], 
     Hue[1.04374694499497, 1, -6.96112675374905], 
     Hue[1.0437469439838163`, 1, -6.770350845008757], 
     Hue[1.0437469425426398`, 1, -6.586884363020244], 
     Hue[1.0437469403193889`, 1, -6.396108467107656], 
     Hue[1.043746937028129, 1, -6.206794466938036], 
     Hue[1.0437469321825035`, 1, -6.01930783876858], 
     Hue[1.0437469250257332`, 1, -5.832552177278213], 
     Hue[1.0437469143715303`, 1, -5.645065610581349], 
     Hue[1.0437468986357583`, 1, -5.458310039883219], 
     Hue[1.0437468752101042`, 1, -5.2708236083477], 
     Hue[1.0437468406115047`, 1, -5.084068237276664], 
     Hue[1.043746789105041, 1, -4.896582102923472], 
     Hue[1.0437467130325118`, 1, -4.709827170776615], 
     Hue[1.043746592085868, 1, -4.511925844684317], 
     Hue[1.0437464293468863`, 1, -4.33266398750402], 
     Hue[1.0437461814674325`, 1, -4.146824551412291], 
     Hue[1.0437458087887692`, 1, -3.958428138357866], 
     Hue[1.0437452268019436`, 1, -3.7622676794577625`], 
     Hue[1.0437444366972752`, 1, -3.5827383588022625`], 
     Hue[1.0437431601468141`, 1, -3.3874532452099686`], 
     Hue[1.0437414193510612`, 1, -3.2077969357493625`], 
     Hue[1.0437386163297264`, 1, -3.012961977757673], 
     Hue[1.0437341620965548`, 1, -2.80951024669712], 
     Hue[1.043728622704971, 1, -2.6385284128625663`], 
     Hue[1.0437188460282418`, 1, -2.4354300006531], 
     Hue[1.0437066765294198`, 1, -2.264518417692475], 
     Hue[1.0436852069119462`, 1, -2.061543973866831], 
     Hue[1.0436584982982298`, 1, -1.8907866646786313`], 
     Hue[1.0436114208243814`, 1, -1.688084296706749], 
     Hue[1.0435529307561047`, 1, -1.5176652835278086`], 
     Hue[1.0434500367979425`, 1, -1.315558744310039], 
     Hue[1.043314065453589, 1, -1.1364677431872374`], 
     Hue[1.0431070726833322`, 1, -0.9508348173508121], 
     Hue[1.0428012492585597`, 1, -0.7652770089106957], 
     Hue[1.0423491915545013`, 1, -0.5796978407278381], 
     Hue[1.0416514968164514`, 1, -0.3873776213843507], 
     Hue[1.040658672031693, 1, -0.20316768726834833`], 
     Hue[1.039175350702127, 1, -0.016884560216318345`], 
     Hue[1.036926934507341, 1, 0.17303483950498022`], 
     Hue[1.033660787284218, 1, 0.3587310840870944], 
     Hue[1.0287448442855474`, 1, 0.5469329087332697], 
     Hue[1.0214712772468646`, 1, 0.7338543986708566], 
     Hue[1.0105338756067979`, 1, 0.9216916210248178], 
     Hue[1.1691417481556805`, 1, -17.264488266373966`], 
     Hue[1.1691417481556805`, 1, -17.07736705803298], 
     Hue[1.1691417481556805`, 1, -16.90742299186392], 
     Hue[1.1691417481556805`, 1, -16.70312464135101], 
     Hue[1.1691417481556805`, 1, -16.53318057518195], 
     Hue[1.1691417481556805`, 1, -16.32888222466904], 
     Hue[1.1691417481556805`, 1, -16.15893815849998], 
     Hue[1.1691417481556805`, 1, -15.954639807987068`], 
     Hue[1.1691417481556805`, 1, -15.784695741818005`], 
     Hue[1.1691417481556803`, 1, -15.580397391305098`], 
     Hue[1.1691417481556803`, 1, -15.407712291810729`], 
     Hue[1.1691417481556803`, 1, -15.206154974623129`], 
     Hue[1.1691417481556803`, 1, -15.033469875128759`], 
     Hue[1.16914174815568, 1, -14.831912557941154`], 
     Hue[1.1691417481556798`, 1, -14.657856941784134`], 
     Hue[1.1691417481556796`, 1, -14.457670141259184`], 
     Hue[1.1691417481556792`, 1, -14.283614525102164`], 
     Hue[1.1691417481556785`, 1, -14.083427724577216`], 
     Hue[1.1691417481556776`, 1, -13.908172906340376`], 
     Hue[1.169141748155676, 1, -13.709185307895249`], 
     Hue[1.1691417481556738`, 1, -13.511830908473119`], 
     Hue[1.1691417481556707`, 1, -13.334942891213288`], 
     Hue[1.1691417481556656`, 1, -13.137588491791163`], 
     Hue[1.169141748155659, 1, -12.960700474531336`], 
     Hue[1.1691417481556479`, 1, -12.76334607510922], 
     Hue[1.1691417481556332`, 1, -12.586458057849407`], 
     Hue[1.1691417481556088`, 1, -12.389103658427313`], 
     Hue[1.1691417481555764`, 1, -12.21221564116753], 
     Hue[1.1691417481555226`, 1, -12.014861241745486`], 
     Hue[1.1691417481554516`, 1, -11.837973224485767`], 
     Hue[1.1691417481553337`, 1, -11.64061882506383], 
     Hue[1.1691417481551771`, 1, -11.463730807804252`], 
     Hue[1.169141748154918, 1, -11.266376408382548`], 
     Hue[1.1691417481545738`, 1, -11.089488391123284`], 
     Hue[1.1691417481540038`, 1, -10.892133991702098`], 
     Hue[1.1691417481532473`, 1, -10.715245974443517`], 
     Hue[1.1691417481519941`, 1, -10.517891575023466`], 
     Hue[1.1691417481503308`, 1, -10.341003557766392`], 
     Hue[1.169141748147575, 1, -10.143649158348838`], 
     Hue[1.1691417481436246`, 1, -9.955066065574254], 
     Hue[1.1691417481376656`, 1, -9.764290146142761], 
     Hue[1.1691417481291726`, 1, -9.580823648916299], 
     Hue[1.1691417481160709`, 1, -9.390047729496674], 
     Hue[1.1691417480973971`, 1, -9.206581232287132], 
     Hue[1.1691417480685895`, 1, -9.015805312893605], 
     Hue[1.169141748027531, 1, -8.832338815721261], 
     Hue[1.1691417479641912`, 1, -8.641562896385121], 
     Hue[1.1691417478739146`, 1, -8.458096399294567], 
     Hue[1.1691417477346482`, 1, -8.267320480084598], 
     Hue[1.1691417475361543`, 1, -8.083853983173874], 
     Hue[1.169141747229945, 1, -7.8930780642413305`], 
     Hue[1.1691417467935112`, 1, -7.709611567726006], 
     Hue[1.1691417461202405`, 1, -7.518835649403434], 
     Hue[1.1691417451606414`, 1, -7.335369153757491], 
     Hue[1.1691417436803024`, 1, -7.144593236776081], 
     Hue[1.1691417415704057`, 1, -6.96112674304167], 
     Hue[1.169141738315544, 1, -6.770350829009109], 
     Hue[1.1691417336764562`, 1, -6.586884339477635], 
     Hue[1.1691417265199031`, 1, -6.396108431928794], 
     Hue[1.1691417159254731`, 1, -6.206794414533082], 
     Hue[1.1691417003276023`, 1, -6.019307761002156], 
     Hue[1.1691416772902474`, 1, -5.832552062054047], 
     Hue[1.169141642994792, 1, -5.645065439594278], 
     Hue[1.1691415923419521`, 1, -5.458309786536903], 
     Hue[1.1691415169356478`, 1, -5.270823232394224], 
     Hue[1.169141405563979, 1, -5.0840676802382445`], 
     Hue[1.169141239766335, 1, -4.896581276306621], 
     Hue[1.1691409948909766`, 1, -4.709825946006176], 
     Hue[1.1691406055662432`, 1, -4.511923986896494], 
     Hue[1.169140081711206, 1, -4.332661277966432], 
     Hue[1.1691392837862913`, 1, -4.146820544519342], 
     Hue[1.1691380841240382`, 1, -3.958422180947136], 
     Hue[1.1691362106736927`, 1, -3.762258676089327], 
     Hue[1.1691336672411317`, 1, -3.5827252203089364`], 
     Hue[1.1691295577932688`, 1, -3.3874334258642085`], 
     Hue[1.1691239536691627`, 1, -3.2077680062238345`], 
     Hue[1.1691149294824938`, 1, -3.012918379813594], 
     Hue[1.1691025660799081`, 1, -2.832835914047128], 
     Hue[1.1690827512607684`, 1, -2.6384348444900514`], 
     Hue[1.1690512641590227`, 1, -2.435282969594068], 
     Hue[1.1690120615379862`, 1, -2.2643077419217166`], 
     Hue[1.1689428740538348`, 1, -2.0612210578575034`], 
     Hue[1.1688567578650375`, 1, -1.8903241959714532`], 
     Hue[1.1687048434621738`, 1, -1.6873760544521963`], 
     Hue[1.1685158827476727`, 1, -1.5166520556732312`], 
     Hue[1.1681828799030676`, 1, -1.3140099931787643`], 
     Hue[1.167741674786426, 1, -1.1342132842134725`], 
     Hue[1.1670926940005968`, 1, -0.9533147930621311], 
     Hue[1.1661117618241006`, 1, -0.7675199550158618], 
     Hue[1.164621334421863, 1, -0.5775335550163843], 
     Hue[1.1624347018587085`, 1, -0.390196600911358], 
     Hue[1.159163319240815, 1, -0.20166540813995337`], 
     Hue[1.1543968068366939`, 1, -0.01655852552840198], 
     Hue[1.147229670021659, 1, 0.1707851221245642], 
     Hue[1.1364667338299625`, 1, 0.3587421912244244], 
     Hue[1.120131224639609, 1, 0.5471291594329019], 
     Hue[1.0950202401850901`, 1, 0.7338571848830887], 
     Hue[1.052977799097538, 1, 0.9216205513025436], 
     Hue[1.2945365492706116`, 1, -17.264488266373966`], 
     Hue[1.2945365492706116`, 1, -17.07736705803298], 
     Hue[1.2945365492706116`, 1, -16.90742299186392], 
     Hue[1.2945365492706116`, 1, -16.70312464135101], 
     Hue[1.2945365492706116`, 1, -16.53318057518195], 
     Hue[1.2945365492706116`, 1, -16.32888222466904], 
     Hue[1.2945365492706116`, 1, -16.15893815849998], 
     Hue[1.2945365492706116`, 1, -15.954639807987068`], 
     Hue[1.2945365492706116`, 1, -15.784695741818005`], 
     Hue[1.2945365492706116`, 1, -15.580397391305098`], 
     Hue[1.2945365492706116`, 1, -15.407712291810729`], 
     Hue[1.2945365492706116`, 1, -15.206154974623129`], 
     Hue[1.2945365492706113`, 1, -15.033469875128759`], 
     Hue[1.2945365492706111`, 1, -14.831912557941154`], 
     Hue[1.2945365492706111`, 1, -14.657856941784134`], 
     Hue[1.2945365492706107`, 1, -14.457670141259184`], 
     Hue[1.2945365492706102`, 1, -14.283614525102161`], 
     Hue[1.2945365492706093`, 1, -14.083427724577211`], 
     Hue[1.2945365492706085`, 1, -13.908172906340367`], 
     Hue[1.2945365492706067`, 1, -13.709185307895238`], 
     Hue[1.2945365492706042`, 1, -13.511830908473101`], 
     Hue[1.294536549270601, 1, -13.334942891213263`], 
     Hue[1.2945365492705954`, 1, -13.137588491791124`], 
     Hue[1.294536549270588, 1, -12.96070047453128], 
     Hue[1.2945365492705758`, 1, -12.763346075109135`], 
     Hue[1.2945365492705596`, 1, -12.586458057849285`], 
     Hue[1.2945365492705327`, 1, -12.389103658427127`], 
     Hue[1.2945365492704972`, 1, -12.21221564116726], 
     Hue[1.2945365492704382`, 1, -12.014861241745075`], 
     Hue[1.2945365492703598`, 1, -11.837973224485172`], 
     Hue[1.29453654927023, 1, -11.640618825062925`], 
     Hue[1.294536549270058, 1, -11.463730807802941`], 
     Hue[1.2945365492697727`, 1, -11.266376408380562`], 
     Hue[1.2945365492693943`, 1, -11.089488391120401`], 
     Hue[1.2945365492687673`, 1, -10.89213399169773], 
     Hue[1.294536549267935, 1, -10.71524597443718], 
     Hue[1.2945365492665564`, 1, -10.517891575013861`], 
     Hue[1.2945365492647265`, 1, -10.341003557752455`], 
     Hue[1.2945365492616951`, 1, -10.14364915832772], 
     Hue[1.2945365492573495`, 1, -9.955066065542846], 
     Hue[1.2945365492507945`, 1, -9.764290146095826], 
     Hue[1.294536549241452, 1, -9.58082364884724], 
     Hue[1.2945365492270393`, 1, -9.390047729393482], 
     Hue[1.2945365492064975`, 1, -9.206581232135289], 
     Hue[1.2945365491748082`, 1, -9.015805312666712], 
     Hue[1.294536549129642, 1, -8.8323388153874], 
     Hue[1.2945365490599656`, 1, -8.641562895886246], 
     Hue[1.2945365489606575`, 1, -8.4580963985605], 
     Hue[1.2945365488074585`, 1, -8.26732047898771], 
     Hue[1.294536548589107, 1, -8.083853981559862], 
     Hue[1.2945365482522642`, 1, -7.893078061829569], 
     Hue[1.2945365477721686`, 1, -7.709611564177233], 
     Hue[1.2945365470315429`, 1, -7.518835644100629], 
     Hue[1.294536545975944, 1, -7.3353691459547035`], 
     Hue[1.2945365443475096`, 1, -7.144593225116657], 
     Hue[1.2945365420265351`, 1, -6.961126725885465], 
     Hue[1.2945365384460517`, 1, -6.770350803373213], 
     Hue[1.2945365333428613`, 1, -6.586884301755813], 
     Hue[1.2945365254703536`, 1, -6.396108375562447], 
     Hue[1.2945365138160363`, 1, -6.2067943305657245`], 
     Hue[1.2945364966577222`, 1, -6.01930763639863], 
     Hue[1.294536471315657, 1, -5.832551877432721], 
     Hue[1.294536433589193, 1, -5.645065165625107], 
     Hue[1.2945363778688823`, 1, -5.458309380604975], 
     Hue[1.2945362949186343`, 1, -5.270822630010795], 
     Hue[1.2945361724047801`, 1, -5.0840667877048125`], 
     Hue[1.2945359900196234`, 1, -4.896579951830183], 
     Hue[1.2945357206446784`, 1, -4.709823983569616], 
     Hue[1.2945352923668223`, 1, -4.511921010172631], 
     Hue[1.2945347160956109`, 1, -4.33265693646805], 
     Hue[1.294533838325124, 1, -4.146814124219815], 
     Hue[1.294532518602381, 1, -3.9584126352042075`], 
     Hue[1.2945304576250547`, 1, -3.762244249473686], 
     Hue[1.294527659534438, 1, -3.5827041672676216`], 
     Hue[1.294523138468192, 1, -3.3874016663033064`], 
     Hue[1.294516972684582, 1, -3.207721645718097], 
     Hue[1.294507043274395, 1, -3.0128485070738824`], 
     Hue[1.2944934458669723`, 1, -2.832819491436992], 
     Hue[1.2944716339820757`, 1, -2.6383159279036317`], 
     Hue[1.2944369636902335`, 1, -2.4350471949532935`], 
     Hue[1.294393787057011, 1, -2.263969790562367], 
     Hue[1.2943175406221354`, 1, -2.0607027393878115`], 
     Hue[1.2942225573690698`, 1, -1.8895813097202796`], 
     Hue[1.2940547817327124`, 1, -1.6862368314639211`], 
     Hue[1.2938457005788482`, 1, -1.5150195163640496`], 
     Hue[1.2934761804796717`, 1, -1.311507212778375], 
     Hue[1.2930153232908816`, 1, -1.140083520605914], 
     Hue[1.2922569130293384`, 1, -0.9479553569467312], 
     Hue[1.2911472065232323`, 1, -0.7595804542882787], 
     Hue[1.2895007315062945`, 1, -0.5715523555848723], 
     Hue[1.2871921484990398`, 1, -0.3923946007604453], 
     Hue[1.2834958559162297`, 1, -0.19897347072798954`], 
     Hue[1.2783018276910376`, 1, -0.016273368748323414`], 
     Hue[1.2702910149202595`, 1, 0.17322509017788024`], 
     Hue[1.2584657538122614`, 1, 0.35968460640013555`], 
     Hue[1.1344725571894694`, 1, 0.7342044782300202], 
     Hue[1.2404703112816007`, 1, 0.5468316849920001], 
     Hue[1.2123021830217497`, 1, 0.7338739972700148], 
     Hue[1.0842249555135834`, 1, 0.9216070879243536], 
     Hue[1.1634805933584786`, 1, 0.9216261884691317], 
     Hue[1.4199313503855429`, 1, -17.264488266373966`], 
     Hue[1.4199313503855429`, 1, -17.07736705803298], 
     Hue[1.4199313503855429`, 1, -16.90742299186392], 
     Hue[1.4199313503855429`, 1, -16.70312464135101], 
     Hue[1.4199313503855429`, 1, -16.53318057518195], 
     Hue[1.4199313503855429`, 1, -16.32888222466904], 
     Hue[1.4199313503855429`, 1, -16.15893815849998], 
     Hue[1.4199313503855429`, 1, -15.954639807987068`], 
     Hue[1.4199313503855429`, 1, -15.784695741818005`], 
     Hue[1.4199313503855429`, 1, -15.580397391305098`], 
     Hue[1.4199313503855429`, 1, -15.407712291810729`], 
     Hue[1.4199313503855429`, 1, -15.206154974623129`], 
     Hue[1.4199313503855426`, 1, -15.033469875128759`], 
     Hue[1.4199313503855426`, 1, -14.831912557941154`], 
     Hue[1.4199313503855424`, 1, -14.65785694178413], 
     Hue[1.4199313503855424`, 1, -14.45767014125918], 
     Hue[1.419931350385542, 1, -14.283614525102157`], 
     Hue[1.4199313503855417`, 1, -14.083427724577206`], 
     Hue[1.419931350385541, 1, -13.908172906340361`], 
     Hue[1.4199313503855404`, 1, -13.709185307895227`], 
     Hue[1.419931350385539, 1, -13.511830908473087`], 
     Hue[1.4199313503855375`, 1, -13.334942891213243`], 
     Hue[1.4199313503855346`, 1, -13.137588491791094`], 
     Hue[1.4199313503855309`, 1, -12.960700474531237`], 
     Hue[1.4199313503855249`, 1, -12.763346075109068`], 
     Hue[1.4199313503855167`, 1, -12.586458057849187`], 
     Hue[1.4199313503855033`, 1, -12.38910365842698], 
     Hue[1.4199313503854853`, 1, -12.212215641167047`], 
     Hue[1.4199313503854558`, 1, -12.014861241744752`], 
     Hue[1.4199313503854165`, 1, -11.837973224484703`], 
     Hue[1.4199313503853515`, 1, -11.640618825062214`], 
     Hue[1.419931350385265, 1, -11.463730807801909`], 
     Hue[1.419931350385122, 1, -11.266376408379], 
     Hue[1.4199313503849322`, 1, -11.089488391118133`], 
     Hue[1.4199313503846176`, 1, -10.892133991694294`], 
     Hue[1.4199313503842002`, 1, -10.715245974432191`], 
     Hue[1.4199313503835085`, 1, -10.517891575006306`], 
     Hue[1.4199313503825906`, 1, -10.341003557741491`], 
     Hue[1.41993135038107, 1, -10.14364915831111], 
     Hue[1.41993135037889, 1, -9.95506606551814], 
     Hue[1.4199313503756017`, 1, -9.76429014605891], 
     Hue[1.419931350370915, 1, -9.580823648792919], 
     Hue[1.419931350363685, 1, -9.390047729312311], 
     Hue[1.4199313503533801`, 1, -9.206581232015852], 
     Hue[1.4199313503374835`, 1, -9.015805312488242], 
     Hue[1.419931350314826, 1, -8.83233881512479], 
     Hue[1.4199313502798734`, 1, -8.641562895493838], 
     Hue[1.4199313502300561`, 1, -8.45809639798309], 
     Hue[1.4199313501532045`, 1, -8.267320478124907], 
     Hue[1.4199313500436697`, 1, -8.083853980290296], 
     Hue[1.4199313498746942`, 1, -7.893078059932502], 
     Hue[1.419931349633857, 1, -7.709611561385802], 
     Hue[1.4199313492623262`, 1, -7.518835639929496], 
     Hue[1.4199313487327907`, 1, -7.335369139817106], 
     Hue[1.4199313479158953`, 1, -7.144593215945473], 
     Hue[1.419931346751591, 1, -6.961126712390564], 
     Hue[1.4199313449554607`, 1, -6.770350783208276], 
     Hue[1.419931342395473, 1, -6.586884272084204], 
     Hue[1.4199313384462715`, 1, -6.39610833122524], 
     Hue[1.419931332599945, 1, -6.2067942645178285`], 
     Hue[1.4199313239925668`, 1, -6.01930753838671], 
     Hue[1.4199313112798508`, 1, -5.832551732211352], 
     Hue[1.4199312923545606`, 1, -5.645064950123503], 
     Hue[1.4199312644027375`, 1, -5.4583090613025345`], 
     Hue[1.4199312227911263`, 1, -5.270822156181004], 
     Hue[1.4199311613325638`, 1, -5.084066085644677], 
     Hue[1.4199310698397036`, 1, -4.896578910005211], 
     Hue[1.4199309347084883`, 1, -4.709822439925456], 
     Hue[1.4199307198634683`, 1, -4.5119186686855075`], 
     Hue[1.4199304307766385`, 1, -4.3326535214335316`], 
     Hue[1.419929990439989, 1, -4.146809073955133], 
     Hue[1.4199293283907308`, 1, -3.9584051263496907`], 
     Hue[1.419928294471592, 1, -3.7622329010278275`], 
     Hue[1.4199268907421385`, 1, -3.582687605846658], 
     Hue[1.4199246225754085`, 1, -3.3873766815691084`], 
     Hue[1.4199215291432978`, 1, -3.2076851726529165`], 
     Hue[1.4199165471494952`, 1, -3.012793531435041], 
     Hue[1.419909728301256, 1, -2.832830565157602], 
     Hue[1.4198987802354441`, 1, -2.6382320850242316`], 
     Hue[1.4198813742958525`, 1, -2.434861572398253], 
     Hue[1.4198596943614792`, 1, -2.2637036231255445`], 
     Hue[1.4198213913870716`, 1, -2.0602942389990346`], 
     Hue[1.4197736436931923`, 1, -1.8889953257421597`], 
     Hue[1.419689216265818, 1, -1.6853368746083548`], 
     Hue[1.4195838467233295`, 1, -1.51372744556226], 
     Hue[1.4193971948751596`, 1, -1.3095198497459613`], 
     Hue[1.4191636379570824`, 1, -1.1372249020059237`], 
     Hue[1.4188060511094531`, 1, -0.9555922038990088], 
     Hue[1.418225623452881, 1, -0.7580247233728645], 
     Hue[1.4174497070848002`, 1, -0.5799433233728961], 
     Hue[1.4162403008274262`, 1, -0.3913964586892398], 
     Hue[1.3944954557457176`, 1, 0.17169751020203083`], 
     Hue[1.4144487276173083`, 1, -0.20350327515696298`], 
     Hue[1.411714407430789, 1, -0.011428408284193114`], 
     Hue[1.4078364668358931`, 1, 0.17195287547343963`], 
     Hue[1.2864215405165191`, 1, 0.5467950553734173], 
     Hue[1.4019508296745573`, 1, 0.35973987633669346`], 
     Hue[1.3931648775567027`, 1, 0.5474934895387712], 
     Hue[1.2184958055857005`, 1, 0.9220846290902422], 
     Hue[1.2882881195481082`, 1, 1.1095182571764242`], 
     Hue[1.3800349519209856`, 1, 0.7343391525371856], 
     Hue[1.3599283542210803`, 1, 0.9218695817586434], 
     Hue[1.3279487764636015`, 1, 1.109354088580396], 
     Hue[1.1150000790795742`, 1, 1.1094796721519242`], 
     Hue[1.1135845593950557`, 1, 1.2975547645063465`], 
     Hue[1.2692711998207717`, 1, 1.2972865486124872`], 
     Hue[1.0481623109572413`, 1, 1.1096399859394233`], 
     Hue[1.0704991472669534`, 1, 1.2970879111781752`], 
     Hue[1.0127485453872067`, 1, 1.10936025508082], 
     Hue[1.0120021514004538`, 1, 1.1097575569749685`], 
     Hue[0.545326151500475, 1, -17.264488266373966`], 
     Hue[0.545326151500475, 1, -17.07736705803298], 
     Hue[0.545326151500475, 1, -16.90742299186392], 
     Hue[0.545326151500475, 1, -16.70312464135101], 
     Hue[0.545326151500475, 1, -16.53318057518195], 
     Hue[0.545326151500475, 1, -16.32888222466904], 
     Hue[0.545326151500475, 1, -16.15893815849998], 
     Hue[0.545326151500475, 1, -15.954639807987068`], 
     Hue[0.545326151500475, 1, -15.784695741818005`], 
     Hue[0.545326151500475, 1, -15.580397391305098`], 
     Hue[0.545326151500475, 1, -15.407712291810729`], 
     Hue[0.5453261515004751, 1, -15.206154974623129`], 
     Hue[0.5453261515004751, 1, -15.033469875128759`], 
     Hue[0.5453261515004753, 1, -14.831912557941154`], 
     Hue[0.5453261515004753, 1, -14.65785694178413], 
     Hue[0.5453261515004754, 1, -14.45767014125918], 
     Hue[0.5453261515004755, 1, -14.283614525102157`], 
     Hue[0.5453261515004757, 1, -14.083427724577206`], 
     Hue[0.545326151500476, 1, -13.90817290634036], 
     Hue[0.5453261515004766, 1, -13.709185307895225`], 
     Hue[0.5453261515004773, 1, -13.511830908473085`], 
     Hue[0.5453261515004781, 1, -13.33494289121324], 
     Hue[0.5453261515004798, 1, -13.137588491791089`], 
     Hue[0.545326151500482, 1, -12.96070047453123], 
     Hue[0.5453261515004856, 1, -12.763346075109059`], 
     Hue[0.5453261515004904, 1, -12.586458057849173`], 
     Hue[0.5453261515004981, 1, -12.38910365842696], 
     Hue[0.5453261515005086, 1, -12.212215641167017`], 
     Hue[0.5453261515005258, 1, -12.014861241744708`], 
     Hue[0.5453261515005488, 1, -11.837973224484635`], 
     Hue[0.5453261515005866, 1, -11.640618825062115`], 
     Hue[0.5453261515006369, 1, -11.463730807801765`], 
     Hue[0.5453261515007203, 1, -11.266376408378783`], 
     Hue[0.545326151500831, 1, -11.089488391117817`], 
     Hue[0.5453261515010142, 1, -10.892133991693814`], 
     Hue[0.5453261515012575, 1, -10.715245974431497`], 
     Hue[0.5453261515016605, 1, -10.517891575005253`], 
     Hue[0.5453261515021954, 1, -10.341003557739963`], 
     Hue[0.5453261515030816, 1, -10.143649158308795`], 
     Hue[0.5453261515043519, 1, -9.955066065514696], 
     Hue[0.5453261515062682, 1, -9.764290146053765], 
     Hue[0.5453261515089993, 1, -9.580823648785346], 
     Hue[0.5453261515132126, 1, -9.390047729300997], 
     Hue[0.5453261515192176, 1, -9.206581231999204], 
     Hue[0.5453261515284813, 1, -9.015805312463364], 
     Hue[0.5453261515416847, 1, -8.832338815088185], 
     Hue[0.5453261515620531, 1, -8.641562895439138], 
     Hue[0.5453261515910838, 1, -8.458096397902604], 
     Hue[0.5453261516358684, 1, -8.26732047800464], 
     Hue[0.545326151699699, 1, -8.08385398011333], 
     Hue[0.545326151798168, 1, -7.89307805966807], 
     Hue[0.5453261519385141, 1, -7.709611560996701], 
     Hue[0.5453261521550208, 1, -7.518835639348079], 
     Hue[0.5453261524636035, 1, -7.335369138961583], 
     Hue[0.5453261529396428, 1, -7.144593214667094], 
     Hue[0.545326153618132, 1, -6.961126710509501], 
     Hue[0.5453261546648128, 1, -6.7703507803974725`], 
     Hue[0.5453261561566258, 1, -6.58688426794826], 
     Hue[0.545326158457992, 1, -6.3961083250450494`], 
     Hue[0.545326161864893, 1, -6.2067942553113715`], 
     Hue[0.5453261668807754, 1, -6.019307524724767], 
     Hue[0.5453261742890116, 1, -5.8325517119688515`], 
     Hue[0.5453261853175775, 1, -5.645064920084591], 
     Hue[0.5453262016062859, 1, -5.458309016794743], 
     Hue[0.5453262258551319, 1, -5.270822090133513], 
     Hue[0.5453262616696399, 1, -5.084065987783933], 
     Hue[0.5453263149864147, 1, -4.8965787647842465`], 
     Hue[0.5453263937331312, 1, -4.709822224755183], 
     Hue[0.5453265189325258, 1, -4.511918342302393], 
     Hue[0.5453266873958955, 1, -4.332653045405941], 
     Hue[0.5453269439992652, 1, -4.146808369987212], 
     Hue[0.5453273298047048, 1, -3.9584040796671465`], 
     Hue[0.5453279323163157, 1, -3.762231319118155], 
     Hue[0.5453287503353557, 1, -3.5826852972486405`], 
     Hue[0.5453300721078608, 1, -3.387373198723437], 
     Hue[0.5453318748136984, 1, -3.207680088205871], 
     Hue[0.5453347781094702, 1, -3.0127858673374446`], 
     Hue[0.5453387518976239, 1, -2.832819369774791], 
     Hue[0.5453451321741063, 1, -2.6382152186939773`], 
     Hue[0.5453552762619714, 1, -2.4348356868356227`], 
     Hue[0.5453679117498593, 1, -2.263666498189413], 
     Hue[0.5453902369312531, 1, -2.0602372420509525`], 
     Hue[0.5454180696568444, 1, -1.8889135301553448`], 
     Hue[0.5454672905754381, 1, -1.685211157845078], 
     Hue[0.5455287334661042, 1, -1.5135467835545413`], 
     Hue[0.5456376085101173, 1, -1.3092415047201096`], 
     Hue[0.5457739067967753, 1, -1.1368236910999012`], 
     Hue[0.5459823391123483, 1, -0.9552794709486101], 
     Hue[0.5462997662826767, 1, -0.7678608210011852], 
     Hue[0.546776308990331, 1, -0.578618864576578], 
     Hue[0.5474860246774358, 1, -0.38939763500342583`], 
     Hue[0.5485305968481712, 1, -0.202032630235502], 
     Hue[0.5500622297218609, 1, -0.0165022040809919], 
     Hue[0.5524275523963235, 1, 0.17582454226468636`], 
     Hue[0.5557601894188844, 1, 0.3584129602080418], 
     Hue[0.5608906109134653, 1, 0.5479563432980902], 
     Hue[1.3760348301825212`, 1, 1.2972922588796256`], 
     Hue[0.5683905056658431, 1, 0.7338666264305591], 
     Hue[0.5797164047352203, 1, 0.9215835763973643], 
     Hue[0.5968925780693284, 1, 1.1093671172023807`], 
     Hue[0.6237023811739864, 1, 1.2972094717288505`], 
     Hue[0.9669638512709977, 1, 1.2971319811570996`], 
     Hue[0.9937691589208228, 1, 1.1092832708765565`], 
     Hue[0.6707209526154063, 1, -17.264488266373966`], 
     Hue[0.6707209526154063, 1, -17.07736705803298], 
     Hue[0.6707209526154063, 1, -16.90742299186392], 
     Hue[0.6707209526154063, 1, -16.70312464135101], 
     Hue[0.6707209526154063, 1, -16.53318057518195], 
     Hue[0.6707209526154063, 1, -16.32888222466904], 
     Hue[0.6707209526154063, 1, -16.15893815849998], 
     Hue[0.6707209526154063, 1, -15.954639807987068`], 
     Hue[0.6707209526154063, 1, -15.784695741818005`], 
     Hue[0.6707209526154063, 1, -15.580397391305098`], 
     Hue[0.6707209526154063, 1, -15.407712291810729`], 
     Hue[0.6707209526154064, 1, -15.206154974623129`], 
     Hue[0.6707209526154065, 1, -15.033469875128759`], 
     Hue[0.6707209526154068, 1, -14.831912557941154`], 
     Hue[0.6707209526154068, 1, -14.657856941784134`], 
     Hue[0.6707209526154072, 1, -14.457670141259184`], 
     Hue[0.6707209526154077, 1, -14.283614525102157`], 
     Hue[0.6707209526154083, 1, -14.08342772457721], 
     Hue[0.6707209526154092, 1, -13.908172906340365`], 
     Hue[0.6707209526154108, 1, -13.709185307895234`], 
     Hue[0.670720952615413, 1, -13.511830908473096`], 
     Hue[0.6707209526154161, 1, -13.334942891213256`], 
     Hue[0.6707209526154212, 1, -13.137588491791114`], 
     Hue[0.6707209526154279, 1, -12.960700474531265`], 
     Hue[0.6707209526154391, 1, -12.763346075109112`], 
     Hue[0.6707209526154538, 1, -12.586458057849251`], 
     Hue[0.6707209526154784, 1, -12.389103658427077`], 
     Hue[0.6707209526155109, 1, -12.212215641167187`], 
     Hue[0.6707209526155649, 1, -12.014861241744967`], 
     Hue[0.6707209526156364, 1, -11.837973224485014`], 
     Hue[0.6707209526157549, 1, -11.640618825062687`], 
     Hue[0.6707209526159124, 1, -11.463730807802593`], 
     Hue[0.670720952616173, 1, -11.266376408380037`], 
     Hue[0.6707209526165189, 1, -11.08948839111964], 
     Hue[0.6707209526170921, 1, -10.892133991696573`], 
     Hue[0.6707209526178527, 1, -10.715245974435502`], 
     Hue[0.6707209526191129, 1, -10.517891575011323`], 
     Hue[0.6707209526207853, 1, -10.34100355774877], 
     Hue[0.6707209526235561, 1, -10.14364915832214], 
     Hue[0.6707209526275282, 1, -9.955066065534544], 
     Hue[0.6707209526335197, 1, -9.764290146083422], 
     Hue[0.6707209526420592, 1, -9.580823648828986], 
     Hue[0.6707209526552328, 1, -9.390047729366206], 
     Hue[0.6707209526740089, 1, -9.206581232095155], 
     Hue[0.670720952702974, 1, -9.01580531260674], 
     Hue[0.6707209527442575, 1, -8.832338815299156], 
     Hue[0.6707209528079439, 1, -8.641562895754385], 
     Hue[0.6707209528987148, 1, -8.458096398366473], 
     Hue[0.6707209530387439, 1, -8.267320478697782], 
     Hue[0.6707209532383247, 1, -8.08385398113325], 
     Hue[0.6707209535462106, 1, -7.8930780611920985`], 
     Hue[0.6707209539850341, 1, -7.709611563239231], 
     Hue[0.6707209546619913, 1, -7.518835642699007], 
     Hue[0.6707209556268448, 1, -7.335369143892293], 
     Hue[0.6707209571152892, 1, -7.144593222034872], 
     Hue[0.6707209592367389, 1, -6.961126721350785], 
     Hue[0.6707209625094228, 1, -6.770350796597209], 
     Hue[0.6707209671739127, 1, -6.586884291785291], 
     Hue[0.6707209743696531, 1, -6.396108360663858], 
     Hue[0.6707209850220966, 1, -6.206794308371714], 
     Hue[0.6707210007053818, 1, -6.019307603463781], 
     Hue[0.6707210238688961, 1, -5.832551828634131], 
     Hue[0.6707210583521774, 1, -5.645065093210327], 
     Hue[0.6707211092824579, 1, -5.458309273310124], 
     Hue[0.6707211851018509, 1, -5.270822470790321], 
     Hue[0.6707212970837777, 1, -5.084066551792437], 
     Hue[0.6707214637902261, 1, -4.896579601747227], 
     Hue[0.6707217100085472, 1, -4.709823464861441], 
     Hue[0.6707221014701643, 1, -4.5119202233674915`], 
     Hue[0.6707226282038159, 1, -4.3326557889226915`], 
     Hue[0.6707234305207295, 1, -4.146812427196106], 
     Hue[0.670724636802964, 1, -3.958410112037373], 
     Hue[0.6707265206315368, 1, -3.7622404361265946`], 
     Hue[0.6707290782321185, 1, -3.582698602277749], 
     Hue[0.6707332107620415, 1, -3.38739327099979], 
     Hue[0.6707388467431956, 1, -3.2077093903331626`], 
     Hue[0.670747923149281, 1, -3.012830035081276], 
     Hue[0.6707603528320576, 1, -2.8327925057509304`], 
     Hue[0.670780292476211, 1, -2.6382752837154566`], 
     Hue[0.6708119891758761, 1, -2.4349848365636877`], 
     Hue[0.6708514666997902, 1, -2.2638803838417756`], 
     Hue[0.6709211917907251, 1, -2.0605655497539486`], 
     Hue[0.671008070773387, 1, -1.889384563320576], 
     Hue[0.6711615845261631, 1, -1.6859348000815844`], 
     Hue[0.6713529879220381, 1, -1.5145861267216703`], 
     Hue[0.6716915244328487, 1, -1.310841254530687], 
     Hue[0.6721142050055107, 1, -1.139126774972928], 
     Hue[0.6728109196809405, 1, -0.9465183234561914], 
     Hue[0.6737682714018821, 1, -0.7674046352339225], 
     Hue[0.6753548602567827, 1, -0.5683519962107619], 
     Hue[0.6774667070364166, 1, -0.390058514503147], 
     Hue[0.6082944269098552, 1, 0.17097196681521332`], 
     Hue[0.6807071130451965, 1, -0.2038917476639759], 
     Hue[0.685592574238181, 1, -0.015100509502169457`], 
     Hue[0.7141441822881323, 1, 0.5462663167587056], 
     Hue[0.6927518242681917, 1, 0.17074322736767555`], 
     Hue[0.7036528320116955, 1, 0.35981508984526], 
     Hue[0.7816379263484002, 1, 0.9217328875985078], 
     Hue[0.7117260647147396, 1, 1.1094815635371307`], 
     Hue[0.6239992589924561, 1, 1.297237519220348], 
     Hue[0.7199724132412548, 1, 0.5467903289361868], 
     Hue[0.7452810505029321, 1, 0.7338589707459502], 
     Hue[0.8850051617855808, 1, 1.1094014611517076`], 
     Hue[0.8863816669686436, 1, 1.2971469330972925`], 
     Hue[0.7877498395241982, 1, 0.9218963132620792], 
     Hue[0.9518147622152757, 1, 1.1093577703184438`], 
     Hue[0.9872152441085836, 1, 1.10928441967346], 
     Hue[0.7961157537303374, 1, -17.264488266373966`], 
     Hue[0.7961157537303374, 1, -17.07736705803298], 
     Hue[0.7961157537303374, 1, -16.90742299186392], 
     Hue[0.7961157537303374, 1, -16.70312464135101], 
     Hue[0.7961157537303374, 1, -16.53318057518195], 
     Hue[0.7961157537303374, 1, -16.32888222466904], 
     Hue[0.7961157537303374, 1, -16.15893815849998], 
     Hue[0.7961157537303375, 1, -15.954639807987068`], 
     Hue[0.7961157537303375, 1, -15.784695741818005`], 
     Hue[0.7961157537303375, 1, -15.580397391305098`], 
     Hue[0.7961157537303376, 1, -15.407712291810729`], 
     Hue[0.7961157537303376, 1, -15.206154974623129`], 
     Hue[0.7961157537303377, 1, -15.033469875128759`], 
     Hue[0.7961157537303378, 1, -14.831912557941154`], 
     Hue[0.796115753730338, 1, -14.657856941784134`], 
     Hue[0.7961157537303385, 1, -14.457670141259184`], 
     Hue[0.7961157537303389, 1, -14.283614525102161`], 
     Hue[0.7961157537303396, 1, -14.083427724577215`], 
     Hue[0.7961157537303406, 1, -13.908172906340374`], 
     Hue[0.7961157537303423, 1, -13.709185307895247`], 
     Hue[0.7961157537303448, 1, -13.511830908473113`], 
     Hue[0.7961157537303482, 1, -13.334942891213283`], 
     Hue[0.7961157537303537, 1, -13.137588491791153`], 
     Hue[0.796115753730361, 1, -12.960700474531322`], 
     Hue[0.7961157537303732, 1, -12.763346075109197`], 
     Hue[0.7961157537303893, 1, -12.586458057849374`], 
     Hue[0.7961157537304161, 1, -12.389103658427263`], 
     Hue[0.7961157537304516, 1, -12.21221564116746], 
     Hue[0.7961157537305104, 1, -12.014861241745377`], 
     Hue[0.7961157537305885, 1, -11.83797322448561], 
     Hue[0.7961157537307179, 1, -11.640618825063592`], 
     Hue[0.7961157537308894, 1, -11.463730807803907`], 
     Hue[0.7961157537311738, 1, -11.266376408382026`], 
     Hue[0.7961157537315512, 1, -11.089488391122526`], 
     Hue[0.7961157537321765, 1, -10.892133991700948`], 
     Hue[0.7961157537330061, 1, -10.715245974441848`], 
     Hue[0.7961157537343809, 1, -10.517891575020938`], 
     Hue[0.7961157537362054, 1, -10.341003557762724`], 
     Hue[0.7961157537392279, 1, -10.14364915834328], 
     Hue[0.796115753743561, 1, -9.955066065565987], 
     Hue[0.796115753750097, 1, -9.764290146130406], 
     Hue[0.7961157537594126, 1, -9.580823648898122], 
     Hue[0.7961157537737833, 1, -9.39004772946951], 
     Hue[0.7961157537942657, 1, -9.206581232247164], 
     Hue[0.7961157538258632, 1, -9.01580531283388], 
     Hue[0.7961157538708983, 1, -8.83233881563338], 
     Hue[0.7961157539403725, 1, -8.641562896253804], 
     Hue[0.7961157540393925, 1, -8.45809639910134], 
     Hue[0.7961157541921472, 1, -8.267320479795865], 
     Hue[0.7961157544098653, 1, -8.08385398274902], 
     Hue[0.7961157547457312, 1, -7.8930780636064855`], 
     Hue[0.796115755224434, 1, -7.7096115667918665`], 
     Hue[0.7961157559629115, 1, -7.518835648007582], 
     Hue[0.7961157570154486, 1, -7.33536915170357], 
     Hue[0.7961157586391594, 1, -7.14459323370698], 
     Hue[0.7961157609534015, 1, -6.961126738525658], 
     Hue[0.7961157645234992, 1, -6.770350822260995], 
     Hue[0.7961157696118867, 1, -6.586884329548152], 
     Hue[0.7961157774615581, 1, -6.39610841709153], 
     Hue[0.7961157890820683, 1, -6.20679439243043], 
     Hue[0.7961158061906074, 1, -6.019307728202882], 
     Hue[0.7961158314591531, 1, -5.832552013456348], 
     Hue[0.7961158690761607, 1, -5.64506536747764], 
     Hue[0.7961159246347901, 1, -5.458309679683858], 
     Hue[0.7961160073443023, 1, -5.270823073829501], 
     Hue[0.7961161295025087, 1, -5.084067445297762], 
     Hue[0.7961163113580123, 1, -4.896580927666546], 
     Hue[0.796116579950237, 1, -4.709825429437263], 
     Hue[0.7961170069825553, 1, -4.511923203339652], 
     Hue[0.7961175815757077, 1, -4.332660135165247], 
     Hue[0.7961184567855168, 1, -4.1468188545262565`], 
     Hue[0.7961197726476741, 1, -3.958419668266651], 
     Hue[0.7961218275705024, 1, -3.762254878668693], 
     Hue[0.7961246173914194, 1, -3.582719678715968], 
     Hue[0.7961291249745551, 1, -3.3874250662341705`], 
     Hue[0.7961352721287214, 1, -3.2077558036653544`], 
     Hue[0.7961451709527142, 1, -3.012899989265777], 
     Hue[0.7961587315030645, 1, -2.8328261762217943`], 
     Hue[0.7961804690859219, 1, -2.638401349644237], 
     Hue[0.7962150141401313, 1, -2.435220929531803], 
     Hue[0.7962580272340094, 1, -2.264218829897673], 
     Hue[0.7963339515763894, 1, -2.0610847309851126`], 
     Hue[0.7964284741626482, 1, -1.8901288718812614`], 
     Hue[0.7965952752221913, 1, -1.6870767072603206`], 
     Hue[0.7968028548411065, 1, -1.5162234107538735`], 
     Hue[0.7971689445286689, 1, -1.3133537417070362`], 
     Hue[0.7976241386154305, 1, -1.1427302352438542`], 
     Hue[0.798369903138857, 1, -0.9519157191053618], 
     Hue[0.7994537145811514, 1, -0.7654556479614549], 
     Hue[0.8011062595770796, 1, -0.5744645046084746], 
     Hue[0.8035061736958071, 1, -0.38804991846441483`], 
     Hue[0.8070189899598764, 1, -0.20353514271076234`], 
     Hue[0.8124085996800599, 1, -0.013201909132083856`], 
     Hue[0.8202077637525144, 1, 0.17161081567001424`], 
     Hue[0.8320339488299089, 1, 0.35908506088805014`], 
     Hue[0.8657117323759435, 1, 0.7338834143998197], 
     Hue[0.8500375528967428, 1, 0.5469899343349589], 
     Hue[0.9157869768724495, 1, 0.9215668863308695], 
     Hue[0.8780954038498181, 1, 0.7339133280464204], 
     Hue[0.9267186995978062, 1, 0.921749546926004], 
     Hue[0.9215105548452691, 1, -17.264488266373966`], 
     Hue[0.9215105548452691, 1, -17.07736705803298], 
     Hue[0.9215105548452691, 1, -16.90742299186392], 
     Hue[0.9215105548452691, 1, -16.70312464135101], 
     Hue[0.9215105548452691, 1, -16.53318057518195], 
     Hue[0.9215105548452692, 1, -16.32888222466904], 
     Hue[0.9215105548452691, 1, -16.15893815849998], 
     Hue[0.9215105548452692, 1, -15.954639807987068`], 
     Hue[0.9215105548452692, 1, -15.784695741818005`], 
     Hue[0.9215105548452692, 1, -15.580397391305098`], 
     Hue[0.9215105548452692, 1, -15.407712291810729`], 
     Hue[0.9215105548452693, 1, -15.206154974623129`], 
     Hue[0.9215105548452693, 1, -15.033469875128759`], 
     Hue[0.9215105548452693, 1, -14.831912557941154`], 
     Hue[0.9215105548452694, 1, -14.657856941784138`], 
     Hue[0.9215105548452697, 1, -14.457670141259188`], 
     Hue[0.9215105548452699, 1, -14.283614525102164`], 
     Hue[0.9215105548452702, 1, -14.08342772457722], 
     Hue[0.9215105548452708, 1, -13.90817290634038], 
     Hue[0.9215105548452716, 1, -13.709185307895256`], 
     Hue[0.9215105548452728, 1, -13.511830908473128`], 
     Hue[0.9215105548452744, 1, -13.334942891213302`], 
     Hue[0.9215105548452772, 1, -13.137588491791181`], 
     Hue[0.9215105548452809, 1, -12.960700474531365`], 
     Hue[0.9215105548452869, 1, -12.763346075109263`], 
     Hue[0.9215105548452949, 1, -12.58645805784947], 
     Hue[0.9215105548453081, 1, -12.38910365842741], 
     Hue[0.9215105548453256, 1, -12.212215641167672`], 
     Hue[0.9215105548453546, 1, -12.014861241745699`], 
     Hue[0.9215105548453932, 1, -11.837973224486076`], 
     Hue[0.9215105548454571, 1, -11.640618825064296`], 
     Hue[0.9215105548455419, 1, -11.463730807804929`], 
     Hue[0.9215105548456823, 1, -11.266376408383577`], 
     Hue[0.9215105548458687, 1, -11.089488391124775`], 
     Hue[0.9215105548461777, 1, -10.892133991704355`], 
     Hue[0.9215105548465876, 1, -10.715245974446795`], 
     Hue[0.9215105548472666, 1, -10.517891575028433`], 
     Hue[0.921510554848168, 1, -10.3410035577736], 
     Hue[0.9215105548496612, 1, -10.143649158359757`], 
     Hue[0.9215105548518018, 1, -9.955066065590495], 
     Hue[0.9215105548550305, 1, -9.76429014616703], 
     Hue[0.9215105548596325, 1, -9.580823648952009], 
     Hue[0.9215105548667318, 1, -9.390047729550034], 
     Hue[0.9215105548768503, 1, -9.206581232365648], 
     Hue[0.9215105548924596, 1, -9.01580531301093], 
     Hue[0.9215105549147073, 1, -8.832338815893896], 
     Hue[0.9215105549490281, 1, -8.641562896643086], 
     Hue[0.9215105549979449, 1, -8.458096399674146], 
     Hue[0.921510555073407, 1, -8.26732048065179], 
     Hue[0.9215105551809615, 1, -8.083853984008465], 
     Hue[0.9215105553468819, 1, -7.893078065488429], 
     Hue[0.9215105555833649, 1, -7.709611569561045], 
     Hue[0.9215105559481789, 1, -7.518835652145465], 
     Hue[0.9215105564681406, 1, -7.335369157792241], 
     Hue[0.9215105572702669, 1, -7.144593242805059], 
     Hue[0.9215105584135213, 1, -6.9611267519129845`], 
     Hue[0.9215105601771783, 1, -6.770350842265188], 
     Hue[0.9215105626908825, 1, -6.586884358983233], 
     Hue[0.9215105665686831, 1, -6.396108461075298], 
     Hue[0.9215105723093079, 1, -6.206794457951805], 
     Hue[0.9215105807610617, 1, -6.019307825433446], 
     Hue[0.9215105932439215, 1, -5.832552157519949], 
     Hue[0.9215106118270137, 1, -5.645065581261046], 
     Hue[0.9215106392733955, 1, -5.458309996440231], 
     Hue[0.9215106801324963, 1, -5.2708235438804545`], 
     Hue[0.9215107404794904, 1, -5.084068141757608], 
     Hue[0.9215108303172538, 1, -4.8965819611780885`], 
     Hue[0.9215109630032698, 1, -4.7098269607573835`], 
     Hue[0.9215111739589792, 1, -4.511925526117893], 
     Hue[0.9215114578092338, 1, -4.332663522883461], 
     Hue[0.9215118901623186, 1, -4.146823864328031], 
     Hue[0.9215125401918236, 1, -3.9584271168109293`], 
     Hue[0.9215135553003544, 1, -3.762266135613465], 
     Hue[0.9215149334141418, 1, -3.5827361059074887`], 
     Hue[0.9215171600035162, 1, -3.3874498467700516`], 
     Hue[0.9215201963577687, 1, -3.2077919752580693`], 
     Hue[0.9215250855234206, 1, -3.0129545022915254`], 
     Hue[0.9215328549192756, 1, -2.8094987753191782`], 
     Hue[0.9215425173093177, 1, -2.6385119730858326`], 
     Hue[0.9215595713113756, 1, -2.4354047947070505`], 
     Hue[0.9215808001255833, 1, -2.2644823049644556`], 
     Hue[0.9216182547032705, 1, -2.061488632451719], 
     Hue[0.9216648531431489, 1, -1.8907074259817167`], 
     Hue[0.9217470004808266, 1, -1.6879629995449525`], 
     Hue[0.9218490823478672, 1, -1.5174918452659638`], 
     Hue[0.9220287159798788, 1, -1.3152938858737724`], 
     Hue[0.9222662023615907, 1, -1.1360826728856728`], 
     Hue[0.9226279641338408, 1, -0.9502680536795556], 
     Hue[0.9231629563384518, 1, -0.7644447004509682], 
     Hue[0.9239511997731972, 1, -0.5791892805288181], 
     Hue[0.9251776795410027, 1, -0.38581854571828433`], 
     Hue[0.9268962182671467, 1, -0.20330918295966405`], 
     Hue[0.929506703443929, 1, -0.015689112860906018`], 
     Hue[0.9333549117494183, 1, 0.17069568227778753`], 
     Hue[0.9391174644094784, 1, 0.35847388477607034`], 
     Hue[0.9477145500146844, 1, 0.5461649021542636], 
     Hue[0.9606300608796646, 1, 0.7338572719889167], 
     Hue[0.9803617451521086, 1, 0.9217610764718807], 
     Hue[1.0469053559602008`, 1, -17.264488266373966`], 
     Hue[1.0469053559602008`, 1, -17.07736705803298], 
     Hue[1.0469053559602008`, 1, -16.90742299186392], 
     Hue[1.0469053559602008`, 1, -16.70312464135101], 
     Hue[1.0469053559602008`, 1, -16.53318057518195], 
     Hue[1.0469053559602008`, 1, -16.32888222466904], 
     Hue[1.0469053559602008`, 1, -16.15893815849998], 
     Hue[1.0469053559602008`, 1, -15.954639807987068`], 
     Hue[1.0469053559602008`, 1, -15.784695741818005`], 
     Hue[1.0469053559602008`, 1, -15.580397391305098`], 
     Hue[1.0469053559602008`, 1, -15.407712291810729`], 
     Hue[1.0469053559602008`, 1, -15.206154974623129`], 
     Hue[1.0469053559602008`, 1, -15.033469875128759`], 
     Hue[1.0469053559602008`, 1, -14.831912557941154`], 
     Hue[1.0469053559602006`, 1, -14.657856941784138`], 
     Hue[1.0469053559602006`, 1, -14.457670141259188`], 
     Hue[1.0469053559602004`, 1, -14.283614525102164`], 
     Hue[1.0469053559602002`, 1, -14.08342772457722], 
     Hue[1.0469053559602, 1, -13.908172906340381`], 
     Hue[1.0469053559601995`, 1, -13.709185307895257`], 
     Hue[1.0469053559601986`, 1, -13.51183090847313], 
     Hue[1.0469053559601977`, 1, -13.334942891213304`], 
     Hue[1.046905355960196, 1, -13.137588491791186`], 
     Hue[1.0469053559601937`, 1, -12.960700474531372`], 
     Hue[1.04690535596019, 1, -12.763346075109272`], 
     Hue[1.046905355960185, 1, -12.586458057849484`], 
     Hue[1.046905355960177, 1, -12.389103658427429`], 
     Hue[1.0469053559601662`, 1, -12.212215641167699`], 
     Hue[1.0469053559601484`, 1, -12.01486124174574], 
     Hue[1.0469053559601247`, 1, -11.837973224486134`], 
     Hue[1.0469053559600856`, 1, -11.640618825064386`], 
     Hue[1.0469053559600336`, 1, -11.46373080780506], 
     Hue[1.0469053559599475`, 1, -11.266376408383774`], 
     Hue[1.046905355959833, 1, -11.089488391125064`], 
     Hue[1.0469053559596435`, 1, -10.892133991704792`], 
     Hue[1.046905355959392, 1, -10.715245974447427`], 
     Hue[1.0469053559589754`, 1, -10.517891575029388`], 
     Hue[1.0469053559584223`, 1, -10.34100355777499], 
     Hue[1.0469053559575061`, 1, -10.143649158361862`], 
     Hue[1.0469053559561927`, 1, -9.955066065593627], 
     Hue[1.0469053559542116`, 1, -9.764290146171708], 
     Hue[1.0469053559513881`, 1, -9.580823648958894], 
     Hue[1.0469053559470323`, 1, -9.390047729560322], 
     Hue[1.0469053559408241`, 1, -9.206581232380788], 
     Hue[1.046905355931247, 1, -9.015805313033553], 
     Hue[1.0469053559175965`, 1, -8.832338815927187], 
     Hue[1.0469053558965389`, 1, -8.641562896692827], 
     Hue[1.0469053558665256`, 1, -8.458096399747339], 
     Hue[1.0469053558202253`, 1, -8.26732048076116], 
     Hue[1.0469053557542345`, 1, -8.0838539841694], 
     Hue[1.0469053556524328`, 1, -7.893078065728907], 
     Hue[1.0469053555073369`, 1, -7.7096115699148955`], 
     Hue[1.0469053552835026`, 1, -7.518835652674208], 
     Hue[1.0469053549644765`, 1, -7.3353691585702565`], 
     Hue[1.046905354472326, 1, -7.144593243967621], 
     Hue[1.0469053537708741`, 1, -6.96112675362363], 
     Hue[1.0469053526887695`, 1, -6.770350844821344], 
     Hue[1.046905351146468, 1, -6.5868843627444775`], 
     Hue[1.0469053487672155`, 1, -6.396108466695587], 
     Hue[1.0469053452450139`, 1, -6.20679446632419], 
     Hue[1.0469053400593793`, 1, -6.019307837857663], 
     Hue[1.046905332400431, 1, -5.832552175928535], 
     Hue[1.0469053209986414`, 1, -5.645065608578491], 
     Hue[1.0469053041587177`, 1, -5.458310036915647], 
     Hue[1.0469052790893263`, 1, -5.27082360394397], 
     Hue[1.046905242063003, 1, -5.084068230751799], 
     Hue[1.0469051869424193`, 1, -4.896582093240907], 
     Hue[1.0469051055320104`, 1, -4.709827156430295], 
     Hue[1.0469049760987434`, 1, -4.511925822923192], 
     Hue[1.0469048019406342`, 1, -4.332663955766013], 
     Hue[1.046904536667871, 1, -4.146824504477917], 
     Hue[1.0469041378389035`, 1, -3.9584280685765645`], 
     Hue[1.046903515014856, 1, -3.762267573998728], 
     Hue[1.0469026694694707`, 1, -3.5827382049086482`], 
     Hue[1.0469013033445989`, 1, -3.3874530130655156`], 
     Hue[1.0468994403980298`, 1, -3.207796596903586], 
     Hue[1.0468964406882528`, 1, -3.0129614671192115`], 
     Hue[1.0468916738963852`, 1, -2.809509463109749], 
     Hue[1.0468857457916418`, 1, -2.6385272899045438`], 
     Hue[1.0468752830400405`, 1, -2.435428278930652], 
     Hue[1.04686225951405, 1, -2.2645159510219415`], 
     Hue[1.046839283109111, 1, -2.061540193928371], 
     Hue[1.0468106998458049`, 1, -1.8907812527577625`], 
     Hue[1.0467603175756492`, 1, -1.6880760129196954`], 
     Hue[1.046697720709571, 1, -1.5176534400626605`], 
     Hue[1.0465875999244822`, 1, -1.31554066133777], 
     Hue[1.0464420741153295`, 1, -1.1364414590549796`], 
     Hue[1.04622052672267, 1, -0.9507961449724254], 
     Hue[1.045893178414325, 1, -0.7652202469935065], 
     Hue[1.045409258120974, 1, -0.579614806703785], 
     Hue[1.0446622838948127`, 1, -0.38725513577247295`], 
     Hue[1.0435991247322098`, 1, -0.20299136167655063`], 
     Hue[1.0420128495414147`, 1, -0.016881508604998485`], 
     Hue[1.0396414134418588`, 1, 0.1707569312422219], 
     Hue[1.0361095810595038`, 1, 0.35876779364419165`], 
     Hue[1.0308264570080135`, 1, 0.5475414749714581], 
     Hue[1.0230528329917663`, 1, 0.733901812393274], 
     Hue[1.0113124851162674`, 1, 0.921836592701431], 
     Hue[1.1723001570751326`, 1, -17.264488266373966`], 
     Hue[1.1723001570751326`, 1, -17.07736705803298], 
     Hue[1.1723001570751326`, 1, -16.90742299186392], 
     Hue[1.1723001570751326`, 1, -16.70312464135101], 
     Hue[1.1723001570751326`, 1, -16.53318057518195], 
     Hue[1.1723001570751326`, 1, -16.32888222466904], 
     Hue[1.1723001570751326`, 1, -16.15893815849998], 
     Hue[1.1723001570751326`, 1, -15.954639807987068`], 
     Hue[1.1723001570751326`, 1, -15.784695741818005`], 
     Hue[1.1723001570751326`, 1, -15.580397391305098`], 
     Hue[1.1723001570751326`, 1, -15.407712291810729`], 
     Hue[1.1723001570751324`, 1, -15.206154974623129`], 
     Hue[1.1723001570751324`, 1, -15.033469875128759`], 
     Hue[1.1723001570751321`, 1, -14.831912557941154`], 
     Hue[1.172300157075132, 1, -14.657856941784134`], 
     Hue[1.1723001570751317`, 1, -14.457670141259184`], 
     Hue[1.1723001570751312`, 1, -14.283614525102164`], 
     Hue[1.1723001570751306`, 1, -14.083427724577216`], 
     Hue[1.1723001570751297`, 1, -13.908172906340376`], 
     Hue[1.1723001570751281`, 1, -13.709185307895249`], 
     Hue[1.172300157075126, 1, -13.511830908473117`], 
     Hue[1.1723001570751228`, 1, -13.334942891213286`], 
     Hue[1.1723001570751177`, 1, -13.137588491791162`], 
     Hue[1.1723001570751108`, 1, -12.960700474531334`], 
     Hue[1.1723001570750997`, 1, -12.763346075109219`], 
     Hue[1.1723001570750848`, 1, -12.586458057849404`], 
     Hue[1.1723001570750602`, 1, -12.38910365842731], 
     Hue[1.1723001570750273`, 1, -12.212215641167525`], 
     Hue[1.1723001570749731`, 1, -12.014861241745477`], 
     Hue[1.1723001570749012`, 1, -11.837973224485753`], 
     Hue[1.172300157074782, 1, -11.640618825063807`], 
     Hue[1.1723001570746239`, 1, -11.463730807804222`], 
     Hue[1.1723001570743619`, 1, -11.266376408382502`], 
     Hue[1.1723001570740141`, 1, -11.089488391123218`], 
     Hue[1.1723001570734377`, 1, -10.892133991701998`], 
     Hue[1.172300157072673, 1, -10.715245974443372`], 
     Hue[1.1723001570714062`, 1, -10.517891575023246`], 
     Hue[1.1723001570697247`, 1, -10.341003557766074`], 
     Hue[1.1723001570669391`, 1, -10.143649158348355`], 
     Hue[1.1723001570629459`, 1, -9.955066065573535], 
     Hue[1.1723001570569223`, 1, -9.764290146141688], 
     Hue[1.1723001570483371`, 1, -9.580823648914722], 
     Hue[1.172300157035093, 1, -9.390047729494315], 
     Hue[1.1723001570162166`, 1, -9.20658123228366], 
     Hue[1.1723001569870966`, 1, -9.01580531288842], 
     Hue[1.1723001569455924`, 1, -8.83233881571363], 
     Hue[1.1723001568815654`, 1, -8.641562896373719], 
     Hue[1.172300156790309, 1, -8.458096399277787], 
     Hue[1.1723001566495312`, 1, -8.267320480059526], 
     Hue[1.1723001564488833`, 1, -8.083853983136983], 
     Hue[1.1723001561393511`, 1, -7.893078064186201], 
     Hue[1.1723001556981811`, 1, -7.709611567644891], 
     Hue[1.172300155017604, 1, -7.518835649282223], 
     Hue[1.1723001540475915`, 1, -7.335369153579136], 
     Hue[1.172300152551188, 1, -7.144593236509569], 
     Hue[1.1723001504183947`, 1, -6.961126742649513], 
     Hue[1.1723001471282115`, 1, -6.770350828423123], 
     Hue[1.1723001424387804`, 1, -6.586884338615389], 
     Hue[1.1723001352045648`, 1, -6.39610843064037], 
     Hue[1.1723001244951643`, 1, -6.206794412613754], 
     Hue[1.172300108728026, 1, -6.019307758153966], 
     Hue[1.1723000854406704`, 1, -5.832552057833969], 
     Hue[1.1723000507730417`, 1, -5.6450654333318875`], 
     Hue[1.172299999570518, 1, -5.458309777258109], 
     Hue[1.172299923345904, 1, -5.270823218624945], 
     Hue[1.172299810765627, 1, -5.084067659836729], 
     Hue[1.1722996431687367`, 1, -4.896581246031789], 
     Hue[1.172299395635963, 1, -4.709825901148934], 
     Hue[1.172299002086202, 1, -4.511923918854882], 
     Hue[1.1722984725461276`, 1, -4.332661178729239], 
     Hue[1.1722976659617508`, 1, -4.146820397765914], 
     Hue[1.1722964532798865`, 1, -3.958421962754592], 
     Hue[1.1722945594967595`, 1, -3.762258346335175], 
     Hue[1.172291988458596, 1, -3.5827247390988353`], 
     Hue[1.1722878344046375`, 1, -3.3874326999508044`], 
     Hue[1.1722821694435404`, 1, -3.2077669466153003`], 
     Hue[1.1722730472757963`, 1, -3.012916782890324], 
     Hue[1.1722605496027358`, 1, -2.8328335810399308`], 
     Hue[1.1722405195075911`, 1, -2.6384313318897172`], 
     Hue[1.1722086901129323`, 1, -2.435277582864596], 
     Hue[1.172169060973413, 1, -2.2643000223891754`], 
     Hue[1.1720991197905675`, 1, -2.0612092227449814`], 
     Hue[1.172012063796397, 1, -1.8903072409838682`], 
     Hue[1.1718584869439992`, 1, -1.6873500749985684`], 
     Hue[1.1716674502309457`, 1, -1.5166148640983452`], 
     Hue[1.1713307669525352`, 1, -1.3139530781199198`], 
     Hue[1.1708846425168966`, 1, -1.1341303071981674`], 
     Hue[1.1702283369784712`, 1, -0.9531936279368216], 
     Hue[1.169236133767091, 1, -0.767341406504296], 
     Hue[1.1677281244810604`, 1, -0.5772686147621799], 
     Hue[1.1655483932518123`, 1, -0.3921689607183374], 
     Hue[1.1622011143341058`, 1, -0.20109276960975242`], 
     Hue[1.1574031621639973`, 1, -0.01682629293678639], 
     Hue[1.1501395069394569`, 1, 0.17098202529683204`], 
     Hue[1.1392263364086626`, 1, 0.3592954905602158], 
     Hue[1.1227325087535218`, 1, 0.5471985765695896], 
     Hue[1.09730753027193, 1, 0.7338681598543828], 
     Hue[1.0545745480988153`, 1, 0.9216519152496054], 
     Hue[1.2976949581900639`, 1, -17.264488266373966`], 
     Hue[1.2976949581900639`, 1, -17.07736705803298], 
     Hue[1.2976949581900639`, 1, -16.90742299186392], 
     Hue[1.2976949581900639`, 1, -16.70312464135101], 
     Hue[1.2976949581900639`, 1, -16.53318057518195], 
     Hue[1.2976949581900639`, 1, -16.32888222466904], 
     Hue[1.2976949581900639`, 1, -16.15893815849998], 
     Hue[1.2976949581900636`, 1, -15.954639807987068`], 
     Hue[1.2976949581900636`, 1, -15.784695741818005`], 
     Hue[1.2976949581900636`, 1, -15.580397391305098`], 
     Hue[1.2976949581900636`, 1, -15.407712291810729`], 
     Hue[1.2976949581900636`, 1, -15.206154974623129`], 
     Hue[1.2976949581900636`, 1, -15.033469875128759`], 
     Hue[1.2976949581900632`, 1, -14.831912557941154`], 
     Hue[1.2976949581900632`, 1, -14.657856941784134`], 
     Hue[1.2976949581900628`, 1, -14.457670141259184`], 
     Hue[1.2976949581900623`, 1, -14.283614525102161`], 
     Hue[1.2976949581900616`, 1, -14.083427724577211`], 
     Hue[1.2976949581900605`, 1, -13.908172906340367`], 
     Hue[1.297694958190059, 1, -13.709185307895236`], 
     Hue[1.2976949581900565`, 1, -13.511830908473101`], 
     Hue[1.297694958190053, 1, -13.334942891213261`], 
     Hue[1.2976949581900477`, 1, -13.137588491791123`], 
     Hue[1.2976949581900403`, 1, -12.960700474531277`], 
     Hue[1.2976949581900281`, 1, -12.763346075109133`], 
     Hue[1.2976949581900121`, 1, -12.586458057849281`], 
     Hue[1.2976949581899855`, 1, -12.389103658427121`], 
     Hue[1.29769495818995, 1, -12.212215641167253`], 
     Hue[1.2976949581898913`, 1, -12.014861241745066`], 
     Hue[1.2976949581898136`, 1, -11.837973224485156`], 
     Hue[1.2976949581896846`, 1, -11.640618825062903`], 
     Hue[1.2976949581895134`, 1, -11.463730807802907`], 
     Hue[1.2976949581892299`, 1, -11.266376408380511`], 
     Hue[1.2976949581888537`, 1, -11.08948839112033], 
     Hue[1.2976949581882304`, 1, -10.89213399169762], 
     Hue[1.297694958187403, 1, -10.71524597443702], 
     Hue[1.2976949581860324`, 1, -10.517891575013621`], 
     Hue[1.2976949581842134`, 1, -10.341003557752106`], 
     Hue[1.2976949581812, 1, -10.143649158327193`], 
     Hue[1.29769495817688, 1, -9.955066065542063], 
     Hue[1.2976949581703636`, 1, -9.764290146094657], 
     Hue[1.2976949581610762`, 1, -9.580823648845518], 
     Hue[1.2976949581467485`, 1, -9.390047729390908], 
     Hue[1.2976949581263277`, 1, -9.206581232131503], 
     Hue[1.2976949580948254`, 1, -9.015805312661056], 
     Hue[1.2976949580499255`, 1, -8.832338815379076], 
     Hue[1.2976949579806605`, 1, -8.641562895873808], 
     Hue[1.2976949578819381`, 1, -8.458096398542196], 
     Hue[1.297694957729643, 1, -8.267320478960357], 
     Hue[1.2976949575125796`, 1, -8.083853981519615], 
     Hue[1.2976949571777239`, 1, -7.893078061769432], 
     Hue[1.2976949567004608`, 1, -7.709611564088742], 
     Hue[1.2976949559642041`, 1, -7.518835643968402], 
     Hue[1.2976949549148327`, 1, -7.3353691457601355`], 
     Hue[1.297694953296005, 1, -7.144593224825926], 
     Hue[1.2976949509887228`, 1, -6.961126725457668], 
     Hue[1.297694947429362, 1, -6.770350802733975], 
     Hue[1.2976949423562774`, 1, -6.586884300815207], 
     Hue[1.2976949345302127`, 1, -6.396108374156935], 
     Hue[1.2976949229446486`, 1, -6.206794328471972], 
     Hue[1.2976949058875575`, 1, -6.019307633291602], 
     Hue[1.2976948806949946`, 1, -5.83255187282913], 
     Hue[1.2976948431910924`, 1, -5.645065158793597], 
     Hue[1.2976947877994953`, 1, -5.458309370482928], 
     Hue[1.2976947053385985`, 1, -5.270822614990157], 
     Hue[1.2976945835474911`, 1, -5.084066765449171], 
     Hue[1.2976944022382733`, 1, -4.896579918803858], 
     Hue[1.297694134452428, 1, -4.709823934635445], 
     Hue[1.2976937087010372`, 1, -4.511920935946621], 
     Hue[1.2976931358292507`, 1, -4.332656828210426], 
     Hue[1.297692263236576, 1, -4.1468139641254345`], 
     Hue[1.2976909512982846`, 1, -3.958412397173242], 
     Hue[1.2976889024768763`, 1, -3.762243889730348], 
     Hue[1.2976861208880894`, 1, -3.582703642279651], 
     Hue[1.2976816264808877`, 1, -3.3874008743145216`], 
     Hue[1.2976754970464641`, 1, -3.2077204895888443`], 
     Hue[1.2976656261534427`, 1, -3.012846764512715], 
     Hue[1.2976521088403155`, 1, -2.832816945775229], 
     Hue[1.2976304253408755`, 1, -2.6383120938835845`], 
     Hue[1.2975959588773944`, 1, -2.4350413128474235`], 
     Hue[1.297553035666147, 1, -2.263961357492187], 
     Hue[1.297477235627856, 1, -2.0606898004900502`], 
     Hue[1.2973828064570405`, 1, -1.8895627558948898`], 
     Hue[1.2972160040793295`, 1, -1.686208354638785], 
     Hue[1.2970081260376018`, 1, -1.5149786647453538`], 
     Hue[1.2966407057574734`, 1, -1.311444466899833], 
     Hue[1.2961824199116, 1, -1.1399934269983938`], 
     Hue[1.2954281261606555`, 1, -0.9478201600095999], 
     Hue[1.2943241843151605`, 1, -0.7593790487326137], 
     Hue[1.29268569382391, 1, -0.5712522736502108], 
     Hue[1.2903943593800844`, 1, -0.39242346849491105`], 
     Hue[1.2868495103713928`, 1, -0.20462474875124426`], 
     Hue[1.2815792933993213`, 1, -0.016947049427390892`], 
     Hue[1.2737090134265838`, 1, 0.17096168443604254`], 
     Hue[1.2617984689820205`, 1, 0.3602335279846347], 
     Hue[1.1342743822829673`, 1, 0.7338592417125178], 
     Hue[1.2439992115685838`, 1, 0.5465017720380567], 
     Hue[1.2157869194320865`, 1, 0.7349662818389422], 
     Hue[1.0842162729189069`, 1, 0.9215778340936664], 
     Hue[1.1676358572345793`, 1, 0.9216623956880535], 
     Hue[1.4230897593049956`, 1, -17.264488266373966`], 
     Hue[1.4230897593049956`, 1, -17.07736705803298], 
     Hue[1.4230897593049954`, 1, -16.90742299186392], 
     Hue[1.4230897593049956`, 1, -16.70312464135101], 
     Hue[1.4230897593049956`, 1, -16.53318057518195], 
     Hue[1.4230897593049956`, 1, -16.32888222466904], 
     Hue[1.4230897593049956`, 1, -16.15893815849998], 
     Hue[1.4230897593049954`, 1, -15.954639807987068`], 
     Hue[1.4230897593049954`, 1, -15.784695741818005`], 
     Hue[1.4230897593049954`, 1, -15.580397391305098`], 
     Hue[1.4230897593049954`, 1, -15.407712291810729`], 
     Hue[1.4230897593049954`, 1, -15.206154974623129`], 
     Hue[1.4230897593049954`, 1, -15.033469875128759`], 
     Hue[1.4230897593049954`, 1, -14.831912557941154`], 
     Hue[1.4230897593049951`, 1, -14.65785694178413], 
     Hue[1.4230897593049951`, 1, -14.45767014125918], 
     Hue[1.423089759304995, 1, -14.283614525102157`], 
     Hue[1.4230897593049945`, 1, -14.083427724577206`], 
     Hue[1.423089759304994, 1, -13.908172906340361`], 
     Hue[1.4230897593049932`, 1, -13.709185307895227`], 
     Hue[1.423089759304992, 1, -13.511830908473087`], 
     Hue[1.4230897593049903`, 1, -13.334942891213242`], 
     Hue[1.4230897593049876`, 1, -13.137588491791092`], 
     Hue[1.423089759304984, 1, -12.960700474531235`], 
     Hue[1.423089759304978, 1, -12.763346075109066`], 
     Hue[1.4230897593049703`, 1, -12.586458057849185`], 
     Hue[1.4230897593049574`, 1, -12.389103658426976`], 
     Hue[1.4230897593049403`, 1, -12.212215641167044`], 
     Hue[1.4230897593049117`, 1, -12.014861241744747`], 
     Hue[1.4230897593048737`, 1, -11.837973224484696`], 
     Hue[1.423089759304811, 1, -11.640618825062203`], 
     Hue[1.423089759304728, 1, -11.463730807801893`], 
     Hue[1.42308975930459, 1, -11.266376408378974`], 
     Hue[1.423089759304407, 1, -11.089488391118097`], 
     Hue[1.4230897593041039`, 1, -10.89213399169424], 
     Hue[1.4230897593037015`, 1, -10.715245974432115`], 
     Hue[1.423089759303035, 1, -10.517891575006189`], 
     Hue[1.4230897593021503`, 1, -10.34100355774132], 
     Hue[1.4230897593006848`, 1, -10.14364915831085], 
     Hue[1.4230897592985838`, 1, -9.955066065517752], 
     Hue[1.4230897592954148`, 1, -9.764290146058332], 
     Hue[1.4230897592908982`, 1, -9.580823648792068], 
     Hue[1.4230897592839302`, 1, -9.39004772931104], 
     Hue[1.423089759273999, 1, -9.206581232013981], 
     Hue[1.4230897592586786`, 1, -9.015805312485448], 
     Hue[1.4230897592368428`, 1, -8.832338815120679], 
     Hue[1.4230897592031573`, 1, -8.641562895487692], 
     Hue[1.423089759155146, 1, -8.458096397974048], 
     Hue[1.4230897590810807`, 1, -8.267320478111396], 
     Hue[1.4230897589755171`, 1, -8.083853980270414], 
     Hue[1.423089758812668, 1, -7.893078059902792], 
     Hue[1.4230897585805624`, 1, -7.709611561342087], 
     Hue[1.4230897582225015`, 1, -7.518835639864174], 
     Hue[1.4230897577121644`, 1, -7.3353691397209895`], 
     Hue[1.423089756924886, 1, -7.144593215801849], 
     Hue[1.423089755802794, 1, -6.96112671217923], 
     Hue[1.423089754071783, 1, -6.7703507828924865`], 
     Hue[1.4230897516046084`, 1, -6.586884271619537], 
     Hue[1.4230897477985867`, 1, -6.396108330530906], 
     Hue[1.423089742164221, 1, -6.206794263483498], 
     Hue[1.4230897338689064`, 1, -6.019307536851812], 
     Hue[1.4230897216170946`, 1, -5.832551729937138], 
     Hue[1.423089703377947, 1, -5.645064946748679], 
     Hue[1.423089676439527, 1, -5.458309056302155], 
     Hue[1.423089636336559, 1, -5.270822148760673], 
     Hue[1.423089577106197, 1, -5.0840660746501785`], 
     Hue[1.4230894889304389`, 1, -4.896578893689868], 
     Hue[1.4230893586984439`, 1, -4.7098224157514235`], 
     Hue[1.423089151642682, 1, -4.5119186320169], 
     Hue[1.4230888730367475`, 1, -4.332653467952626], 
     Hue[1.4230884486645452`, 1, -4.1468089948655456`], 
     Hue[1.4230878106178604`, 1, -3.95840500875678], 
     Hue[1.4230868141832174`, 1, -3.762232723303283], 
     Hue[1.4230854613452424`, 1, -3.5826873464804123`], 
     Hue[1.4230832754087301`, 1, -3.3873762902794073`], 
     Hue[1.4230802941240877`, 1, -3.2076846014286957`], 
     Hue[1.4230754927398097`, 1, -3.0127926703980332`], 
     Hue[1.4230689210820866`, 1, -2.8328293074002238`], 
     Hue[1.4230583698723651`, 1, -2.6382301901782164`], 
     Hue[1.4230415948218451`, 1, -2.434858664336584], 
     Hue[1.4230207005900288`, 1, -2.263699452486577], 
     Hue[1.422983785482233, 1, -2.060287836163363], 
     Hue[1.4229377673880188`, 1, -1.888986137540875], 
     Hue[1.4228563969152106`, 1, -1.6853227538450055`], 
     Hue[1.4227548402275096`, 1, -1.5137071553203294`], 
     Hue[1.4225749359914697`, 1, -1.3094885943802075`], 
     Hue[1.4223498106124388`, 1, -1.1371798603711116`], 
     Hue[1.4220053187624415`, 1, -0.9556184636995015], 
     Hue[1.4214456572795187`, 1, -0.7579614250967996], 
     Hue[1.4206973482418848`, 1, -0.5797948902673855], 
     Hue[1.419530876663302, 1, -0.39117273097454963`], 
     Hue[1.391441453103158, 1, 0.1709024461071431], 
     Hue[1.4178194754699234`, 1, -0.20471710396772336`], 
     Hue[1.415175162470852, 1, -0.011679428682600967`], 
     Hue[1.4114148327459248`, 1, 0.17273929637918062`], 
     Hue[1.2861300135602463`, 1, 0.5465226465665172], 
     Hue[1.4057977220442697`, 1, 0.35881171212502283`], 
     Hue[1.3973627102165618`, 1, 0.5463921665657105], 
     Hue[1.2183701610713926`, 1, 0.9217541561152196], 
     Hue[1.2881975094051408`, 1, 1.1092838312755027`], 
     Hue[1.3847014182031305`, 1, 0.7339480387348916], 
     Hue[1.3653923950015572`, 1, 0.9216548728263432], 
     Hue[1.3348510525992818`, 1, 1.109312724127656], 
     Hue[1.1149962659252484`, 1, 1.1094227597814277`], 
     Hue[1.1136283130250013`, 1, 1.297026087046032], 
     Hue[1.280276336468643, 1, 1.2970626426632839`], 
     Hue[1.0481894521524797`, 1, 1.1093056374645751`], 
     Hue[1.0659964313362635`, 1, 1.297284573949247], 
     Hue[1.0127855036525828`, 1, 1.1092828502643297`], 
     Hue[1.0113455683765635`, 1, 1.1093951463223477`], 
     Hue[0.5484845604199272, 1, -17.264488266373966`], 
     Hue[0.5484845604199272, 1, -17.07736705803298], 
     Hue[0.5484845604199272, 1, -16.90742299186392], 
     Hue[0.5484845604199272, 1, -16.70312464135101], 
     Hue[0.5484845604199272, 1, -16.53318057518195], 
     Hue[0.5484845604199272, 1, -16.32888222466904], 
     Hue[0.5484845604199272, 1, -16.15893815849998], 
     Hue[0.5484845604199272, 1, -15.954639807987068`], 
     Hue[0.5484845604199272, 1, -15.784695741818005`], 
     Hue[0.5484845604199272, 1, -15.580397391305098`], 
     Hue[0.5484845604199273, 1, -15.407712291810729`], 
     Hue[0.5484845604199273, 1, -15.206154974623129`], 
     Hue[0.5484845604199273, 1, -15.033469875128759`], 
     Hue[0.5484845604199273, 1, -14.831912557941154`], 
     Hue[0.5484845604199274, 1, -14.65785694178413], 
     Hue[0.5484845604199275, 1, -14.45767014125918], 
     Hue[0.5484845604199278, 1, -14.283614525102157`], 
     Hue[0.548484560419928, 1, -14.083427724577206`], 
     Hue[0.5484845604199282, 1, -13.90817290634036], 
     Hue[0.5484845604199288, 1, -13.709185307895225`], 
     Hue[0.5484845604199295, 1, -13.511830908473085`], 
     Hue[0.5484845604199307, 1, -13.33494289121324], 
     Hue[0.5484845604199323, 1, -13.137588491791089`], 
     Hue[0.5484845604199347, 1, -12.96070047453123], 
     Hue[0.5484845604199384, 1, -12.763346075109059`], 
     Hue[0.5484845604199435, 1, -12.586458057849175`], 
     Hue[0.5484845604199519, 1, -12.38910365842696], 
     Hue[0.548484560419963, 1, -12.212215641167019`], 
     Hue[0.5484845604199813, 1, -12.01486124174471], 
     Hue[0.5484845604200058, 1, -11.83797322448464], 
     Hue[0.5484845604200463, 1, -11.640618825062122`], 
     Hue[0.5484845604201001, 1, -11.463730807801776`], 
     Hue[0.548484560420189, 1, -11.266376408378797`], 
     Hue[0.5484845604203071, 1, -11.08948839111784], 
     Hue[0.5484845604205029, 1, -10.892133991693846`], 
     Hue[0.5484845604207625, 1, -10.715245974431546`], 
     Hue[0.5484845604211928, 1, -10.517891575005326`], 
     Hue[0.5484845604217639, 1, -10.341003557740068`], 
     Hue[0.54848456042271, 1, -10.143649158308955`], 
     Hue[0.5484845604240662, 1, -9.955066065514934], 
     Hue[0.5484845604261118, 1, -9.764290146054119], 
     Hue[0.5484845604290276, 1, -9.58082364878587], 
     Hue[0.5484845604335256, 1, -9.390047729301777], 
     Hue[0.5484845604399364, 1, -9.206581232000351], 
     Hue[0.5484845604498263, 1, -9.015805312465078], 
     Hue[0.5484845604639221, 1, -8.832338815090708], 
     Hue[0.5484845604856671, 1, -8.64156289544291], 
     Hue[0.5484845605166598, 1, -8.458096397908154], 
     Hue[0.5484845605644713, 1, -8.26732047801293], 
     Hue[0.5484845606326159, 1, -8.083853980125529], 
     Hue[0.5484845607377402, 1, -7.893078059686297], 
     Hue[0.5484845608875717, 1, -7.709611561023524], 
     Hue[0.5484845611187112, 1, -7.518835639388159], 
     Hue[0.5484845614481499, 1, -7.335369139020556], 
     Hue[0.548484561956363, 1, -7.144593214755218], 
     Hue[0.5484845626807088, 1, -6.961126710639166], 
     Hue[0.5484845637981309, 1, -6.770350780591227], 
     Hue[0.5484845653907701, 1, -6.5868842682333595`], 
     Hue[0.5484845678476771, 1, -6.396108325471063], 
     Hue[0.548484571484838, 1, -6.206794255945992], 
     Hue[0.5484845768397255, 1, -6.019307525666514], 
     Hue[0.548484584748657, 1, -5.832551713364212], 
     Hue[0.5484845965226028, 1, -5.645064922155239], 
     Hue[0.5484846139122048, 1, -5.458309019862763], 
     Hue[0.5484846397999406, 1, -5.270822094686312], 
     Hue[0.5484846780350183, 1, -5.0840659945296895`], 
     Hue[0.5484847349552755, 1, -4.896578774794648], 
     Hue[0.548484819024188, 1, -4.709822239587348], 
     Hue[0.548484952685338, 1, -4.511918364800711], 
     Hue[0.548485132534505, 1, -4.3326530782195976`], 
     Hue[0.5484854064807043, 1, -4.14680841851333], 
     Hue[0.5484858183612074, 1, -3.958404151817417], 
     Hue[0.5484864615941127, 1, -3.7622314281629956`], 
     Hue[0.5484873348995527, 1, -3.5826854563860833`], 
     Hue[0.5484887460046055, 1, -3.3873734388052634`], 
     Hue[0.548490670546296, 1, -3.2076804386914466`], 
     Hue[0.5484937700593979, 1, -3.0127863956484315`], 
     Hue[0.5484980124096408, 1, -2.8328201415140084`], 
     Hue[0.5485048238777639, 1, -2.638216381365538], 
     Hue[0.548515653499962, 1, -2.4348374712747454`], 
     Hue[0.5485291428505675, 1, -2.2636690574788876`], 
     Hue[0.5485529765831488, 1, -2.060241171414522], 
     Hue[0.548582689821574, 1, -1.8889191694085639`], 
     Hue[0.5486352358180782, 1, -1.6852198259129996`], 
     Hue[0.5487008284902335, 1, -1.513559241393829], 
     Hue[0.5488170542527503, 1, -1.309260702124824], 
     Hue[0.5489625500819006, 1, -1.1368513692076283`], 
     Hue[0.5491850375292604, 1, -0.9553202117167581], 
     Hue[0.5495240247560369, 1, -0.7678399776915961], 
     Hue[0.5500324333829437, 1, -0.5787103998263061], 
     Hue[0.5507897499209796, 1, -0.38953595944207975`], 
     Hue[0.5519041055467602, 1, -0.20224218804437832`], 
     Hue[0.5535374405316048, 1, -0.016821280858799748`], 
     Hue[0.5560582889112415, 1, 0.1753245920607257], 
     Hue[0.5596536819051453, 1, 0.35963598167918076`], 
     Hue[0.5650859881923, 1, 0.5474237221308683], 
     Hue[0.5731228597267535, 1, 0.7339230186686969], 
     Hue[0.5852389210092295, 1, 0.9215707462887543], 
     Hue[0.6036725266870453, 1, 1.1093246819609168`], 
     Hue[0.6326577214543744, 1, 1.2970405705535886`], 
     Hue[0.9643141453712193, 1, 1.2970265467916389`], 
     Hue[0.9932369876266284, 1, 1.1098166950787416`], 
     Hue[0.6738793615348584, 1, -17.264488266373966`], 
     Hue[0.6738793615348584, 1, -17.07736705803298], 
     Hue[0.6738793615348584, 1, -16.90742299186392], 
     Hue[0.6738793615348584, 1, -16.70312464135101], 
     Hue[0.6738793615348584, 1, -16.53318057518195], 
     Hue[0.6738793615348584, 1, -16.32888222466904], 
     Hue[0.6738793615348584, 1, -16.15893815849998], 
     Hue[0.6738793615348584, 1, -15.954639807987068`], 
     Hue[0.6738793615348584, 1, -15.784695741818005`], 
     Hue[0.6738793615348584, 1, -15.580397391305098`], 
     Hue[0.6738793615348585, 1, -15.407712291810729`], 
     Hue[0.6738793615348586, 1, -15.206154974623129`], 
     Hue[0.6738793615348586, 1, -15.033469875128759`], 
     Hue[0.6738793615348588, 1, -14.831912557941154`], 
     Hue[0.6738793615348591, 1, -14.657856941784134`], 
     Hue[0.6738793615348594, 1, -14.457670141259184`], 
     Hue[0.6738793615348597, 1, -14.283614525102157`], 
     Hue[0.6738793615348604, 1, -14.08342772457721], 
     Hue[0.6738793615348613, 1, -13.908172906340365`], 
     Hue[0.6738793615348628, 1, -13.709185307895234`], 
     Hue[0.6738793615348653, 1, -13.511830908473097`], 
     Hue[0.6738793615348684, 1, -13.334942891213256`], 
     Hue[0.6738793615348735, 1, -13.137588491791114`], 
     Hue[0.6738793615348804, 1, -12.960700474531267`], 
     Hue[0.6738793615348915, 1, -12.763346075109116`], 
     Hue[0.6738793615349066, 1, -12.586458057849255`], 
     Hue[0.6738793615349313, 1, -12.38910365842708], 
     Hue[0.6738793615349642, 1, -12.212215641167194`], 
     Hue[0.6738793615350187, 1, -12.014861241744976`], 
     Hue[0.673879361535091, 1, -11.837973224485028`], 
     Hue[0.6738793615352108, 1, -11.640618825062708`], 
     Hue[0.6738793615353698, 1, -11.463730807802625`], 
     Hue[0.6738793615356332, 1, -11.266376408380083`], 
     Hue[0.6738793615359828, 1, -11.089488391119705`], 
     Hue[0.6738793615365621, 1, -10.892133991696674`], 
     Hue[0.6738793615373309, 1, -10.715245974435648`], 
     Hue[0.6738793615386043, 1, -10.517891575011543`], 
     Hue[0.6738793615402945, 1, -10.341003557749092`], 
     Hue[0.6738793615430947, 1, -10.143649158322624`], 
     Hue[0.6738793615471088, 1, -9.955066065535265], 
     Hue[0.6738793615531637, 1, -9.7642901460845], 
     Hue[0.6738793615617937, 1, -9.580823648830574], 
     Hue[0.673879361575107, 1, -9.390047729368577], 
     Hue[0.6738793615940819, 1, -9.206581232098644], 
     Hue[0.673879361623354, 1, -9.015805312611954], 
     Hue[0.6738793616650749, 1, -8.83233881530683], 
     Hue[0.6738793617294361, 1, -8.64156289576585], 
     Hue[0.6738793618211688, 1, -8.458096398383342], 
     Hue[0.6738793619626815, 1, -8.267320478722988], 
     Hue[0.6738793621643769, 1, -8.083853981170341], 
     Hue[0.673879362475525, 1, -7.893078061247521], 
     Hue[0.6738793629189981, 1, -7.709611563320782], 
     Hue[0.673879363603128, 1, -7.518835642820867], 
     Hue[0.6738793645782044, 1, -7.335369144071602], 
     Hue[0.6738793660824196, 1, -7.144593222302809], 
     Hue[0.6738793682263469, 1, -6.96112672174504], 
     Hue[0.6738793715337061, 1, -6.770350797186327], 
     Hue[0.6738793762476183, 1, -6.586884292652147], 
     Hue[0.6738793835196006, 1, -6.396108361959171], 
     Hue[0.6738793942849113, 1, -6.206794310301305], 
     Hue[0.6738794101343673, 1, -6.019307606327203], 
     Hue[0.6738794335433085, 1, -5.832551832876779], 
     Hue[0.673879468391954, 1, -5.645065099506214], 
     Hue[0.6738795198618606, 1, -5.458309282638553], 
     Hue[0.6738795964845885, 1, -5.27082248463327], 
     Hue[0.6738797096530031, 1, -5.084066572303137], 
     Hue[0.6738798781257589, 1, -4.896579632184157], 
     Hue[0.6738801269528278, 1, -4.709823509959007], 
     Hue[0.6738805225620521, 1, -4.511920291773999], 
     Hue[0.6738810548764814, 1, -4.332655888692789], 
     Hue[0.6738818656938604, 1, -4.146812574739204], 
     Hue[0.6738830847562247, 1, -3.958410331407583], 
     Hue[0.6738849885425513, 1, -3.7622407676690086`], 
     Hue[0.6738875732375578, 1, -3.582699086114218], 
     Hue[0.6738917495427147, 1, -3.387394000915962], 
     Hue[0.6738974452179477, 1, -3.207710455865816], 
     Hue[0.6739066177408111, 1, -3.012831641130094], 
     Hue[0.6739191790168232, 1, -2.8327948520618795`], 
     Hue[0.6739393296804981, 1, -2.6382788176781418`], 
     Hue[0.6739713616161582, 1, -2.4349902587760743`], 
     Hue[0.6740112563127773, 1, -2.263888158376007], 
     Hue[0.674081717247529, 1, -2.0605774804396058`], 
     Hue[0.6741695113817963, 1, -1.8894016753146905`], 
     Hue[0.6743246375084767, 1, -1.6859610745416769`], 
     Hue[0.6745180428506758, 1, -1.5146238378853243`], 
     Hue[0.6748600973934522, 1, -1.3108992284419199`], 
     Hue[0.6752871293989892, 1, -1.1392101094892209`], 
     Hue[0.6759909169379279, 1, -0.9466436077012634], 
     Hue[0.6769577841536794, 1, -0.7675878559230755], 
     Hue[0.6785596213492622, 1, -0.5686319599045571], 
     Hue[0.6806907469990259, 1, -0.3904685953036271], 
     Hue[0.6052399337438246, 1, 0.17176548624051668`], 
     Hue[0.6839584478803646, 1, -0.20450426797599164`], 
     Hue[0.6888797448787474, 1, -0.01602393767514676], 
     Hue[0.7133244909012157, 1, 0.5470322649100486], 
     Hue[0.6961567508493065, 1, 0.17098825985331767`], 
     Hue[0.7070724371583874, 1, 0.35850716074681754`], 
     Hue[0.7816163173566215, 1, 0.9217897163769051], 
     Hue[0.7117999850293385, 1, 1.1092903144260917`], 
     Hue[0.723657926486037, 1, 0.5466763598239336], 
     Hue[0.7493463672406472, 1, 0.7341637268644003], 
     Hue[0.8850013478323249, 1, 1.1094583703912533`], 
     Hue[0.8863840153877425, 1, 1.2971753475275971`], 
     Hue[0.7924801397704994, 1, 0.9220253148573281], 
     Hue[0.9518118448002574, 1, 1.1093216896761953`], 
     Hue[0.9872185336476526, 1, 1.1092913221677727`], 
     Hue[0.7992741626497901, 1, -17.264488266373966`], 
     Hue[0.7992741626497901, 1, -17.07736705803298], 
     Hue[0.7992741626497901, 1, -16.90742299186392], 
     Hue[0.7992741626497901, 1, -16.70312464135101], 
     Hue[0.7992741626497901, 1, -16.53318057518195], 
     Hue[0.7992741626497901, 1, -16.32888222466904], 
     Hue[0.7992741626497901, 1, -16.15893815849998], 
     Hue[0.7992741626497901, 1, -15.954639807987068`], 
     Hue[0.7992741626497901, 1, -15.784695741818005`], 
     Hue[0.7992741626497902, 1, -15.580397391305098`], 
     Hue[0.7992741626497902, 1, -15.407712291810729`], 
     Hue[0.7992741626497903, 1, -15.206154974623129`], 
     Hue[0.7992741626497905, 1, -15.033469875128759`], 
     Hue[0.7992741626497906, 1, -14.831912557941154`], 
     Hue[0.7992741626497908, 1, -14.657856941784134`], 
     Hue[0.7992741626497911, 1, -14.457670141259184`], 
     Hue[0.7992741626497916, 1, -14.283614525102161`], 
     Hue[0.7992741626497923, 1, -14.083427724577215`], 
     Hue[0.7992741626497933, 1, -13.908172906340374`], 
     Hue[0.799274162649795, 1, -13.709185307895247`], 
     Hue[0.7992741626497974, 1, -13.511830908473113`], 
     Hue[0.7992741626498008, 1, -13.334942891213283`], 
     Hue[0.7992741626498063, 1, -13.137588491791153`], 
     Hue[0.7992741626498135, 1, -12.960700474531322`], 
     Hue[0.7992741626498256, 1, -12.7633460751092], 
     Hue[0.7992741626498417, 1, -12.586458057849377`], 
     Hue[0.7992741626498683, 1, -12.389103658427269`], 
     Hue[0.7992741626499036, 1, -12.212215641167466`], 
     Hue[0.7992741626499621, 1, -12.014861241745388`], 
     Hue[0.7992741626500397, 1, -11.837973224485625`], 
     Hue[0.7992741626501683, 1, -11.640618825063614`], 
     Hue[0.7992741626503388, 1, -11.46373080780394], 
     Hue[0.7992741626506215, 1, -11.266376408382074`], 
     Hue[0.7992741626509965, 1, -11.089488391122597`], 
     Hue[0.7992741626516179, 1, -10.892133991701057`], 
     Hue[0.7992741626524426, 1, -10.715245974442007`], 
     Hue[0.7992741626538089, 1, -10.517891575021178`], 
     Hue[0.7992741626556222, 1, -10.34100355776307], 
     Hue[0.7992741626586263, 1, -10.143649158343804`], 
     Hue[0.7992741626629329, 1, -9.955066065566767], 
     Hue[0.7992741626694289, 1, -9.764290146131572], 
     Hue[0.7992741626786874, 1, -9.580823648899838], 
     Hue[0.7992741626929705, 1, -9.390047729472077], 
     Hue[0.7992741627133276, 1, -9.206581232250937], 
     Hue[0.7992741627447318, 1, -9.015805312839522], 
     Hue[0.7992741627894917, 1, -8.832338815641679], 
     Hue[0.7992741628585411, 1, -8.641562896266205], 
     Hue[0.7992741629569559, 1, -8.458096399119588], 
     Hue[0.7992741631087767, 1, -8.267320479823134], 
     Hue[0.7992741633251639, 1, -8.083853982789146], 
     Hue[0.7992741636589766, 1, -7.893078063666441], 
     Hue[0.799274164134753, 1, -7.709611566880091], 
     Hue[0.7992741648687162, 1, -7.518835648139411], 
     Hue[0.7992741659148189, 1, -7.33536915189755], 
     Hue[0.7992741675286038, 1, -7.144593233996839], 
     Hue[0.7992741698286985, 1, -6.961126738952166], 
     Hue[0.7992741733769716, 1, -6.770350822898311], 
     Hue[0.799274178434253, 1, -6.586884330485929], 
     Hue[0.7992741862359382, 1, -6.3961084184928145`], 
     Hue[0.7992741977854101, 1, -6.2067943945178845`], 
     Hue[0.7992742147893619, 1, -6.019307731300565], 
     Hue[0.7992742399034366, 1, -5.832552018046092], 
     Hue[0.7992742772904846, 1, -5.645065374288598], 
     Hue[0.7992743325094733, 1, -5.458309689775452], 
     Hue[0.7992744147133651, 1, -5.270823088804934], 
     Hue[0.7992745361247896, 1, -5.084067467486406], 
     Hue[0.799274716868561, 1, -4.896580960593405], 
     Hue[0.7992749838187932, 1, -4.709825478223958], 
     Hue[0.7992754082404862, 1, -4.5119232773417215`], 
     Hue[0.7992759793208415, 1, -4.332660243095784], 
     Hue[0.7992768491798656, 1, -4.146819014135866], 
     Hue[0.7992781569968578, 1, -3.9584199055744733`], 
     Hue[0.7992801993550576, 1, -3.762255237313509], 
     Hue[0.799282972116212, 1, -3.582720202089697], 
     Hue[0.7992874521314007, 1, -3.3874258557606263`], 
     Hue[0.7992935616820688, 1, -3.2077569561461807`], 
     Hue[0.7993033999331485, 1, -3.0129017261969144`], 
     Hue[0.7993168774644395, 1, -2.8328287137627832`], 
     Hue[0.7993384818728357, 1, -2.6384051704733658`], 
     Hue[0.7993728150479558, 1, -2.4352267895140463`], 
     Hue[0.7994155639127662, 1, -2.264227228496197], 
     Hue[0.7994910207375832, 1, -2.0610976095376685`], 
     Hue[0.7995849592956501, 1, -1.8901473258696673`], 
     Hue[0.7997507243610905, 1, -1.6871049948377703`], 
     Hue[0.7999570051306293, 1, -1.516263926637501], 
     Hue[0.8003207782881009, 1, -1.3134157980831331`], 
     Hue[0.8007730460402883, 1, -1.142819029016137], 
     Hue[0.8015139063396558, 1, -0.9520482057340518], 
     Hue[0.8025903481006871, 1, -0.7656513776962617], 
     Hue[0.8042311063566202, 1, -0.5747560587403882], 
     Hue[0.8066127307909933, 1, -0.38847925667080263`], 
     Hue[0.81009630611703, 1, -0.2041629864094634], 
     Hue[0.8154354741241875, 1, -0.014126202570420299`], 
     Hue[0.8232191127509674, 1, 0.17163725881888015`], 
     Hue[0.8349279659777032, 1, 0.35854768454578534`], 
     Hue[0.8657352908450489, 1, 0.7338424034611479], 
     Hue[0.8528173761329134, 1, 0.546683983691362], 
     Hue[0.915783517661688, 1, 0.9215785396069187], 
     Hue[0.8807661466908361, 1, 0.7342456031781284], 
     Hue[0.9290186851501459, 1, 0.9222615996809774], 
     Hue[0.9246689637647219, 1, -17.264488266373966`], 
     Hue[0.9246689637647219, 1, -17.07736705803298], 
     Hue[0.9246689637647219, 1, -16.90742299186392], 
     Hue[0.9246689637647219, 1, -16.70312464135101], 
     Hue[0.9246689637647219, 1, -16.53318057518195], 
     Hue[0.9246689637647219, 1, -16.32888222466904], 
     Hue[0.9246689637647219, 1, -16.15893815849998], 
     Hue[0.9246689637647219, 1, -15.954639807987068`], 
     Hue[0.9246689637647219, 1, -15.784695741818005`], 
     Hue[0.9246689637647219, 1, -15.580397391305098`], 
     Hue[0.924668963764722, 1, -15.407712291810729`], 
     Hue[0.924668963764722, 1, -15.206154974623129`], 
     Hue[0.924668963764722, 1, -15.033469875128759`], 
     Hue[0.9246689637647221, 1, -14.831912557941154`], 
     Hue[0.9246689637647222, 1, -14.657856941784138`], 
     Hue[0.9246689637647224, 1, -14.457670141259188`], 
     Hue[0.9246689637647225, 1, -14.283614525102164`], 
     Hue[0.924668963764723, 1, -14.08342772457722], 
     Hue[0.9246689637647234, 1, -13.90817290634038], 
     Hue[0.9246689637647242, 1, -13.709185307895256`], 
     Hue[0.9246689637647254, 1, -13.511830908473128`], 
     Hue[0.924668963764727, 1, -13.334942891213302`], 
     Hue[0.9246689637647296, 1, -13.137588491791183`], 
     Hue[0.9246689637647331, 1, -12.960700474531366`], 
     Hue[0.924668963764739, 1, -12.763346075109265`], 
     Hue[0.9246689637647466, 1, -12.586458057849471`], 
     Hue[0.9246689637647593, 1, -12.389103658427413`], 
     Hue[0.9246689637647763, 1, -12.212215641167676`], 
     Hue[0.9246689637648041, 1, -12.014861241745704`], 
     Hue[0.9246689637648413, 1, -11.837973224486083`], 
     Hue[0.9246689637649028, 1, -11.640618825064307`], 
     Hue[0.9246689637649844, 1, -11.463730807804946`], 
     Hue[0.9246689637651198, 1, -11.2663764083836], 
     Hue[0.9246689637652993, 1, -11.08948839112481], 
     Hue[0.9246689637655967, 1, -10.892133991704409`], 
     Hue[0.9246689637659913, 1, -10.715245974446873`], 
     Hue[0.9246689637666452, 1, -10.517891575028548`], 
     Hue[0.9246689637675131, 1, -10.34100355777377], 
     Hue[0.9246689637689508, 1, -10.143649158360013`], 
     Hue[0.9246689637710119, 1, -9.955066065590874], 
     Hue[0.9246689637741209, 1, -9.764290146167596], 
     Hue[0.9246689637785521, 1, -9.580823648952844], 
     Hue[0.9246689637853879, 1, -9.39004772955128], 
     Hue[0.9246689637951307, 1, -9.206581232367483], 
     Hue[0.9246689638101607, 1, -9.015805313013672], 
     Hue[0.9246689638315827, 1, -8.832338815897934], 
     Hue[0.9246689638646295, 1, -8.641562896649116], 
     Hue[0.9246689639117306, 1, -8.45809639968302], 
     Hue[0.9246689639843916, 1, -8.267320480665052], 
     Hue[0.924668964087954, 1, -8.08385398402798], 
     Hue[0.9246689642477157, 1, -7.893078065517588], 
     Hue[0.924668964475421, 1, -7.709611569603951], 
     Hue[0.9246689648266937, 1, -7.518835652209579], 
     Hue[0.9246689653273557, 1, -7.335369157886578], 
     Hue[0.9246689660997086, 1, -7.1445932429460255`], 
     Hue[0.9246689672005275, 1, -6.961126752120406], 
     Hue[0.9246689688987212, 1, -6.770350842575132], 
     Hue[0.9246689713191218, 1, -6.586884359439299], 
     Hue[0.9246689750529863, 1, -6.396108461756779], 
     Hue[0.9246689805805305, 1, -6.206794458966989], 
     Hue[0.9246689887185722, 1, -6.01930782693993], 
     Hue[0.9246690007380931, 1, -5.832552159752061], 
     Hue[0.924669018631418, 1, -5.645065584573391], 
     Hue[0.9246690450590449, 1, -5.458310001348031], 
     Hue[0.9246690844015368, 1, -5.270823551163388], 
     Hue[0.9246691425085697, 1, -5.084068152548498], 
     Hue[0.9246692290117307, 1, -4.896581977191216], 
     Hue[0.9246693567726976, 1, -4.709826984483485], 
     Hue[0.924669559898129, 1, -4.511925562106696], 
     Hue[0.9246698332123813, 1, -4.332663575372175], 
     Hue[0.9246702495172736, 1, -4.146823941948756], 
     Hue[0.9246708754187343, 1, -3.9584272322163736`], 
     Hue[0.9246718528478785, 1, -3.76226631002367], 
     Hue[0.9246731798076511, 1, -3.5827363604204345`], 
     Hue[0.9246753237476173, 1, -3.3874502306977936`], 
     Hue[0.9246782473926844, 1, -3.20779253565514], 
     Hue[0.9246829550684008, 1, -3.012955346814529], 
     Hue[0.924690436046171, 1, -2.809500071280482], 
     Hue[0.9246997397259346, 1, -2.63851383036159], 
     Hue[0.9247161605550264, 1, -2.4354076423831277`], 
     Hue[0.9247366011001562, 1, -2.2644863849321766`], 
     Hue[0.9247726646546115, 1, -2.061494885075314], 
     Hue[0.9248175320176144, 1, -1.8907163789847454`], 
     Hue[0.9248966264376406, 1, -1.6879767057162909`], 
     Hue[0.9249949123384189, 1, -1.5175114451146745`], 
     Hue[0.9251678602909914, 1, -1.315323822011296], 
     Hue[0.925396496282546, 1, -1.1361262059744928`], 
     Hue[0.9257447512432928, 1, -0.9503321493714456], 
     Hue[0.9262597139274812, 1, -0.764538873482395], 
     Hue[0.9270183286054358, 1, -0.579327045243236], 
     Hue[0.9281984339667063, 1, -0.3860224155096259], 
     Hue[0.9298514517419443, 1, -0.20360212808871725`], 
     Hue[0.9323612612181548, 1, -0.016109360852583077`], 
     Hue[0.936120837615853, 1, 0.17268422742112488`], 
     Hue[0.941623522429738, 1, 0.35857752814164645`], 
     Hue[0.9499450779321743, 1, 0.5471563249781543], 
     Hue[0.9623197149947542, 1, 0.7340001958781808], 
     Hue[0.9812142743584765, 1, 0.92158103287394], 
     Hue[1.0500637648796531`, 1, -17.264488266373966`], 
     Hue[1.0500637648796531`, 1, -17.07736705803298], 
     Hue[1.0500637648796531`, 1, -16.90742299186392], 
     Hue[1.0500637648796531`, 1, -16.70312464135101], 
     Hue[1.0500637648796531`, 1, -16.53318057518195], 
     Hue[1.0500637648796531`, 1, -16.32888222466904], 
     Hue[1.0500637648796531`, 1, -16.15893815849998], 
     Hue[1.0500637648796531`, 1, -15.954639807987068`], 
     Hue[1.050063764879653, 1, -15.784695741818005`], 
     Hue[1.050063764879653, 1, -15.580397391305098`], 
     Hue[1.050063764879653, 1, -15.407712291810729`], 
     Hue[1.050063764879653, 1, -15.206154974623129`], 
     Hue[1.050063764879653, 1, -15.033469875128759`], 
     Hue[1.050063764879653, 1, -14.831912557941154`], 
     Hue[1.050063764879653, 1, -14.657856941784138`], 
     Hue[1.0500637648796527`, 1, -14.457670141259188`], 
     Hue[1.0500637648796525`, 1, -14.283614525102164`], 
     Hue[1.0500637648796523`, 1, -14.08342772457722], 
     Hue[1.050063764879652, 1, -13.908172906340381`], 
     Hue[1.0500637648796514`, 1, -13.709185307895257`], 
     Hue[1.0500637648796507`, 1, -13.51183090847313], 
     Hue[1.0500637648796496`, 1, -13.334942891213304`], 
     Hue[1.0500637648796478`, 1, -13.137588491791186`], 
     Hue[1.0500637648796454`, 1, -12.96070047453137], 
     Hue[1.0500637648796416`, 1, -12.763346075109272`], 
     Hue[1.0500637648796363`, 1, -12.586458057849482`], 
     Hue[1.0500637648796276`, 1, -12.389103658427427`], 
     Hue[1.050063764879616, 1, -12.212215641167695`], 
     Hue[1.0500637648795972`, 1, -12.014861241745738`], 
     Hue[1.050063764879572, 1, -11.83797322448613], 
     Hue[1.0500637648795301`, 1, -11.64061882506438], 
     Hue[1.0500637648794748`, 1, -11.463730807805051`], 
     Hue[1.050063764879383, 1, -11.266376408383758`], 
     Hue[1.0500637648792612`, 1, -11.08948839112504], 
     Hue[1.0500637648790594`, 1, -10.892133991704757`], 
     Hue[1.0500637648787914`, 1, -10.71524597444738], 
     Hue[1.0500637648783475`, 1, -10.517891575029314`], 
     Hue[1.0500637648777587`, 1, -10.341003557774881`], 
     Hue[1.0500637648767828`, 1, -10.143649158361697`], 
     Hue[1.0500637648753837`, 1, -9.955066065593382], 
     Hue[1.0500637648732736`, 1, -9.764290146171342], 
     Hue[1.050063764870266, 1, -9.580823648958356], 
     Hue[1.0500637648656264`, 1, -9.390047729559518], 
     Hue[1.0500637648590134`, 1, -9.206581232379603], 
     Hue[1.050063764848812, 1, -9.015805313031782], 
     Hue[1.050063764834272, 1, -8.83233881592458], 
     Hue[1.0500637648118418`, 1, -8.641562896688933], 
     Hue[1.0500637647798725`, 1, -8.45809639974161], 
     Hue[1.0500637647305548`, 1, -8.2673204807526], 
     Hue[1.050063764660263, 1, -8.083853984156802], 
     Hue[1.0500637645518265`, 1, -7.893078065710083], 
     Hue[1.0500637643972741`, 1, -7.709611569887197], 
     Hue[1.050063764158852, 1, -7.518835652632821], 
     Hue[1.0500637638190335`, 1, -7.335369158509358], 
     Hue[1.0500637632948078`, 1, -7.144593243876623], 
     Hue[1.0500637625476397`, 1, -6.961126753489732], 
     Hue[1.0500637613950106`, 1, -6.770350844621266], 
     Hue[1.0500637597521916`, 1, -6.586884362450073], 
     Hue[1.0500637572178744`, 1, -6.3961084662556695`], 
     Hue[1.0500637534661177`, 1, -6.206794465668858], 
     Hue[1.0500637479425163`, 1, -6.019307836885179], 
     Hue[1.0500637397844061`, 1, -5.8325521744876365`], 
     Hue[1.05006372763952, 1, -5.645065606440268], 
     Hue[1.0500637097020762`, 1, -5.458310033747508], 
     Hue[1.0500636829988197`, 1, -5.2708235992426085`], 
     Hue[1.0500636435593538`, 1, -5.084068223785942], 
     Hue[1.0500635848463566`, 1, -4.896582082903933], 
     Hue[1.0500634981301273`, 1, -4.70982714111436], 
     Hue[1.0500633602612066`, 1, -4.511925799691311], 
     Hue[1.0500631747525502`, 1, -4.332663921882948], 
     Hue[1.050062892190935, 1, -4.146824454371412], 
     Hue[1.050062467368704, 1, -3.9584279940789795`], 
     Hue[1.0500618039526601`, 1, -3.762267461412053], 
     Hue[1.0500609032994452`, 1, -3.5827380406138216`], 
     Hue[1.050059448137925, 1, -3.3874527652310222`], 
     Hue[1.0500574637737257`, 1, -3.2077962351559375`], 
     Hue[1.0500542685557224`, 1, -3.012960921967367], 
     Hue[1.0500491910797158`, 1, -2.809508626559742], 
     Hue[1.0500428765915113`, 1, -2.638526091044066], 
     Hue[1.0500317318726267`, 1, -2.435426440829551], 
     Hue[1.0500178594249248`, 1, -2.2645133176099606`], 
     Hue[1.0499933852194958`, 1, -2.0615361584514], 
     Hue[1.0499629384506934`, 1, -1.8907754749289925`], 
     Hue[1.0499092709304432`, 1, -1.6880671689431013`], 
     Hue[1.0498425913795473`, 1, -1.5176407954894804`], 
     Hue[1.049725285725975, 1, -1.3155213546843678`], 
     Hue[1.0495702600018375`, 1, -1.1364133952642843`], 
     Hue[1.0493342390800262`, 1, -0.9507548519194462], 
     Hue[1.0489854814302175`, 1, -0.7651596337714752], 
     Hue[1.0484698601299682`, 1, -0.5795261286648041], 
     Hue[1.0476738346659298`, 1, -0.3871243020540551], 
     Hue[1.0465406230488559`, 1, -0.20280297429679472`], 
     Hue[1.0448493332229758`, 1, -0.016612614837757], 
     Hue[1.0423224198019447`, 1, 0.17097909817136858`], 
     Hue[1.0385685081367835`, 1, 0.3585488930163766], 
     Hue[1.032983627428326, 1, 0.5461411632672365], 
     Hue[1.024645935814395, 1, 0.7338613108434204], 
     Hue[1.0121284819931982`, 1, 0.9215806124010145], 
     Hue[1.1754585659945849`, 1, -17.264488266373966`], 
     Hue[1.1754585659945849`, 1, -17.07736705803298], 
     Hue[1.1754585659945849`, 1, -16.90742299186392], 
     Hue[1.1754585659945849`, 1, -16.70312464135101], 
     Hue[1.1754585659945849`, 1, -16.53318057518195], 
     Hue[1.1754585659945849`, 1, -16.32888222466904], 
     Hue[1.1754585659945849`, 1, -16.15893815849998], 
     Hue[1.1754585659945849`, 1, -15.954639807987068`], 
     Hue[1.1754585659945846`, 1, -15.784695741818005`], 
     Hue[1.1754585659945846`, 1, -15.580397391305098`], 
     Hue[1.1754585659945846`, 1, -15.407712291810729`], 
     Hue[1.1754585659945846`, 1, -15.206154974623129`], 
     Hue[1.1754585659945844`, 1, -15.033469875128759`], 
     Hue[1.1754585659945844`, 1, -14.831912557941154`], 
     Hue[1.1754585659945842`, 1, -14.657856941784134`], 
     Hue[1.1754585659945838`, 1, -14.457670141259184`], 
     Hue[1.1754585659945835`, 1, -14.283614525102164`], 
     Hue[1.1754585659945826`, 1, -14.083427724577216`], 
     Hue[1.1754585659945818`, 1, -13.908172906340376`], 
     Hue[1.1754585659945802`, 1, -13.709185307895249`], 
     Hue[1.175458565994578, 1, -13.511830908473117`], 
     Hue[1.1754585659945747`, 1, -13.334942891213286`], 
     Hue[1.1754585659945695`, 1, -13.137588491791162`], 
     Hue[1.1754585659945627`, 1, -12.960700474531334`], 
     Hue[1.1754585659945516`, 1, -12.763346075109217`], 
     Hue[1.1754585659945365`, 1, -12.5864580578494], 
     Hue[1.1754585659945116`, 1, -12.389103658427306`], 
     Hue[1.1754585659944785`, 1, -12.21221564116752], 
     Hue[1.1754585659944237`, 1, -12.014861241745468`], 
     Hue[1.175458565994351, 1, -11.83797322448574], 
     Hue[1.1754585659942305`, 1, -11.640618825063788`], 
     Hue[1.1754585659940708`, 1, -11.463730807804192`], 
     Hue[1.175458565993806, 1, -11.266376408382458`], 
     Hue[1.1754585659934547`, 1, -11.089488391123151`], 
     Hue[1.1754585659928725`, 1, -10.892133991701897`], 
     Hue[1.1754585659920997`, 1, -10.715245974443226`], 
     Hue[1.1754585659908199`, 1, -10.517891575023025`], 
     Hue[1.175458565989121, 1, -10.341003557765752`], 
     Hue[1.1754585659863066`, 1, -10.143649158347868`], 
     Hue[1.1754585659822718`, 1, -9.955066065572812], 
     Hue[1.1754585659761863`, 1, -9.764290146140604], 
     Hue[1.175458565967512, 1, -9.580823648913125], 
     Hue[1.1754585659541312`, 1, -9.390047729491933], 
     Hue[1.1754585659350596`, 1, -9.206581232280152], 
     Hue[1.1754585659056382`, 1, -9.015805312883177], 
     Hue[1.175458565863705, 1, -8.832338815705917], 
     Hue[1.1754585657990158`, 1, -8.641562896362194], 
     Hue[1.1754585657068157`, 1, -8.45809639926083], 
     Hue[1.175458565564582, 1, -8.267320480034188], 
     Hue[1.175458565361859, 1, -8.083853983099697], 
     Hue[1.1754585650491256`, 1, -7.893078064130489], 
     Hue[1.1754585646033933`, 1, -7.709611567562912], 
     Hue[1.175458563915778, 1, -7.518835649159729], 
     Hue[1.175458562935734, 1, -7.335369153398889], 
     Hue[1.175458561423855, 1, -7.144593236240234], 
     Hue[1.1754585592690052`, 1, -6.961126742253202], 
     Hue[1.175458555944796, 1, -6.770350827830928], 
     Hue[1.1754585512068685`, 1, -6.586884337744006], 
     Hue[1.175458543897839, 1, -6.3961084293382955`], 
     Hue[1.1754585330776859`, 1, -6.206794410674091], 
     Hue[1.1754585171474892`, 1, -6.019307755275598], 
     Hue[1.1754584936193035`, 1, -5.832552053569179], 
     Hue[1.1754584585931536`, 1, -5.645065427003144], 
     Hue[1.1754584068611096`, 1, -5.458309767881002], 
     Hue[1.175458329848204, 1, -5.270823204709775], 
     Hue[1.175458216103653, 1, -5.084067639219052], 
     Hue[1.1754580467735167`, 1, -4.896581215436178], 
     Hue[1.1754577966808064`, 1, -4.7098258558164], 
     Hue[1.1754573990609969`, 1, -4.51192385009232], 
     Hue[1.1754568640444156`, 1, -4.332661078440546], 
     Hue[1.175456049118201, 1, -4.1468202494574795`], 
     Hue[1.175454823894257, 1, -3.9584217422500014`], 
     Hue[1.1754529105240623`, 1, -3.7622580130866723`], 
     Hue[1.1754503128926466`, 1, -3.582724252789119], 
     Hue[1.175446115868148, 1, -3.3874319663437857`], 
     Hue[1.1754403923002779`, 1, -3.207765875774963], 
     Hue[1.1754311757421996`, 1, -3.0129151690360665`], 
     Hue[1.17541854919806, 1, -2.832836933049605], 
     Hue[1.1753983115202378`, 1, -2.6384301014594316`], 
     Hue[1.175366152054067, 1, -2.4352721389363152`], 
     Hue[1.1753261119674387`, 1, -2.264292220809997], 
     Hue[1.1752554445373913`, 1, -2.0611972616352245`], 
     Hue[1.1751674828526497`, 1, -1.8902901051212073`], 
     Hue[1.17501230358639, 1, -1.6873238173941603`], 
     Hue[1.1748192652917115`, 1, -1.516577272545088], 
     Hue[1.174479032019876, 1, -1.3138955461617738`], 
     Hue[1.1740281596956934`, 1, -1.1340464215432375`], 
     Hue[1.173364778645786, 1, -0.9530711161828085], 
     Hue[1.1723616744174743`, 1, -0.7671608297216364], 
     Hue[1.17083662962914, 1, -0.5770005667512843], 
     Hue[1.168631288874555, 1, -0.3917761996454925], 
     Hue[1.1652424535965125`, 1, -0.20051265760141912`], 
     Hue[1.1603803560247181`, 1, -0.01598704199793244], 
     Hue[1.1530730002639773`, 1, 0.17086024313839954`], 
     Hue[1.14210127376586, 1, 0.3584032259054051], 
     Hue[1.125474342684825, 1, 0.5461563557624215], 
     Hue[1.0995441396198862`, 1, 0.734342733656978], 
     Hue[1.0562483152132756`, 1, 0.921575367420902], 
     Hue[1.3008533671095166`, 1, -17.264488266373966`], 
     Hue[1.3008533671095166`, 1, -17.07736705803298], 
     Hue[1.3008533671095166`, 1, -16.90742299186392], 
     Hue[1.3008533671095166`, 1, -16.70312464135101], 
     Hue[1.3008533671095166`, 1, -16.53318057518195], 
     Hue[1.3008533671095166`, 1, -16.32888222466904], 
     Hue[1.3008533671095166`, 1, -16.15893815849998], 
     Hue[1.3008533671095166`, 1, -15.954639807987068`], 
     Hue[1.3008533671095166`, 1, -15.784695741818005`], 
     Hue[1.3008533671095164`, 1, -15.580397391305098`], 
     Hue[1.3008533671095164`, 1, -15.407712291810729`], 
     Hue[1.3008533671095164`, 1, -15.206154974623129`], 
     Hue[1.3008533671095162`, 1, -15.033469875128759`], 
     Hue[1.3008533671095162`, 1, -14.831912557941154`], 
     Hue[1.3008533671095157`, 1, -14.657856941784134`], 
     Hue[1.3008533671095155`, 1, -14.457670141259184`], 
     Hue[1.300853367109515, 1, -14.283614525102161`], 
     Hue[1.3008533671095144`, 1, -14.083427724577211`], 
     Hue[1.3008533671095133`, 1, -13.908172906340367`], 
     Hue[1.3008533671095117`, 1, -13.709185307895236`], 
     Hue[1.300853367109509, 1, -13.511830908473101`], 
     Hue[1.300853367109506, 1, -13.334942891213261`], 
     Hue[1.3008533671095004`, 1, -13.137588491791123`], 
     Hue[1.300853367109493, 1, -12.960700474531276`], 
     Hue[1.300853367109481, 1, -12.76334607510913], 
     Hue[1.300853367109465, 1, -12.586458057849278`], 
     Hue[1.3008533671094384`, 1, -12.389103658427116`], 
     Hue[1.3008533671094034`, 1, -12.212215641167248`], 
     Hue[1.3008533671093452`, 1, -12.014861241745056`], 
     Hue[1.300853367109268, 1, -11.837973224485141`], 
     Hue[1.3008533671091396`, 1, -11.640618825062882`], 
     Hue[1.3008533671089695`, 1, -11.463730807802875`], 
     Hue[1.300853367108688, 1, -11.266376408380463`], 
     Hue[1.300853367108314, 1, -11.089488391120257`], 
     Hue[1.3008533671076947`, 1, -10.892133991697513`], 
     Hue[1.3008533671068725`, 1, -10.715245974436863`], 
     Hue[1.3008533671055107`, 1, -10.517891575013383`], 
     Hue[1.3008533671037033`, 1, -10.341003557751762`], 
     Hue[1.3008533671007088`, 1, -10.14364915832667], 
     Hue[1.300853367096416, 1, -9.955066065541283], 
     Hue[1.3008533670899411`, 1, -9.764290146093494], 
     Hue[1.3008533670807123`, 1, -9.580823648843806], 
     Hue[1.3008533670664755`, 1, -9.390047729388352], 
     Hue[1.3008533670461837`, 1, -9.20658123212774], 
     Hue[1.3008533670148807`, 1, -9.015805312655433], 
     Hue[1.300853366970265, 1, -8.832338815370802], 
     Hue[1.3008533669014384`, 1, -8.641562895861444], 
     Hue[1.3008533668033408`, 1, -8.458096398524004], 
     Hue[1.3008533666520092`, 1, -8.267320478933172], 
     Hue[1.3008533664363195`, 1, -8.083853981479617], 
     Hue[1.3008533661035828`, 1, -7.893078061709661], 
     Hue[1.30085336562934, 1, -7.7096115640007925`], 
     Hue[1.3008533648977425`, 1, -7.518835643836984], 
     Hue[1.3008533638550115`, 1, -7.335369145566761], 
     Hue[1.3008533622464282`, 1, -7.14459322453697], 
     Hue[1.300853359953747, 1, -6.961126725032487], 
     Hue[1.3008533564169107`, 1, -6.770350802098643], 
     Hue[1.3008533513759293`, 1, -6.58688429988035], 
     Hue[1.3008533435993894`, 1, -6.396108372760015], 
     Hue[1.3008533320871412`, 1, -6.206794326391019], 
     Hue[1.3008533151379906`, 1, -6.019307630203567], 
     Hue[1.3008532901048508`, 1, -5.83255186825368], 
     Hue[1.30085325283828, 1, -5.645065152003848], 
     Hue[1.3008531977972098`, 1, -5.458309360422756], 
     Hue[1.3008531158581378`, 1, -5.270822600061343], 
     Hue[1.3008529948377392`, 1, -5.084066743329579], 
     Hue[1.3008528146758613`, 1, -4.896579885979422], 
     Hue[1.3008525485845728`, 1, -4.709823886000404], 
     Hue[1.3008521255273124`, 1, -4.5119208621743425`], 
     Hue[1.3008515562805552`, 1, -4.3326567206145485`], 
     Hue[1.3008506892093339`, 1, -4.14681380500963], 
     Hue[1.300849385572163, 1, -3.9584121605971596`], 
     Hue[1.3008473497135582`, 1, -3.7622435321856376`], 
     Hue[1.300844585722102, 1, -3.5827031204998665`], 
     Hue[1.3008401197440973`, 1, -3.3874000871646732`], 
     Hue[1.3008340290731277`, 1, -3.2077193405216153`], 
     Hue[1.300824220585592, 1, -3.0128450325914304`], 
     Hue[1.300810788692193, 1, -2.8328144156484587`], 
     Hue[1.3007892421226315`, 1, -2.6383082832401756`], 
     Hue[1.3007549930735063`, 1, -2.4350354665554397`], 
     Hue[1.3007123402112901`, 1, -2.263952975677981], 
     Hue[1.3006370164823147`, 1, -2.0606769399913123`], 
     Hue[1.3005431786944837`, 1, -1.8895443140556523`], 
     Hue[1.3003774155627312`, 1, -1.6861800485133587`], 
     Hue[1.3001708230442293`, 1, -1.5149380558953764`], 
     Hue[1.2998056487096838`, 1, -1.3113820881670504`], 
     Hue[1.299350117291381, 1, -1.139903850270963], 
     Hue[1.2986002433157626`, 1, -0.9476857132527188], 
     Hue[1.297502514101608, 1, -0.7591787050240539], 
     Hue[1.2958726814363104`, 1, -0.5709536500054659], 
     Hue[1.2935923192173466`, 1, -0.3919865256865578], 
     Hue[1.2900702756912414`, 1, -0.20434400215386228`], 
     Hue[1.284829165938638, 1, -0.01662592689720621], 
     Hue[1.2769842143443215`, 1, 0.17167611262784743`], 
     Hue[1.2653001002204871`, 1, 0.3587623380606073], 
     Hue[1.1342777862525226`, 1, 0.7338651673761678], 
     Hue[1.2474676762684793`, 1, 0.5468710297241182], 
     Hue[1.2197196326296904`, 1, 0.733871671622141], 
     Hue[1.0842911502325823`, 1, 0.9218303186914868], 
     Hue[1.1715913505291875`, 1, 0.9224343216848381], 
     Hue[1.4262481682244483`, 1, -17.264488266373966`], 
     Hue[1.4262481682244483`, 1, -17.07736705803298], 
     Hue[1.4262481682244483`, 1, -16.90742299186392], 
     Hue[1.4262481682244483`, 1, -16.70312464135101], 
     Hue[1.4262481682244483`, 1, -16.53318057518195], 
     Hue[1.4262481682244483`, 1, -16.32888222466904], 
     Hue[1.4262481682244483`, 1, -16.15893815849998], 
     Hue[1.4262481682244483`, 1, -15.954639807987068`], 
     Hue[1.4262481682244483`, 1, -15.784695741818005`], 
     Hue[1.4262481682244483`, 1, -15.580397391305098`], 
     Hue[1.426248168224448, 1, -15.407712291810729`], 
     Hue[1.426248168224448, 1, -15.206154974623129`], 
     Hue[1.426248168224448, 1, -15.033469875128759`], 
     Hue[1.426248168224448, 1, -14.831912557941154`], 
     Hue[1.4262481682244479`, 1, -14.65785694178413], 
     Hue[1.4262481682244479`, 1, -14.45767014125918], 
     Hue[1.4262481682244477`, 1, -14.283614525102157`], 
     Hue[1.4262481682244472`, 1, -14.083427724577206`], 
     Hue[1.4262481682244468`, 1, -13.908172906340361`], 
     Hue[1.4262481682244461`, 1, -13.709185307895227`], 
     Hue[1.4262481682244448`, 1, -13.511830908473087`], 
     Hue[1.4262481682244432`, 1, -13.334942891213242`], 
     Hue[1.4262481682244408`, 1, -13.137588491791092`], 
     Hue[1.4262481682244372`, 1, -12.960700474531235`], 
     Hue[1.4262481682244315`, 1, -12.763346075109066`], 
     Hue[1.4262481682244241`, 1, -12.586458057849184`], 
     Hue[1.4262481682244115`, 1, -12.389103658426976`], 
     Hue[1.426248168224395, 1, -12.21221564116704], 
     Hue[1.4262481682243675`, 1, -12.014861241744741`], 
     Hue[1.426248168224331, 1, -11.837973224484688`], 
     Hue[1.426248168224271, 1, -11.640618825062193`], 
     Hue[1.4262481682241908`, 1, -11.463730807801879`], 
     Hue[1.426248168224058, 1, -11.266376408378951`], 
     Hue[1.4262481682238821`, 1, -11.089488391118064`], 
     Hue[1.4262481682235904`, 1, -10.892133991694188`], 
     Hue[1.4262481682232035`, 1, -10.715245974432039`], 
     Hue[1.4262481682225623`, 1, -10.517891575006075`], 
     Hue[1.4262481682217112`, 1, -10.341003557741155`], 
     Hue[1.4262481682203014`, 1, -10.1436491583106], 
     Hue[1.4262481682182804`, 1, -9.95506606551738], 
     Hue[1.4262481682152317`, 1, -9.764290146057776], 
     Hue[1.4262481682108867`, 1, -9.580823648791249], 
     Hue[1.4262481682041837`, 1, -9.390047729309817], 
     Hue[1.42624816819463, 1, -9.20658123201218], 
     Hue[1.426248168179892, 1, -9.015805312482755], 
     Hue[1.426248168158886, 1, -8.832338815116717], 
     Hue[1.4262481681264811`, 1, -8.641562895481774], 
     Hue[1.426248168080295, 1, -8.45809639796534], 
     Hue[1.426248168009045, 1, -8.267320478098384], 
     Hue[1.4262481679074943`, 1, -8.08385398025127], 
     Hue[1.4262481677508356`, 1, -7.893078059874187], 
     Hue[1.426248167527553, 1, -7.709611561299995], 
     Hue[1.426248167183103, 1, -7.518835639801279], 
     Hue[1.4262481666921656`, 1, -7.335369139628441], 
     Hue[1.426248165934814, 1, -7.144593215663554], 
     Hue[1.4262481648553762`, 1, -6.96112671197574], 
     Hue[1.4262481631901662`, 1, -6.770350782588418], 
     Hue[1.4262481608167765`, 1, -6.586884271172118], 
     Hue[1.4262481571554333`, 1, -6.396108329862343], 
     Hue[1.4262481517352472`, 1, -6.206794262487558], 
     Hue[1.426248143755263, 1, -6.019307535373887], 
     Hue[1.4262481319691798`, 1, -5.832551727747339], 
     Hue[1.4262481144233583`, 1, -5.645064943499121], 
     Hue[1.4262480885089501`, 1, -5.458309051487378], 
     Hue[1.426248049930418, 1, -5.27082214161577], 
     Hue[1.4262479929515817`, 1, -5.084066064063772], 
     Hue[1.42624790812765, 1, -4.896578877980116], 
     Hue[1.4262477828461628`, 1, -4.709822392474679], 
     Hue[1.4262475836612016`, 1, -4.51191859670935], 
     Hue[1.4262473156458855`, 1, -4.332653416456814], 
     Hue[1.426246907405264, 1, -4.146808918711581], 
     Hue[1.426246293612448, 1, -3.9584048955286253`], 
     Hue[1.426245335054772, 1, -3.7622325521753917`], 
     Hue[1.4262440336411695`, 1, -3.5826870967410525`], 
     Hue[1.4262419307960428`, 1, -3.3873759135129875`], 
     Hue[1.4262390628335884`, 1, -3.207684051405873], 
     Hue[1.4262344439512604`, 1, -3.012791841318041], 
     Hue[1.4262281220752744`, 1, -2.83282809632198], 
     Hue[1.4262179718845678`, 1, -2.638228365650794], 
     Hue[1.4262018343481149`, 1, -2.4348558641826736`], 
     Hue[1.4261817340817862`, 1, -2.2636954365841397`], 
     Hue[1.4261462214694416`, 1, -2.060281670824966], 
     Hue[1.4261019512651636`, 1, -1.8889772900512403`], 
     Hue[1.4260236702352647`, 1, -1.6853091564225953`], 
     Hue[1.4259259672140498`, 1, -1.5136876165731705`], 
     Hue[1.4257528836067754`, 1, -1.3094584952632966`], 
     Hue[1.4255362824369777`, 1, -1.1371364825174608`], 
     Hue[1.4252048109911404`, 1, -0.9555546291413333], 
     Hue[1.4246662412354247`, 1, -0.757864003344672], 
     Hue[1.423946013448571, 1, -0.5796518789804181], 
     Hue[1.4228230362226781`, 1, -0.39095710823513263`], 
     Hue[1.3927873755709679`, 1, 0.1712552153812802], 
     Hue[1.421174816217609, 1, -0.20439156557859484`], 
     Hue[1.41862658805487, 1, -0.011176243151418408`], 
     Hue[1.4149995004613471`, 1, 0.17351113257575335`], 
     Hue[1.2857067603993435`, 1, 0.5461269250214251], 
     Hue[1.409619603795451, 1, 0.3587064763509831], 
     Hue[1.401470641145348, 1, 0.5470878625541153], 
     Hue[1.2184525676491422`, 1, 0.9219708932037445], 
     Hue[1.2882391417034404`, 1, 1.1093915491661366`], 
     Hue[1.3893476936746638`, 1, 0.7339313450690189], 
     Hue[1.3708365866681946`, 1, 0.9216772877712172], 
     Hue[1.3417176024832247`, 1, 1.1093708839549592`], 
     Hue[1.1149924506365647`, 1, 1.1093658557759511`], 
     Hue[1.1136251411567386`, 1, 1.2970645112210766`], 
     Hue[1.2905395043522607`, 1, 1.2977578488049077`], 
     Hue[1.0481865361439142`, 1, 1.109341717829257], 
     Hue[1.0616874436468986`, 1, 1.2970541698433549`], 
     Hue[1.012755133297771, 1, 1.10934648189227], 
     Hue[1.010854806145527, 1, 1.1097571708449387`], 
     Hue[0.5516429693393794, 1, -17.264488266373966`], 
     Hue[0.5516429693393794, 1, -17.07736705803298], 
     Hue[0.5516429693393794, 1, -16.90742299186392], 
     Hue[0.5516429693393794, 1, -16.70312464135101], 
     Hue[0.5516429693393794, 1, -16.53318057518195], 
     Hue[0.5516429693393794, 1, -16.32888222466904], 
     Hue[0.5516429693393794, 1, -16.15893815849998], 
     Hue[0.5516429693393794, 1, -15.954639807987068`], 
     Hue[0.5516429693393794, 1, -15.784695741818005`], 
     Hue[0.5516429693393794, 1, -15.580397391305098`], 
     Hue[0.5516429693393794, 1, -15.407712291810729`], 
     Hue[0.5516429693393794, 1, -15.206154974623129`], 
     Hue[0.5516429693393794, 1, -15.033469875128759`], 
     Hue[0.5516429693393795, 1, -14.831912557941154`], 
     Hue[0.5516429693393796, 1, -14.65785694178413], 
     Hue[0.5516429693393796, 1, -14.45767014125918], 
     Hue[0.5516429693393798, 1, -14.283614525102157`], 
     Hue[0.5516429693393801, 1, -14.083427724577206`], 
     Hue[0.5516429693393805, 1, -13.90817290634036], 
     Hue[0.551642969339381, 1, -13.709185307895225`], 
     Hue[0.5516429693393818, 1, -13.511830908473085`], 
     Hue[0.551642969339383, 1, -13.33494289121324], 
     Hue[0.5516429693393847, 1, -13.13758849179109], 
     Hue[0.5516429693393872, 1, -12.960700474531231`], 
     Hue[0.5516429693393913, 1, -12.763346075109059`], 
     Hue[0.5516429693393967, 1, -12.586458057849175`], 
     Hue[0.5516429693394056, 1, -12.389103658426961`], 
     Hue[0.5516429693394174, 1, -12.21221564116702], 
     Hue[0.5516429693394369, 1, -12.014861241744713`], 
     Hue[0.5516429693394629, 1, -11.837973224484646`], 
     Hue[0.551642969339506, 1, -11.64061882506213], 
     Hue[0.551642969339563, 1, -11.463730807801785`], 
     Hue[0.5516429693396576, 1, -11.266376408378813`], 
     Hue[0.5516429693397832, 1, -11.089488391117863`], 
     Hue[0.5516429693399911, 1, -10.892133991693882`], 
     Hue[0.5516429693402672, 1, -10.715245974431596`], 
     Hue[0.5516429693407245, 1, -10.517891575005404`], 
     Hue[0.5516429693413316, 1, -10.341003557740182`], 
     Hue[0.5516429693423371, 1, -10.143649158309126`], 
     Hue[0.5516429693437787, 1, -9.955066065515185], 
     Hue[0.551642969345953, 1, -9.764290146054497], 
     Hue[0.5516429693490522, 1, -9.580823648786424], 
     Hue[0.5516429693538332, 1, -9.390047729302607], 
     Hue[0.5516429693606475, 1, -9.206581232001573], 
     Hue[0.5516429693711595, 1, -9.015805312466906], 
     Hue[0.5516429693861421, 1, -8.832338815093395], 
     Hue[0.5516429694092552, 1, -8.641562895446926], 
     Hue[0.5516429694421978, 1, -8.458096397914064], 
     Hue[0.5516429694930172, 1, -8.26732047802176], 
     Hue[0.5516429695654491, 1, -8.083853980138523], 
     Hue[0.5516429696771872, 1, -7.893078059705712], 
     Hue[0.5516429698364451, 1, -7.709611561052093], 
     Hue[0.5516429700821266, 1, -7.518835639430848], 
     Hue[0.5516429704322915, 1, -7.335369139083373], 
     Hue[0.5516429709724782, 1, -7.14459321484908], 
     Hue[0.5516429717423952, 1, -6.961126710777283], 
     Hue[0.5516429729301187, 1, -6.770350780797609], 
     Hue[0.5516429746229567, 1, -6.586884268537041], 
     Hue[0.5516429772344371, 1, -6.396108325924843], 
     Hue[0.5516429811004255, 1, -6.206794256621975], 
     Hue[0.5516429867922091, 1, -6.01930752666964], 
     Hue[0.5516429951987214, 1, -5.832551714850512], 
     Hue[0.5516430077134107, 1, -5.645064924360839], 
     Hue[0.5516430261970582, 1, -5.458309023130737], 
     Hue[0.5516430537134889, 1, -5.270822099535834], 
     Hue[0.5516430943540789, 1, -5.084066001715092], 
     Hue[0.5516431548554024, 1, -4.896578785457464], 
     Hue[0.5516432442134034, 1, -4.709822255386179], 
     Hue[0.55164338628367, 1, -4.511918388765325], 
     Hue[0.551643577447805, 1, -4.332653113171835], 
     Hue[0.5516438686289427, 1, -4.146808470202065], 
     Hue[0.5516443064222879, 1, -3.958404228669962], 
     Hue[0.5516449901231311, 1, -3.762231544314634], 
     Hue[0.5516459183709617, 1, -3.5826856258949817`], 
     Hue[0.5516474182526288, 1, -3.3873736945338395`], 
     Hue[0.5516494638718086, 1, -3.2076808120188867`], 
     Hue[0.5516527583805129, 1, -3.0127869583900964`], 
     Hue[0.5516572676199127, 1, -2.832820963547552], 
     Hue[0.5516645075918578, 1, -2.638217619806422], 
     Hue[0.5516760184704854, 1, -2.4348393719975867`], 
     Hue[0.5516903563475104, 1, -2.263671783536343], 
     Hue[0.5517156891817789, 1, -2.060245356797674], 
     Hue[0.5517472711148061, 1, -1.888925176045399], 
     Hue[0.5518031211870147, 1, -1.6852290585628629`], 
     Hue[0.5518728372399043, 1, -1.5135725104376563`], 
     Hue[0.5519963664377304, 1, -1.3092811489884546`], 
     Hue[0.5521509997089733, 1, -1.1368808476521528`], 
     Hue[0.5523874484184064, 1, -0.9553636000253445], 
     Hue[0.5527476805827464, 1, -0.7679047894466366], 
     Hue[0.5532878906551657, 1, -0.5788078619781913], 
     Hue[0.5540924386339758, 1, -0.38968321043759113`], 
     Hue[0.5552759808940706, 1, -0.2024652003219689], 
     Hue[0.5570269374592602, 1, -0.01566677230376734], 
     Hue[0.5596854014611266, 1, 0.17484194588316382`], 
     Hue[0.5634952655724494, 1, 0.35880528004853895`], 
     Hue[0.5692859393941705, 1, 0.5472336533194804], 
     Hue[0.5778552885266655, 1, 0.7341062994848937], 
     Hue[0.5907588504985932, 1, 0.9216060435058236], 
     Hue[0.6105091285995394, 1, 1.1096682183576496`], 
     Hue[0.6417375924398797, 1, 1.297059939984658], 
     Hue[0.9615418337512915, 1, 1.297090525578683], 
     Hue[0.9928183043095479, 1, 1.1093486807067694`], 
     Hue[0.6770377704543111, 1, -17.264488266373966`], 
     Hue[0.6770377704543111, 1, -17.07736705803298], 
     Hue[0.6770377704543111, 1, -16.90742299186392], 
     Hue[0.6770377704543111, 1, -16.70312464135101], 
     Hue[0.6770377704543111, 1, -16.53318057518195], 
     Hue[0.6770377704543111, 1, -16.32888222466904], 
     Hue[0.6770377704543111, 1, -16.15893815849998], 
     Hue[0.6770377704543111, 1, -15.954639807987068`], 
     Hue[0.6770377704543111, 1, -15.784695741818005`], 
     Hue[0.6770377704543111, 1, -15.580397391305098`], 
     Hue[0.6770377704543111, 1, -15.407712291810729`], 
     Hue[0.6770377704543113, 1, -15.206154974623129`], 
     Hue[0.6770377704543113, 1, -15.033469875128759`], 
     Hue[0.6770377704543116, 1, -14.831912557941154`], 
     Hue[0.6770377704543117, 1, -14.657856941784134`], 
     Hue[0.677037770454312, 1, -14.457670141259184`], 
     Hue[0.6770377704543125, 1, -14.283614525102157`], 
     Hue[0.6770377704543131, 1, -14.08342772457721], 
     Hue[0.6770377704543141, 1, -13.908172906340365`], 
     Hue[0.6770377704543157, 1, -13.709185307895234`], 
     Hue[0.677037770454318, 1, -13.511830908473097`], 
     Hue[0.6770377704543211, 1, -13.334942891213256`], 
     Hue[0.6770377704543263, 1, -13.137588491791115`], 
     Hue[0.6770377704543331, 1, -12.960700474531269`], 
     Hue[0.6770377704543445, 1, -12.763346075109117`], 
     Hue[0.6770377704543598, 1, -12.586458057849258`], 
     Hue[0.6770377704543847, 1, -12.389103658427086`], 
     Hue[0.6770377704544179, 1, -12.212215641167202`], 
     Hue[0.677037770454473, 1, -12.014861241744986`], 
     Hue[0.677037770454546, 1, -11.83797322448504], 
     Hue[0.6770377704546671, 1, -11.640618825062727`], 
     Hue[0.6770377704548276, 1, -11.463730807802655`], 
     Hue[0.6770377704550938, 1, -11.266376408380129`], 
     Hue[0.6770377704554469, 1, -11.089488391119772`], 
     Hue[0.677037770456032, 1, -10.892133991696776`], 
     Hue[0.6770377704568085, 1, -10.715245974435796`], 
     Hue[0.6770377704580948, 1, -10.517891575011767`], 
     Hue[0.6770377704598021, 1, -10.341003557749415`], 
     Hue[0.6770377704626305, 1, -10.143649158323115`], 
     Hue[0.6770377704666852, 1, -9.955066065535995], 
     Hue[0.6770377704728012, 1, -9.76429014608559], 
     Hue[0.6770377704815183, 1, -9.580823648832178], 
     Hue[0.6770377704949657, 1, -9.390047729370973], 
     Hue[0.6770377705141322, 1, -9.20658123210217], 
     Hue[0.6770377705436996, 1, -9.015805312617223], 
     Hue[0.6770377705858415, 1, -8.83233881531458], 
     Hue[0.6770377706508521, 1, -8.641562895777433], 
     Hue[0.6770377707435106, 1, -8.458096398400386], 
     Hue[0.6770377708864512, 1, -8.267320478748456], 
     Hue[0.6770377710901818, 1, -8.083853981207817], 
     Hue[0.6770377714044695, 1, -7.893078061303519], 
     Hue[0.6770377718524175, 1, -7.709611563403178], 
     Hue[0.6770377725434507, 1, -7.518835642943986], 
     Hue[0.6770377735283659, 1, -7.335369144252765], 
     Hue[0.6770377750477596, 1, -7.1445932225735165`], 
     Hue[0.6770377772133203, 1, -6.96112672214337], 
     Hue[0.6770377805540526, 1, -6.770350797781541], 
     Hue[0.6770377853155305, 1, -6.5868842935279694`], 
     Hue[0.677037792660891, 1, -6.396108363267881], 
     Hue[0.6770378035348292, 1, -6.206794312250852], 
     Hue[0.6770378195442146, 1, -6.019307609220236], 
     Hue[0.6770378431893642, 1, -5.832551837163301], 
     Hue[0.6770378783896502, 1, -5.645065105867209], 
     Hue[0.6770379303789138, 1, -5.458309292063454], 
     Hue[0.6770380077748019, 1, -5.270822498619378], 
     Hue[0.6770381220851378, 1, -5.08406659302595], 
     Hue[0.6770382922578548, 1, -4.89657966293585], 
     Hue[0.6770385435956808, 1, -4.709823555522947], 
     Hue[0.6770389431967159, 1, -4.511920360887923], 
     Hue[0.6770394808822886, 1, -4.33265598949463], 
     Hue[0.6770402998808154, 1, -4.14681272380805], 
     Hue[0.6770415312432061, 1, -3.9584105530462352`], 
     Hue[0.6770434542374957, 1, -3.7622411026396483`], 
     Hue[0.6770460650089214, 1, -3.5826995749533515`], 
     Hue[0.6770502834443275, 1, -3.387394738378391], 
     Hue[0.6770560365699816, 1, -3.2077115324129775`], 
     Hue[0.6770653015958297, 1, -3.0128332637770745`], 
     Hue[0.6770779895151324, 1, -2.8327972226140092`], 
     Hue[0.677098343255147, 1, -2.63828238813442], 
     Hue[0.6771306977937256, 1, -2.4349957369373554`], 
     Hue[0.6771709939179642, 1, -2.2638960130532784`], 
     Hue[0.6772421628581786, 1, -2.060589533899577], 
     Hue[0.6773308374043647, 1, -1.8894189630229852`], 
     Hue[0.6774875143785171, 1, -1.6859876177713289`], 
     Hue[0.6776828447019443, 1, -1.514661932964376], 
     Hue[0.67802828046497, 1, -1.3109577875306793`], 
     Hue[0.6784594918728943, 1, -1.1392942761364304`], 
     Hue[0.6791700658124482, 1, -0.946770120509693], 
     Hue[0.6801460491280005, 1, -0.7677728279805904], 
     Hue[0.681762458554351, 1, -0.5689144841247171], 
     Hue[0.6839119370672071, 1, -0.39088219917274447`], 
     Hue[0.6087869045260172, 1, 0.1708422231103902], 
     Hue[0.6872700540151324, 1, -0.2021175273097262], 
     Hue[0.6922042290059247, 1, -0.015578571964191212`], 
     Hue[0.7140893558074278, 1, 0.546317579776174], 
     Hue[0.6995295197278071, 1, 0.17073799255745714`], 
     Hue[0.7107666296171111, 1, 0.36123173982322887`], 
     Hue[0.7817019470427994, 1, 0.921564537889457], 
     Hue[0.7117352341707297, 1, 1.109457842084938], 
     Hue[0.7273196685620125, 1, 0.5465277412388309], 
     Hue[0.7532961529517832, 1, 0.7339687667026289], 
     Hue[0.8849975360139433, 1, 1.1095152879966206`], 
     Hue[0.8863753995900836, 1, 1.2970710603151816`], 
     Hue[0.7971246782666557, 1, 0.9220187943127015], 
     Hue[0.9518389990369598, 1, 1.1096560406825273`], 
     Hue[0.987317029976648, 1, 1.1094967764155106`], 
     Hue[0.8024325715692429, 1, -17.264488266373966`], 
     Hue[0.8024325715692429, 1, -17.07736705803298], 
     Hue[0.8024325715692429, 1, -16.90742299186392], 
     Hue[0.8024325715692429, 1, -16.70312464135101], 
     Hue[0.8024325715692429, 1, -16.53318057518195], 
     Hue[0.8024325715692429, 1, -16.32888222466904], 
     Hue[0.8024325715692429, 1, -16.15893815849998], 
     Hue[0.8024325715692429, 1, -15.954639807987068`], 
     Hue[0.8024325715692429, 1, -15.784695741818005`], 
     Hue[0.802432571569243, 1, -15.580397391305098`], 
     Hue[0.802432571569243, 1, -15.407712291810729`], 
     Hue[0.8024325715692431, 1, -15.206154974623129`], 
     Hue[0.8024325715692432, 1, -15.033469875128759`], 
     Hue[0.8024325715692433, 1, -14.831912557941154`], 
     Hue[0.8024325715692435, 1, -14.657856941784134`], 
     Hue[0.8024325715692439, 1, -14.457670141259184`], 
     Hue[0.8024325715692443, 1, -14.283614525102161`], 
     Hue[0.8024325715692451, 1, -14.083427724577215`], 
     Hue[0.802432571569246, 1, -13.908172906340374`], 
     Hue[0.8024325715692477, 1, -13.709185307895247`], 
     Hue[0.8024325715692502, 1, -13.511830908473113`], 
     Hue[0.8024325715692534, 1, -13.334942891213283`], 
     Hue[0.8024325715692588, 1, -13.137588491791155`], 
     Hue[0.8024325715692662, 1, -12.960700474531324`], 
     Hue[0.8024325715692782, 1, -12.763346075109201`], 
     Hue[0.8024325715692942, 1, -12.58645805784938], 
     Hue[0.8024325715693206, 1, -12.389103658427274`], 
     Hue[0.8024325715693557, 1, -12.212215641167473`], 
     Hue[0.8024325715694136, 1, -12.014861241745399`], 
     Hue[0.8024325715694908, 1, -11.83797322448564], 
     Hue[0.8024325715696184, 1, -11.640618825063635`], 
     Hue[0.802432571569788, 1, -11.463730807803973`], 
     Hue[0.8024325715700686, 1, -11.266376408382124`], 
     Hue[0.8024325715704413, 1, -11.08948839112267], 
     Hue[0.8024325715710586, 1, -10.892133991701163`], 
     Hue[0.802432571571878, 1, -10.715245974442162`], 
     Hue[0.8024325715732353, 1, -10.517891575021414`], 
     Hue[0.8024325715750368, 1, -10.341003557763413`], 
     Hue[0.8024325715780212, 1, -10.143649158344326`], 
     Hue[0.8024325715822996, 1, -9.955066065567543], 
     Hue[0.802432571588753, 1, -9.764290146132732], 
     Hue[0.8024325715979511, 1, -9.580823648901543], 
     Hue[0.8024325716121405, 1, -9.390047729474626], 
     Hue[0.8024325716323645, 1, -9.206581232254688], 
     Hue[0.8024325716635632, 1, -9.015805312845126], 
     Hue[0.8024325717080302, 1, -8.832338815649926], 
     Hue[0.8024325717766276, 1, -8.64156289627853], 
     Hue[0.8024325718743983, 1, -8.458096399137721], 
     Hue[0.8024325720252257, 1, -8.26732047985023], 
     Hue[0.8024325722401966, 1, -8.083853982829016], 
     Hue[0.8024325725718247, 1, -7.893078063726018], 
     Hue[0.8024325730444873, 1, -7.709611566967754], 
     Hue[0.802432573773647, 1, -7.518835648270406], 
     Hue[0.8024325748129034, 1, -7.335369152090302], 
     Hue[0.8024325764161269, 1, -7.144593234284861], 
     Hue[0.8024325787011684, 1, -6.961126739375975], 
     Hue[0.8024325822262196, 1, -6.770350823531594], 
     Hue[0.8024325872504032, 1, -6.586884331417771], 
     Hue[0.8024325950010297, 1, -6.396108419885233], 
     Hue[0.8024326064749154, 1, -6.206794396592129], 
     Hue[0.8024326233675836, 1, -6.019307734378646], 
     Hue[0.8024326483172972, 1, -5.832552022606791], 
     Hue[0.8024326854596624, 1, -5.6450653810564555`], 
     Hue[0.8024327403172651, 1, -5.4583096998031815`], 
     Hue[0.8024328219831639, 1, -5.270823103685601], 
     Hue[0.8024329425999942, 1, -5.084067489534633], 
     Hue[0.8024331221608558, 1, -4.896580993311892], 
     Hue[0.80243338736397, 1, -4.709825526701912], 
     Hue[0.8024338090078997, 1, -4.511923350875468], 
     Hue[0.8024343763505675, 1, -4.332660350343266], 
     Hue[0.8024352405162603, 1, -4.146819172735328], 
     Hue[0.802436539773082, 1, -3.95842014138033], 
     Hue[0.8024385687624092, 1, -3.762255593688213], 
     Hue[0.8024413233719693, 1, -3.5827207221502713`], 
     Hue[0.8024457740551897, 1, -3.3874266402882016`], 
     Hue[0.8024518435968568, 1, -3.2077581013283405`], 
     Hue[0.8024616174017991, 1, -3.0129034521238243`], 
     Hue[0.802475006608804, 1, -2.832831235218852], 
     Hue[0.8024964693402934, 1, -2.6384089670626425`], 
     Hue[0.8025305771290289, 1, -2.4352326122699433`], 
     Hue[0.8025730449544529, 1, -2.264235573652546], 
     Hue[0.8026480046108295, 1, -2.0611104059004877`], 
     Hue[0.8027413222655886, 1, -1.8901656616573594`], 
     Hue[0.802905986370529, 1, -1.6871331000689007`], 
     Hue[0.8031108876319512, 1, -1.5163041792834513`], 
     Hue[0.8034722025285476, 1, -1.3134774456971854`], 
     Hue[0.8039213686581523, 1, -1.1429072280132473`], 
     Hue[0.8046570398523116, 1, -0.9521797807955472], 
     Hue[0.8057257031725289, 1, -0.7658457091674753], 
     Hue[0.8073540639632488, 1, -0.5750454137719585], 
     Hue[0.8097165404236404, 1, -0.3889051105407171], 
     Hue[0.8132019154053137, 1, -0.20336366375065884`], 
     Hue[0.8184737581463317, 1, -0.01453901864500562], 
     Hue[0.8261872072321446, 1, 0.17099417552927298`], 
     Hue[0.8379446499222487, 1, 0.3598062948992682], 
     Hue[0.8655169578344826, 1, 0.7342227581605933], 
     Hue[0.8555786661776874, 1, 0.5464001821301507], 
     Hue[0.9157696118082346, 1, 0.9216253951316155], 
     Hue[0.8834057553523527, 1, 0.7345989612017355], 
     Hue[0.9308715064880441, 1, 0.921679275147619], 
     Hue[0.927827372684174, 1, -17.264488266373966`], 
     Hue[0.927827372684174, 1, -17.07736705803298], 
     Hue[0.927827372684174, 1, -16.90742299186392], 
     Hue[0.927827372684174, 1, -16.70312464135101], 
     Hue[0.927827372684174, 1, -16.53318057518195], 
     Hue[0.927827372684174, 1, -16.32888222466904], 
     Hue[0.927827372684174, 1, -16.15893815849998], 
     Hue[0.927827372684174, 1, -15.954639807987068`], 
     Hue[0.927827372684174, 1, -15.784695741818005`], 
     Hue[0.927827372684174, 1, -15.580397391305098`], 
     Hue[0.9278273726841741, 1, -15.407712291810729`], 
     Hue[0.9278273726841741, 1, -15.206154974623129`], 
     Hue[0.9278273726841741, 1, -15.033469875128759`], 
     Hue[0.9278273726841743, 1, -14.831912557941154`], 
     Hue[0.9278273726841744, 1, -14.657856941784138`], 
     Hue[0.9278273726841745, 1, -14.457670141259188`], 
     Hue[0.9278273726841747, 1, -14.283614525102164`], 
     Hue[0.927827372684175, 1, -14.08342772457722], 
     Hue[0.9278273726841755, 1, -13.90817290634038], 
     Hue[0.9278273726841763, 1, -13.709185307895256`], 
     Hue[0.9278273726841774, 1, -13.511830908473128`], 
     Hue[0.9278273726841789, 1, -13.334942891213302`], 
     Hue[0.9278273726841815, 1, -13.137588491791183`], 
     Hue[0.9278273726841848, 1, -12.960700474531366`], 
     Hue[0.9278273726841904, 1, -12.763346075109265`], 
     Hue[0.9278273726841978, 1, -12.586458057849473`], 
     Hue[0.92782737268421, 1, -12.389103658427414`], 
     Hue[0.9278273726842262, 1, -12.212215641167678`], 
     Hue[0.9278273726842531, 1, -12.01486124174571], 
     Hue[0.9278273726842888, 1, -11.837973224486088`], 
     Hue[0.9278273726843479, 1, -11.640618825064317`], 
     Hue[0.9278273726844264, 1, -11.46373080780496], 
     Hue[0.9278273726845564, 1, -11.266376408383623`], 
     Hue[0.9278273726847289, 1, -11.089488391124844`], 
     Hue[0.9278273726850147, 1, -10.89213399170446], 
     Hue[0.9278273726853941, 1, -10.715245974446944`], 
     Hue[0.9278273726860224, 1, -10.51789157502866], 
     Hue[0.9278273726868566, 1, -10.34100355777393], 
     Hue[0.9278273726882383, 1, -10.143649158360258`], 
     Hue[0.9278273726902192, 1, -9.95506606559124], 
     Hue[0.927827372693207, 1, -9.764290146168143], 
     Hue[0.9278273726974656, 1, -9.580823648953649], 
     Hue[0.9278273727040353, 1, -9.390047729552482], 
     Hue[0.9278273727133987, 1, -9.206581232369249], 
     Hue[0.9278273727278433, 1, -9.015805313016312], 
     Hue[0.9278273727484311, 1, -8.832338815901817], 
     Hue[0.927827372780191, 1, -8.641562896654918], 
     Hue[0.9278273728254578, 1, -8.458096399691557], 
     Hue[0.9278273728952893, 1, -8.267320480677808], 
     Hue[0.9278273729948185, 1, -8.083853984046753], 
     Hue[0.9278273731483588, 1, -7.893078065545638], 
     Hue[0.9278273733671967, 1, -7.709611569645227], 
     Hue[0.92782737370479, 1, -7.518835652271252], 
     Hue[0.9278273741859546, 1, -7.33536915797733], 
     Hue[0.9278273749282302, 1, -7.144593243081631], 
     Hue[0.9278273759861803, 1, -6.961126752319944], 
     Hue[0.9278273776182417, 1, -6.770350842873294], 
     Hue[0.9278273799443856, 1, -6.586884359878027], 
     Hue[0.9278273835328434, 1, -6.396108462412356], 
     Hue[0.9278273888451304, 1, -6.206794459943583], 
     Hue[0.9278273966662551, 1, -6.019307828389148], 
     Hue[0.9278274082177039, 1, -5.832552161899324], 
     Hue[0.9278274254142151, 1, -5.645065587759825], 
     Hue[0.9278274508126796, 1, -5.4583100060692695`], 
     Hue[0.9278274886230695, 1, -5.270823558169473], 
     Hue[0.9278275444672582, 1, -5.084068162929192], 
     Hue[0.9278276276017521, 1, -4.896581992595636], 
     Hue[0.9278277503873581, 1, -4.709827007307682], 
     Hue[0.9278279456025226, 1, -4.5119255967274485`], 
     Hue[0.9278282082731455, 1, -4.332663625865623], 
     Hue[0.9278286083659152, 1, -4.146824016618856], 
     Hue[0.9278292098928768, 1, -3.95842734323485], 
     Hue[0.927830149257785, 1, -3.7622664778038866`], 
     Hue[0.9278314245411149, 1, -3.5827366052583036`], 
     Hue[0.9278334849877052, 1, -3.387450600030677], 
     Hue[0.9278362947729014, 1, -3.207793074748551], 
     Hue[0.9278408191063594, 1, -3.012956159231787], 
     Hue[0.9278480087238359, 1, -2.8095013179716437`], 
     Hue[0.9278569500365204, 1, -2.638515617022886], 
     Hue[0.9278727312445765, 1, -2.4354103817780706`], 
     Hue[0.9278923755050227, 1, -2.264490309741653], 
     Hue[0.9279270339236915, 1, -2.0615008998621454`], 
     Hue[0.9279701527046513, 1, -1.8907249913381483`], 
     Hue[0.9280461634897716, 1, -1.6879898901275558`], 
     Hue[0.9281406155055012, 1, -1.517530298386642], 
     Hue[0.9283068117311414, 1, -1.315352616623816], 
     Hue[0.9285265113377043, 1, -1.136168076708002], 
     Hue[0.9288611313761138, 1, -0.9503937922694548], 
     Hue[0.9293558814256926, 1, -0.7646294314822335], 
     Hue[0.9300846112058518, 1, -0.5794594977271799], 
     Hue[0.9312179754645484, 1, -0.38621837057265385`], 
     Hue[0.9328050221595663, 1, -0.20388359689123314`], 
     Hue[0.9352136089417259, 1, -0.016512933384755124`], 
     Hue[0.9388193614400306, 1, 0.17211540302815886`], 
     Hue[0.9441150460844768, 1, 0.35845355891737485`], 
     Hue[0.9520603458994352, 1, 0.5461664000707267], 
     Hue[0.963998439385463, 1, 0.7341660392188136], 
     Hue[0.9821094655790804, 1, 0.9218361970029396], 
     Hue[1.0532221737991057`, 1, -17.264488266373966`], 
     Hue[1.0532221737991057`, 1, -17.07736705803298], 
     Hue[1.0532221737991057`, 1, -16.90742299186392], 
     Hue[1.0532221737991057`, 1, -16.70312464135101], 
     Hue[1.0532221737991057`, 1, -16.53318057518195], 
     Hue[1.0532221737991057`, 1, -16.32888222466904], 
     Hue[1.0532221737991057`, 1, -16.15893815849998], 
     Hue[1.0532221737991057`, 1, -15.954639807987068`], 
     Hue[1.0532221737991057`, 1, -15.784695741818005`], 
     Hue[1.0532221737991057`, 1, -15.580397391305098`], 
     Hue[1.0532221737991057`, 1, -15.407712291810729`], 
     Hue[1.0532221737991057`, 1, -15.206154974623129`], 
     Hue[1.0532221737991057`, 1, -15.033469875128759`], 
     Hue[1.0532221737991057`, 1, -14.831912557941154`], 
     Hue[1.0532221737991054`, 1, -14.657856941784138`], 
     Hue[1.0532221737991054`, 1, -14.457670141259188`], 
     Hue[1.0532221737991052`, 1, -14.283614525102164`], 
     Hue[1.053222173799105, 1, -14.08342772457722], 
     Hue[1.0532221737991048`, 1, -13.908172906340381`], 
     Hue[1.053222173799104, 1, -13.709185307895257`], 
     Hue[1.0532221737991032`, 1, -13.51183090847313], 
     Hue[1.053222173799102, 1, -13.334942891213304`], 
     Hue[1.0532221737991, 1, -13.137588491791185`], 
     Hue[1.0532221737990977`, 1, -12.96070047453137], 
     Hue[1.0532221737990934`, 1, -12.76334607510927], 
     Hue[1.053222173799088, 1, -12.586458057849482`], 
     Hue[1.0532221737990788`, 1, -12.389103658427425`], 
     Hue[1.0532221737990666`, 1, -12.212215641167694`], 
     Hue[1.0532221737990466`, 1, -12.014861241745734`], 
     Hue[1.0532221737990197`, 1, -11.837973224486126`], 
     Hue[1.0532221737989755`, 1, -11.640618825064372`], 
     Hue[1.0532221737989167`, 1, -11.463730807805039`], 
     Hue[1.0532221737988192`, 1, -11.266376408383742`], 
     Hue[1.05322217379869, 1, -11.089488391125016`], 
     Hue[1.053222173798476, 1, -10.892133991704721`], 
     Hue[1.0532221737981917`, 1, -10.715245974447324`], 
     Hue[1.053222173797721, 1, -10.517891575029235`], 
     Hue[1.0532221737970962`, 1, -10.341003557774764`], 
     Hue[1.053222173796061, 1, -10.143649158361523`], 
     Hue[1.0532221737945768`, 1, -9.95506606559312], 
     Hue[1.0532221737923384`, 1, -9.764290146170952], 
     Hue[1.053222173789148, 1, -9.580823648957784], 
     Hue[1.0532221737842262`, 1, -9.390047729558663], 
     Hue[1.0532221737772114`, 1, -9.206581232378344], 
     Hue[1.0532221737663898`, 1, -9.0158053130299], 
     Hue[1.053222173750966, 1, -8.83233881592181], 
     Hue[1.0532221737271723`, 1, -8.641562896684796], 
     Hue[1.0532221736932594`, 1, -8.458096399735522], 
     Hue[1.0532221736409435`, 1, -8.2673204807435], 
     Hue[1.0532221735663785`, 1, -8.083853984143413], 
     Hue[1.05322217345135, 1, -7.893078065690076], 
     Hue[1.053222173287402, 1, -7.709611569857759], 
     Hue[1.0532221730344855`, 1, -7.518835652588833], 
     Hue[1.0532221726740087`, 1, -7.335369158444629], 
     Hue[1.0532221721179145`, 1, -7.1445932437799025`], 
     Hue[1.0532221713253243`, 1, -6.96112675334741], 
     Hue[1.0532221701026243`, 1, -6.7703508444086005`], 
     Hue[1.0532221683599348`, 1, -6.586884362137146], 
     Hue[1.053222165671551, 1, -6.396108465788075], 
     Hue[1.053222161691717, 1, -6.206794464972295], 
     Hue[1.0532221558323238`, 1, -6.019307835851514], 
     Hue[1.0532221471782646`, 1, -5.832552172956086], 
     Hue[1.0532221342950643`, 1, -5.645065604167521], 
     Hue[1.0532221152671644`, 1, -5.458310030380049], 
     Hue[1.0532220869405589`, 1, -5.270823594245466], 
     Hue[1.0532220451034815`, 1, -5.084068216381836], 
     Hue[1.053221982821192, 1, -4.896582071916621], 
     Hue[1.0532218908332904`, 1, -4.70982712483484], 
     Hue[1.0532217445830079`, 1, -4.511925774997821], 
     Hue[1.0532215477968543`, 1, -4.332663885868166], 
     Hue[1.0532212480576517`, 1, -4.146824401112505], 
     Hue[1.0532207974094343`, 1, -3.9584279148944432`], 
     Hue[1.0532200936626015`, 1, -3.7622673417420662`], 
     Hue[1.0532191382561407`, 1, -3.5827378659824616`], 
     Hue[1.0532175946307853`, 1, -3.3874525018040416`], 
     Hue[1.0532154896299288`, 1, -3.2077958506487727`], 
     Hue[1.0532121001608434`, 1, -3.0129603425165863`], 
     Hue[1.0532067139974508`, 1, -2.809507737375979], 
     Hue[1.053200015607361, 1, -2.6385248167521054`], 
     Hue[1.053188193296601, 1, -2.4354244870709607`], 
     Hue[1.0531734773655914`, 1, -2.2645105184880556`], 
     Hue[1.0531475149329002`, 1, -2.0615318690121294`], 
     Hue[1.053115216529978, 1, -1.890769333441049], 
     Hue[1.0530582845823144`, 1, -1.6880577681974074`], 
     Hue[1.0529875480357815`, 1, -1.5176273546602623`], 
     Hue[1.0528631022188442`, 1, -1.315500831655539], 
     Hue[1.0526986347081186`, 1, -1.1363835622382845`], 
     Hue[1.0524482266866249`, 1, -0.9507109530916911], 
     Hue[1.0520781828753791`, 1, -0.7650951901780516], 
     Hue[1.0515335536764663`, 1, -0.5801403599011703], 
     Hue[1.050687479209351, 1, -0.38722483784355166`], 
     Hue[1.0494832368964744`, 1, -0.20260257079040778`], 
     Hue[1.0476930877199468`, 1, -0.0168243500021672], 
     Hue[1.045008231533833, 1, 0.17107027899382055`], 
     Hue[1.0410130394295234`, 1, 0.35908211088101794`], 
     Hue[1.0350866641979588`, 1, 0.5464712633091217], 
     Hue[1.026239089629983, 1, 0.7339575908190102], 
     Hue[1.0129054180490058`, 1, 0.9218838721169582], 
     Hue[1.1786169749140374`, 1, -17.264488266373966`], 
     Hue[1.1786169749140374`, 1, -17.07736705803298], 
     Hue[1.1786169749140374`, 1, -16.90742299186392], 
     Hue[1.1786169749140374`, 1, -16.70312464135101], 
     Hue[1.1786169749140374`, 1, -16.53318057518195], 
     Hue[1.1786169749140374`, 1, -16.32888222466904], 
     Hue[1.1786169749140374`, 1, -16.15893815849998], 
     Hue[1.1786169749140374`, 1, -15.954639807987068`], 
     Hue[1.1786169749140374`, 1, -15.784695741818005`], 
     Hue[1.1786169749140374`, 1, -15.580397391305098`], 
     Hue[1.1786169749140374`, 1, -15.407712291810729`], 
     Hue[1.1786169749140374`, 1, -15.206154974623129`], 
     Hue[1.1786169749140372`, 1, -15.033469875128759`], 
     Hue[1.178616974914037, 1, -14.831912557941154`], 
     Hue[1.178616974914037, 1, -14.657856941784134`], 
     Hue[1.1786169749140365`, 1, -14.457670141259184`], 
     Hue[1.178616974914036, 1, -14.283614525102164`], 
     Hue[1.1786169749140354`, 1, -14.083427724577216`], 
     Hue[1.1786169749140345`, 1, -13.908172906340376`], 
     Hue[1.178616974914033, 1, -13.709185307895249`], 
     Hue[1.1786169749140305`, 1, -13.511830908473117`], 
     Hue[1.1786169749140274`, 1, -13.334942891213286`], 
     Hue[1.1786169749140223`, 1, -13.13758849179116], 
     Hue[1.1786169749140152`, 1, -12.960700474531333`], 
     Hue[1.1786169749140039`, 1, -12.763346075109215`], 
     Hue[1.1786169749139885`, 1, -12.586458057849399`], 
     Hue[1.1786169749139634`, 1, -12.3891036584273], 
     Hue[1.1786169749139301`, 1, -12.212215641167512`], 
     Hue[1.1786169749138748`, 1, -12.014861241745457`], 
     Hue[1.1786169749138014`, 1, -11.837973224485726`], 
     Hue[1.17861697491368, 1, -11.640618825063767`], 
     Hue[1.1786169749135185`, 1, -11.463730807804161`], 
     Hue[1.1786169749132511`, 1, -11.26637640838241], 
     Hue[1.178616974912896, 1, -11.089488391123083`], 
     Hue[1.1786169749123083`, 1, -10.892133991701796`], 
     Hue[1.178616974911528, 1, -10.715245974443079`], 
     Hue[1.1786169749102355`, 1, -10.5178915750228], 
     Hue[1.17861697490852, 1, -10.341003557765427`], 
     Hue[1.1786169749056778`, 1, -10.143649158347374`], 
     Hue[1.1786169749016036`, 1, -9.955066065572076], 
     Hue[1.1786169748954578`, 1, -9.764290146139508], 
     Hue[1.1786169748866984`, 1, -9.580823648911515], 
     Hue[1.1786169748731858`, 1, -9.390047729489524], 
     Hue[1.1786169748539264`, 1, -9.20658123227661], 
     Hue[1.1786169748242157`, 1, -9.015805312877884], 
     Hue[1.1786169747818696`, 1, -8.832338815698128], 
     Hue[1.1786169747165438`, 1, -8.641562896350553], 
     Hue[1.1786169746234363`, 1, -8.458096399243702], 
     Hue[1.1786169744798025`, 1, -8.267320480008593], 
     Hue[1.1786169742750845`, 1, -8.083853983062038], 
     Hue[1.1786169739592731`, 1, -7.893078064074214], 
     Hue[1.1786169735091538`, 1, -7.709611567480107], 
     Hue[1.178616972814771, 1, -7.518835649035997], 
     Hue[1.1786169718250814`, 1, -7.335369153216825], 
     Hue[1.1786169702983227`, 1, -7.144593235968181], 
     Hue[1.178616968122265, 1, -6.961126741852891], 
     Hue[1.1786169647653388`, 1, -6.770350827232758], 
     Hue[1.1786169599807808`, 1, -6.586884336863831], 
     Hue[1.1786169525998158`, 1, -6.396108428023083], 
     Hue[1.1786169416731707`, 1, -6.206794408714854], 
     Hue[1.1786169255861891`, 1, -6.019307752368187], 
     Hue[1.1786169018264392`, 1, -5.832552049261354], 
     Hue[1.1786168664555614`, 1, -5.64506542061054], 
     Hue[1.1786168142143696`, 1, -5.458309758409274], 
     Hue[1.1786167364435, 1, -5.270823190654192], 
     Hue[1.1786166215794687`, 1, -5.084067618393328], 
     Hue[1.1786164505827685`, 1, -4.896581184531836], 
     Hue[1.1786161980286083`, 1, -4.70982581002643], 
     Hue[1.1786157964953328`, 1, -4.51192378063589], 
     Hue[1.178615256212931, 1, -4.332660977139843], 
     Hue[1.1786144332657884`, 1, -4.14682009965244], 
     Hue[1.1786131959822368`, 1, -3.9584215195201944`], 
     Hue[1.178611263778403, 1, -3.7622576764750404`], 
     Hue[1.1786086405765621`, 1, -3.5827237615712697`], 
     Hue[1.1786044022340099`, 1, -3.3874312253319827`], 
     Hue[1.1785986223126832`, 1, -3.207764794124375], 
     Hue[1.1785893149922284`, 1, -3.0129135388860284`], 
     Hue[1.1785765640701216`, 1, -2.83283455151384], 
     Hue[1.1785561269566025`, 1, -2.6384265157323874`], 
     Hue[1.1785236503562617`, 1, -2.4352666399492193`], 
     Hue[1.1784832150566869`, 1, -2.2642843402485626`], 
     Hue[1.178411849119441, 1, -2.0611851792199367`], 
     Hue[1.178323016220186, 1, -1.890272795093342], 
     Hue[1.1781662952187972`, 1, -1.6872972918891491`], 
     Hue[1.177971330569519, 1, -1.5165392956317445`], 
     Hue[1.1776276791994802`, 1, -1.3138374195239428`], 
     Hue[1.1771722323972662`, 1, -1.1339616593481348`], 
     Hue[1.1765020280951686`, 1, -0.9529473040306324], 
     Hue[1.1754883976583814`, 1, -0.7669782913346159], 
     Hue[1.1739468715184298`, 1, -0.5767295065244649], 
     Hue[1.171716687990952, 1, -0.3913788149196107], 
     Hue[1.1682873912148974`, 1, -0.19992524992046334`], 
     Hue[1.16336253274802, 1, -0.015136301129348606`], 
     Hue[1.1559508831059486`, 1, 0.1720841062608327], 
     Hue[1.144902462245711, 1, 0.3587357243400877], 
     Hue[1.1281222212018431`, 1, 0.5461698288132797], 
     Hue[1.1019140833641188`, 1, 0.7342166836567744], 
     Hue[1.0579206365348715`, 1, 0.9216491902299325], 
     Hue[1.3040117760289687`, 1, -17.264488266373966`], 
     Hue[1.3040117760289687`, 1, -17.07736705803298], 
     Hue[1.3040117760289687`, 1, -16.90742299186392], 
     Hue[1.3040117760289687`, 1, -16.70312464135101], 
     Hue[1.3040117760289687`, 1, -16.53318057518195], 
     Hue[1.3040117760289687`, 1, -16.32888222466904], 
     Hue[1.3040117760289687`, 1, -16.15893815849998], 
     Hue[1.3040117760289687`, 1, -15.954639807987068`], 
     Hue[1.3040117760289687`, 1, -15.784695741818005`], 
     Hue[1.3040117760289687`, 1, -15.580397391305098`], 
     Hue[1.3040117760289687`, 1, -15.407712291810729`], 
     Hue[1.3040117760289685`, 1, -15.206154974623129`], 
     Hue[1.3040117760289685`, 1, -15.033469875128759`], 
     Hue[1.3040117760289682`, 1, -14.831912557941154`], 
     Hue[1.304011776028968, 1, -14.657856941784134`], 
     Hue[1.3040117760289678`, 1, -14.457670141259184`], 
     Hue[1.3040117760289673`, 1, -14.283614525102161`], 
     Hue[1.3040117760289665`, 1, -14.083427724577211`], 
     Hue[1.3040117760289656`, 1, -13.908172906340367`], 
     Hue[1.3040117760289638`, 1, -13.709185307895236`], 
     Hue[1.3040117760289613`, 1, -13.5118309084731], 
     Hue[1.304011776028958, 1, -13.33494289121326], 
     Hue[1.3040117760289527`, 1, -13.13758849179112], 
     Hue[1.3040117760289454`, 1, -12.960700474531274`], 
     Hue[1.3040117760289336`, 1, -12.763346075109128`], 
     Hue[1.3040117760289176`, 1, -12.586458057849274`], 
     Hue[1.3040117760288912`, 1, -12.389103658427112`], 
     Hue[1.3040117760288563`, 1, -12.21221564116724], 
     Hue[1.3040117760287984`, 1, -12.014861241745045`], 
     Hue[1.3040117760287218`, 1, -11.837973224485127`], 
     Hue[1.3040117760285943`, 1, -11.640618825062857`], 
     Hue[1.3040117760284256`, 1, -11.463730807802843`], 
     Hue[1.3040117760281458`, 1, -11.266376408380413`], 
     Hue[1.3040117760277743`, 1, -11.089488391120186`], 
     Hue[1.304011776027159, 1, -10.892133991697404`], 
     Hue[1.3040117760263426`, 1, -10.715245974436707`], 
     Hue[1.3040117760249899`, 1, -10.517891575013147`], 
     Hue[1.3040117760231946`, 1, -10.341003557751419`], 
     Hue[1.3040117760202206`, 1, -10.14364915832615], 
     Hue[1.3040117760159569`, 1, -9.95506606554051], 
     Hue[1.3040117760095256`, 1, -9.764290146092339], 
     Hue[1.3040117760003591`, 1, -9.580823648842106], 
     Hue[1.3040117759862186`, 1, -9.39004772938581], 
     Hue[1.3040117759660643`, 1, -9.206581232124002], 
     Hue[1.304011775934973, 1, -9.015805312649846], 
     Hue[1.304011775890659, 1, -8.832338815362583], 
     Hue[1.3040117758222975`, 1, -8.64156289584916], 
     Hue[1.3040117757248635`, 1, -8.45809639850593], 
     Hue[1.3040117755745553`, 1, -8.267320478906168], 
     Hue[1.304011775360324, 1, -8.083853981439878], 
     Hue[1.3040117750298374`, 1, -7.893078061650281], 
     Hue[1.3040117745588016`, 1, -7.709611563913421], 
     Hue[1.3040117738321513`, 1, -7.518835643706425], 
     Hue[1.3040117727964717`, 1, -7.335369145374652], 
     Hue[1.304011771198766, 1, -7.144593224249909], 
     Hue[1.3040117689215887`, 1, -6.96112672461009], 
     Hue[1.3040117654086694`, 1, -6.77035080146747], 
     Hue[1.3040117604017767`, 1, -6.586884298951613], 
     Hue[1.304011752677824, 1, -6.396108371372237], 
     Hue[1.3040117412434251`, 1, -6.206794324323685], 
     Hue[1.3040117244088898`, 1, -6.019307627135742], 
     Hue[1.3040116995450313`, 1, -5.832551863708175], 
     Hue[1.3040116625304676`, 1, -5.645065145258535], 
     Hue[1.3040116078616002`, 1, -5.458309350428426], 
     Hue[1.3040115264766208`, 1, -5.27082258523023], 
     Hue[1.30401140627459, 1, -5.084066721354749], 
     Hue[1.3040112273310012`, 1, -4.896579853369805], 
     Hue[1.3040109630390584`, 1, -4.70982383768365], 
     Hue[1.304010542842533, 1, -4.511920788884849], 
     Hue[1.3040099774449823`, 1, -4.332656613722791], 
     Hue[1.3040091162366816`, 1, -4.146813646935064], 
     Hue[1.3040078214140327`, 1, -3.9584119255691315`], 
     Hue[1.3040057993200143`, 1, -3.762243176980368], 
     Hue[1.3040030540144656`, 1, -3.5827026021337662`], 
     Hue[1.3039986182246275`, 1, -3.387399305163793], 
     Hue[1.3039925687161413`, 1, -3.207718198969025], 
     Hue[1.303982826497898, 1, -3.0128433119923077`], 
     Hue[1.3039694853161499`, 1, -2.8328119020535745`], 
     Hue[1.3039480841672715`, 1, -2.6383044974752226`], 
     Hue[1.30391406603362, 1, -2.43502965838238], 
     Hue[1.3038717003423872`, 1, -2.263944648426169], 
     Hue[1.3037968826514799`, 1, -2.0606641629693216`], 
     Hue[1.3037036733210874`, 1, -1.8895259914921165`], 
     Hue[1.303539015030821, 1, -1.6861519242981917`], 
     Hue[1.3033337899726007`, 1, -1.5148977059359565`], 
     Hue[1.3029710069112246`, 1, -1.3113201014484879`], 
     Hue[1.302518412078928, 1, -1.1398148263172747`], 
     Hue[1.3017732597913325`, 1, -0.9475520709850296], 
     Hue[1.300682189595087, 1, -0.7589795049919676], 
     Hue[1.2990616865936992`, 1, -0.5706566084558153], 
     Hue[1.2968027561673767`, 1, -0.3921769661761947], 
     Hue[1.2933038645591273`, 1, -0.20443925474195113`], 
     Hue[1.2880968016214216`, 1, -0.016640868648846174`], 
     Hue[1.2803452484855833`, 1, 0.1708797789018519], 
     Hue[1.2686658438079863`, 1, 0.3592532901058312], 
     Hue[1.1344222904515524`, 1, 0.7341168610794524], 
     Hue[1.2509604481753134`, 1, 0.5472217453387014], 
     Hue[1.2234840644214817`, 1, 0.7338449725222136], 
     Hue[1.0843659904457246`, 1, 0.9220831406745311], 
     Hue[1.1761301276168725`, 1, 0.9217184375221988], 
     Hue[1.4294065771439004`, 1, -17.264488266373966`], 
     Hue[1.4294065771439004`, 1, -17.07736705803298], 
     Hue[1.4294065771439004`, 1, -16.90742299186392], 
     Hue[1.4294065771439004`, 1, -16.70312464135101], 
     Hue[1.4294065771439004`, 1, -16.53318057518195], 
     Hue[1.4294065771439004`, 1, -16.32888222466904], 
     Hue[1.4294065771439004`, 1, -16.15893815849998], 
     Hue[1.4294065771439004`, 1, -15.954639807987068`], 
     Hue[1.4294065771439004`, 1, -15.784695741818005`], 
     Hue[1.4294065771439004`, 1, -15.580397391305098`], 
     Hue[1.4294065771439004`, 1, -15.407712291810729`], 
     Hue[1.4294065771439004`, 1, -15.206154974623129`], 
     Hue[1.4294065771439004`, 1, -15.033469875128759`], 
     Hue[1.4294065771439002`, 1, -14.831912557941154`], 
     Hue[1.4294065771439, 1, -14.65785694178413], 
     Hue[1.4294065771439, 1, -14.45767014125918], 
     Hue[1.4294065771438997`, 1, -14.283614525102157`], 
     Hue[1.4294065771438995`, 1, -14.083427724577206`], 
     Hue[1.429406577143899, 1, -13.908172906340361`], 
     Hue[1.4294065771438982`, 1, -13.709185307895227`], 
     Hue[1.429406577143897, 1, -13.511830908473087`], 
     Hue[1.4294065771438955`, 1, -13.334942891213242`], 
     Hue[1.429406577143893, 1, -13.137588491791092`], 
     Hue[1.4294065771438897`, 1, -12.960700474531235`], 
     Hue[1.4294065771438844`, 1, -12.763346075109064`], 
     Hue[1.4294065771438773`, 1, -12.586458057849182`], 
     Hue[1.429406577143865, 1, -12.389103658426974`], 
     Hue[1.4294065771438493`, 1, -12.212215641167038`], 
     Hue[1.429406577143823, 1, -12.014861241744738`], 
     Hue[1.429406577143788, 1, -11.83797322448468], 
     Hue[1.42940657714373, 1, -11.640618825062182`], 
     Hue[1.4294065771436533`, 1, -11.463730807801863`], 
     Hue[1.4294065771435258`, 1, -11.266376408378928`], 
     Hue[1.4294065771433568`, 1, -11.089488391118032`], 
     Hue[1.4294065771430768`, 1, -10.89213399169414], 
     Hue[1.4294065771427054`, 1, -10.715245974431966`], 
     Hue[1.4294065771420896`, 1, -10.517891575005965`], 
     Hue[1.4294065771412727`, 1, -10.341003557740997`], 
     Hue[1.4294065771399191`, 1, -10.143649158310359`], 
     Hue[1.4294065771379785`, 1, -9.955066065517022], 
     Hue[1.4294065771350517`, 1, -9.764290146057242], 
     Hue[1.4294065771308802`, 1, -9.580823648790462], 
     Hue[1.4294065771244446`, 1, -9.390047729308641], 
     Hue[1.4294065771152722`, 1, -9.206581232010448], 
     Hue[1.4294065771011224`, 1, -9.015805312480168], 
     Hue[1.4294065770809548`, 1, -8.832338815112912], 
     Hue[1.429406577049843, 1, -8.641562895476088], 
     Hue[1.4294065770055, 1, -8.458096397956973], 
     Hue[1.4294065769370938`, 1, -8.267320478085882], 
     Hue[1.4294065768395958`, 1, -8.083853980232872], 
     Hue[1.429406576689189, 1, -7.893078059846695], 
     Hue[1.4294065764748174`, 1, -7.7096115612595435`], 
     Hue[1.4294065761441144`, 1, -7.518835639740831], 
     Hue[1.4294065756727696`, 1, -7.3353691395394955`], 
     Hue[1.429406574945643, 1, -7.144593215530647], 
     Hue[1.4294065739092845`, 1, -6.961126711780174], 
     Hue[1.4294065723105314`, 1, -6.770350782296192], 
     Hue[1.429406570031861, 1, -6.5868842707421225`], 
     Hue[1.4294065665166384`, 1, -6.396108329219816], 
     Hue[1.4294065613127662`, 1, -6.206794261530405], 
     Hue[1.429406553651255, 1, -6.019307533953516], 
     Hue[1.4294065423355422`, 1, -5.832551725642817], 
     Hue[1.4294065254899562`, 1, -5.645064940376109], 
     Hue[1.429406500609765, 1, -5.458309046860102], 
     Hue[1.4294064635708612`, 1, -5.270822134749107], 
     Hue[1.4294064088659897`, 1, -5.084066053889629], 
     Hue[1.4294063274272895`, 1, -4.8965788628821425`], 
     Hue[1.429406207145648, 1, -4.7098223701043915`], 
     Hue[1.4294060159099304`, 1, -4.511918562776767], 
     Hue[1.429405758590784, 1, -4.332653366966374], 
     Hue[1.4294053666425237`, 1, -4.146808845523229], 
     Hue[1.4294047773453207`, 1, -3.958404786709826], 
     Hue[1.4294038570421639`, 1, -3.762232387711558], 
     Hue[1.429402607565573, 1, -3.5826868567269594`], 
     Hue[1.4294005886402688`, 1, -3.3873755514182875`], 
     Hue[1.429397835130077, 1, -3.207683522801199], 
     Hue[1.429393400570208, 1, -3.0127910445218964`], 
     Hue[1.4293873309687228`, 1, -2.8328269324005158`], 
     Hue[1.4293775858018123`, 1, -2.6382266121621027`], 
     Hue[1.4293620921528334`, 1, -2.434853173043078], 
     Hue[1.4293427938012795`, 1, -2.2636915770076103`], 
     Hue[1.4293086977583438`, 1, -2.060275745430384], 
     Hue[1.4292661930412245`, 1, -1.8889687867957303`], 
     Hue[1.4291910327134905`, 1, -1.6852960877862568`], 
     Hue[1.4290972226300025`, 1, -1.5136688372018103`], 
     Hue[1.4289310299217677`, 1, -1.3094295646908038`], 
     Hue[1.4287230421634955`, 1, -1.1370947864453156`], 
     Hue[1.4284047303625926`, 1, -0.9554932642979719], 
     Hue[1.4278874856566528`, 1, -0.7577703377809955], 
     Hue[1.4271956649645539`, 1, -0.5795143557352058], 
     Hue[1.4261167220718947`, 1, -0.39074969778012436`], 
     Hue[1.3908349073528832`, 1, 0.1707422511677238], 
     Hue[1.4245325473712198`, 1, -0.20407828347111767`], 
     Hue[1.4221787758116808`, 1, -0.017010752656506645`], 
     Hue[1.4186633277944454`, 1, 0.17105453825467687`], 
     Hue[1.2860751616984933`, 1, 0.546471377674215], 
     Hue[1.4134046876110384`, 1, 0.3598686410386287], 
     Hue[1.4055865710998658`, 1, 0.5478585832122963], 
     Hue[1.2183269478743874`, 1, 0.9216405173623133], 
     Hue[1.2882283979488662`, 1, 1.1093637523242874`], 
     Hue[1.3940055776539118`, 1, 0.7339116904659975], 
     Hue[1.3762628943159603`, 1, 0.9219482180637514], 
     Hue[1.348530818388575, 1, 1.1096460453217332`], 
     Hue[1.1149886332143484`, 1, 1.1093089601342006`], 
     Hue[1.1136301610073531`, 1, 1.2970036933691578`], 
     Hue[1.3007445997767502`, 1, 1.2978846767308445`], 
     Hue[1.0481886098069073`, 1, 1.10931606393109], 
     Hue[1.0577876088486773`, 1, 1.2970824980431057`], 
     Hue[1.012758426556363, 1, 1.1093395927854621`], 
     Hue[1.0102204941490207`, 1, 1.1093144993386304`], 
     Hue[0.5548013782588318, 1, -17.264488266373966`], 
     Hue[0.5548013782588318, 1, -17.07736705803298], 
     Hue[0.5548013782588318, 1, -16.90742299186392], 
     Hue[0.5548013782588318, 1, -16.70312464135101], 
     Hue[0.5548013782588318, 1, -16.53318057518195], 
     Hue[0.5548013782588318, 1, -16.32888222466904], 
     Hue[0.5548013782588318, 1, -16.15893815849998], 
     Hue[0.5548013782588318, 1, -15.954639807987068`], 
     Hue[0.5548013782588318, 1, -15.784695741818005`], 
     Hue[0.5548013782588318, 1, -15.580397391305098`], 
     Hue[0.5548013782588319, 1, -15.407712291810729`], 
     Hue[0.5548013782588319, 1, -15.206154974623129`], 
     Hue[0.5548013782588319, 1, -15.033469875128759`], 
     Hue[0.554801378258832, 1, -14.831912557941154`], 
     Hue[0.554801378258832, 1, -14.65785694178413], 
     Hue[0.5548013782588321, 1, -14.45767014125918], 
     Hue[0.5548013782588324, 1, -14.283614525102157`], 
     Hue[0.5548013782588326, 1, -14.083427724577206`], 
     Hue[0.5548013782588329, 1, -13.90817290634036], 
     Hue[0.5548013782588336, 1, -13.709185307895227`], 
     Hue[0.5548013782588344, 1, -13.511830908473085`], 
     Hue[0.5548013782588357, 1, -13.33494289121324], 
     Hue[0.5548013782588375, 1, -13.13758849179109], 
     Hue[0.5548013782588401, 1, -12.960700474531231`], 
     Hue[0.5548013782588445, 1, -12.76334607510906], 
     Hue[0.5548013782588501, 1, -12.586458057849176`], 
     Hue[0.5548013782588594, 1, -12.389103658426963`], 
     Hue[0.554801378258872, 1, -12.212215641167024`], 
     Hue[0.5548013782588928, 1, -12.014861241744716`], 
     Hue[0.5548013782589203, 1, -11.837973224484651`], 
     Hue[0.5548013782589658, 1, -11.640618825062138`], 
     Hue[0.5548013782590262, 1, -11.463730807801797`], 
     Hue[0.5548013782591265, 1, -11.266376408378829`], 
     Hue[0.5548013782592593, 1, -11.089488391117886`], 
     Hue[0.5548013782594796, 1, -10.89213399169392], 
     Hue[0.5548013782597718, 1, -10.715245974431651`], 
     Hue[0.5548013782602561, 1, -10.517891575005486`], 
     Hue[0.5548013782608988, 1, -10.341003557740299`], 
     Hue[0.5548013782619634, 1, -10.143649158309305`], 
     Hue[0.5548013782634897, 1, -9.955066065515453], 
     Hue[0.5548013782657921, 1, -9.764290146054897], 
     Hue[0.5548013782690735, 1, -9.580823648787016], 
     Hue[0.5548013782741354, 1, -9.390047729303488], 
     Hue[0.5548013782813503, 1, -9.20658123200287], 
     Hue[0.5548013782924804, 1, -9.015805312468844], 
     Hue[0.554801378308344, 1, -8.832338815096248], 
     Hue[0.5548013783328161, 1, -8.641562895451186], 
     Hue[0.5548013783676955, 1, -8.45809639792033], 
     Hue[0.5548013784215029, 1, -8.267320478031127], 
     Hue[0.5548013784981936, 1, -8.083853980152305], 
     Hue[0.5548013786165014, 1, -7.893078059726309], 
     Hue[0.554801378785123, 1, -7.7096115610824], 
     Hue[0.5548013790452497, 1, -7.518835639476133], 
     Hue[0.5548013794160029, 1, -7.335369139150008], 
     Hue[0.5548013799879504, 1, -7.14459321494865], 
     Hue[0.5548013808031357, 1, -6.961126710923797], 
     Hue[0.5548013820606926, 1, -6.770350781016539], 
     Hue[0.554801383853063, 1, -6.5868842688591815`], 
     Hue[0.5548013866180883, 1, -6.396108326406208], 
     Hue[0.5548013907113818, 1, -6.206794257339051], 
     Hue[0.5548013967378201, 1, -6.019307527733746], 
     Hue[0.5548014056386026, 1, -5.832551716427169], 
     Hue[0.5548014188891068, 1, -5.645064926700522], 
     Hue[0.5548014384595208, 1, -5.458309026597378], 
     Hue[0.5548014675938102, 1, -5.2708221046801675`], 
     Hue[0.5548015106239079, 1, -5.0840660093373105`], 
     Hue[0.5548015746824717, 1, -4.896578796768496], 
     Hue[0.5548016692943704, 1, -4.709822272145453], 
     Hue[0.5548018197178035, 1, -4.511918414186797], 
     Hue[0.5548020221216202, 1, -4.3326531502488885`], 
     Hue[0.5548023304230181, 1, -4.146808525033056], 
     Hue[0.5548027939567782, 1, -3.9584043101945117`], 
     Hue[0.5548035178562629, 1, -3.7622316675273186`], 
     Hue[0.5548045006808331, 1, -3.58268580570856], 
     Hue[0.5548060887482075, 1, -3.3873739658084077`], 
     Hue[0.5548082546388057, 1, -3.207681208041068], 
     Hue[0.5548117428445316, 1, -3.0127875553405863`], 
     Hue[0.5548165171949263, 1, -2.832821835551181], 
     Hue[0.5548241828138233, 1, -2.6382189335277433`], 
     Hue[0.5548363704019579, 1, -2.434841388252849], 
     Hue[0.5548515511335983, 1, -2.2636746752825188`], 
     Hue[0.5548783730261333, 1, -2.060249796538689], 
     Hue[0.5549118110930775, 1, -1.8889315476726167`], 
     Hue[0.5549709429203142, 1, -1.685238852093163], 
     Hue[0.5550447542975094, 1, -1.513586585325055], 
     Hue[0.5551755366868796, 1, -1.3093028369371738`], 
     Hue[0.5553392435453193, 1, -1.1369121141562408`], 
     Hue[0.5555895538019597, 1, -0.9554096173406095], 
     Hue[0.5559710249527003, 1, -0.7679122681209416], 
     Hue[0.5565426394175983, 1, -0.5789112053671994], 
     Hue[0.5573940269695175, 1, -0.38983931341340705`], 
     Hue[0.5586461233866908, 1, -0.2027015413301294], 
     Hue[0.5604977048977196, 1, -0.016027511119745652`], 
     Hue[0.5633070261457194, 1, 0.17427949487983296`], 
     Hue[0.567352170782636, 1, 0.35881357737941055`], 
     Hue[0.573443009726325, 1, 0.5461358194378898], 
     Hue[0.5825572535245221, 1, 0.7338860671335348], 
     Hue[0.5962766749013724, 1, 0.9216917360345032], 
     Hue[0.6172626783270443, 1, 1.109311987156502], 
     Hue[0.6509858503497087, 1, 1.2973612883062595`], 
     Hue[0.9586972572639603, 1, 1.2970138205300212`], 
     Hue[0.9923238476061808, 1, 1.109428996198686], 
     Hue[0.6801961793737635, 1, -17.264488266373966`], 
     Hue[0.6801961793737635, 1, -17.07736705803298], 
     Hue[0.6801961793737635, 1, -16.90742299186392], 
     Hue[0.6801961793737635, 1, -16.70312464135101], 
     Hue[0.6801961793737635, 1, -16.53318057518195], 
     Hue[0.6801961793737635, 1, -16.32888222466904], 
     Hue[0.6801961793737636, 1, -16.15893815849998], 
     Hue[0.6801961793737636, 1, -15.954639807987068`], 
     Hue[0.6801961793737636, 1, -15.784695741818005`], 
     Hue[0.6801961793737636, 1, -15.580397391305098`], 
     Hue[0.6801961793737636, 1, -15.407712291810729`], 
     Hue[0.6801961793737638, 1, -15.206154974623129`], 
     Hue[0.6801961793737639, 1, -15.033469875128759`], 
     Hue[0.680196179373764, 1, -14.831912557941154`], 
     Hue[0.6801961793737641, 1, -14.657856941784134`], 
     Hue[0.6801961793737645, 1, -14.457670141259184`], 
     Hue[0.680196179373765, 1, -14.283614525102157`], 
     Hue[0.6801961793737656, 1, -14.08342772457721], 
     Hue[0.6801961793737665, 1, -13.908172906340367`], 
     Hue[0.6801961793737681, 1, -13.709185307895234`], 
     Hue[0.6801961793737705, 1, -13.511830908473097`], 
     Hue[0.6801961793737736, 1, -13.334942891213258`], 
     Hue[0.680196179373779, 1, -13.137588491791115`], 
     Hue[0.6801961793737858, 1, -12.960700474531269`], 
     Hue[0.6801961793737974, 1, -12.76334607510912], 
     Hue[0.6801961793738126, 1, -12.58645805784926], 
     Hue[0.6801961793738378, 1, -12.38910365842709], 
     Hue[0.6801961793738713, 1, -12.212215641167207`], 
     Hue[0.6801961793739271, 1, -12.014861241744995`], 
     Hue[0.6801961793740008, 1, -11.837973224485054`], 
     Hue[0.6801961793741229, 1, -11.64061882506275], 
     Hue[0.680196179374285, 1, -11.463730807802685`], 
     Hue[0.6801961793745537, 1, -11.266376408380175`], 
     Hue[0.6801961793749103, 1, -11.08948839111984], 
     Hue[0.6801961793755009, 1, -10.892133991696879`], 
     Hue[0.6801961793762848, 1, -10.715245974435943`], 
     Hue[0.6801961793775836, 1, -10.517891575011992`], 
     Hue[0.6801961793793072, 1, -10.341003557749742`], 
     Hue[0.6801961793821627, 1, -10.14364915832361], 
     Hue[0.6801961793862563, 1, -9.95506606553673], 
     Hue[0.680196179392431, 1, -9.76429014608669], 
     Hue[0.6801961794012318, 1, -9.580823648833796], 
     Hue[0.6801961794148084, 1, -9.390047729373393], 
     Hue[0.6801961794341587, 1, -9.20658123210573], 
     Hue[0.6801961794640099, 1, -9.015805312622543], 
     Hue[0.6801961795065561, 1, -8.832338815322409], 
     Hue[0.6801961795721906, 1, -8.64156289578913], 
     Hue[0.6801961796657381, 1, -8.458096398417597], 
     Hue[0.6801961798100504, 1, -8.267320478774174], 
     Hue[0.680196180015736, 1, -8.083853981245657], 
     Hue[0.6801961803330396, 1, -7.8930780613600655`], 
     Hue[0.6801961807852861, 1, -7.709611563486384], 
     Hue[0.6801961814829502, 1, -7.5188356430683205`], 
     Hue[0.6801961824773168, 1, -7.335369144435714], 
     Hue[0.6801961840112905, 1, -7.144593222846889], 
     Hue[0.6801961861976316, 1, -6.961126722545623], 
     Hue[0.6801961895704214, 1, -6.7703507983826094`], 
     Hue[0.68019619437759, 1, -6.58688429441241], 
     Hue[0.680196201793436, 1, -6.396108364589469], 
     Hue[0.6801962127717197, 1, -6.206794314219586], 
     Hue[0.6801962289347296, 1, -6.019307612141744], 
     Hue[0.680196252806776, 1, -5.832551841492012], 
     Hue[0.6801962883448407, 1, -5.645065112290809], 
     Hue[0.6801963408329874, 1, -5.458309301581115], 
     Hue[0.6801964189715568, 1, -5.270822512743135], 
     Hue[0.6801965343787973, 1, -5.084066613952715], 
     Hue[0.68019670618446, 1, -4.896579693990197], 
     Hue[0.6801969599340636, 1, -4.709823601535318], 
     Hue[0.6801973633695416, 1, -4.5119204306820455`], 
     Hue[0.6801979062145083, 1, -4.332656091288518], 
     Hue[0.6801987330716435, 1, -4.146812874343933], 
     Hue[0.6801999762491147, 1, -3.9584107768660424`], 
     Hue[0.6802019176940144, 1, -3.7622414409065836`], 
     Hue[0.6802045535135884, 1, -3.5827000686026116`], 
     Hue[0.6802088124176776, 1, -3.3873954830965918`], 
     Hue[0.6802146207274893, 1, -3.2077126195505485`], 
     Hue[0.6802239746061469, 1, -3.012834902382873], 
     Hue[0.680236784169016, 1, -2.8327996164730695`], 
     Hue[0.6802573329624388, 1, -2.63828599367661], 
     Hue[0.6802899973443568, 1, -2.4350012688863973`], 
     Hue[0.6803306789940378, 1, -2.263903944772566], 
     Hue[0.6804025278251682, 1, -2.0606017053687804`], 
     Hue[0.680492047701706, 1, -1.8894364195997493`], 
     Hue[0.6806502133989705, 1, -1.6860144192289932`], 
     Hue[0.6808473910041427, 1, -1.5147003967747168`], 
     Hue[0.6811960699073514, 1, -1.3110169083083851`], 
     Hue[0.6816312871592664, 1, -1.1393792408921841`], 
     Hue[0.682348358656253, 1, -0.9468978101024246], 
     Hue[0.6833995071957928, 1, -0.758003503525611], 
     Hue[0.68496335707642, 1, -0.5691994482904881], 
     Hue[0.687130258491754, 1, -0.39129914404899235`], 
     Hue[0.6090330873501211, 1, 0.17077717934913628`], 
     Hue[0.6905131692569482, 1, -0.20274327782003088`], 
     Hue[0.6954783334858234, 1, -0.016516190808322895`], 
     Hue[0.7137979638012115, 1, 0.5465899578194733], 
     Hue[0.7029293878809462, 1, 0.17123964909109335`], 
     Hue[0.7141643720906297, 1, 0.3600032225697457], 
     Hue[0.7816900918756704, 1, 0.9215957105715354], 
     Hue[0.7117960201315199, 1, 1.1093005735094867`], 
     Hue[0.730957506415352, 1, 0.5463465629071851], 
     Hue[0.7573173743386497, 1, 0.7343564111819556], 
     Hue[0.8850126557945959, 1, 1.1092897575448437`], 
     Hue[0.8863857117208288, 1, 1.2971958668699108`], 
     Hue[0.8016833711520388, 1, 0.9218890083323259], 
     Hue[0.9518209957953103, 1, 1.1094347344884792`], 
     Hue[0.9872251141215549, 1, 1.1093051221391985`], 
     Hue[0.8055909804886949, 1, -17.264488266373966`], 
     Hue[0.805590980488695, 1, -17.07736705803298], 
     Hue[0.8055909804886949, 1, -16.90742299186392], 
     Hue[0.8055909804886949, 1, -16.70312464135101], 
     Hue[0.8055909804886949, 1, -16.53318057518195], 
     Hue[0.8055909804886949, 1, -16.32888222466904], 
     Hue[0.805590980488695, 1, -16.15893815849998], 
     Hue[0.805590980488695, 1, -15.954639807987068`], 
     Hue[0.805590980488695, 1, -15.784695741818005`], 
     Hue[0.8055909804886952, 1, -15.580397391305098`], 
     Hue[0.8055909804886952, 1, -15.407712291810729`], 
     Hue[0.8055909804886952, 1, -15.206154974623129`], 
     Hue[0.8055909804886953, 1, -15.033469875128759`], 
     Hue[0.8055909804886954, 1, -14.831912557941154`], 
     Hue[0.8055909804886956, 1, -14.657856941784134`], 
     Hue[0.805590980488696, 1, -14.457670141259184`], 
     Hue[0.8055909804886965, 1, -14.283614525102161`], 
     Hue[0.8055909804886972, 1, -14.083427724577215`], 
     Hue[0.8055909804886981, 1, -13.908172906340374`], 
     Hue[0.8055909804886998, 1, -13.709185307895247`], 
     Hue[0.8055909804887023, 1, -13.511830908473115`], 
     Hue[0.8055909804887055, 1, -13.334942891213283`], 
     Hue[0.8055909804887109, 1, -13.137588491791155`], 
     Hue[0.8055909804887181, 1, -12.960700474531325`], 
     Hue[0.80559098048873, 1, -12.763346075109204`], 
     Hue[0.8055909804887459, 1, -12.586458057849384`], 
     Hue[0.8055909804887721, 1, -12.38910365842728], 
     Hue[0.805590980488807, 1, -12.21221564116748], 
     Hue[0.8055909804888646, 1, -12.014861241745407`], 
     Hue[0.8055909804889412, 1, -11.837973224485655`], 
     Hue[0.805590980489068, 1, -11.640618825063658`], 
     Hue[0.8055909804892363, 1, -11.463730807804005`], 
     Hue[0.805590980489515, 1, -11.266376408382172`], 
     Hue[0.8055909804898851, 1, -11.08948839112274], 
     Hue[0.8055909804904982, 1, -10.892133991701272`], 
     Hue[0.8055909804913117, 1, -10.715245974442318`], 
     Hue[0.8055909804926595, 1, -10.51789157502165], 
     Hue[0.8055909804944484, 1, -10.341003557763756`], 
     Hue[0.8055909804974121, 1, -10.143649158344843`], 
     Hue[0.8055909805016606, 1, -9.955066065568314], 
     Hue[0.805590980508069, 1, -9.764290146133884], 
     Hue[0.8055909805172028, 1, -9.580823648903237], 
     Hue[0.8055909805312932, 1, -9.390047729477159], 
     Hue[0.805590980551376, 1, -9.206581232258413], 
     Hue[0.8055909805823569, 1, -9.015805312850693], 
     Hue[0.8055909806265134, 1, -8.832338815658119], 
     Hue[0.805590980694632, 1, -8.64156289629077], 
     Hue[0.8055909807917201, 1, -8.458096399155732], 
     Hue[0.8055909809414943, 1, -8.267320479877144], 
     Hue[0.8055909811549645, 1, -8.083853982868618], 
     Hue[0.8055909814842772, 1, -7.893078063785194], 
     Hue[0.8055909819536401, 1, -7.709611567054828], 
     Hue[0.8055909826777091, 1, -7.518835648400516], 
     Hue[0.8055909837097099, 1, -7.335369152281751], 
     Hue[0.8055909853017404, 1, -7.144593234570936], 
     Hue[0.8055909875708291, 1, -6.96112673979692], 
     Hue[0.8055909910712702, 1, -6.7703508241605945`], 
     Hue[0.8055909960603775, 1, -6.586884332343312], 
     Hue[0.8055910037568932, 1, -6.396108421268234], 
     Hue[0.805591015150674, 1, -6.206794398652348], 
     Hue[0.8055910319254062, 1, -6.019307737435911], 
     Hue[0.8055910567009333, 1, -5.83255202713665], 
     Hue[0.805591093583989, 1, -5.645065387778547], 
     Hue[0.8055911480586022, 1, -5.458309709763101], 
     Hue[0.8055912291543478, 1, -5.270823118465637], 
     Hue[0.8055913489290845, 1, -5.084067511433762], 
     Hue[0.8055915272363245, 1, -4.896581025809122], 
     Hue[0.805591790587883, 1, -4.709825574852033], 
     Hue[0.805592209288006, 1, -4.511923423911934], 
     Hue[0.8055927726695676, 1, -4.33266045686546], 
     Hue[0.8055936308016254, 1, -4.146819330262187], 
     Hue[0.8055949209866438, 1, -3.9584203755913645`], 
     Hue[0.8055969358081214, 1, -3.7622559476524726`], 
     Hue[0.8055996711814088, 1, -3.5827212386929093`], 
     Hue[0.8056040907802039, 1, -3.387427419507997], 
     Hue[0.8056101179231493, 1, -3.2077592387609615`], 
     Hue[0.8056198234341713, 1, -3.012905166367073], 
     Hue[0.8056331190465722, 1, -2.8328337395975645`], 
     Hue[0.8056544316548033, 1, -2.638412737918145], 
     Hue[0.8056883006393454, 1, -2.4352383955092733`], 
     Hue[0.805730470727073, 1, -2.2642438620861443`], 
     Hue[0.8058049037634293, 1, -2.0611231150479377`], 
     Hue[0.8058975638907029, 1, -1.8901838720516941`], 
     Hue[0.8060610625191765, 1, -1.6871610119519918`], 
     Hue[0.8062645041877825, 1, -1.5163441529766597`], 
     Hue[0.8066232201412619, 1, -1.3135386605954384`], 
     Hue[0.8070691107276367, 1, -1.1429947981712643`], 
     Hue[0.8077993103252405, 1, -0.9523103939910726], 
     Hue[0.80885979024012, 1, -0.7660385692378149], 
     Hue[0.8104751493279635, 1, -0.5753324635548218], 
     Hue[0.8128176303446, 1, -0.38932733014560417`], 
     Hue[0.8162710945411891, 1, -0.20398187011846836`], 
     Hue[0.8214893395578612, 1, -0.015445162688782599`], 
     Hue[0.8292825088532647, 1, 0.17306780316192405`], 
     Hue[0.8407764222381044, 1, 0.3588173201831161], 
     Hue[0.8656614775299709, 1, 0.7339709229844384], 
     Hue[0.8583216702076122, 1, 0.546139180673575], 
     Hue[0.9157818229887295, 1, 0.9215842489252335], 
     Hue[0.8858076566706821, 1, 0.7338559473848616], 
     Hue[0.9328458074794204, 1, 0.9215973133024544], 
     Hue[0.9309857816036268, 1, -17.264488266373966`], 
     Hue[0.9309857816036267, 1, -17.07736705803298], 
     Hue[0.9309857816036268, 1, -16.90742299186392], 
     Hue[0.9309857816036268, 1, -16.70312464135101], 
     Hue[0.9309857816036268, 1, -16.53318057518195], 
     Hue[0.9309857816036268, 1, -16.32888222466904], 
     Hue[0.9309857816036268, 1, -16.15893815849998], 
     Hue[0.9309857816036268, 1, -15.954639807987068`], 
     Hue[0.9309857816036268, 1, -15.784695741818005`], 
     Hue[0.9309857816036268, 1, -15.580397391305098`], 
     Hue[0.9309857816036268, 1, -15.407712291810729`], 
     Hue[0.9309857816036268, 1, -15.206154974623129`], 
     Hue[0.9309857816036269, 1, -15.033469875128759`], 
     Hue[0.9309857816036269, 1, -14.831912557941154`], 
     Hue[0.930985781603627, 1, -14.657856941784138`], 
     Hue[0.9309857816036272, 1, -14.457670141259188`], 
     Hue[0.9309857816036273, 1, -14.283614525102164`], 
     Hue[0.9309857816036277, 1, -14.08342772457722], 
     Hue[0.9309857816036281, 1, -13.90817290634038], 
     Hue[0.9309857816036289, 1, -13.709185307895256`], 
     Hue[0.93098578160363, 1, -13.511830908473128`], 
     Hue[0.9309857816036314, 1, -13.334942891213302`], 
     Hue[0.9309857816036339, 1, -13.137588491791183`], 
     Hue[0.9309857816036371, 1, -12.960700474531368`], 
     Hue[0.9309857816036424, 1, -12.763346075109267`], 
     Hue[0.9309857816036495, 1, -12.586458057849475`], 
     Hue[0.9309857816036612, 1, -12.389103658427416`], 
     Hue[0.9309857816036768, 1, -12.212215641167681`], 
     Hue[0.9309857816037026, 1, -12.014861241745713`], 
     Hue[0.9309857816037368, 1, -11.837973224486095`], 
     Hue[0.9309857816037935, 1, -11.640618825064328`], 
     Hue[0.9309857816038688, 1, -11.463730807804975`], 
     Hue[0.9309857816039935, 1, -11.266376408383646`], 
     Hue[0.9309857816041589, 1, -11.089488391124876`], 
     Hue[0.930985781604433, 1, -10.892133991704508`], 
     Hue[0.9309857816047968, 1, -10.715245974447015`], 
     Hue[0.9309857816053996, 1, -10.517891575028768`], 
     Hue[0.9309857816061995, 1, -10.341003557774085`], 
     Hue[0.9309857816075248, 1, -10.143649158360494`], 
     Hue[0.9309857816094245, 1, -9.95506606559159], 
     Hue[0.9309857816122902, 1, -9.764290146168666], 
     Hue[0.9309857816163746, 1, -9.58082364895442], 
     Hue[0.9309857816226753, 1, -9.390047729553634], 
     Hue[0.9309857816316557, 1, -9.206581232370946], 
     Hue[0.9309857816455094, 1, -9.015805313018845], 
     Hue[0.9309857816652547, 1, -8.832338815905544], 
     Hue[0.9309857816957152, 1, -8.641562896660488], 
     Hue[0.9309857817391299, 1, -8.458096399699755], 
     Hue[0.9309857818061043, 1, -8.267320480690056], 
     Hue[0.9309857819015614, 1, -8.083853984064776], 
     Hue[0.9309857820488197, 1, -7.89307806557257], 
     Hue[0.9309857822587039, 1, -7.709611569684854], 
     Hue[0.9309857825824847, 1, -7.518835652330467], 
     Hue[0.9309857830439628, 1, -7.335369158064458], 
     Hue[0.9309857837558686, 1, -7.144593243211825], 
     Hue[0.9309857847705333, 1, -6.961126752511519], 
     Hue[0.9309857863358199, 1, -6.770350843159557], 
     Hue[0.9309857885667908, 1, -6.586884360299247], 
     Hue[0.9309857920084289, 1, -6.396108463041768], 
     Hue[0.9309857971033666, 1, -6.206794460881201], 
     Hue[0.9309858046044943, 1, -6.019307829780529], 
     Hue[0.930985815683322, 1, -5.832552163960891], 
     Hue[0.9309858321762473, 1, -5.645065590819089], 
     Hue[0.9309858565355474, 1, -5.45831001060209], 
     Hue[0.9309858927989456, 1, -5.270823564895954], 
     Hue[0.9309859463582987, 1, -5.084068172895602], 
     Hue[0.930986026091387, 1, -4.8965820073852795`], 
     Hue[0.9309861438532796, 1, -4.709827029220986], 
     Hue[0.930986331081303, 1, -4.511925629966519], 
     Hue[0.930986583004861, 1, -4.332663674343919], 
     Hue[0.9309869667279618, 1, -4.146824088308926], 
     Hue[0.9309875436435677, 1, -3.9584274498226435`], 
     Hue[0.9309884445743783, 1, -3.7622666388880557`], 
     Hue[0.9309896676791841, 1, -3.582736840324708], 
     Hue[0.9309916438213016, 1, -3.3874509546233256`], 
     Hue[0.93099433864076, 1, -3.207793592326146], 
     Hue[0.9309986778517918, 1, -3.0129569392236935`], 
     Hue[0.9310055732813921, 1, -2.809502514902488], 
     Hue[0.9310141487126923, 1, -2.6385173323677256`], 
     Hue[0.9310292841029844, 1, -2.4354130118168547`], 
     Hue[0.9310481243757225, 1, -2.2644940778550016`], 
     Hue[0.9310813640967669, 1, -2.0615066744617074`], 
     Hue[0.9311227174742887, 1, -1.8907332596875552`], 
     Hue[0.9311956151088902, 1, -1.6880025476739144`], 
     Hue[0.9312861968073052, 1, -1.5175483978358526`], 
     Hue[0.9314455778561734, 1, -1.3153802587885515`], 
     Hue[0.9316562584813131, 1, -1.1362082694791817`], 
     Hue[0.9319771205840177, 1, -0.9504529600124221], 
     Hue[0.9324514822450624, 1, -0.7647163429277664], 
     Hue[0.9331500814355006, 1, -0.5795865947018419], 
     Hue[0.9342363531909985, 1, -0.38640635326555306`], 
     Hue[0.935756998067528, 1, -0.204153519051413], 
     Hue[0.938063839885671, 1, -0.01689975555331702], 
     Hue[0.9415152639774589, 1, 0.17157055874152827`], 
     Hue[0.9466811932456883, 1, 0.3607618401574967], 
     Hue[0.9542215192169667, 1, 0.5461968924419008], 
     Hue[0.9656547348997865, 1, 0.7341957241582873], 
     Hue[0.9829929767613931, 1, 0.9221048559130482], 
     Hue[1.0563805827185582`, 1, -17.264488266373966`], 
     Hue[1.0563805827185582`, 1, -17.07736705803298], 
     Hue[1.0563805827185582`, 1, -16.90742299186392], 
     Hue[1.0563805827185582`, 1, -16.70312464135101], 
     Hue[1.0563805827185582`, 1, -16.53318057518195], 
     Hue[1.0563805827185582`, 1, -16.32888222466904], 
     Hue[1.0563805827185582`, 1, -16.15893815849998], 
     Hue[1.0563805827185582`, 1, -15.954639807987068`], 
     Hue[1.0563805827185582`, 1, -15.784695741818005`], 
     Hue[1.0563805827185582`, 1, -15.580397391305098`], 
     Hue[1.0563805827185582`, 1, -15.407712291810729`], 
     Hue[1.0563805827185582`, 1, -15.206154974623129`], 
     Hue[1.0563805827185582`, 1, -15.033469875128759`], 
     Hue[1.056380582718558, 1, -14.831912557941154`], 
     Hue[1.056380582718558, 1, -14.657856941784138`], 
     Hue[1.0563805827185577`, 1, -14.457670141259188`], 
     Hue[1.0563805827185577`, 1, -14.283614525102164`], 
     Hue[1.0563805827185573`, 1, -14.08342772457722], 
     Hue[1.056380582718557, 1, -13.908172906340381`], 
     Hue[1.0563805827185564`, 1, -13.709185307895256`], 
     Hue[1.0563805827185555`, 1, -13.51183090847313], 
     Hue[1.0563805827185542`, 1, -13.334942891213304`], 
     Hue[1.0563805827185524`, 1, -13.137588491791185`], 
     Hue[1.0563805827185497`, 1, -12.96070047453137], 
     Hue[1.0563805827185453`, 1, -12.76334607510927], 
     Hue[1.0563805827185393`, 1, -12.58645805784948], 
     Hue[1.0563805827185297`, 1, -12.389103658427423`], 
     Hue[1.0563805827185169`, 1, -12.212215641167692`], 
     Hue[1.0563805827184956`, 1, -12.014861241745729`], 
     Hue[1.0563805827184674`, 1, -11.83797322448612], 
     Hue[1.0563805827184205`, 1, -11.640618825064363`], 
     Hue[1.0563805827183583`, 1, -11.463730807805026`], 
     Hue[1.0563805827182555`, 1, -11.266376408383724`], 
     Hue[1.0563805827181187`, 1, -11.089488391124991`], 
     Hue[1.0563805827178925`, 1, -10.892133991704682`], 
     Hue[1.056380582717592, 1, -10.715245974447269`], 
     Hue[1.0563805827170945`, 1, -10.51789157502915], 
     Hue[1.056380582716434, 1, -10.341003557774643`], 
     Hue[1.05638058271534, 1, -10.143649158361338`], 
     Hue[1.0563805827137716`, 1, -9.955066065592845], 
     Hue[1.0563805827114057`, 1, -9.764290146170541], 
     Hue[1.0563805827080337`, 1, -9.580823648957177], 
     Hue[1.0563805827028319`, 1, -9.390047729557756], 
     Hue[1.0563805826954176`, 1, -9.20658123237701], 
     Hue[1.0563805826839803`, 1, -9.015805313027906], 
     Hue[1.0563805826676784`, 1, -8.83233881591888], 
     Hue[1.0563805826425305`, 1, -8.641562896680414], 
     Hue[1.0563805826066877`, 1, -8.458096399729074], 
     Hue[1.056380582551394, 1, -8.267320480733867], 
     Hue[1.0563805824725854`, 1, -8.083853984129238], 
     Hue[1.0563805823510102`, 1, -7.893078065668893], 
     Hue[1.0563805821777312`, 1, -7.7096115698265875`], 
     Hue[1.0563805819104202`, 1, -7.518835652542255], 
     Hue[1.056380581529427, 1, -7.335369158376095], 
     Hue[1.0563805809416826`, 1, -7.144593243677492], 
     Hue[1.0563805801039827`, 1, -6.96112675319672], 
     Hue[1.0563805788116933`, 1, -6.77035084418343], 
     Hue[1.0563805769698198`, 1, -6.586884361805821], 
     Hue[1.056380574128428, 1, -6.396108465292987], 
     Hue[1.0563805699220838`, 1, -6.206794464234777], 
     Hue[1.0563805637292065`, 1, -6.019307834757073], 
     Hue[1.056380554582606, 1, -5.832552171334485], 
     Hue[1.0563805409661653`, 1, -5.645065601761146], 
     Hue[1.0563805208553025`, 1, -5.458310026814596], 
     Hue[1.0563804909165029`, 1, -5.270823588954511], 
     Hue[1.0563804466982898`, 1, -5.084068208542397], 
     Hue[1.0563803808712344`, 1, -4.896582060283296], 
     Hue[1.0563802836478853`, 1, -4.709827107598146], 
     Hue[1.0563801290738326`, 1, -4.511925748852448], 
     Hue[1.056379921087673, 1, -4.332663847735847], 
     Hue[1.0563796042889124`, 1, -4.1468243447221695`], 
     Hue[1.0563791279921542`, 1, -3.958427831054135], 
     Hue[1.0563783841916203`, 1, -3.762267215035883], 
     Hue[1.0563773744080538`, 1, -3.582737681083315], 
     Hue[1.0563757429265006`, 1, -3.387452222888257], 
     Hue[1.0563735181174427`, 1, -3.207795443533402], 
     Hue[1.056369935730855, 1, -3.012959728994809], 
     Hue[1.0563642429982418`, 1, -2.809506795908036], 
     Hue[1.056357163338751, 1, -2.638523467529275], 
     Hue[1.0563446680776398`, 1, -2.435422418421437], 
     Hue[1.0563291144325695`, 1, -2.2645075547527], 
     Hue[1.0563016739284274`, 1, -2.061527327286054], 
     Hue[1.0562675364855576`, 1, -1.8907628306843745`], 
     Hue[1.0562073622019148`, 1, -1.6880478143188078`], 
     Hue[1.0561325959158867`, 1, -1.5176131227333947`], 
     Hue[1.05600105737206, 1, -1.3154791000192427`], 
     Hue[1.0558272097632553`, 1, -1.136351971061331], 
     Hue[1.05556250638341, 1, -0.9506644643379187], 
     Hue[1.0551713072005917`, 1, -0.7650269384876784], 
     Hue[1.0545954769833024`, 1, -0.5800406257630351], 
     Hue[1.0537007828805527`, 1, -0.38707749457890595`], 
     Hue[1.0524270360891919`, 1, -0.2023901998672153], 
     Hue[1.0505329425575196`, 1, -0.016521286722926964`], 
     Hue[1.0477022738307848`, 1, 0.17087471906987695`], 
     Hue[1.04345995174535, 1, 0.35963761088526824`], 
     Hue[1.0371978225396101`, 1, 0.5467225078606449], 
     Hue[1.0278505528812831`, 1, 0.7338754570052515], 
     Hue[1.0136911007271423`, 1, 0.9221355400629268], 
     Hue[1.1817753838334897`, 1, -17.264488266373966`], 
     Hue[1.1817753838334897`, 1, -17.07736705803298], 
     Hue[1.1817753838334897`, 1, -16.90742299186392], 
     Hue[1.1817753838334897`, 1, -16.70312464135101], 
     Hue[1.1817753838334897`, 1, -16.53318057518195], 
     Hue[1.1817753838334897`, 1, -16.32888222466904], 
     Hue[1.1817753838334897`, 1, -16.15893815849998], 
     Hue[1.1817753838334897`, 1, -15.954639807987068`], 
     Hue[1.1817753838334895`, 1, -15.784695741818005`], 
     Hue[1.1817753838334895`, 1, -15.580397391305098`], 
     Hue[1.1817753838334895`, 1, -15.407712291810729`], 
     Hue[1.1817753838334895`, 1, -15.206154974623129`], 
     Hue[1.1817753838334895`, 1, -15.033469875128759`], 
     Hue[1.1817753838334892`, 1, -14.831912557941154`], 
     Hue[1.181775383833489, 1, -14.657856941784134`], 
     Hue[1.1817753838334886`, 1, -14.457670141259184`], 
     Hue[1.1817753838334883`, 1, -14.283614525102164`], 
     Hue[1.1817753838334875`, 1, -14.083427724577216`], 
     Hue[1.1817753838334866`, 1, -13.908172906340374`], 
     Hue[1.181775383833485, 1, -13.709185307895249`], 
     Hue[1.1817753838334826`, 1, -13.511830908473117`], 
     Hue[1.1817753838334795`, 1, -13.334942891213284`], 
     Hue[1.1817753838334741`, 1, -13.137588491791158`], 
     Hue[1.1817753838334673`, 1, -12.96070047453133], 
     Hue[1.1817753838334557`, 1, -12.763346075109212`], 
     Hue[1.1817753838334404`, 1, -12.586458057849397`], 
     Hue[1.1817753838334148`, 1, -12.389103658427295`], 
     Hue[1.1817753838333813`, 1, -12.212215641167507`], 
     Hue[1.1817753838333254`, 1, -12.014861241745448`], 
     Hue[1.1817753838332514`, 1, -11.837973224485713`], 
     Hue[1.1817753838331286`, 1, -11.640618825063745`], 
     Hue[1.1817753838329657`, 1, -11.46373080780413], 
     Hue[1.1817753838326959`, 1, -11.266376408382364`], 
     Hue[1.1817753838323377`, 1, -11.089488391123016`], 
     Hue[1.1817753838317442`, 1, -10.892133991701693`], 
     Hue[1.1817753838309568`, 1, -10.715245974442928`], 
     Hue[1.181775383829652, 1, -10.517891575022574`], 
     Hue[1.1817753838279206`, 1, -10.341003557765099`], 
     Hue[1.1817753838250518`, 1, -10.143649158346877`], 
     Hue[1.1817753838209393`, 1, -9.955066065571337], 
     Hue[1.1817753838147362`, 1, -9.764290146138402], 
     Hue[1.1817753838058949`, 1, -9.580823648909886], 
     Hue[1.1817753837922558`, 1, -9.390047729487092], 
     Hue[1.1817753837728164`, 1, -9.206581232273033], 
     Hue[1.1817753837428278`, 1, -9.015805312872539], 
     Hue[1.1817753837000855`, 1, -8.832338815690264], 
     Hue[1.181775383634149, 1, -8.641562896338801], 
     Hue[1.1817753835401705`, 1, -8.45809639922641], 
     Hue[1.1817753833951936`, 1, -8.267320479982754], 
     Hue[1.181775383188561, 1, -8.083853983024017], 
     Hue[1.181775382869796, 1, -7.893078064017401], 
     Hue[1.1817753824154673`, 1, -7.709611567396508], 
     Hue[1.1817753817145904`, 1, -7.518835648911076], 
     Hue[1.1817753807156448`, 1, -7.335369153033013], 
     Hue[1.1817753791746075`, 1, -7.144593235693518], 
     Hue[1.1817753769781985`, 1, -6.961126741448738], 
     Hue[1.1817753735898777`, 1, -6.770350826628847], 
     Hue[1.1817753687605732`, 1, -6.58688433597521], 
     Hue[1.1817753613105795`, 1, -6.396108426695249], 
     Hue[1.1817753502817454`, 1, -6.206794406736818], 
     Hue[1.181775334044314, 1, -6.019307749432875], 
     Hue[1.1817753100623565`, 1, -5.832552044912191], 
     Hue[1.1817752743606802`, 1, -5.645065414156592], 
     Hue[1.1817752216309134`, 1, -5.458309748846656], 
     Hue[1.1817751431327066`, 1, -5.2708231764637326`], 
     Hue[1.181775027194428, 1, -5.084067597367761], 
     Hue[1.1817748545985036`, 1, -4.896581153330935], 
     Hue[1.1817745996823497`, 1, -4.709825763797053], 
     Hue[1.1817741943937312`, 1, -4.511923710512939], 
     Hue[1.18177364905827, 1, -4.332660874867022], 
     Hue[1.1817728184142684`, 1, -4.146819948409786], 
     Hue[1.1817715695583304`, 1, -3.9584212946528776`], 
     Hue[1.1817696192817053`, 1, -3.7622573366328256`], 
     Hue[1.18176697154234, 1, -3.582723265638699], 
     Hue[1.181762693550502, 1, -3.3874304772071397`], 
     Hue[1.181756859551247, 1, -3.2077637020893537`], 
     Hue[1.181747465132163, 1, -3.012911893081844], 
     Hue[1.1817345948503757`, 1, -2.832832147100812], 
     Hue[1.1817139663420184`, 1, -2.6384228955420586`], 
     Hue[1.1816811853790805`, 1, -2.435261088065098], 
     Hue[1.181640370757368, 1, -2.2642763838005866`], 
     Hue[1.1815683343306558`, 1, -2.061172980239128], 
     Hue[1.181478665040882, 1, -1.8902553176798202`], 
     Hue[1.1813204636029428`, 1, -1.6872705088417488`], 
     Hue[1.1811236486078127`, 1, -1.516500948133525], 
     Hue[1.1807767124409994`, 1, -1.3137787206721907`], 
     Hue[1.180345633673168, 1, -1.1433381192079926`], 
     Hue[1.1796400941276672`, 1, -0.9528222382749811], 
     Hue[1.1786163169658208`, 1, -0.7667938588911851], 
     Hue[1.17705887124945, 1, -0.5764555310334383], 
     Hue[1.1748046237139433`, 1, -0.39097694127731386`], 
     Hue[1.171335980622145, 1, -0.19933072802993124`], 
     Hue[1.16642146916016, 1, -0.016480135565524856`], 
     Hue[1.158835525551331, 1, 0.1733261446149238], 
     Hue[1.147757487204413, 1, 0.3585048530209993], 
     Hue[1.130791217617105, 1, 0.5461735608472409], 
     Hue[1.104347701753427, 1, 0.7339076345862691], 
     Hue[1.0596748413378243`, 1, 0.9216125338922733], 
     Hue[1.3071701849484214`, 1, -17.264488266373966`], 
     Hue[1.3071701849484214`, 1, -17.07736705803298], 
     Hue[1.3071701849484214`, 1, -16.90742299186392], 
     Hue[1.3071701849484214`, 1, -16.70312464135101], 
     Hue[1.3071701849484214`, 1, -16.53318057518195], 
     Hue[1.3071701849484214`, 1, -16.32888222466904], 
     Hue[1.3071701849484214`, 1, -16.15893815849998], 
     Hue[1.3071701849484214`, 1, -15.954639807987068`], 
     Hue[1.3071701849484214`, 1, -15.784695741818005`], 
     Hue[1.3071701849484212`, 1, -15.580397391305098`], 
     Hue[1.3071701849484212`, 1, -15.407712291810729`], 
     Hue[1.3071701849484212`, 1, -15.206154974623129`], 
     Hue[1.3071701849484212`, 1, -15.033469875128759`], 
     Hue[1.307170184948421, 1, -14.831912557941154`], 
     Hue[1.3071701849484207`, 1, -14.657856941784134`], 
     Hue[1.3071701849484203`, 1, -14.457670141259184`], 
     Hue[1.3071701849484199`, 1, -14.283614525102161`], 
     Hue[1.3071701849484192`, 1, -14.08342772457721], 
     Hue[1.3071701849484183`, 1, -13.908172906340367`], 
     Hue[1.3071701849484165`, 1, -13.709185307895236`], 
     Hue[1.307170184948414, 1, -13.5118309084731], 
     Hue[1.307170184948411, 1, -13.33494289121326], 
     Hue[1.3071701849484054`, 1, -13.137588491791119`], 
     Hue[1.3071701849483983`, 1, -12.960700474531274`], 
     Hue[1.3071701849483865`, 1, -12.763346075109126`], 
     Hue[1.3071701849483706`, 1, -12.58645805784927], 
     Hue[1.3071701849483446`, 1, -12.389103658427109`], 
     Hue[1.3071701849483097`, 1, -12.212215641167234`], 
     Hue[1.3071701849482524`, 1, -12.014861241745034`], 
     Hue[1.307170184948176, 1, -11.837973224485111`], 
     Hue[1.3071701849480497`, 1, -11.640618825062836`], 
     Hue[1.307170184947882, 1, -11.463730807802811`], 
     Hue[1.3071701849476043`, 1, -11.266376408380365`], 
     Hue[1.3071701849472357`, 1, -11.089488391120117`], 
     Hue[1.3071701849466248`, 1, -10.892133991697298`], 
     Hue[1.3071701849458142`, 1, -10.715245974436552`], 
     Hue[1.3071701849444712`, 1, -10.517891575012912`], 
     Hue[1.3071701849426889`, 1, -10.341003557751078`], 
     Hue[1.3071701849397361`, 1, -10.143649158325635`], 
     Hue[1.3071701849355033`, 1, -9.955066065539741], 
     Hue[1.3071701849291184`, 1, -9.764290146091192], 
     Hue[1.307170184920018, 1, -9.580823648840417], 
     Hue[1.3071701849059791`, 1, -9.390047729383287], 
     Hue[1.30717018488597, 1, -9.20658123212029], 
     Hue[1.3071701848551025`, 1, -9.015805312644298], 
     Hue[1.307170184811108, 1, -8.83233881535442], 
     Hue[1.3071701847432387`, 1, -8.641562895836964], 
     Hue[1.3071701846465063`, 1, -8.458096398487983], 
     Hue[1.3071701844972807`, 1, -8.267320478879348], 
     Hue[1.3071701842845924`, 1, -8.083853981400418], 
     Hue[1.307170183956486, 1, -7.893078061591317], 
     Hue[1.3071701834888425`, 1, -7.709611563826658], 
     Hue[1.3071701827674258`, 1, -7.518835643576776], 
     Hue[1.3071701817392054`, 1, -7.335369145183882], 
     Hue[1.3071701801530067`, 1, -7.14459322396485], 
     Hue[1.3071701778922298`, 1, -6.961126724190641], 
     Hue[1.3071701744046111`, 1, -6.770350800840703], 
     Hue[1.307170169433779, 1, -6.586884298029362], 
     Hue[1.3071701617654554`, 1, -6.396108369994147], 
     Hue[1.3071701504134086`, 1, -6.206794322270783], 
     Hue[1.3071701337001178`, 1, -6.019307624089335], 
     Hue[1.3071701090153323`, 1, -5.832551859194404], 
     Hue[1.3071700722673523`, 1, -5.645065138560314], 
     Hue[1.3071700179922163`, 1, -5.458309340503869], 
     Hue[1.3071699371933798`, 1, -5.270822570502659], 
     Hue[1.307169817857053, 1, -5.084066699533334], 
     Hue[1.307169640202223, 1, -4.896579820987846], 
     Hue[1.3071693778137066`, 1, -4.709823789704209], 
     Hue[1.3071689606433945`, 1, -4.511920716107003], 
     Hue[1.3071683993177114`, 1, -4.332656507577249], 
     Hue[1.30716754431149, 1, -4.146813489963988], 
     Hue[1.3071662588132946`, 1, -3.958411692181718], 
     Hue[1.3071642512802275`, 1, -3.7622428242544332`], 
     Hue[1.3071615257418094`, 1, -3.5827020873855115`], 
     Hue[1.3071571218872324`, 1, -3.387398528619891], 
     Hue[1.3071511159240747`, 1, -3.207717065380735], 
     Hue[1.3071414438128957`, 1, -3.0128416033931833`], 
     Hue[1.307128198599122, 1, -2.832809405980984], 
     Hue[1.3071069513047615`, 1, -2.6383007380808072`], 
     Hue[1.3070731774974853`, 1, -2.43502389061842], 
     Hue[1.307031115687422, 1, -2.2639363790219935`], 
     Hue[1.306956833567546, 1, -2.060651474469659], 
     Hue[1.3068642895279758`, 1, -1.8895077954483648`], 
     Hue[1.3067008012566113`, 1, -1.6861239931357555`], 
     Hue[1.3064970250885264`, 1, -1.514857630894327], 
     Hue[1.30613677776938, 1, -1.311258531475685], 
     Hue[1.3056873006793432`, 1, -1.1397263908495845`], 
     Hue[1.3049471705116091`, 1, -0.9474192872814651], 
     Hue[1.3038632039392906`, 1, -0.7587815302025214], 
     Hue[1.302252700671138, 1, -0.5703612726096567], 
     Hue[1.3000066033244888`, 1, -0.3917449097148429], 
     Hue[1.2965250219755546`, 1, -0.20379335851939961`], 
     Hue[1.2913819492193002`, 1, -0.0169926993664824], 
     Hue[1.2836405396371116`, 1, 0.17157812448609588`], 
     Hue[1.2720467935366533`, 1, 0.359735772897705], 
     Hue[1.1344055358641136`, 1, 0.7340876644128047], 
     Hue[1.2544775558552401`, 1, 0.5475520246032926], 
     Hue[1.227184585477209, 1, 0.7343465473086157], 
     Hue[1.084232012909934, 1, 0.9216308706294174], 
     Hue[1.1804261843070696`, 1, 0.9218537610541715], 
     Hue[1.432564986063353, 1, -17.264488266373966`], 
     Hue[1.432564986063353, 1, -17.07736705803298], 
     Hue[1.432564986063353, 1, -16.90742299186392], 
     Hue[1.432564986063353, 1, -16.70312464135101], 
     Hue[1.432564986063353, 1, -16.53318057518195], 
     Hue[1.432564986063353, 1, -16.32888222466904], 
     Hue[1.432564986063353, 1, -16.15893815849998], 
     Hue[1.432564986063353, 1, -15.954639807987068`], 
     Hue[1.432564986063353, 1, -15.784695741818005`], 
     Hue[1.432564986063353, 1, -15.580397391305098`], 
     Hue[1.4325649860633527`, 1, -15.407712291810729`], 
     Hue[1.4325649860633527`, 1, -15.206154974623129`], 
     Hue[1.4325649860633527`, 1, -15.033469875128759`], 
     Hue[1.4325649860633527`, 1, -14.831912557941154`], 
     Hue[1.4325649860633525`, 1, -14.65785694178413], 
     Hue[1.4325649860633525`, 1, -14.45767014125918], 
     Hue[1.4325649860633523`, 1, -14.283614525102157`], 
     Hue[1.432564986063352, 1, -14.083427724577206`], 
     Hue[1.4325649860633516`, 1, -13.908172906340361`], 
     Hue[1.4325649860633507`, 1, -13.709185307895227`], 
     Hue[1.4325649860633496`, 1, -13.511830908473087`], 
     Hue[1.4325649860633483`, 1, -13.334942891213242`], 
     Hue[1.4325649860633458`, 1, -13.137588491791092`], 
     Hue[1.4325649860633427`, 1, -12.960700474531233`], 
     Hue[1.4325649860633374`, 1, -12.763346075109064`], 
     Hue[1.4325649860633305`, 1, -12.586458057849182`], 
     Hue[1.4325649860633192`, 1, -12.389103658426972`], 
     Hue[1.4325649860633038`, 1, -12.212215641167035`], 
     Hue[1.4325649860632785`, 1, -12.014861241744732`], 
     Hue[1.432564986063245, 1, -11.837973224484674`], 
     Hue[1.4325649860631895`, 1, -11.640618825062173`], 
     Hue[1.432564986063116, 1, -11.463730807801848`], 
     Hue[1.432564986062994, 1, -11.266376408378907`], 
     Hue[1.432564986062832, 1, -11.089488391118], 
     Hue[1.4325649860625638`, 1, -10.89213399169409], 
     Hue[1.4325649860622078`, 1, -10.715245974431896`], 
     Hue[1.432564986061618, 1, -10.51789157500586], 
     Hue[1.4325649860608354`, 1, -10.341003557740843`], 
     Hue[1.4325649860595386`, 1, -10.143649158310128`], 
     Hue[1.4325649860576797`, 1, -9.955066065516679], 
     Hue[1.4325649860548755`, 1, -9.764290146056728], 
     Hue[1.432564986050879, 1, -9.580823648789707], 
     Hue[1.4325649860447134`, 1, -9.390047729307511], 
     Hue[1.432564986035926, 1, -9.206581232008789], 
     Hue[1.4325649860223697`, 1, -9.01580531247769], 
     Hue[1.4325649860030485`, 1, -8.832338815109262], 
     Hue[1.4325649859732423`, 1, -8.641562895470633], 
     Hue[1.43256498593076, 1, -8.458096397948948], 
     Hue[1.4325649858652243`, 1, -8.267320478073888], 
     Hue[1.4325649857718175`, 1, -8.083853980215226], 
     Hue[1.432564985627722, 1, -7.893078059820328], 
     Hue[1.432564985422346, 1, -7.709611561220744], 
     Hue[1.4325649851055193`, 1, -7.518835639682856], 
     Hue[1.4325649846539532`, 1, -7.335369139454191], 
     Hue[1.4325649839573382`, 1, -7.144593215403179], 
     Hue[1.4325649829644669`, 1, -6.96112671159261], 
     Hue[1.4325649814328003`, 1, -6.770350782015922], 
     Hue[1.4325649792497468`, 1, -6.58688427032972], 
     Hue[1.432564975882029, 1, -6.396108328603578], 
     Hue[1.4325649708965202`, 1, -6.206794260612411], 
     Hue[1.4325649635564988`, 1, -6.019307532591259], 
     Hue[1.4325649527156126`, 1, -5.832551723624401], 
     Hue[1.432564936576896, 1, -5.645064937380874], 
     Hue[1.4325649127407196`, 1, -5.458309042422148], 
     Hue[1.4325648772560307`, 1, -5.270822128163391], 
     Hue[1.4325648248466671`, 1, -5.084066044131754], 
     Hue[1.4325647468252698`, 1, -4.896578848401894], 
     Hue[1.4325646315908425`, 1, -4.709822348649371], 
     Hue[1.4325644483796816`, 1, -4.511918530232511], 
     Hue[1.4325642018580442`, 1, -4.332653319500797], 
     Hue[1.4325638263565093`, 1, -4.146808775329317], 
     Hue[1.4325632617870154`, 1, -3.9584046823432395`], 
     Hue[1.432562380100864, 1, -3.7622322299765623`], 
     Hue[1.4325611830534664`, 1, -3.5826866265326807`], 
     Hue[1.4325592488433632`, 1, -3.387375204137971], 
     Hue[1.4325566108704157`, 1, -3.207683015822984], 
     Hue[1.4325523623808807`, 1, -3.012790280323709], 
     Hue[1.4325465474472154`, 1, -2.832825816094889], 
     Hue[1.4325372111491501`, 1, -2.6382249304042578`], 
     Hue[1.432522367506925, 1, -2.434850591981304], 
     Hue[1.4325038787026056`, 1, -2.2636878752845693`], 
     Hue[1.4324712127424721`, 1, -2.060270062331119], 
     Hue[1.4324304904094967`, 1, -1.8889606311601395`], 
     Hue[1.432358480801098, 1, -1.6852835531702468`], 
     Hue[1.432268601369382, 1, -1.5136508247828016`], 
     Hue[1.4321093670530254`, 1, -1.3094018144853232`], 
     Hue[1.4319100783991847`, 1, -1.1370547894663317`], 
     Hue[1.4316054341870985`, 1, -0.9556195672897438], 
     Hue[1.4311095967611687`, 1, -0.7577562050512137], 
     Hue[1.4304462645244047`, 1, -0.579382384322809], 
     Hue[1.4294118758596632`, 1, -0.39055060309496503`], 
     Hue[1.3910810701291059`, 1, 0.17080735625737697`], 
     Hue[1.4278925795938848`, 1, -0.2037774303976816], 
     Hue[1.4256394002418045`, 1, -0.016923620949846452`], 
     Hue[1.4222580202882926`, 1, 0.17175295023044357`], 
     Hue[1.2857838476623904`, 1, 0.5461990176782575], 
     Hue[1.4172715576200032`, 1, 0.3587903524316608], 
     Hue[1.4098333527602742`, 1, 0.5461642805657623], 
     Hue[1.218305344463482, 1, 0.9215837105115283], 
     Hue[1.28821890740073, 1, 1.1093391971785038`], 
     Hue[1.3986745425948066`, 1, 0.7338886177452849], 
     Hue[1.3817750488051561`, 1, 0.9215623870458152], 
     Hue[1.3554434348439517`, 1, 1.109315752560586], 
     Hue[1.1149940015481274`, 1, 1.1093889823571912`], 
     Hue[1.113616567087933, 1, 1.2971683007161527`], 
     Hue[1.3109599706635624`, 1, 1.297213579697899], 
     Hue[1.0481706703786164`, 1, 1.1095373577455034`], 
     Hue[1.054104557462804, 1, 1.297009661566131], 
     Hue[1.0126982467595145`, 1, 1.1094650650331164`], 
     Hue[1.0097367819376237`, 1, 1.1096004966483273`], 
     Hue[0.5579597871782842, 1, -17.264488266373966`], 
     Hue[0.5579597871782842, 1, -17.07736705803298], 
     Hue[0.5579597871782842, 1, -16.90742299186392], 
     Hue[0.5579597871782842, 1, -16.70312464135101], 
     Hue[0.5579597871782842, 1, -16.53318057518195], 
     Hue[0.5579597871782842, 1, -16.32888222466904], 
     Hue[0.5579597871782842, 1, -16.15893815849998], 
     Hue[0.5579597871782842, 1, -15.954639807987068`], 
     Hue[0.5579597871782842, 1, -15.784695741818005`], 
     Hue[0.5579597871782842, 1, -15.580397391305098`], 
     Hue[0.5579597871782842, 1, -15.407712291810729`], 
     Hue[0.5579597871782843, 1, -15.206154974623129`], 
     Hue[0.5579597871782843, 1, -15.033469875128759`], 
     Hue[0.5579597871782844, 1, -14.831912557941154`], 
     Hue[0.5579597871782844, 1, -14.65785694178413], 
     Hue[0.5579597871782846, 1, -14.45767014125918], 
     Hue[0.5579597871782848, 1, -14.283614525102157`], 
     Hue[0.5579597871782851, 1, -14.083427724577206`], 
     Hue[0.5579597871782853, 1, -13.908172906340361`], 
     Hue[0.557959787178286, 1, -13.709185307895227`], 
     Hue[0.5579597871782869, 1, -13.511830908473085`], 
     Hue[0.5579597871782882, 1, -13.33494289121324], 
     Hue[0.5579597871782902, 1, -13.13758849179109], 
     Hue[0.5579597871782931, 1, -12.960700474531231`], 
     Hue[0.5579597871782975, 1, -12.76334607510906], 
     Hue[0.5579597871783035, 1, -12.586458057849176`], 
     Hue[0.5579597871783135, 1, -12.389103658426965`], 
     Hue[0.5579597871783266, 1, -12.212215641167026`], 
     Hue[0.5579597871783485, 1, -12.014861241744722`], 
     Hue[0.5579597871783776, 1, -11.837973224484656`], 
     Hue[0.5579597871784256, 1, -11.640618825062147`], 
     Hue[0.5579597871784894, 1, -11.46373080780181], 
     Hue[0.5579597871785951, 1, -11.266376408378848`], 
     Hue[0.5579597871787354, 1, -11.089488391117914`], 
     Hue[0.5579597871789677, 1, -10.89213399169396], 
     Hue[0.5579597871792762, 1, -10.715245974431708`], 
     Hue[0.557959787179787, 1, -10.517891575005573`], 
     Hue[0.5579597871804651, 1, -10.341003557740427`], 
     Hue[0.5579597871815886, 1, -10.143649158309497`], 
     Hue[0.557959787183199, 1, -9.955066065515737], 
     Hue[0.5579597871856282, 1, -9.76429014605532], 
     Hue[0.5579597871890906, 1, -9.580823648787637], 
     Hue[0.5579597871944317, 1, -9.39004772930442], 
     Hue[0.5579597872020444, 1, -9.20658123200424], 
     Hue[0.5579597872137881, 1, -9.015805312470892], 
     Hue[0.5579597872305264, 1, -8.832338815099261], 
     Hue[0.5579597872563478, 1, -8.641562895455689], 
     Hue[0.5579597872931504, 1, -8.458096397926957], 
     Hue[0.5579597873499247, 1, -8.267320478041029], 
     Hue[0.5579597874308437, 1, -8.083853980166875], 
     Hue[0.5579597875556747, 1, -7.893078059748077], 
     Hue[0.5579597877335938, 1, -7.709611561114431], 
     Hue[0.5579597880080631, 1, -7.518835639523997], 
     Hue[0.5579597883992586, 1, -7.335369139220437], 
     Hue[0.5579597890027418, 1, -7.144593215053889], 
     Hue[0.5579597898628741, 1, -6.961126711078649], 
     Hue[0.5579597911897693, 1, -6.770350781247928], 
     Hue[0.5579597930809662, 1, -6.586884269199659], 
     Hue[0.5579597959984475, 1, -6.39610832691497], 
     Hue[0.557959800317434, 1, -6.206794258096939], 
     Hue[0.557959806676154, 1, -6.019307528858417], 
     Hue[0.5579598160677015, 1, -5.832551718093559], 
     Hue[0.5579598300488027, 1, -5.645064929173367], 
     Hue[0.5579598506982759, 1, -5.458309030261321], 
     Hue[0.5579598814389507, 1, -5.270822110117289], 
     Hue[0.5579599268416104, 1, -5.084066017393344], 
     Hue[0.5579599944321874, 1, -4.896578808723289], 
     Hue[0.557960094260724, 1, -4.709822289858571], 
     Hue[0.5579602529780836, 1, -4.511918441055116], 
     Hue[0.55796046654187, 1, -4.332653189436158], 
     Hue[0.5579607918421068, 1, -4.14680858298471], 
     Hue[0.5579612809337169, 1, -3.958404396358958], 
     Hue[0.557962044746714, 1, -3.762231797752518], 
     Hue[0.5579630817608745, 1, -3.582685995755983], 
     Hue[0.5579647573883084, 1, -3.3873742525220836`], 
     Hue[0.5579670426968651, 1, -3.2076816266019197`], 
     Hue[0.557970723224692, 1, -3.01278818626456], 
     Hue[0.5579757608033936, 1, -2.8328227571809457`], 
     Hue[0.5579838490444552, 1, -2.6382203220109073`], 
     Hue[0.557996708527968, 1, -2.4348435192435858`], 
     Hue[0.5580127261091874, 1, -2.2636777315725958`], 
     Hue[0.5580410264267104, 1, -2.060254488874956], 
     Hue[0.5580763073295757, 1, -1.8889382817517582`], 
     Hue[0.558138697282004, 1, -1.6852492025780006`], 
     Hue[0.5582165742834162, 1, -1.513601460370458], 
     Hue[0.5583545566823633, 1, -1.3093257570912218`], 
     Hue[0.5585272695485994, 1, -1.136945155702897], 
     Hue[0.5587913358426888, 1, -0.9554582440166877], 
     Hue[0.5592212524990655, 1, -0.7575098155229689], 
     Hue[0.5597966386650985, 1, -0.5790203816318928], 
     Hue[0.5606944517600362, 1, -0.39000418945368986`], 
     Hue[0.5620144347869251, 1, -0.20295107817609193`], 
     Hue[0.5639655220127942, 1, -0.01640818653710774], 
     Hue[0.5669236882730573, 1, 0.17368647660912118`], 
     Hue[0.5711968049728358, 1, 0.35855046791338263`], 
     Hue[0.5777242344981983, 1, 0.5482887533623002], 
     Hue[0.5872902260155061, 1, 0.7343205540556985], 
     Hue[0.601778466619932, 1, 0.9216774074077239], 
     Hue[0.6240785271327915, 1, 1.1093621731586607`], 
     Hue[0.6602774966417482, 1, 1.2973220806517807`], 
     Hue[0.9556789799350207, 1, 1.2971750084149773`], 
     Hue[0.9917670111621016, 1, 1.109862779815168], 
     Hue[0.6833545882932159, 1, -17.264488266373966`], 
     Hue[0.6833545882932159, 1, -17.07736705803298], 
     Hue[0.6833545882932159, 1, -16.90742299186392], 
     Hue[0.6833545882932159, 1, -16.70312464135101], 
     Hue[0.6833545882932159, 1, -16.53318057518195], 
     Hue[0.6833545882932159, 1, -16.32888222466904], 
     Hue[0.6833545882932159, 1, -16.15893815849998], 
     Hue[0.683354588293216, 1, -15.954639807987068`], 
     Hue[0.683354588293216, 1, -15.784695741818005`], 
     Hue[0.683354588293216, 1, -15.580397391305098`], 
     Hue[0.6833545882932162, 1, -15.407712291810729`], 
     Hue[0.6833545882932162, 1, -15.206154974623129`], 
     Hue[0.6833545882932163, 1, -15.033469875128759`], 
     Hue[0.6833545882932164, 1, -14.831912557941154`], 
     Hue[0.6833545882932166, 1, -14.657856941784134`], 
     Hue[0.6833545882932169, 1, -14.457670141259184`], 
     Hue[0.6833545882932173, 1, -14.283614525102157`], 
     Hue[0.6833545882932182, 1, -14.08342772457721], 
     Hue[0.683354588293219, 1, -13.908172906340367`], 
     Hue[0.6833545882932206, 1, -13.709185307895234`], 
     Hue[0.683354588293223, 1, -13.511830908473097`], 
     Hue[0.6833545882932262, 1, -13.334942891213258`], 
     Hue[0.6833545882932315, 1, -13.137588491791117`], 
     Hue[0.6833545882932386, 1, -12.96070047453127], 
     Hue[0.6833545882932501, 1, -12.763346075109121`], 
     Hue[0.6833545882932655, 1, -12.586458057849262`], 
     Hue[0.683354588293291, 1, -12.389103658427095`], 
     Hue[0.6833545882933248, 1, -12.212215641167214`], 
     Hue[0.6833545882933809, 1, -12.014861241745004`], 
     Hue[0.6833545882934553, 1, -11.83797322448507], 
     Hue[0.6833545882935785, 1, -11.640618825062772`], 
     Hue[0.6833545882937422, 1, -11.463730807802717`], 
     Hue[0.6833545882940133, 1, -11.266376408380221`], 
     Hue[0.6833545882943731, 1, -11.089488391119907`], 
     Hue[0.6833545882949692, 1, -10.892133991696982`], 
     Hue[0.6833545882957602, 1, -10.715245974436094`], 
     Hue[0.6833545882970709, 1, -10.51789157501222], 
     Hue[0.6833545882988101, 1, -10.341003557750073`], 
     Hue[0.6833545883016916, 1, -10.143649158324111`], 
     Hue[0.6833545883058225, 1, -9.955066065537475], 
     Hue[0.6833545883120535, 1, -9.7642901460878], 
     Hue[0.6833545883209344, 1, -9.58082364883543], 
     Hue[0.6833545883346347, 1, -9.390047729375835], 
     Hue[0.6833545883541614, 1, -9.206581232109324], 
     Hue[0.6833545883842844, 1, -9.015805312627913], 
     Hue[0.6833545884272183, 1, -8.83233881533031], 
     Hue[0.6833545884934509, 1, -8.641562895800936], 
     Hue[0.6833545885878507, 1, -8.45809639843497], 
     Hue[0.6833545887334779, 1, -8.267320478800132], 
     Hue[0.6833545889410374, 1, -8.083853981283855], 
     Hue[0.6833545892612319, 1, -7.893078061417142], 
     Hue[0.6833545897175988, 1, -7.709611563570367], 
     Hue[0.6833545904216193, 1, -7.518835643193813], 
     Hue[0.6833545914250455, 1, -7.335369144620372], 
     Hue[0.683354592972995, 1, -7.144593223122816], 
     Hue[0.6833545951792557, 1, -6.961126722951636], 
     Hue[0.6833545985827746, 1, -6.7703507989893], 
     Hue[0.683354603433741, 1, -6.586884295305124], 
     Hue[0.683354610917152, 1, -6.396108365923418], 
     Hue[0.6833546219954578, 1, -6.206794316206732], 
     Hue[0.6833546383057274, 1, -6.0193076150905735`], 
     Hue[0.6833546623952694, 1, -5.832551845861206], 
     Hue[0.6833546982571174, 1, -5.645065118774484], 
     Hue[0.6833547512234772, 1, -5.458309311187786], 
     Hue[0.6833548300739563, 1, -5.270822526998981], 
     Hue[0.6833549465326534, 1, -5.0840666350751915`], 
     Hue[0.6833551199036032, 1, -4.896579725334968], 
     Hue[0.683355375965055, 1, -4.709823647978], 
     Hue[0.6833557830760979, 1, -4.511920501128879], 
     Hue[0.6833563308666775, 1, -4.3326561940343655`], 
     Hue[0.6833571652567877, 1, -4.146813026287571], 
     Hue[0.6833584197597412, 1, -3.958411002778858], 
     Hue[0.6833603788906342, 1, -3.7622417823365915`], 
     Hue[0.6833630387202257, 1, -3.582700566867568], 
     Hue[0.6833673364155051, 1, -3.3873962347772233`], 
     Hue[0.6833731976214998, 1, -3.207713716850268], 
     Hue[0.6833826366678493, 1, -3.012836556301875], 
     Hue[0.6833955628267547, 1, -2.8328020326956542`], 
     Hue[0.6834162985740759, 1, -2.6382896328832617`], 
     Hue[0.6834492599183053, 1, -2.4350068524410036`], 
     Hue[0.6834903110404752, 1, -2.2639119504027434`], 
     Hue[0.6835628113829912, 1, -2.0606139900362157`], 
     Hue[0.6836531411805022, 1, -1.8894540381339164`], 
     Hue[0.6838127329037228, 1, -1.686041468274148], 
     Hue[0.684011679388588, 1, -1.5147392139926572`], 
     Hue[0.6843634621411449, 1, -1.3110765670787037`], 
     Hue[0.6848025102249419, 1, -1.1394649694479526`], 
     Hue[0.6855257881836487, 1, -0.9470266243019203], 
     Hue[0.6865857970142293, 1, -0.7581957682330243], 
     Hue[0.6881623030027816, 1, -0.5694867312078382], 
     Hue[0.6903456938952284, 1, -0.391719247339821], 
     Hue[0.6070804610264058, 1, 0.17128965411441932`], 
     Hue[0.6937518915186879, 1, -0.20337321304174738`], 
     Hue[0.6988326968573795, 1, -0.014791189078606326`], 
     Hue[0.7142983676853003, 1, 0.5461221288828877], 
     Hue[0.7062828928756222, 1, 0.17096273208800927`], 
     Hue[0.7176223336261567, 1, 0.35980153798862324`], 
     Hue[0.7816814853236274, 1, 0.9216183416731883], 
     Hue[0.7117880817846387, 1, 1.109321113473107], 
     Hue[0.7345713324942954, 1, 0.5461348927028068], 
     Hue[0.7611665194567794, 1, 0.7339438475611282], 
     Hue[0.8850128575047035, 1, 1.109286753048122], 
     Hue[0.8863767721490838, 1, 1.2970876816406254`], 
     Hue[0.8061563761714235, 1, 0.9216477717443373], 
     Hue[0.9518230768529415, 1, 1.1094603898369109`], 
     Hue[0.9872601064586131, 1, 1.1093783272191862`], 
     Hue[0.8087493894081474, 1, -17.264488266373966`], 
     Hue[0.8087493894081474, 1, -17.07736705803298], 
     Hue[0.8087493894081474, 1, -16.90742299186392], 
     Hue[0.8087493894081474, 1, -16.70312464135101], 
     Hue[0.8087493894081474, 1, -16.53318057518195], 
     Hue[0.8087493894081474, 1, -16.32888222466904], 
     Hue[0.8087493894081474, 1, -16.15893815849998], 
     Hue[0.8087493894081474, 1, -15.954639807987068`], 
     Hue[0.8087493894081474, 1, -15.784695741818005`], 
     Hue[0.8087493894081476, 1, -15.580397391305098`], 
     Hue[0.8087493894081476, 1, -15.407712291810729`], 
     Hue[0.8087493894081477, 1, -15.206154974623129`], 
     Hue[0.8087493894081477, 1, -15.033469875128759`], 
     Hue[0.8087493894081479, 1, -14.831912557941154`], 
     Hue[0.8087493894081481, 1, -14.657856941784134`], 
     Hue[0.8087493894081484, 1, -14.457670141259184`], 
     Hue[0.8087493894081488, 1, -14.283614525102161`], 
     Hue[0.8087493894081496, 1, -14.083427724577215`], 
     Hue[0.8087493894081506, 1, -13.908172906340374`], 
     Hue[0.8087493894081522, 1, -13.709185307895247`], 
     Hue[0.8087493894081547, 1, -13.511830908473115`], 
     Hue[0.8087493894081579, 1, -13.334942891213283`], 
     Hue[0.8087493894081632, 1, -13.137588491791156`], 
     Hue[0.8087493894081704, 1, -12.960700474531327`], 
     Hue[0.8087493894081823, 1, -12.763346075109206`], 
     Hue[0.808749389408198, 1, -12.586458057849388`], 
     Hue[0.808749389408224, 1, -12.389103658427281`], 
     Hue[0.8087493894082586, 1, -12.212215641167488`], 
     Hue[0.8087493894083158, 1, -12.014861241745418`], 
     Hue[0.8087493894083917, 1, -11.837973224485669`], 
     Hue[0.8087493894085176, 1, -11.64061882506368], 
     Hue[0.8087493894086847, 1, -11.463730807804037`], 
     Hue[0.8087493894089615, 1, -11.266376408382222`], 
     Hue[0.8087493894093287, 1, -11.089488391122808`], 
     Hue[0.8087493894099371, 1, -10.892133991701378`], 
     Hue[0.8087493894107447, 1, -10.715245974442473`], 
     Hue[0.8087493894120825, 1, -10.517891575021883`], 
     Hue[0.8087493894138581, 1, -10.341003557764095`], 
     Hue[0.8087493894167997, 1, -10.143649158345358`], 
     Hue[0.8087493894210167, 1, -9.955066065569078], 
     Hue[0.8087493894273776, 1, -9.764290146135027], 
     Hue[0.8087493894364436, 1, -9.58082364890492], 
     Hue[0.8087493894504294, 1, -9.39004772947967], 
     Hue[0.808749389470363, 1, -9.206581232262113], 
     Hue[0.808749389501114, 1, -9.01580531285622], 
     Hue[0.8087493895449426, 1, -8.832338815666251], 
     Hue[0.8087493896125555, 1, -8.64156289630292], 
     Hue[0.8087493897089227, 1, -8.458096399173613], 
     Hue[0.808749389857585, 1, -8.267320479903862], 
     Hue[0.8087493900694703, 1, -8.083853982907934], 
     Hue[0.8087493903963381, 1, -7.893078063843942], 
     Hue[0.8087493908622162, 1, -7.709611567141272], 
     Hue[0.8087493915809095, 1, -7.518835648529689], 
     Hue[0.8087493926052484, 1, -7.335369152471821], 
     Hue[0.8087493941854591, 1, -7.144593234854951], 
     Hue[0.8087493964377012, 1, -6.961126740214831], 
     Hue[0.8087493999121536, 1, -6.770350824785066], 
     Hue[0.80874940486422, 1, -6.586884333262185], 
     Hue[0.8087494125035938, 1, -6.396108422641275], 
     Hue[0.8087494238127828, 1, -6.206794400697729], 
     Hue[0.8087494404629729, 1, -6.019307740471157], 
     Hue[0.808749465054557, 1, -5.832552031633883], 
     Hue[0.8087495016637782, 1, -5.6450653944522236`], 
     Hue[0.8087495557339498, 1, -5.458309719651287], 
     Hue[0.8087496362276061, 1, -5.270823133139225], 
     Hue[0.8087497551130814, 1, -5.084067533175168], 
     Hue[0.8087499320964819, 1, -4.8965810580722975`], 
     Hue[0.8087501934927762, 1, -4.70982562265536], 
     Hue[0.8087506090842083, 1, -4.511923496422359], 
     Hue[0.8087511682828054, 1, -4.332660562620417], 
     Hue[0.8087520200433008, 1, -4.146819486654411], 
     Hue[0.8087533006484564, 1, -3.958420608115347], 
     Hue[0.8087553005086902, 1, -3.762256299066906], 
     Hue[0.808758015568607, 1, -3.5827217515142182`], 
     Hue[0.8087624023427731, 1, -3.3874281931132035`], 
     Hue[0.8087683847139981, 1, -3.2077603679962303`], 
     Hue[0.808778018110272, 1, -3.012906868251841], 
     Hue[0.8087912148947318, 1, -2.832836225913237], 
     Hue[0.8088123689927642, 1, -2.6384164815561473`], 
     Hue[0.8088459858500521, 1, -2.4352441369575315`], 
     Hue[0.8088878416203176, 1, -2.2642520905390544`], 
     Hue[0.8089617187958617, 1, -2.061135731989445], 
     Hue[0.8090536850366359, 1, -1.8902019499108647`], 
     Hue[0.8092159541479897, 1, -1.6871887195648798`], 
     Hue[0.8094178567436922, 1, -1.5163838321188907`], 
     Hue[0.8097738341731858, 1, -1.3135994190107778`], 
     Hue[0.8102162767267598, 1, -1.143081705706826], 
     Hue[0.8109407247257632, 1, -0.9524399954727418], 
     Hue[0.811992620199129, 1, -0.7662298855029697], 
     Hue[0.8135943800100551, 1, -0.5756171031756372], 
     Hue[0.8159160291261203, 1, -0.3897457676534022], 
     Hue[0.8193364191400477, 1, -0.20459403634940587`], 
     Hue[0.8244994809161432, 1, -0.016341373487125166`], 
     Hue[0.8321990565583399, 1, 0.1717691387182202], 
     Hue[0.8436401424724453, 1, 0.3584267827737614], 
     Hue[0.865644724924523, 1, 0.7340001015567614], 
     Hue[0.8611116009229997, 1, 0.5464699143259594], 
     Hue[0.9156687105159924, 1, 0.9219658578068505], 
     Hue[0.8883493496100086, 1, 0.7340430561883736], 
     Hue[0.935004077510551, 1, 0.9222172056974245], 
     Hue[0.9341441905230791, 1, -17.264488266373966`], 
     Hue[0.934144190523079, 1, -17.07736705803298], 
     Hue[0.934144190523079, 1, -16.90742299186392], 
     Hue[0.934144190523079, 1, -16.70312464135101], 
     Hue[0.9341441905230791, 1, -16.53318057518195], 
     Hue[0.934144190523079, 1, -16.32888222466904], 
     Hue[0.9341441905230791, 1, -16.15893815849998], 
     Hue[0.9341441905230791, 1, -15.954639807987068`], 
     Hue[0.9341441905230791, 1, -15.784695741818005`], 
     Hue[0.9341441905230791, 1, -15.580397391305098`], 
     Hue[0.9341441905230791, 1, -15.407712291810729`], 
     Hue[0.9341441905230791, 1, -15.206154974623129`], 
     Hue[0.9341441905230792, 1, -15.033469875128759`], 
     Hue[0.9341441905230792, 1, -14.831912557941154`], 
     Hue[0.9341441905230793, 1, -14.657856941784138`], 
     Hue[0.9341441905230794, 1, -14.457670141259188`], 
     Hue[0.9341441905230796, 1, -14.283614525102164`], 
     Hue[0.93414419052308, 1, -14.08342772457722], 
     Hue[0.9341441905230804, 1, -13.90817290634038], 
     Hue[0.9341441905230811, 1, -13.709185307895256`], 
     Hue[0.9341441905230821, 1, -13.51183090847313], 
     Hue[0.9341441905230835, 1, -13.334942891213302`], 
     Hue[0.9341441905230858, 1, -13.137588491791185`], 
     Hue[0.934144190523089, 1, -12.960700474531368`], 
     Hue[0.934144190523094, 1, -12.763346075109267`], 
     Hue[0.9341441905231008, 1, -12.586458057849477`], 
     Hue[0.934144190523112, 1, -12.389103658427418`], 
     Hue[0.9341441905231269, 1, -12.212215641167685`], 
     Hue[0.9341441905231516, 1, -12.014861241745717`], 
     Hue[0.9341441905231843, 1, -11.837973224486102`], 
     Hue[0.9341441905232386, 1, -11.640618825064339`], 
     Hue[0.9341441905233107, 1, -11.463730807804989`], 
     Hue[0.9341441905234299, 1, -11.266376408383666`], 
     Hue[0.9341441905235883, 1, -11.089488391124906`], 
     Hue[0.9341441905238506, 1, -10.892133991704554`], 
     Hue[0.9341441905241987, 1, -10.715245974447084`], 
     Hue[0.9341441905247755, 1, -10.51789157502887], 
     Hue[0.934144190525541, 1, -10.341003557774235`], 
     Hue[0.9341441905268092, 1, -10.14364915836072], 
     Hue[0.9341441905286272, 1, -9.955066065591925], 
     Hue[0.9341441905313694, 1, -9.764290146169168], 
     Hue[0.934144190535278, 1, -9.580823648955159], 
     Hue[0.9341441905413075, 1, -9.390047729554738], 
     Hue[0.9341441905499012, 1, -9.206581232372569], 
     Hue[0.9341441905631584, 1, -9.015805313021273], 
     Hue[0.9341441905820538, 1, -8.832338815909116], 
     Hue[0.9341441906112028, 1, -8.641562896665826], 
     Hue[0.9341441906527483, 1, -8.458096399707609], 
     Hue[0.9341441907168392, 1, -8.267320480701791], 
     Hue[0.9341441908081866, 1, -8.08385398408204], 
     Hue[0.9341441909491048, 1, -7.893078065598369], 
     Hue[0.9341441911499527, 1, -7.709611569722818], 
     Hue[0.9341441914597935, 1, -7.518835652387195], 
     Hue[0.9341441919014034, 1, -7.335369158147933], 
     Hue[0.934144192582659, 1, -7.1445932433365575`], 
     Hue[0.9341441935536386, 1, -6.961126752695054], 
     Hue[0.9341441950515339, 1, -6.770350843433808], 
     Hue[0.9341441971864535, 1, -6.586884360702792], 
     Hue[0.9341442004799164, 1, -6.396108463644771], 
     Hue[0.9341442053554985, 1, -6.206794461779476], 
     Hue[0.9341442125336753, 1, -6.019307831113526], 
     Hue[0.9341442231355188, 1, -5.832552165935952], 
     Hue[0.9341442389183634, 1, -5.645065593749984], 
     Hue[0.9341442622289063, 1, -5.458310014944705], 
     Hue[0.9341442969310321, 1, -5.27082357134018], 
     Hue[0.9341443481844578, 1, -5.084068182443805], 
     Hue[0.9341444244847419, 1, -4.896582021554323], 
     Hue[0.9341445371765467, 1, -4.709827050214769], 
     Hue[0.9341447163437004, 1, -4.511925661810815], 
     Hue[0.9341449574209899, 1, -4.332663720787972], 
     Hue[0.9341453246233216, 1, -4.146824156990739], 
     Hue[0.9341458767004063, 1, -3.9584275519377874`], 
     Hue[0.9341467388423915, 1, -3.7622667932127563`], 
     Hue[0.9341479092871356, 1, -3.582737065527107], 
     Hue[0.9341498003468727, 1, -3.3874512943361648`], 
     Hue[0.9341523791399804, 1, -3.2077940881842446`], 
     Hue[0.9341565315212711, 1, -3.0129576864834062`], 
     Hue[0.9341631300511472, 1, -2.8095036616024123`], 
     Hue[0.9341713362306259, 1, -2.638518975722146], 
     Hue[0.9341858198601788, 1, -2.435415531467404], 
     Hue[0.9342038487577479, 1, -2.2644976877958083`], 
     Hue[0.9342356567752511, 1, -2.061512206617526], 
     Hue[0.9342752286180882, 1, -1.8907411808129229`], 
     Hue[0.9343449847991715, 1, -1.6880146734553334`], 
     Hue[0.9344316612476908, 1, -1.5175657365076465`], 
     Hue[0.9345841662895144, 1, -1.3154067380236516`], 
     Hue[0.9347857487617686, 1, -1.1362467693143221`], 
     Hue[0.9350927350482252, 1, -0.9505096311537369], 
     Hue[0.9355465399685325, 1, -0.764799577600503], 
     Hue[0.9362147733654611, 1, -0.5797082947094689], 
     Hue[0.9372536165264732, 1, -0.3865863084357479], 
     Hue[0.9387074481762131, 1, -0.20441182740282526`], 
     Hue[0.9409264456213327, 1, -0.016260894514989133`], 
     Hue[0.9442086639847374, 1, 0.1710497467879195], 
     Hue[0.9491393156660923, 1, 0.36005228075912143`], 
     Hue[0.9563704358652878, 1, 0.5461458936943395], 
     Hue[0.9672745033026157, 1, 0.7338634683102744], 
     Hue[0.9837916272447883, 1, 0.9217067238369046], 
     Hue[1.0595389916380107`, 1, -17.264488266373966`], 
     Hue[1.0595389916380107`, 1, -17.07736705803298], 
     Hue[1.0595389916380107`, 1, -16.90742299186392], 
     Hue[1.0595389916380107`, 1, -16.70312464135101], 
     Hue[1.0595389916380107`, 1, -16.53318057518195], 
     Hue[1.0595389916380107`, 1, -16.32888222466904], 
     Hue[1.0595389916380107`, 1, -16.15893815849998], 
     Hue[1.0595389916380107`, 1, -15.954639807987068`], 
     Hue[1.0595389916380107`, 1, -15.784695741818005`], 
     Hue[1.0595389916380107`, 1, -15.580397391305098`], 
     Hue[1.0595389916380105`, 1, -15.407712291810729`], 
     Hue[1.0595389916380105`, 1, -15.206154974623129`], 
     Hue[1.0595389916380105`, 1, -15.033469875128759`], 
     Hue[1.0595389916380105`, 1, -14.831912557941154`], 
     Hue[1.0595389916380105`, 1, -14.657856941784138`], 
     Hue[1.0595389916380102`, 1, -14.457670141259188`], 
     Hue[1.05953899163801, 1, -14.283614525102164`], 
     Hue[1.0595389916380098`, 1, -14.08342772457722], 
     Hue[1.0595389916380094`, 1, -13.908172906340381`], 
     Hue[1.0595389916380087`, 1, -13.709185307895256`], 
     Hue[1.0595389916380078`, 1, -13.51183090847313], 
     Hue[1.0595389916380065`, 1, -13.334942891213302`], 
     Hue[1.0595389916380045`, 1, -13.137588491791185`], 
     Hue[1.0595389916380016`, 1, -12.96070047453137], 
     Hue[1.059538991637997, 1, -12.76334607510927], 
     Hue[1.0595389916379907`, 1, -12.586458057849478`], 
     Hue[1.0595389916379807`, 1, -12.389103658427421`], 
     Hue[1.0595389916379672`, 1, -12.21221564116769], 
     Hue[1.0595389916379445`, 1, -12.014861241745725`], 
     Hue[1.0595389916379148`, 1, -11.837973224486115`], 
     Hue[1.0595389916378655`, 1, -11.640618825064355`], 
     Hue[1.0595389916378002`, 1, -11.463730807805016`], 
     Hue[1.0595389916376916`, 1, -11.266376408383707`], 
     Hue[1.0595389916375477`, 1, -11.089488391124965`], 
     Hue[1.0595389916373092`, 1, -10.892133991704641`], 
     Hue[1.0595389916369928`, 1, -10.71524597444721], 
     Hue[1.0595389916364688`, 1, -10.517891575029061`], 
     Hue[1.059538991635773, 1, -10.341003557774513`], 
     Hue[1.0595389916346205`, 1, -10.143649158361141`], 
     Hue[1.059538991632968, 1, -9.955066065592554], 
     Hue[1.0595389916304758`, 1, -9.764290146170106], 
     Hue[1.0595389916269236`, 1, -9.580823648956537], 
     Hue[1.0595389916214435`, 1, -9.3900477295568], 
     Hue[1.059538991613633, 1, -9.206581232375603], 
     Hue[1.0595389916015843`, 1, -9.015805313025803], 
     Hue[1.0595389915844111`, 1, -8.832338815915785], 
     Hue[1.059538991557919, 1, -8.641562896675792], 
     Hue[1.05953899152016, 1, -8.458096399722269], 
     Hue[1.0595389914619107`, 1, -8.2673204807237], 
     Hue[1.0595389913788893`, 1, -8.08385398411428], 
     Hue[1.0595389912508149`, 1, -7.893078065646541], 
     Hue[1.0595389910682733`, 1, -7.7096115697937], 
     Hue[1.0595389907866728`, 1, -7.51883565249311], 
     Hue[1.0595389903853134`, 1, -7.33536915830378], 
     Hue[1.0595389897661507`, 1, -7.144593243569436], 
     Hue[1.0595389888836708`, 1, -6.961126753037722], 
     Hue[1.0595389875223011`, 1, -6.770350843945845], 
     Hue[1.0595389855819686`, 1, -6.586884361456227], 
     Hue[1.0595389825886878`, 1, -6.3961084647706015`], 
     Hue[1.0595389781574902`, 1, -6.2067944634565935`], 
     Hue[1.0595389716335675`, 1, -6.019307833602287], 
     Hue[1.0595389619980276`, 1, -5.832552169623475], 
     Hue[1.0595389476537087`, 1, -5.645065599222089], 
     Hue[1.0595389264678026`, 1, -5.4583100230525545`], 
     Hue[1.059538894928599, 1, -5.270823583371827], 
     Hue[1.059538848346663, 1, -5.084068200270713], 
     Hue[1.0595387790007649`, 1, -4.896582048008541], 
     Hue[1.0595386765802541`, 1, -4.709827089411067], 
     Hue[1.059538513743301, 1, -4.511925721265487], 
     Hue[1.0595382946390373`, 1, -4.332663807501009], 
     Hue[1.0595379609054654`, 1, -4.146824285222607], 
     Hue[1.0595374591477116`, 1, -3.958427742591068], 
     Hue[1.0595366755863351`, 1, -3.762267081343391], 
     Hue[1.0595356118232118`, 1, -3.582737485989174], 
     Hue[1.0595338931276845`, 1, -3.387451928593457], 
     Hue[1.0595315493860364`, 1, -3.207795013970033], 
     Hue[1.059527775491438, 1, -3.0129590816433813`], 
     Hue[1.0595217784283537`, 1, -2.8095058025260498`], 
     Hue[1.0595143202818265`, 1, -2.6385220439056365`], 
     Hue[1.0595011569761994`, 1, -2.4354202356926358`], 
     Hue[1.0594847717149274`, 1, -2.2645044275648907`], 
     Hue[1.059455863873838, 1, -2.061522535047315], 
     Hue[1.0594199007032223`, 1, -1.8907559691902314`], 
     Hue[1.0593565074356006`, 1, -1.68803731115792], 
     Hue[1.0592777402233753`, 1, -1.5175981051718372`], 
     Hue[1.0591391591042207`, 1, -1.3154561680031096`], 
     Hue[1.0589559966263298`, 1, -1.1363186334756203`], 
     Hue[1.0586770949154067`, 1, -0.9506154024517042], 
     Hue[1.0582648787307816`, 1, -0.7649549023114268], 
     Hue[1.057658040396912, 1, -0.5799353471251898], 
     Hue[1.0567150014002489`, 1, -0.3869219280313829], 
     Hue[1.055372090332659, 1, -0.20216591329918598`], 
     Hue[1.0533744526387074`, 1, -0.01620109350029253], 
     Hue[1.0503876150008986`, 1, 0.17132411731864838`], 
     Hue[1.0459504653838674`, 1, 0.35878634738443027`], 
     Hue[1.0393336085072273`, 1, 0.5465304968939276], 
     Hue[1.0294450455355415`, 1, 0.7342013862511438], 
     Hue[1.0145464469135488`, 1, 0.9217235916141256], 
     Hue[1.1849337927529422`, 1, -17.264488266373966`], 
     Hue[1.1849337927529422`, 1, -17.07736705803298], 
     Hue[1.1849337927529422`, 1, -16.90742299186392], 
     Hue[1.1849337927529422`, 1, -16.70312464135101], 
     Hue[1.1849337927529422`, 1, -16.53318057518195], 
     Hue[1.1849337927529422`, 1, -16.32888222466904], 
     Hue[1.1849337927529422`, 1, -16.15893815849998], 
     Hue[1.1849337927529422`, 1, -15.954639807987068`], 
     Hue[1.1849337927529422`, 1, -15.784695741818005`], 
     Hue[1.1849337927529422`, 1, -15.580397391305098`], 
     Hue[1.184933792752942, 1, -15.407712291810729`], 
     Hue[1.184933792752942, 1, -15.206154974623129`], 
     Hue[1.184933792752942, 1, -15.033469875128759`], 
     Hue[1.1849337927529418`, 1, -14.831912557941154`], 
     Hue[1.1849337927529415`, 1, -14.657856941784134`], 
     Hue[1.1849337927529413`, 1, -14.457670141259184`], 
     Hue[1.1849337927529409`, 1, -14.283614525102164`], 
     Hue[1.1849337927529402`, 1, -14.083427724577216`], 
     Hue[1.184933792752939, 1, -13.908172906340374`], 
     Hue[1.1849337927529375`, 1, -13.709185307895249`], 
     Hue[1.184933792752935, 1, -13.511830908473115`], 
     Hue[1.184933792752932, 1, -13.334942891213284`], 
     Hue[1.1849337927529267`, 1, -13.137588491791158`], 
     Hue[1.1849337927529195`, 1, -12.960700474531329`], 
     Hue[1.184933792752908, 1, -12.76334607510921], 
     Hue[1.1849337927528925`, 1, -12.586458057849393`], 
     Hue[1.184933792752867, 1, -12.389103658427292`], 
     Hue[1.184933792752833, 1, -12.2122156411675], 
     Hue[1.1849337927527765`, 1, -12.01486124174544], 
     Hue[1.1849337927527017`, 1, -11.837973224485697`], 
     Hue[1.184933792752578, 1, -11.640618825063724`], 
     Hue[1.1849337927524137`, 1, -11.4637308078041], 
     Hue[1.1849337927521413`, 1, -11.266376408382317`], 
     Hue[1.18493379275178, 1, -11.089488391122947`], 
     Hue[1.1849337927511814`, 1, -10.892133991701588`], 
     Hue[1.184933792750387, 1, -10.715245974442778`], 
     Hue[1.1849337927490706`, 1, -10.517891575022345`], 
     Hue[1.1849337927473236`, 1, -10.341003557764767`], 
     Hue[1.1849337927444294`, 1, -10.143649158346376`], 
     Hue[1.1849337927402805`, 1, -9.95506606557059], 
     Hue[1.1849337927340224`, 1, -9.764290146137286], 
     Hue[1.1849337927251027`, 1, -9.580823648908247], 
     Hue[1.1849337927113426`, 1, -9.39004772948464], 
     Hue[1.1849337926917307`, 1, -9.206581232269423], 
     Hue[1.184933792661476, 1, -9.015805312867144], 
     Hue[1.1849337926183547`, 1, -8.832338815682327], 
     Hue[1.184933792551833, 1, -8.641562896326942], 
     Hue[1.184933792457021, 1, -8.458096399208959], 
     Hue[1.1849337923107577`, 1, -8.267320479956679], 
     Hue[1.1849337921022918`, 1, -8.083853982985648], 
     Hue[1.184933791780699, 1, -7.8930780639600675`], 
     Hue[1.1849337913223392`, 1, -7.709611567312147], 
     Hue[1.1849337906152444`, 1, -7.518835648785019], 
     Hue[1.1849337896074363`, 1, -7.335369152847524], 
     Hue[1.1849337880527275`, 1, -7.144593235416353], 
     Hue[1.1849337858368323`, 1, -6.961126741040903], 
     Hue[1.184933782418451, 1, -6.770350826019436], 
     Hue[1.1849337775463018`, 1, -6.586884335078494], 
     Hue[1.1849337700302134`, 1, -6.396108425355317], 
     Hue[1.1849337589035336`, 1, -6.2067944047407595`], 
     Hue[1.1849337425220468`, 1, -6.019307746470821], 
     Hue[1.1849337183273256`, 1, -5.832552040523405], 
     Hue[1.1849336823089105`, 1, -5.645065407643844], 
     Hue[1.184933629111334, 1, -5.458309739196912], 
     Hue[1.1849335499167026`, 1, -5.270823162143984], 
     Hue[1.1849334329498342`, 1, -5.0840675761506295`], 
     Hue[1.184933258822654, 1, -4.896581121845761], 
     Hue[1.1849330016448927`, 1, -4.709825717146475], 
     Hue[1.1849325927605334`, 1, -4.511923639751082], 
     Hue[1.184932042586764, 1, -4.332660771662359], 
     Hue[1.1849312045730038`, 1, -4.146819795789077], 
     Hue[1.1849299446364592`, 1, -3.958421067736599], 
     Hue[1.1849279770550099`, 1, -3.7622569936938444`], 
     Hue[1.1849253058206881`, 1, -3.5827227651866815`], 
     Hue[1.184920989863956, 1, -3.3874297222638097`], 
     Hue[1.1849151040836186`, 1, -3.207762600099807], 
     Hue[1.1849056262640025`, 1, -3.012910232271321], 
     Hue[1.184892641687926, 1, -2.8328297207567124`], 
     Hue[1.1848718299012013`, 1, -2.6384192423125556`], 
     Hue[1.1848387574676778`, 1, -2.4352554854666852`], 
     Hue[1.1847975795650765`, 1, -2.264268354591904], 
     Hue[1.184724900933461, 1, -2.0611606694792695`], 
     Hue[1.1846344304116367`, 1, -1.8902376797272507`], 
     Hue[1.1844748104320941`, 1, -1.6872434787142725`], 
     Hue[1.1842762218528673`, 1, -1.5164622449770293`], 
     Hue[1.1839261355476316`, 1, -1.3137194723102514`], 
     Hue[1.1834911004901627`, 1, -1.1432533992527933`], 
     Hue[1.1827789852486121`, 1, -0.9526959662593824], 
     Hue[1.1817454454020035`, 1, -0.7666076008008063], 
     Hue[1.180172649359907, 1, -0.5761787386182415], 
     Hue[1.1778951284451369`, 1, -0.3905707156923435], 
     Hue[1.1745210400308936`, 1, -0.204738678071839], 
     Hue[1.169410240781886, 1, -0.015472793139903906`], 
     Hue[1.1618913706877156`, 1, 0.17123484790847843`], 
     Hue[1.1505980458824534`, 1, 0.35865883182384184`], 
     Hue[1.1334620317570532`, 1, 0.546341965261971], 
     Hue[1.1066519604083414`, 1, 0.7345009664565734], 
     Hue[1.061392726807985, 1, 0.921835710982156], 
     Hue[1.3103285938678737`, 1, -17.264488266373966`], 
     Hue[1.3103285938678737`, 1, -17.07736705803298], 
     Hue[1.3103285938678737`, 1, -16.90742299186392], 
     Hue[1.3103285938678737`, 1, -16.70312464135101], 
     Hue[1.3103285938678737`, 1, -16.53318057518195], 
     Hue[1.3103285938678737`, 1, -16.32888222466904], 
     Hue[1.3103285938678737`, 1, -16.15893815849998], 
     Hue[1.3103285938678737`, 1, -15.954639807987068`], 
     Hue[1.3103285938678737`, 1, -15.784695741818005`], 
     Hue[1.3103285938678737`, 1, -15.580397391305098`], 
     Hue[1.3103285938678737`, 1, -15.407712291810729`], 
     Hue[1.3103285938678737`, 1, -15.206154974623129`], 
     Hue[1.3103285938678735`, 1, -15.033469875128759`], 
     Hue[1.3103285938678733`, 1, -14.831912557941154`], 
     Hue[1.3103285938678733`, 1, -14.657856941784134`], 
     Hue[1.3103285938678728`, 1, -14.457670141259184`], 
     Hue[1.3103285938678724`, 1, -14.283614525102161`], 
     Hue[1.3103285938678717`, 1, -14.08342772457721], 
     Hue[1.3103285938678706`, 1, -13.908172906340367`], 
     Hue[1.310328593867869, 1, -13.709185307895236`], 
     Hue[1.3103285938678666`, 1, -13.5118309084731], 
     Hue[1.3103285938678635`, 1, -13.33494289121326], 
     Hue[1.310328593867858, 1, -13.137588491791119`], 
     Hue[1.3103285938678508`, 1, -12.960700474531272`], 
     Hue[1.310328593867839, 1, -12.763346075109125`], 
     Hue[1.3103285938678235`, 1, -12.586458057849269`], 
     Hue[1.3103285938677975`, 1, -12.389103658427103`], 
     Hue[1.3103285938677631`, 1, -12.212215641167226`], 
     Hue[1.310328593867706, 1, -12.014861241745026`], 
     Hue[1.3103285938676303`, 1, -11.837973224485099`], 
     Hue[1.310328593867505, 1, -11.640618825062814`], 
     Hue[1.3103285938673386`, 1, -11.46373080780278], 
     Hue[1.310328593867063, 1, -11.266376408380317`], 
     Hue[1.310328593866697, 1, -11.089488391120046`], 
     Hue[1.3103285938660911`, 1, -10.892133991697191`], 
     Hue[1.3103285938652867`, 1, -10.715245974436398`], 
     Hue[1.310328593863954, 1, -10.51789157501268], 
     Hue[1.3103285938621854`, 1, -10.34100355775074], 
     Hue[1.310328593859255, 1, -10.143649158325124`], 
     Hue[1.3103285938550546`, 1, -9.955066065538979], 
     Hue[1.3103285938487184`, 1, -9.764290146090051], 
     Hue[1.3103285938396876`, 1, -9.580823648838741], 
     Hue[1.3103285938257563`, 1, -9.390047729380782], 
     Hue[1.3103285938059002`, 1, -9.206581232116605], 
     Hue[1.3103285937752687`, 1, -9.015805312638792], 
     Hue[1.3103285937316105`, 1, -8.832338815346318], 
     Hue[1.3103285936642606`, 1, -8.641562895824858], 
     Hue[1.3103285935682678`, 1, -8.45809639847017], 
     Hue[1.3103285934201836`, 1, -8.267320478852731], 
     Hue[1.310328593209122, 1, -8.083853981361251], 
     Hue[1.310328592883525, 1, -7.89307806153279], 
     Hue[1.310328592419458, 1, -7.709611563740537], 
     Hue[1.310328591703559, 1, -7.518835643448093], 
     Hue[1.3103285906832025`, 1, -7.335369144994529], 
     Hue[1.3103285891091354`, 1, -7.144593223681906], 
     Hue[1.3103285868656496`, 1, -6.961126723774307], 
     Hue[1.3103285834047047`, 1, -6.77035080021859], 
     Hue[1.3103285784718905`, 1, -6.586884297113954], 
     Hue[1.3103285708622159`, 1, -6.396108368626289], 
     Hue[1.3103285595969916`, 1, -6.206794320233124], 
     Hue[1.3103285430115275`, 1, -6.019307621065545], 
     Hue[1.3103285185155358`, 1, -5.832551854714144], 
     Hue[1.310328482048611, 1, -5.6450651319118235`], 
     Hue[1.3103284281885808`, 1, -5.458309330652996], 
     Hue[1.3103283480077061`, 1, -5.270822555884431], 
     Hue[1.310328229584079, 1, -5.0840666778739285`], 
     Hue[1.3103280532879695`, 1, -4.896579788846298], 
     Hue[1.3103277929062105`, 1, -4.7098237420809745`], 
     Hue[1.3103273789263983`, 1, -4.511920643869464], 
     Hue[1.310326821893641, 1, -4.332656402219724], 
     Hue[1.3103259734262163`, 1, -4.146813334158222], 
     Hue[1.3103246977587344`, 1, -3.9584114605268326`], 
     Hue[1.3103227055772522`, 1, -3.762242474146748], 
     Hue[1.3103200008794085`, 1, -3.5827015764578363`], 
     Hue[1.310315630694623, 1, -3.387397757838829], 
     Hue[1.310309670642515, 1, -3.2077159402032764`], 
     Hue[1.3103000724486225`, 1, -3.012839907467182], 
     Hue[1.3102869284214758`, 1, -2.832806928414225], 
     Hue[1.3102658433551664`, 1, -2.6382970065386893`], 
     Hue[1.3102323271896485`, 1, -2.4350181655379695`], 
     Hue[1.310190585852551, 1, -2.2639281707282155`], 
     Hue[1.310116868629142, 1, -2.060638879503755], 
     Hue[1.3100250264580038`, 1, -1.8894897331201157`], 
     Hue[1.3098627729386556`, 1, -1.6860962660959464`], 
     Hue[1.3096605265503387`, 1, -1.5148178466965938`], 
     Hue[1.3093029585245823`, 1, -1.3111974028330244`], 
     Hue[1.308856779255054, 1, -1.139638579383688], 
     Hue[1.3081219700292834`, 1, -0.947287415959494], 
     Hue[1.3070455497092293`, 1, -0.7585848619220494], 
     Hue[1.3054457141660094`, 1, -0.5700677658208924], 
     Hue[1.303213400476802, 1, -0.3913152823328072], 
     Hue[1.2997839070196433`, 1, -0.20464449942793483`], 
     Hue[1.2946518409503633`, 1, -0.016700802940586845`], 
     Hue[1.2870209362245262`, 1, 0.17075492350337296`], 
     Hue[1.2753933908692199`, 1, 0.3608721178312312], 
     Hue[1.1345500726738398`, 1, 0.7343396557289731], 
     Hue[1.2582098853829007`, 1, 0.5461862470924573], 
     Hue[1.2310653149920916`, 1, 0.7340500254675892], 
     Hue[1.084265112347023, 1, 0.9217424671110239], 
     Hue[1.1846384902408735`, 1, 0.9224029716197861], 
     Hue[1.4357233949828054`, 1, -17.264488266373966`], 
     Hue[1.4357233949828054`, 1, -17.07736705803298], 
     Hue[1.4357233949828054`, 1, -16.90742299186392], 
     Hue[1.4357233949828054`, 1, -16.70312464135101], 
     Hue[1.4357233949828054`, 1, -16.53318057518195], 
     Hue[1.4357233949828054`, 1, -16.32888222466904], 
     Hue[1.4357233949828054`, 1, -16.15893815849998], 
     Hue[1.4357233949828054`, 1, -15.954639807987068`], 
     Hue[1.4357233949828054`, 1, -15.784695741818005`], 
     Hue[1.4357233949828054`, 1, -15.580397391305098`], 
     Hue[1.4357233949828054`, 1, -15.407712291810729`], 
     Hue[1.4357233949828054`, 1, -15.206154974623129`], 
     Hue[1.4357233949828054`, 1, -15.033469875128759`], 
     Hue[1.4357233949828052`, 1, -14.831912557941154`], 
     Hue[1.4357233949828052`, 1, -14.65785694178413], 
     Hue[1.435723394982805, 1, -14.45767014125918], 
     Hue[1.435723394982805, 1, -14.283614525102157`], 
     Hue[1.4357233949828045`, 1, -14.083427724577206`], 
     Hue[1.435723394982804, 1, -13.908172906340361`], 
     Hue[1.4357233949828034`, 1, -13.709185307895227`], 
     Hue[1.4357233949828023`, 1, -13.511830908473085`], 
     Hue[1.435723394982801, 1, -13.334942891213242`], 
     Hue[1.4357233949827988`, 1, -13.13758849179109], 
     Hue[1.4357233949827959`, 1, -12.960700474531233`], 
     Hue[1.4357233949827908`, 1, -12.763346075109062`], 
     Hue[1.4357233949827841`, 1, -12.58645805784918], 
     Hue[1.4357233949827732`, 1, -12.389103658426968`], 
     Hue[1.4357233949827586`, 1, -12.212215641167031`], 
     Hue[1.4357233949827346`, 1, -12.014861241744729`], 
     Hue[1.4357233949827024`, 1, -11.837973224484669`], 
     Hue[1.4357233949826496`, 1, -11.640618825062163`], 
     Hue[1.4357233949825792`, 1, -11.463730807801834`], 
     Hue[1.4357233949824626`, 1, -11.266376408378887`], 
     Hue[1.4357233949823076`, 1, -11.08948839111797], 
     Hue[1.4357233949820514`, 1, -10.892133991694044`], 
     Hue[1.4357233949817112`, 1, -10.71524597443183], 
     Hue[1.4357233949811474`, 1, -10.517891575005759`], 
     Hue[1.4357233949803994`, 1, -10.341003557740699`], 
     Hue[1.4357233949791597`, 1, -10.143649158309907`], 
     Hue[1.4357233949773829`, 1, -9.95506606551635], 
     Hue[1.4357233949747028`, 1, -9.764290146056236], 
     Hue[1.4357233949708827`, 1, -9.580823648788984], 
     Hue[1.43572339496499, 1, -9.390047729306431], 
     Hue[1.4357233949565906`, 1, -9.206581232007201], 
     Hue[1.4357233949436337`, 1, -9.015805312475315], 
     Hue[1.4357233949251662`, 1, -8.83233881510577], 
     Hue[1.4357233948966772`, 1, -8.641562895465414], 
     Hue[1.4357233948560724`, 1, -8.458096397941267], 
     Hue[1.435723394793433, 1, -8.267320478062413], 
     Hue[1.435723394704154, 1, -8.08385398019834], 
     Hue[1.4357233945664267`, 1, -7.893078059795097], 
     Hue[1.4357233943701266`, 1, -7.709611561183617], 
     Hue[1.435723394067302, 1, -7.518835639627379], 
     Hue[1.435723393635692, 1, -7.335369139372559], 
     Hue[1.4357233929698627`, 1, -7.144593215281197], 
     Hue[1.4357233920208698`, 1, -6.9611267114131214`], 
     Hue[1.435723390556893, 1, -6.770350781747718], 
     Hue[1.4357233884703162`, 1, -6.586884269935072], 
     Hue[1.435723385251429, 1, -6.396108328013871], 
     Hue[1.435723380486247, 1, -6.206794259733942], 
     Hue[1.4357233734706063`, 1, -6.019307531287652], 
     Hue[1.435723363108816, 1, -5.832551721692885], 
     Hue[1.4357233476833242`, 1, -5.645064934514595], 
     Hue[1.4357233249005494`, 1, -5.458309038175265], 
     Hue[1.4357232909840496`, 1, -5.270822121861213], 
     Hue[1.4357232408908334`, 1, -5.084066034793991], 
     Hue[1.4357231663174648`, 1, -4.896578834545072], 
     Hue[1.435723056175633, 1, -4.709822328118063], 
     Hue[1.4357228810611806`, 1, -4.5119184990894], 
     Hue[1.4357226454341396`, 1, -4.332653274078779], 
     Hue[1.4357222865272163`, 1, -4.146808708157491], 
     Hue[1.4357217469077894`, 1, -3.9584045824699725`], 
     Hue[1.4357209041859191`, 1, -3.762232079032538], 
     Hue[1.4357197600392455`, 1, -3.5826864062488966`], 
     Hue[1.4357179113063507`, 1, -3.3873748718088654`], 
     Hue[1.4357153899101096`, 1, -3.2076825306710184`], 
     Hue[1.4357113291654564`, 1, -3.01278954902474], 
     Hue[1.4357057711925392`, 1, -2.8328247478453816`], 
     Hue[1.43569684744711, 1, -2.6382233210410764`], 
     Hue[1.4356826596743533`, 1, -2.4348481220173976`], 
     Hue[1.4356649877298442`, 1, -2.263684332880193], 
     Hue[1.4356337647998827`, 1, -2.0602646237826843`], 
     Hue[1.4355948410408934`, 1, -1.888952826392187], 
     Hue[1.4355260109144286`, 1, -1.6852715575957429`], 
     Hue[1.4354400982752478`, 1, -1.513633586584948], 
     Hue[1.435287887036292, 1, -1.3093752559911127`], 
     Hue[1.4350973796304782`, 1, -1.1370165081951924`], 
     Hue[1.4348061407020722`, 1, -0.9555632413696518], 
     Hue[1.434332074051817, 1, -0.75767018832769], 
     Hue[1.4336977733564145`, 1, -0.5792560260597965], 
     Hue[1.4327084383483117`, 1, -0.39035992375939665`], 
     Hue[1.3946277557447482`, 1, 0.17173151513013685`], 
     Hue[1.431254821920255, 1, -0.20348917286078239`], 
     Hue[1.4290979212294679`, 1, -0.01648391066858279], 
     Hue[1.425858355525414, 1, 0.17243484268663423`], 
     Hue[1.2865485077942158`, 1, 0.5469136563949301], 
     Hue[1.421115521491696, 1, 0.35853960308464516`], 
     Hue[1.4139699821046583`, 1, 0.546876578298102], 
     Hue[1.2183357287920706`, 1, 0.9216636078521747], 
     Hue[1.2882421344287343`, 1, 1.109399291968781], 
     Hue[1.4033271072870361`, 1, 0.7342515385961632], 
     Hue[1.387238270492091, 1, 0.9216924752975764], 
     Hue[1.362210441065885, 1, 1.1097478994606909`], 
     Hue[1.1149901849929469`, 1, 1.1093320833163138`], 
     Hue[1.1136210430694864`, 1, 1.2971141328062623`], 
     Hue[1.3207827150987244`, 1, 1.297030032577998], 
     Hue[1.0481526119271278`, 1, 1.1097586745173291`], 
     Hue[1.0507106228884175`, 1, 1.2971876819562311`], 
     Hue[1.0127333013366369`, 1, 1.1093920849023198`], 
     Hue[1.0091733878595621`, 1, 1.1093702441679865`], 
     Hue[0.5611181960977369, 1, -17.264488266373966`], 
     Hue[0.5611181960977369, 1, -17.07736705803298], 
     Hue[0.5611181960977369, 1, -16.90742299186392], 
     Hue[0.5611181960977369, 1, -16.70312464135101], 
     Hue[0.5611181960977369, 1, -16.53318057518195], 
     Hue[0.5611181960977369, 1, -16.32888222466904], 
     Hue[0.5611181960977369, 1, -16.15893815849998], 
     Hue[0.5611181960977369, 1, -15.954639807987068`], 
     Hue[0.5611181960977369, 1, -15.784695741818005`], 
     Hue[0.561118196097737, 1, -15.580397391305098`], 
     Hue[0.561118196097737, 1, -15.407712291810729`], 
     Hue[0.561118196097737, 1, -15.206154974623129`], 
     Hue[0.5611181960977372, 1, -15.033469875128759`], 
     Hue[0.5611181960977372, 1, -14.831912557941154`], 
     Hue[0.5611181960977373, 1, -14.65785694178413], 
     Hue[0.5611181960977374, 1, -14.45767014125918], 
     Hue[0.5611181960977376, 1, -14.283614525102157`], 
     Hue[0.5611181960977378, 1, -14.083427724577206`], 
     Hue[0.5611181960977383, 1, -13.908172906340361`], 
     Hue[0.5611181960977389, 1, -13.709185307895227`], 
     Hue[0.5611181960977398, 1, -13.511830908473085`], 
     Hue[0.5611181960977412, 1, -13.334942891213242`], 
     Hue[0.5611181960977434, 1, -13.13758849179109], 
     Hue[0.5611181960977463, 1, -12.960700474531233`], 
     Hue[0.5611181960977509, 1, -12.763346075109062`], 
     Hue[0.5611181960977574, 1, -12.586458057849178`], 
     Hue[0.5611181960977678, 1, -12.389103658426967`], 
     Hue[0.5611181960977817, 1, -12.21221564116703], 
     Hue[0.5611181960978047, 1, -12.014861241744725`], 
     Hue[0.5611181960978352, 1, -11.837973224484662`], 
     Hue[0.5611181960978857, 1, -11.640618825062154`], 
     Hue[0.5611181960979529, 1, -11.46373080780182], 
     Hue[0.561118196098064, 1, -11.266376408378866`], 
     Hue[0.5611181960982116, 1, -11.089488391117941`], 
     Hue[0.5611181960984559, 1, -10.892133991694001`], 
     Hue[0.5611181960987803, 1, -10.715245974431767`], 
     Hue[0.5611181960993178, 1, -10.517891575005663`], 
     Hue[0.5611181961000311, 1, -10.341003557740558`], 
     Hue[0.5611181961012127, 1, -10.143649158309698`], 
     Hue[0.5611181961029067, 1, -9.955066065516036], 
     Hue[0.5611181961054619, 1, -9.764290146055767], 
     Hue[0.5611181961091037, 1, -9.580823648788295], 
     Hue[0.561118196114722, 1, -9.390047729305403], 
     Hue[0.5611181961227294, 1, -9.206581232005684], 
     Hue[0.5611181961350823, 1, -9.015805312473049], 
     Hue[0.5611181961526885, 1, -8.832338815102435], 
     Hue[0.561118196179849, 1, -8.641562895460433], 
     Hue[0.5611181962185604, 1, -8.458096397933938], 
     Hue[0.5611181962782791, 1, -8.26732047805146], 
     Hue[0.5611181963633949, 1, -8.083853980182221], 
     Hue[0.5611181964946999, 1, -7.8930780597710095`], 
     Hue[0.5611181966818461, 1, -7.709611561148173], 
     Hue[0.5611181969705501, 1, -7.5188356395744185`], 
     Hue[0.5611181973820338, 1, -7.335369139294628], 
     Hue[0.561118198016815, 1, -7.144593215164751], 
     Hue[0.5611181989215558, 1, -6.961126711241778], 
     Hue[0.5611182003172668, 1, -6.770350781491686], 
     Hue[0.5611182023065453, 1, -6.586884269558336], 
     Hue[0.5611182053753336, 1, -6.3961083274509285`], 
     Hue[0.5611182099183125, 1, -6.20679425889534], 
     Hue[0.5611182166068098, 1, -6.019307530043207], 
     Hue[0.5611182264854239, 1, -5.832551719849028], 
     Hue[0.561118241191616, 1, -5.6450649317784], 
     Hue[0.5611182629120168, 1, -5.458309034121124], 
     Hue[0.561118295246971, 1, -5.270822115845056], 
     Hue[0.5611183430043127, 1, -5.084066025880017], 
     Hue[0.5611184141002846, 1, -4.896578821317134], 
     Hue[0.5611185191061454, 1, -4.709822308518558], 
     Hue[0.5611186860549253, 1, -4.511918469359698], 
     Hue[0.5611189106945738, 1, -4.332653230718207], 
     Hue[0.5611192528655338, 1, -4.146808644034203], 
     Hue[0.5611197673223627, 1, -3.9584044871293615`], 
     Hue[0.5611205707480225, 1, -3.762231934938937], 
     Hue[0.5611216615432789, 1, -3.582686195962384], 
     Hue[0.5611234240706309, 1, -3.3873745545619043`], 
     Hue[0.561125827896634, 1, -3.207682067536492], 
     Hue[0.5611296992958443, 1, -3.012788850913286], 
     Hue[0.5611349981163848, 1, -2.8328237280733273`], 
     Hue[0.561143505788107, 1, -2.638221784707812], 
     Hue[0.5611570320875816, 1, -2.434845764127523], 
     Hue[0.5611738801825192, 1, -2.263680951196662], 
     Hue[0.5612036477061921, 1, -2.060259431943689], 
     Hue[0.5612407574151147, 1, -1.888945375600186], 
     Hue[0.5613063805635914, 1, -1.6852601058687362`], 
     Hue[0.5613882918581821, 1, -1.5136171295661642`], 
     Hue[0.5615334181701948, 1, -1.3093499000689535`], 
     Hue[0.561715065772025, 1, -1.1369799585416522`], 
     Hue[0.5619927768520067, 1, -0.9555094593059092], 
     Hue[0.5624448667851797, 1, -0.7575880463527733], 
     Hue[0.5630498477981036, 1, -0.5791353397473544], 
     Hue[0.5639936505539833, 1, -0.3901777553680419], 
     Hue[0.5653808181884064, 1, -0.20321367094868492`], 
     Hue[0.5674302360933375, 1, -0.016808552408828614`], 
     Hue[0.5705351402995056, 1, 0.17306335548743446`], 
     Hue[0.5750732230085649, 1, 0.35956309045002266`], 
     Hue[0.5818743863907067, 1, 0.5474019030220804], 
     Hue[0.5919736048618136, 1, 0.7340919467738694], 
     Hue[0.6072825664656633, 1, 0.9217675090788328], 
     Hue[0.6309330139892123, 1, 1.109592633990576], 
     Hue[0.6697803083720739, 1, 1.297569797298349], 
     Hue[0.9525706110705651, 1, 1.2971491687131622`], 
     Hue[0.9913499519288228, 1, 1.1092962370834702`], 
     Hue[0.6865129972126687, 1, -17.264488266373966`], 
     Hue[0.6865129972126687, 1, -17.07736705803298], 
     Hue[0.6865129972126687, 1, -16.90742299186392], 
     Hue[0.6865129972126687, 1, -16.70312464135101], 
     Hue[0.6865129972126687, 1, -16.53318057518195], 
     Hue[0.6865129972126687, 1, -16.32888222466904], 
     Hue[0.6865129972126687, 1, -16.15893815849998], 
     Hue[0.6865129972126687, 1, -15.954639807987068`], 
     Hue[0.6865129972126687, 1, -15.784695741818005`], 
     Hue[0.6865129972126687, 1, -15.580397391305098`], 
     Hue[0.6865129972126689, 1, -15.407712291810729`], 
     Hue[0.6865129972126689, 1, -15.206154974623129`], 
     Hue[0.6865129972126689, 1, -15.033469875128759`], 
     Hue[0.6865129972126691, 1, -14.831912557941154`], 
     Hue[0.6865129972126693, 1, -14.657856941784134`], 
     Hue[0.6865129972126697, 1, -14.457670141259184`], 
     Hue[0.68651299721267, 1, -14.283614525102157`], 
     Hue[0.6865129972126709, 1, -14.08342772457721], 
     Hue[0.6865129972126718, 1, -13.908172906340367`], 
     Hue[0.6865129972126733, 1, -13.709185307895236`], 
     Hue[0.6865129972126758, 1, -13.5118309084731], 
     Hue[0.686512997212679, 1, -13.334942891213258`], 
     Hue[0.6865129972126843, 1, -13.137588491791117`], 
     Hue[0.6865129972126913, 1, -12.960700474531272`], 
     Hue[0.6865129972127031, 1, -12.763346075109121`], 
     Hue[0.6865129972127186, 1, -12.586458057849265`], 
     Hue[0.6865129972127444, 1, -12.3891036584271], 
     Hue[0.6865129972127785, 1, -12.21221564116722], 
     Hue[0.686512997212835, 1, -12.014861241745015`], 
     Hue[0.68651299721291, 1, -11.837973224485083`], 
     Hue[0.6865129972130344, 1, -11.640618825062791`], 
     Hue[0.6865129972131996, 1, -11.463730807802747`], 
     Hue[0.6865129972134729, 1, -11.26637640838027], 
     Hue[0.6865129972138357, 1, -11.089488391119977`], 
     Hue[0.686512997214437, 1, -10.892133991697087`], 
     Hue[0.6865129972152348, 1, -10.715245974436245`], 
     Hue[0.6865129972165568, 1, -10.517891575012449`], 
     Hue[0.686512997218311, 1, -10.341003557750405`], 
     Hue[0.6865129972212176, 1, -10.143649158324614`], 
     Hue[0.6865129972253842, 1, -9.955066065538222], 
     Hue[0.6865129972316689, 1, -9.764290146088921], 
     Hue[0.6865129972406265, 1, -9.580823648837079], 
     Hue[0.686512997254445, 1, -9.3900477293783], 
     Hue[0.6865129972741404, 1, -9.206581232112947], 
     Hue[0.6865129973045236, 1, -9.01580531263333], 
     Hue[0.6865129973478281, 1, -8.83233881533828], 
     Hue[0.6865129974146326, 1, -8.641562895812847], 
     Hue[0.6865129975098475, 1, -8.458096398452495], 
     Hue[0.6865129976567321, 1, -8.26732047882632], 
     Hue[0.686512997866084, 1, -8.08385398132239], 
     Hue[0.6865129981890433, 1, -7.893078061474724], 
     Hue[0.6865129986493508, 1, -7.7096115636550975`], 
     Hue[0.6865129993594505, 1, -7.518835643320421], 
     Hue[0.6865130003715412, 1, -7.335369144806669], 
     Hue[0.6865130019328567, 1, -7.144593223401192], 
     Hue[0.6865130041581683, 1, -6.961126723361251], 
     Hue[0.6865130075910761, 1, -6.770350799601374], 
     Hue[0.6865130124839298, 1, -6.586884296205756], 
     Hue[0.6865130200319589, 1, -6.396108367269201], 
     Hue[0.6865130312059241, 1, -6.206794318211507], 
     Hue[0.6865130476570303, 1, -6.019307618065565], 
     Hue[0.6865130719545813, 1, -5.832551850269162], 
     Hue[0.68651310812609, 1, -5.645065125315681], 
     Hue[0.6865131615498044, 1, -5.4583093208796845`], 
     Hue[0.6865132410811412, 1, -5.270822541381301], 
     Hue[0.6865133585454324, 1, -5.084066656385059], 
     Hue[0.6865135334133943, 1, -4.896579756957819], 
     Hue[0.6865137916858549, 1, -4.709823694832703], 
     Hue[0.6865142023121373, 1, -4.511920572200681], 
     Hue[0.6865147548326012, 1, -4.332656297691709], 
     Hue[0.6865155964270868, 1, -4.146813179579124], 
     Hue[0.6865168617614654, 1, -3.958411230695707], 
     Hue[0.6865188378067721, 1, -3.7622421267952006`], 
     Hue[0.6865215205987996, 1, -3.5827010695519723`], 
     Hue[0.6865258553925107, 1, -3.387396993124203], 
     Hue[0.6865317671859039, 1, -3.207714823879873], 
     Hue[0.686541287681339, 1, -3.0128382248824446`], 
     Hue[0.6865543253429379, 1, -2.832804470329573], 
     Hue[0.6865752398712704, 1, -2.6382933043197205`], 
     Hue[0.6866084851804343, 1, -2.4350124853987714`], 
     Hue[0.6866498895777351, 1, -2.263920026783823], 
     Hue[0.6867230127984335, 1, -2.0606263830468903`], 
     Hue[0.6868141167939172, 1, -1.889471811651844], 
     Hue[0.6869750712984766, 1, -1.6860687541716206`], 
     Hue[0.6871757075904692, 1, -1.5147783691612398`], 
     Hue[0.6875304537487189, 1, -1.3111367399475313`], 
     Hue[0.6879731562731403, 1, -1.1395514272238831`], 
     Hue[0.6887023474734432, 1, -0.9471565105556297], 
     Hue[0.6897707810883402, 1, -0.7583895810802193], 
     Hue[0.6913592833040489, 1, -0.5697762111305584], 
     Hue[0.6935582272669583, 1, -0.3921423260197807], 
     Hue[0.6084264922610343, 1, 0.17093722297686642`], 
     Hue[0.6969862042272286, 1, -0.20400704831221605`], 
     Hue[0.7020938021137811, 1, -0.01574392186276352], 
     Hue[0.7142709641539142, 1, 0.5461477581064232], 
     Hue[0.709663826305711, 1, 0.17143445346789732`], 
     Hue[0.7209884513300969, 1, 0.35854327786172835`], 
     Hue[0.781685875482314, 1, 0.9216067976078458], 
     Hue[0.7117011844212839, 1, 1.1095459260876583`], 
     Hue[0.7382033352354103, 1, 0.5462696299157094], 
     Hue[0.7652326800491136, 1, 0.7349177458109576], 
     Hue[0.8850090392498811, 1, 1.1093436454254195`], 
     Hue[0.8863961434645579, 1, 1.2973219557074267`], 
     Hue[0.8106308006102927, 1, 0.9215683028033799], 
     Hue[0.9518151506383099, 1, 1.109362571174966], 
     Hue[0.9872158596665221, 1, 1.1092857115103212`], 
     Hue[0.8119077983276003, 1, -17.264488266373966`], 
     Hue[0.8119077983276003, 1, -17.07736705803298], 
     Hue[0.8119077983276003, 1, -16.90742299186392], 
     Hue[0.8119077983276003, 1, -16.70312464135101], 
     Hue[0.8119077983276004, 1, -16.53318057518195], 
     Hue[0.8119077983276004, 1, -16.32888222466904], 
     Hue[0.8119077983276004, 1, -16.15893815849998], 
     Hue[0.8119077983276004, 1, -15.954639807987068`], 
     Hue[0.8119077983276004, 1, -15.784695741818005`], 
     Hue[0.8119077983276004, 1, -15.580397391305098`], 
     Hue[0.8119077983276004, 1, -15.407712291810729`], 
     Hue[0.8119077983276005, 1, -15.206154974623129`], 
     Hue[0.8119077983276006, 1, -15.033469875128759`], 
     Hue[0.8119077983276007, 1, -14.831912557941154`], 
     Hue[0.811907798327601, 1, -14.657856941784134`], 
     Hue[0.8119077983276013, 1, -14.457670141259184`], 
     Hue[0.8119077983276017, 1, -14.283614525102161`], 
     Hue[0.8119077983276024, 1, -14.083427724577216`], 
     Hue[0.8119077983276034, 1, -13.908172906340374`], 
     Hue[0.8119077983276051, 1, -13.709185307895247`], 
     Hue[0.8119077983276075, 1, -13.511830908473115`], 
     Hue[0.8119077983276107, 1, -13.334942891213284`], 
     Hue[0.8119077983276161, 1, -13.137588491791156`], 
     Hue[0.8119077983276232, 1, -12.960700474531329`], 
     Hue[0.8119077983276348, 1, -12.763346075109208`], 
     Hue[0.8119077983276505, 1, -12.58645805784939], 
     Hue[0.8119077983276763, 1, -12.389103658427286`], 
     Hue[0.8119077983277105, 1, -12.212215641167493`], 
     Hue[0.8119077983277674, 1, -12.014861241745429`], 
     Hue[0.8119077983278428, 1, -11.837973224485683`], 
     Hue[0.8119077983279676, 1, -11.6406188250637], 
     Hue[0.8119077983281333, 1, -11.463730807804067`], 
     Hue[0.8119077983284079, 1, -11.266376408382268`], 
     Hue[0.8119077983287722, 1, -11.08948839112288], 
     Hue[0.811907798329376, 1, -10.892133991701483`], 
     Hue[0.8119077983301771, 1, -10.715245974442626`], 
     Hue[0.8119077983315045, 1, -10.517891575022116`], 
     Hue[0.8119077983332661, 1, -10.341003557764433`], 
     Hue[0.8119077983361845, 1, -10.143649158345868`], 
     Hue[0.8119077983403683, 1, -9.955066065569838], 
     Hue[0.8119077983466791, 1, -9.764290146136162], 
     Hue[0.8119077983556737, 1, -9.58082364890659], 
     Hue[0.8119077983695493, 1, -9.390047729482164], 
     Hue[0.811907798389326, 1, -9.206581232265783], 
     Hue[0.8119077984198348, 1, -9.015805312861705], 
     Hue[0.8119077984633184, 1, -8.832338815674321], 
     Hue[0.8119077985303988, 1, -8.64156289631498], 
     Hue[0.8119077986260074, 1, -8.458096399191358], 
     Hue[0.8119077987734991, 1, -8.267320479930378], 
     Hue[0.8119077989837161, 1, -8.083853982946948], 
     Hue[0.8119077993080104, 1, -7.893078063902242], 
     Hue[0.8119077997702202, 1, -7.709611567227056], 
     Hue[0.8119078004832547, 1, -7.5188356486578725`], 
     Hue[0.8119078014995282, 1, -7.335369152660438], 
     Hue[0.8119078030672968, 1, -7.144593235136793], 
     Hue[0.8119078053018054, 1, -6.961126740629546], 
     Hue[0.811907808748901, 1, -6.77035082540476], 
     Hue[0.8119078136619762, 1, -6.586884334174034], 
     Hue[0.8119078212411996, 1, -6.396108424003815], 
     Hue[0.8119078324613433, 1, -6.206794402727465], 
     Hue[0.8119078489804344, 1, -6.019307743483189], 
     Hue[0.8119078733783911, 1, -5.83255203609672], 
     Hue[0.811907909699361, 1, -5.645065401074858], 
     Hue[0.8119079633437978, 1, -5.458309729463846], 
     Hue[0.811908043203666, 1, -5.270823147700585], 
     Hue[0.8119081611530625, 1, -5.084067554750289], 
     Hue[0.8119083367429268, 1, -4.896581090088714], 
     Hue[0.8119085960810186, 1, -4.709825670093068], 
     Hue[0.8119090084000997, 1, -4.511923568378187], 
     Hue[0.8119095631955213, 1, -4.3326606675664925`], 
     Hue[0.811910408249037, 1, -4.146819641850412], 
     Hue[0.811911678770044, 1, -3.9584208388607127`], 
     Hue[0.8119136628815334, 1, -3.762256647793137], 
     Hue[0.8119163565589866, 1, -3.582722260412269], 
     Hue[0.811920708781259, 1, -3.3874289607992276`], 
     Hue[0.8119266440254205, 1, -3.20776148858957], 
     Hue[0.8119362015145759, 1, -3.0129085571081893`], 
     Hue[0.8119492952744352, 1, -2.8328272734363944`], 
     Hue[0.8119702821506296, 1, -2.6384155574810517`], 
     Hue[0.8120036330473377, 1, -2.435249834356809], 
     Hue[0.8120451580454058, 1, -2.2642602557772555`], 
     Hue[0.8121184503415362, 1, -2.0611482517714386`], 
     Hue[0.8122096866160717, 1, -1.8902198881466685`], 
     Hue[0.8123706626696372, 1, -1.6872162120691467`], 
     Hue[0.8125709473472489, 1, -1.5164232012346475`], 
     Hue[0.8129240478255406, 1, -1.3136596973715446`], 
     Hue[0.8133628713507582, 1, -1.1431679171293003`], 
     Hue[0.8140812903364503, 1, -0.9525685358606004], 
     Hue[0.8151242043912637, 1, -0.7664195863142609], 
     Hue[0.8167117741862975, 1, -0.5758992289837945], 
     Hue[0.8190117661431657, 1, -0.39016027735551906`], 
     Hue[0.8224136091240403, 1, -0.20449190168314302`], 
     Hue[0.8275124899141106, 1, -0.016977718501920425`], 
     Hue[0.8351746043164885, 1, 0.1718321099306549], 
     Hue[0.8465871725085399, 1, 0.3593412573608895], 
     Hue[0.8657085976649668, 1, 0.7338888718976831], 
     Hue[0.8638178005784829, 1, 0.5462531650343513], 
     Hue[0.9157435679447978, 1, 0.9217131923177281], 
     Hue[0.8908227872896294, 1, 0.7340378207581447], 
     Hue[0.9366776682815277, 1, 0.9215689340718403], 
     Hue[0.9373025994425319, 1, -17.264488266373966`], 
     Hue[0.9373025994425319, 1, -17.07736705803298], 
     Hue[0.9373025994425319, 1, -16.90742299186392], 
     Hue[0.9373025994425319, 1, -16.70312464135101], 
     Hue[0.9373025994425319, 1, -16.53318057518195], 
     Hue[0.9373025994425319, 1, -16.32888222466904], 
     Hue[0.9373025994425319, 1, -16.15893815849998], 
     Hue[0.9373025994425319, 1, -15.954639807987068`], 
     Hue[0.9373025994425319, 1, -15.784695741818005`], 
     Hue[0.9373025994425319, 1, -15.580397391305098`], 
     Hue[0.937302599442532, 1, -15.407712291810729`], 
     Hue[0.937302599442532, 1, -15.206154974623129`], 
     Hue[0.937302599442532, 1, -15.033469875128759`], 
     Hue[0.9373025994425321, 1, -14.831912557941154`], 
     Hue[0.9373025994425321, 1, -14.657856941784138`], 
     Hue[0.9373025994425324, 1, -14.457670141259188`], 
     Hue[0.9373025994425325, 1, -14.283614525102164`], 
     Hue[0.9373025994425328, 1, -14.08342772457722], 
     Hue[0.9373025994425332, 1, -13.908172906340381`], 
     Hue[0.9373025994425339, 1, -13.709185307895256`], 
     Hue[0.9373025994425349, 1, -13.51183090847313], 
     Hue[0.9373025994425362, 1, -13.334942891213302`], 
     Hue[0.9373025994425385, 1, -13.137588491791185`], 
     Hue[0.9373025994425414, 1, -12.960700474531368`], 
     Hue[0.9373025994425462, 1, -12.763346075109268`], 
     Hue[0.9373025994425528, 1, -12.586458057849478`], 
     Hue[0.9373025994425634, 1, -12.38910365842742], 
     Hue[0.9373025994425777, 1, -12.212215641167688`], 
     Hue[0.9373025994426012, 1, -12.014861241745722`], 
     Hue[0.9373025994426325, 1, -11.83797322448611], 
     Hue[0.9373025994426842, 1, -11.640618825064346`], 
     Hue[0.9373025994427531, 1, -11.463730807805003`], 
     Hue[0.937302599442867, 1, -11.266376408383685`], 
     Hue[0.9373025994430181, 1, -11.089488391124936`], 
     Hue[0.9373025994432685, 1, -10.8921339917046], 
     Hue[0.9373025994436008, 1, -10.715245974447148`], 
     Hue[0.9373025994441515, 1, -10.517891575028969`], 
     Hue[0.9373025994448823, 1, -10.341003557774378`], 
     Hue[0.9373025994460928, 1, -10.143649158360937`], 
     Hue[0.9373025994478283, 1, -9.955066065592248], 
     Hue[0.9373025994504461, 1, -9.764290146169648], 
     Hue[0.9373025994541773, 1, -9.580823648955864], 
     Hue[0.9373025994599331, 1, -9.390047729555794], 
     Hue[0.9373025994681368, 1, -9.206581232374122], 
     Hue[0.9373025994807924, 1, -9.015805313023593], 
     Hue[0.9373025994988301, 1, -8.832338815912529], 
     Hue[0.9373025995266563, 1, -8.641562896670928], 
     Hue[0.9373025995663162, 1, -8.458096399715114], 
     Hue[0.9373025996274984, 1, -8.267320480713007], 
     Hue[0.9373025997147, 1, -8.083853984098544], 
     Hue[0.9373025998492227, 1, -7.893078065623031], 
     Hue[0.9373026000409553, 1, -7.709611569759105], 
     Hue[0.9373026003367342, 1, -7.518835652441418], 
     Hue[0.9373026007583019, 1, -7.335369158227716], 
     Hue[0.937302601408639, 1, -7.144593243455776], 
     Hue[0.9373026023355513, 1, -6.961126752870478], 
     Hue[0.9373026037654653, 1, -6.770350843695938], 
     Hue[0.9373026058034927, 1, -6.586884361088503], 
     Hue[0.9373026089474836, 1, -6.396108464221124], 
     Hue[0.9373026136017899, 1, -6.206794462638053], 
     Hue[0.9373026204541889, 1, -6.019307832387612], 
     Hue[0.9373026305748734, 1, -5.832552167823727], 
     Hue[0.9373026456414218, 1, -5.645065596551351], 
     Hue[0.9373026678940278, 1, -5.458310019095404], 
     Hue[0.9373027010212154, 1, -5.270823577499613], 
     Hue[0.93730274994853, 1, -5.084068191570041], 
     Hue[0.9373028227859628, 1, -4.896582035097189], 
     Hue[0.9373029303633024, 1, -4.709827070280764], 
     Hue[0.9373031013990318, 1, -4.5119256922478], 
     Hue[0.9373033315351205, 1, -4.332663765179496], 
     Hue[0.9373036820720883, 1, -4.146824222637249], 
     Hue[0.937304209093267, 1, -3.958427649540072], 
     Hue[0.9373050321069719, 1, -3.7622669407172262`], 
     Hue[0.9373061494308503, 1, -3.5827372807768425`], 
     Hue[0.9373079546637946, 1, -3.3874516190354775`], 
     Hue[0.9373104164156092, 1, -3.2077945621277095`], 
     Hue[0.9373143803333672, 1, -3.0129584007169585`], 
     Hue[0.9373206793684671, 1, -2.809504757620571], 
     Hue[0.9373285130708731, 1, -2.6385205464404873`], 
     Hue[0.9373423392527778, 1, -2.4354179397409954`], 
     Hue[0.9373595497061389, 1, -2.2645011381496998`], 
     Hue[0.9373899135750955, 1, -2.061517494168018], 
     Hue[0.9374276884482619, 1, -1.8907487516297496`], 
     Hue[0.9374942760959568, 1, -1.688026262778375], 
     Hue[0.9375770138742955, 1, -1.5175823077411887`], 
     Hue[0.9377225847193496, 1, -1.3154320442917078`], 
     Hue[0.9379149933176398, 1, -1.136283561877628], 
     Hue[0.9382079910739044, 1, -0.9505637851670492], 
     Hue[0.9386410783424853, 1, -0.7648791065923433], 
     Hue[0.9392787212672169, 1, -0.5798245581179615], 
     Hue[0.9402698150642846, 1, -0.3867581834178213], 
     Hue[0.9416564413492708, 1, -0.2046584579110866], 
     Hue[0.9437720486681683, 1, -0.016614673473870134`], 
     Hue[0.9469248922532297, 1, 0.17179774181283103`], 
     Hue[0.9515964842236706, 1, 0.3594293038544558], 
     Hue[0.9585681638778369, 1, 0.5473510247753475], 
     Hue[0.9689200993965549, 1, 0.7340320885184648], 
     Hue[0.9846611938834313, 1, 0.9220478660070415], 
     Hue[1.0626974005574636`, 1, -17.264488266373966`], 
     Hue[1.0626974005574636`, 1, -17.07736705803298], 
     Hue[1.0626974005574636`, 1, -16.90742299186392], 
     Hue[1.0626974005574636`, 1, -16.70312464135101], 
     Hue[1.0626974005574636`, 1, -16.53318057518195], 
     Hue[1.0626974005574636`, 1, -16.32888222466904], 
     Hue[1.0626974005574636`, 1, -16.15893815849998], 
     Hue[1.0626974005574636`, 1, -15.954639807987068`], 
     Hue[1.0626974005574636`, 1, -15.784695741818005`], 
     Hue[1.0626974005574636`, 1, -15.580397391305098`], 
     Hue[1.0626974005574634`, 1, -15.407712291810729`], 
     Hue[1.0626974005574634`, 1, -15.206154974623129`], 
     Hue[1.0626974005574634`, 1, -15.033469875128759`], 
     Hue[1.0626974005574634`, 1, -14.831912557941154`], 
     Hue[1.0626974005574632`, 1, -14.657856941784138`], 
     Hue[1.0626974005574632`, 1, -14.457670141259188`], 
     Hue[1.062697400557463, 1, -14.283614525102164`], 
     Hue[1.0626974005574628`, 1, -14.08342772457722], 
     Hue[1.0626974005574623`, 1, -13.908172906340381`], 
     Hue[1.0626974005574616`, 1, -13.709185307895256`], 
     Hue[1.0626974005574605`, 1, -13.51183090847313], 
     Hue[1.0626974005574592`, 1, -13.334942891213302`], 
     Hue[1.062697400557457, 1, -13.137588491791185`], 
     Hue[1.062697400557454, 1, -12.960700474531368`], 
     Hue[1.0626974005574492`, 1, -12.763346075109268`], 
     Hue[1.0626974005574428`, 1, -12.586458057849478`], 
     Hue[1.0626974005574321`, 1, -12.38910365842742], 
     Hue[1.062697400557418, 1, -12.212215641167688`], 
     Hue[1.0626974005573944`, 1, -12.014861241745722`], 
     Hue[1.062697400557363, 1, -11.83797322448611], 
     Hue[1.0626974005573113`, 1, -11.640618825064346`], 
     Hue[1.0626974005572425`, 1, -11.463730807805003`], 
     Hue[1.0626974005571286`, 1, -11.266376408383685`], 
     Hue[1.0626974005569774`, 1, -11.089488391124934`], 
     Hue[1.062697400556727, 1, -10.8921339917046], 
     Hue[1.0626974005563947`, 1, -10.715245974447148`], 
     Hue[1.062697400555844, 1, -10.517891575028969`], 
     Hue[1.0626974005551133`, 1, -10.341003557774378`], 
     Hue[1.0626974005539027`, 1, -10.143649158360937`], 
     Hue[1.0626974005521672`, 1, -9.955066065592248], 
     Hue[1.0626974005495493`, 1, -9.764290146169648], 
     Hue[1.0626974005458183`, 1, -9.580823648955864], 
     Hue[1.0626974005400625`, 1, -9.390047729555794], 
     Hue[1.0626974005318588`, 1, -9.206581232374122], 
     Hue[1.0626974005192031`, 1, -9.015805313023593], 
     Hue[1.0626974005011653`, 1, -8.83233881591253], 
     Hue[1.0626974004733392`, 1, -8.641562896670928], 
     Hue[1.0626974004336793`, 1, -8.458096399715114], 
     Hue[1.0626974003724972`, 1, -8.267320480713007], 
     Hue[1.0626974002852956`, 1, -8.083853984098544], 
     Hue[1.0626974001507727`, 1, -7.893078065623031], 
     Hue[1.0626973999590401`, 1, -7.709611569759105], 
     Hue[1.0626973996632614`, 1, -7.518835652441418], 
     Hue[1.0626973992416937`, 1, -7.335369158227716], 
     Hue[1.0626973985913566`, 1, -7.144593243455776], 
     Hue[1.0626973976644443`, 1, -6.961126752870478], 
     Hue[1.06269739623453, 1, -6.770350843695938], 
     Hue[1.0626973941965028`, 1, -6.586884361088503], 
     Hue[1.062697391052512, 1, -6.396108464221124], 
     Hue[1.0626973863982057`, 1, -6.206794462638053], 
     Hue[1.0626973795458066`, 1, -6.019307832387612], 
     Hue[1.062697369425122, 1, -5.832552167823727], 
     Hue[1.0626973543585736`, 1, -5.645065596551351], 
     Hue[1.0626973321059676`, 1, -5.458310019095404], 
     Hue[1.0626972989787802`, 1, -5.270823577499613], 
     Hue[1.0626972500514655`, 1, -5.084068191570041], 
     Hue[1.0626971772140328`, 1, -4.896582035097189], 
     Hue[1.062697069636693, 1, -4.709827070280764], 
     Hue[1.0626968986009637`, 1, -4.5119256922478], 
     Hue[1.062696668464875, 1, -4.332663765179496], 
     Hue[1.0626963179279072`, 1, -4.14682422263725], 
     Hue[1.0626957909067285`, 1, -3.958427649540072], 
     Hue[1.0626949678930235`, 1, -3.7622669407172262`], 
     Hue[1.0626938505691452`, 1, -3.5827372807768425`], 
     Hue[1.062692045336201, 1, -3.3874516190354775`], 
     Hue[1.0626895835843864`, 1, -3.2077945621277095`], 
     Hue[1.0626856196666283`, 1, -3.0129584007169585`], 
     Hue[1.0626793206315284`, 1, -2.809504757620571], 
     Hue[1.0626714869291225`, 1, -2.6385205464404873`], 
     Hue[1.0626576607472178`, 1, -2.4354179397409954`], 
     Hue[1.0626404502938565`, 1, -2.2645011381496998`], 
     Hue[1.0626100864249, 1, -2.061517494168018], 
     Hue[1.0625723115517336`, 1, -1.8907487516297492`], 
     Hue[1.0625057239040387`, 1, -1.688026262778375], 
     Hue[1.0624229861257, 1, -1.5175823077411892`], 
     Hue[1.062277415280646, 1, -1.3154320442917082`], 
     Hue[1.0620850066823557`, 1, -1.136283561877628], 
     Hue[1.061792008926091, 1, -0.9505637851670492], 
     Hue[1.0613589216575103`, 1, -0.7648791065923435], 
     Hue[1.0607212787327787`, 1, -0.5798245581179617], 
     Hue[1.059730184935711, 1, -0.38675818341782153`], 
     Hue[1.058343558650725, 1, -0.20465845791108683`], 
     Hue[1.0562279513318276`, 1, -0.016614673473870578`], 
     Hue[1.0530751077467664`, 1, 0.17179774181283036`], 
     Hue[1.0484035157763258`, 1, 0.35942930385445493`], 
     Hue[1.04143183612216, 1, 0.5473510247753463], 
     Hue[1.0310799006034428`, 1, 0.7340320885184635], 
     Hue[1.0153388061165676`, 1, 0.9220478660070406], 
     Hue[1.1880922016723952`, 1, -17.264488266373966`], 
     Hue[1.1880922016723952`, 1, -17.07736705803298], 
     Hue[1.1880922016723952`, 1, -16.90742299186392], 
     Hue[1.1880922016723952`, 1, -16.70312464135101], 
     Hue[1.1880922016723952`, 1, -16.53318057518195], 
     Hue[1.1880922016723952`, 1, -16.32888222466904], 
     Hue[1.1880922016723952`, 1, -16.15893815849998], 
     Hue[1.1880922016723952`, 1, -15.954639807987068`], 
     Hue[1.1880922016723952`, 1, -15.784695741818005`], 
     Hue[1.1880922016723952`, 1, -15.580397391305098`], 
     Hue[1.1880922016723952`, 1, -15.407712291810729`], 
     Hue[1.188092201672395, 1, -15.206154974623129`], 
     Hue[1.188092201672395, 1, -15.033469875128759`], 
     Hue[1.1880922016723947`, 1, -14.831912557941154`], 
     Hue[1.1880922016723945`, 1, -14.657856941784134`], 
     Hue[1.1880922016723943`, 1, -14.457670141259184`], 
     Hue[1.1880922016723938`, 1, -14.283614525102161`], 
     Hue[1.1880922016723932`, 1, -14.083427724577216`], 
     Hue[1.188092201672392, 1, -13.908172906340374`], 
     Hue[1.1880922016723905`, 1, -13.709185307895247`], 
     Hue[1.188092201672388, 1, -13.511830908473115`], 
     Hue[1.188092201672385, 1, -13.334942891213284`], 
     Hue[1.1880922016723794`, 1, -13.137588491791156`], 
     Hue[1.1880922016723725`, 1, -12.960700474531327`], 
     Hue[1.1880922016723607`, 1, -12.763346075109208`], 
     Hue[1.188092201672345, 1, -12.58645805784939], 
     Hue[1.1880922016723192`, 1, -12.389103658427286`], 
     Hue[1.188092201672285, 1, -12.212215641167493`], 
     Hue[1.1880922016722282`, 1, -12.014861241745429`], 
     Hue[1.1880922016721527`, 1, -11.837973224485683`], 
     Hue[1.188092201672028, 1, -11.6406188250637], 
     Hue[1.1880922016718622`, 1, -11.463730807804067`], 
     Hue[1.1880922016715876`, 1, -11.266376408382268`], 
     Hue[1.1880922016712232`, 1, -11.08948839112288], 
     Hue[1.1880922016706195`, 1, -10.892133991701483`], 
     Hue[1.1880922016698183`, 1, -10.715245974442626`], 
     Hue[1.188092201668491, 1, -10.517891575022116`], 
     Hue[1.1880922016667295`, 1, -10.341003557764433`], 
     Hue[1.188092201663811, 1, -10.143649158345868`], 
     Hue[1.1880922016596271`, 1, -9.955066065569838], 
     Hue[1.1880922016533164`, 1, -9.764290146136162], 
     Hue[1.1880922016443218`, 1, -9.58082364890659], 
     Hue[1.1880922016304463`, 1, -9.390047729482164], 
     Hue[1.1880922016106694`, 1, -9.206581232265783], 
     Hue[1.1880922015801607`, 1, -9.015805312861705], 
     Hue[1.188092201536677, 1, -8.832338815674321], 
     Hue[1.1880922014695967`, 1, -8.64156289631498], 
     Hue[1.188092201373988, 1, -8.458096399191358], 
     Hue[1.1880922012264965`, 1, -8.267320479930378], 
     Hue[1.1880922010162793`, 1, -8.083853982946948], 
     Hue[1.1880922006919852`, 1, -7.893078063902242], 
     Hue[1.1880922002297754`, 1, -7.709611567227056], 
     Hue[1.1880921995167408`, 1, -7.5188356486578725`], 
     Hue[1.1880921985004673`, 1, -7.335369152660438], 
     Hue[1.1880921969326987`, 1, -7.144593235136793], 
     Hue[1.1880921946981902`, 1, -6.961126740629546], 
     Hue[1.1880921912510944`, 1, -6.77035082540476], 
     Hue[1.1880921863380194`, 1, -6.586884334174034], 
     Hue[1.188092178758796, 1, -6.396108424003815], 
     Hue[1.188092167538652, 1, -6.206794402727465], 
     Hue[1.188092151019561, 1, -6.019307743483189], 
     Hue[1.1880921266216045`, 1, -5.83255203609672], 
     Hue[1.1880920903006345`, 1, -5.645065401074858], 
     Hue[1.1880920366561978`, 1, -5.458309729463846], 
     Hue[1.1880919567963293`, 1, -5.270823147700585], 
     Hue[1.188091838846933, 1, -5.084067554750289], 
     Hue[1.1880916632570686`, 1, -4.896581090088714], 
     Hue[1.188091403918977, 1, -4.709825670093068], 
     Hue[1.1880909915998958`, 1, -4.511923568378187], 
     Hue[1.1880904368044742`, 1, -4.3326606675664925`], 
     Hue[1.1880895917509584`, 1, -4.146819641850412], 
     Hue[1.1880883212299516`, 1, -3.9584208388607127`], 
     Hue[1.188086337118462, 1, -3.7622566477931363`], 
     Hue[1.1880836434410087`, 1, -3.582722260412269], 
     Hue[1.1880792912187366`, 1, -3.3874289607992276`], 
     Hue[1.188073355974575, 1, -3.20776148858957], 
     Hue[1.1880637984854197`, 1, -3.0129085571081893`], 
     Hue[1.1880507047255604`, 1, -2.8328272734363944`], 
     Hue[1.188029717849366, 1, -2.6384155574810517`], 
     Hue[1.1879963669526579`, 1, -2.435249834356809], 
     Hue[1.1879548419545898`, 1, -2.2642602557772555`], 
     Hue[1.1878815496584594`, 1, -2.0611482517714386`], 
     Hue[1.1877903133839238`, 1, -1.8902198881466685`], 
     Hue[1.1876293373303584`, 1, -1.6872162120691467`], 
     Hue[1.1874290526527467`, 1, -1.5164232012346475`], 
     Hue[1.187075952174455, 1, -1.3136596973715446`], 
     Hue[1.1866371286492372`, 1, -1.1431679171293003`], 
     Hue[1.1859187096635453`, 1, -0.9525685358606004], 
     Hue[1.184875795608732, 1, -0.7664195863142611], 
     Hue[1.183288225813698, 1, -0.5758992289837952], 
     Hue[1.1809882338568298`, 1, -0.3901602773555197], 
     Hue[1.1775863908759554`, 1, -0.20449190168314413`], 
     Hue[1.1724875100858851`, 1, -0.016977718501921757`], 
     Hue[1.1648253956835073`, 1, 0.17183210993065312`], 
     Hue[1.1534128274914563`, 1, 0.35934125736088685`], 
     Hue[1.1361821994215136`, 1, 0.5462531650343478], 
     Hue[1.1091772127103678`, 1, 0.7340378207581403], 
     Hue[1.063322331718471, 1, 0.9215689340718364], 
     Hue[1.3134870027873269`, 1, -17.264488266373966`], 
     Hue[1.3134870027873269`, 1, -17.07736705803298], 
     Hue[1.3134870027873269`, 1, -16.90742299186392], 
     Hue[1.3134870027873269`, 1, -16.70312464135101], 
     Hue[1.3134870027873269`, 1, -16.53318057518195], 
     Hue[1.3134870027873267`, 1, -16.32888222466904], 
     Hue[1.3134870027873267`, 1, -16.15893815849998], 
     Hue[1.3134870027873267`, 1, -15.954639807987068`], 
     Hue[1.3134870027873267`, 1, -15.784695741818005`], 
     Hue[1.3134870027873267`, 1, -15.580397391305098`], 
     Hue[1.3134870027873267`, 1, -15.407712291810729`], 
     Hue[1.3134870027873267`, 1, -15.206154974623129`], 
     Hue[1.3134870027873267`, 1, -15.033469875128759`], 
     Hue[1.3134870027873264`, 1, -14.831912557941154`], 
     Hue[1.3134870027873262`, 1, -14.657856941784134`], 
     Hue[1.3134870027873258`, 1, -14.457670141259184`], 
     Hue[1.3134870027873253`, 1, -14.283614525102157`], 
     Hue[1.3134870027873247`, 1, -14.08342772457721], 
     Hue[1.3134870027873238`, 1, -13.908172906340367`], 
     Hue[1.3134870027873222`, 1, -13.709185307895234`], 
     Hue[1.3134870027873198`, 1, -13.5118309084731], 
     Hue[1.3134870027873164`, 1, -13.334942891213258`], 
     Hue[1.3134870027873111`, 1, -13.137588491791117`], 
     Hue[1.313487002787304, 1, -12.960700474531272`], 
     Hue[1.3134870027872925`, 1, -12.763346075109121`], 
     Hue[1.313487002787277, 1, -12.586458057849265`], 
     Hue[1.3134870027872512`, 1, -12.3891036584271], 
     Hue[1.313487002787217, 1, -12.21221564116722], 
     Hue[1.3134870027871606`, 1, -12.014861241745015`], 
     Hue[1.3134870027870855`, 1, -11.837973224485083`], 
     Hue[1.313487002786961, 1, -11.640618825062791`], 
     Hue[1.313487002786796, 1, -11.463730807802747`], 
     Hue[1.3134870027865226`, 1, -11.26637640838027], 
     Hue[1.3134870027861596`, 1, -11.089488391119977`], 
     Hue[1.3134870027855585`, 1, -10.892133991697087`], 
     Hue[1.3134870027847607`, 1, -10.715245974436245`], 
     Hue[1.3134870027834387`, 1, -10.517891575012449`], 
     Hue[1.3134870027816845`, 1, -10.341003557750405`], 
     Hue[1.313487002778778, 1, -10.143649158324614`], 
     Hue[1.3134870027746115`, 1, -9.955066065538222], 
     Hue[1.3134870027683265`, 1, -9.764290146088921], 
     Hue[1.313487002759369, 1, -9.580823648837079], 
     Hue[1.3134870027455505`, 1, -9.3900477293783], 
     Hue[1.3134870027258552`, 1, -9.206581232112947], 
     Hue[1.313487002695472, 1, -9.01580531263333], 
     Hue[1.3134870026521672`, 1, -8.83233881533828], 
     Hue[1.3134870025853629`, 1, -8.641562895812847], 
     Hue[1.313487002490148, 1, -8.458096398452495], 
     Hue[1.3134870023432632`, 1, -8.26732047882632], 
     Hue[1.3134870021339116`, 1, -8.08385398132239], 
     Hue[1.3134870018109521`, 1, -7.893078061474724], 
     Hue[1.3134870013506448`, 1, -7.7096115636550975`], 
     Hue[1.313487000640545, 1, -7.518835643320421], 
     Hue[1.3134869996284544`, 1, -7.335369144806669], 
     Hue[1.3134869980671389`, 1, -7.144593223401192], 
     Hue[1.3134869958418272`, 1, -6.961126723361251], 
     Hue[1.3134869924089194`, 1, -6.770350799601374], 
     Hue[1.3134869875160657`, 1, -6.586884296205756], 
     Hue[1.3134869799680366`, 1, -6.396108367269202], 
     Hue[1.3134869687940713`, 1, -6.206794318211507], 
     Hue[1.3134869523429653`, 1, -6.019307618065565], 
     Hue[1.3134869280454142`, 1, -5.832551850269162], 
     Hue[1.3134868918739055`, 1, -5.645065125315681], 
     Hue[1.3134868384501912`, 1, -5.4583093208796845`], 
     Hue[1.3134867589188544`, 1, -5.270822541381301], 
     Hue[1.313486641454563, 1, -5.084066656385059], 
     Hue[1.3134864665866013`, 1, -4.896579756957819], 
     Hue[1.3134862083141405`, 1, -4.709823694832703], 
     Hue[1.3134857976878582`, 1, -4.511920572200681], 
     Hue[1.3134852451673944`, 1, -4.332656297691709], 
     Hue[1.3134844035729087`, 1, -4.146813179579124], 
     Hue[1.3134831382385301`, 1, -3.958411230695707], 
     Hue[1.3134811621932234`, 1, -3.7622421267952006`], 
     Hue[1.313478479401196, 1, -3.5827010695519723`], 
     Hue[1.313474144607485, 1, -3.387396993124203], 
     Hue[1.3134682328140916`, 1, -3.207714823879873], 
     Hue[1.3134587123186565`, 1, -3.0128382248824446`], 
     Hue[1.3134456746570575`, 1, -2.832804470329573], 
     Hue[1.313424760128725, 1, -2.6382933043197205`], 
     Hue[1.3133915148195612`, 1, -2.4350124853987714`], 
     Hue[1.3133501104222605`, 1, -2.263920026783823], 
     Hue[1.313276987201562, 1, -2.0606263830468903`], 
     Hue[1.3131858832060783`, 1, -1.889471811651844], 
     Hue[1.3130249287015188`, 1, -1.686068754171621], 
     Hue[1.3128242924095264`, 1, -1.5147783691612398`], 
     Hue[1.3124695462512765`, 1, -1.3111367399475313`], 
     Hue[1.3120268437268552`, 1, -1.1395514272238831`], 
     Hue[1.3112976525265523`, 1, -0.9471565105556299], 
     Hue[1.3102292189116553`, 1, -0.7583895810802199], 
     Hue[1.3086407166959466`, 1, -0.5697762111305589], 
     Hue[1.306441772733037, 1, -0.3921423260197816], 
     Hue[1.3030137957727668`, 1, -0.20400704831221694`], 
     Hue[1.2979061978862143`, 1, -0.015743921862764854`], 
     Hue[1.2903361736942842`, 1, 0.17143445346789532`], 
     Hue[1.2790115486698983`, 1, 0.35854327786172524`], 
     Hue[1.1342914023350303`, 1, 0.7338888718976782], 
     Hue[1.261796664764585, 1, 0.5462696299157047], 
     Hue[1.2347673199508822`, 1, 0.7349177458109508], 
     Hue[1.0842564320552006`, 1, 0.9217131923177229], 
     Hue[1.189369199389704, 1, 0.9215683028033703], 
     Hue[1.4388818039022584`, 1, -17.264488266373966`], 
     Hue[1.4388818039022584`, 1, -17.07736705803298], 
     Hue[1.4388818039022584`, 1, -16.90742299186392], 
     Hue[1.4388818039022584`, 1, -16.70312464135101], 
     Hue[1.4388818039022584`, 1, -16.53318057518195], 
     Hue[1.4388818039022584`, 1, -16.32888222466904], 
     Hue[1.4388818039022584`, 1, -16.15893815849998], 
     Hue[1.4388818039022584`, 1, -15.954639807987068`], 
     Hue[1.4388818039022584`, 1, -15.784695741818005`], 
     Hue[1.4388818039022584`, 1, -15.580397391305098`], 
     Hue[1.4388818039022584`, 1, -15.407712291810729`], 
     Hue[1.4388818039022584`, 1, -15.206154974623129`], 
     Hue[1.4388818039022584`, 1, -15.033469875128759`], 
     Hue[1.4388818039022584`, 1, -14.831912557941154`], 
     Hue[1.4388818039022582`, 1, -14.65785694178413], 
     Hue[1.438881803902258, 1, -14.45767014125918], 
     Hue[1.438881803902258, 1, -14.283614525102157`], 
     Hue[1.4388818039022575`, 1, -14.083427724577206`], 
     Hue[1.438881803902257, 1, -13.908172906340361`], 
     Hue[1.4388818039022566`, 1, -13.709185307895227`], 
     Hue[1.4388818039022555`, 1, -13.511830908473085`], 
     Hue[1.4388818039022542`, 1, -13.334942891213242`], 
     Hue[1.4388818039022522`, 1, -13.13758849179109], 
     Hue[1.4388818039022493`, 1, -12.960700474531233`], 
     Hue[1.4388818039022444`, 1, -12.763346075109062`], 
     Hue[1.4388818039022382`, 1, -12.586458057849178`], 
     Hue[1.4388818039022278`, 1, -12.389103658426967`], 
     Hue[1.4388818039022138`, 1, -12.21221564116703], 
     Hue[1.438881803902191, 1, -12.014861241744725`], 
     Hue[1.4388818039021603`, 1, -11.837973224484662`], 
     Hue[1.4388818039021096`, 1, -11.640618825062154`], 
     Hue[1.4388818039020426`, 1, -11.46373080780182], 
     Hue[1.4388818039019315`, 1, -11.266376408378866`], 
     Hue[1.4388818039017839`, 1, -11.089488391117941`], 
     Hue[1.4388818039015394`, 1, -10.892133991694001`], 
     Hue[1.4388818039012152`, 1, -10.715245974431767`], 
     Hue[1.4388818039006777`, 1, -10.517891575005663`], 
     Hue[1.4388818038999645`, 1, -10.341003557740558`], 
     Hue[1.4388818038987827`, 1, -10.143649158309698`], 
     Hue[1.4388818038970888`, 1, -9.955066065516036], 
     Hue[1.4388818038945335`, 1, -9.764290146055767], 
     Hue[1.4388818038908917`, 1, -9.580823648788295], 
     Hue[1.4388818038852735`, 1, -9.390047729305403], 
     Hue[1.438881803877266, 1, -9.206581232005684], 
     Hue[1.4388818038649132`, 1, -9.015805312473049], 
     Hue[1.4388818038473068`, 1, -8.832338815102435], 
     Hue[1.4388818038201463`, 1, -8.641562895460433], 
     Hue[1.438881803781435, 1, -8.458096397933938], 
     Hue[1.4388818037217164`, 1, -8.26732047805146], 
     Hue[1.4388818036366007`, 1, -8.083853980182221], 
     Hue[1.4388818035052957`, 1, -7.8930780597710095`], 
     Hue[1.4388818033181492`, 1, -7.709611561148173], 
     Hue[1.4388818030294455`, 1, -7.5188356395744185`], 
     Hue[1.4388818026179617`, 1, -7.335369139294628], 
     Hue[1.4388818019831806`, 1, -7.144593215164751], 
     Hue[1.4388818010784397`, 1, -6.961126711241778], 
     Hue[1.4388817996827288`, 1, -6.770350781491686], 
     Hue[1.4388817976934503`, 1, -6.586884269558336], 
     Hue[1.438881794624662, 1, -6.396108327450928], 
     Hue[1.438881790081683, 1, -6.20679425889534], 
     Hue[1.4388817833931857`, 1, -6.019307530043207], 
     Hue[1.4388817735145716`, 1, -5.832551719849028], 
     Hue[1.4388817588083795`, 1, -5.6450649317784], 
     Hue[1.4388817370879787`, 1, -5.458309034121124], 
     Hue[1.4388817047530245`, 1, -5.270822115845056], 
     Hue[1.4388816569956828`, 1, -5.084066025880017], 
     Hue[1.4388815858997108`, 1, -4.896578821317134], 
     Hue[1.43888148089385, 1, -4.709822308518558], 
     Hue[1.4388813139450702`, 1, -4.511918469359698], 
     Hue[1.4388810893054218`, 1, -4.332653230718207], 
     Hue[1.4388807471344616`, 1, -4.146808644034203], 
     Hue[1.4388802326776329`, 1, -3.9584044871293615`], 
     Hue[1.438879429251973, 1, -3.762231934938937], 
     Hue[1.4388783384567165`, 1, -3.582686195962384], 
     Hue[1.4388765759293647`, 1, -3.3873745545619043`], 
     Hue[1.4388741721033615`, 1, -3.207682067536492], 
     Hue[1.4388703007041512`, 1, -3.012788850913286], 
     Hue[1.4388650018836107`, 1, -2.8328237280733273`], 
     Hue[1.4388564942118884`, 1, -2.638221784707812], 
     Hue[1.4388429679124137`, 1, -2.434845764127523], 
     Hue[1.4388261198174763`, 1, -2.263680951196662], 
     Hue[1.4387963522938034`, 1, -2.060259431943689], 
     Hue[1.4387592425848807`, 1, -1.888945375600186], 
     Hue[1.4386936194364042`, 1, -1.6852601058687362`], 
     Hue[1.4386117081418135`, 1, -1.5136171295661642`], 
     Hue[1.4384665818298006`, 1, -1.3093499000689535`], 
     Hue[1.4382849342279704`, 1, -1.1369799585416522`], 
     Hue[1.4380072231479888`, 1, -0.9555094593059092], 
     Hue[1.4375551332148158`, 1, -0.7575880463527733], 
     Hue[1.436950152201892, 1, -0.5791353397473549], 
     Hue[1.436006349446012, 1, -0.3901777553680421], 
     Hue[1.3915735077389608`, 1, 0.1709372229768651], 
     Hue[1.4346191818115888`, 1, -0.20321367094868514`], 
     Hue[1.4325697639066575`, 1, -0.01680855240882928], 
     Hue[1.4294648597004893`, 1, 0.17306335548743335`], 
     Hue[1.285729035846081, 1, 0.5461477581064187], 
     Hue[1.4249267769914296`, 1, 0.3595630904500211], 
     Hue[1.4181256136092875`, 1, 0.547401903022078], 
     Hue[1.2183141245176823`, 1, 0.9216067976078359], 
     Hue[1.2882988155787103`, 1, 1.1095459260876435`], 
     Hue[1.40802639513818, 1, 0.7340919467738657], 
     Hue[1.3927174335343295`, 1, 0.9217675090788262], 
     Hue[1.3690669860107796`, 1, 1.1095926339905646`], 
     Hue[1.1149909607501183`, 1, 1.1093436454254093`], 
     Hue[1.1136038565354434`, 1, 1.297321955707412], 
     Hue[1.3302196916279179`, 1, 1.2975697972983293`], 
     Hue[1.0481848493616905`, 1, 1.1093625711749613`], 
     Hue[1.0474293889294377`, 1, 1.2971491687131556`], 
     Hue[1.0127841403334783`, 1, 1.10928571151032], 
     Hue[1.0086500480711778`, 1, 1.1092962370834694`], 
     Hue[0.5642766050171901, 1, -17.264488266373966`], 
     Hue[0.5642766050171901, 1, -17.07736705803298], 
     Hue[0.5642766050171901, 1, -16.90742299186392], 
     Hue[0.5642766050171901, 1, -16.70312464135101], 
     Hue[0.5642766050171901, 1, -16.53318057518195], 
     Hue[0.5642766050171901, 1, -16.32888222466904], 
     Hue[0.5642766050171901, 1, -16.15893815849998], 
     Hue[0.5642766050171901, 1, -15.954639807987068`], 
     Hue[0.5642766050171901, 1, -15.784695741818005`], 
     Hue[0.5642766050171901, 1, -15.580397391305098`], 
     Hue[0.5642766050171901, 1, -15.407712291810729`], 
     Hue[0.5642766050171901, 1, -15.206154974623129`], 
     Hue[0.5642766050171901, 1, -15.033469875128759`], 
     Hue[0.5642766050171902, 1, -14.831912557941154`], 
     Hue[0.5642766050171903, 1, -14.65785694178413], 
     Hue[0.5642766050171905, 1, -14.45767014125918], 
     Hue[0.5642766050171907, 1, -14.283614525102157`], 
     Hue[0.564276605017191, 1, -14.083427724577206`], 
     Hue[0.5642766050171915, 1, -13.908172906340361`], 
     Hue[0.5642766050171921, 1, -13.709185307895227`], 
     Hue[0.564276605017193, 1, -13.511830908473085`], 
     Hue[0.5642766050171946, 1, -13.334942891213242`], 
     Hue[0.5642766050171968, 1, -13.13758849179109], 
     Hue[0.5642766050171998, 1, -12.960700474531233`], 
     Hue[0.5642766050172048, 1, -12.763346075109062`], 
     Hue[0.5642766050172114, 1, -12.58645805784918], 
     Hue[0.5642766050172223, 1, -12.389103658426968`], 
     Hue[0.564276605017237, 1, -12.212215641167031`], 
     Hue[0.564276605017261, 1, -12.014861241744729`], 
     Hue[0.564276605017293, 1, -11.837973224484669`], 
     Hue[0.5642766050173461, 1, -11.640618825062163`], 
     Hue[0.5642766050174164, 1, -11.463730807801834`], 
     Hue[0.5642766050175331, 1, -11.266376408378887`], 
     Hue[0.5642766050176878, 1, -11.08948839111797], 
     Hue[0.5642766050179442, 1, -10.892133991694044`], 
     Hue[0.5642766050182844, 1, -10.71524597443183], 
     Hue[0.5642766050188481, 1, -10.517891575005759`], 
     Hue[0.5642766050195963, 1, -10.341003557740699`], 
     Hue[0.5642766050208359, 1, -10.143649158309907`], 
     Hue[0.5642766050226127, 1, -9.95506606551635], 
     Hue[0.5642766050252928, 1, -9.764290146056236], 
     Hue[0.5642766050291128, 1, -9.580823648788984], 
     Hue[0.5642766050350059, 1, -9.390047729306431], 
     Hue[0.5642766050434049, 1, -9.206581232007201], 
     Hue[0.5642766050563619, 1, -9.015805312475315], 
     Hue[0.5642766050748294, 1, -8.83233881510577], 
     Hue[0.5642766051033183, 1, -8.641562895465414], 
     Hue[0.5642766051439232, 1, -8.458096397941267], 
     Hue[0.5642766052065626, 1, -8.267320478062413], 
     Hue[0.5642766052958416, 1, -8.08385398019834], 
     Hue[0.5642766054335688, 1, -7.893078059795097], 
     Hue[0.5642766056298687, 1, -7.709611561183617], 
     Hue[0.5642766059326936, 1, -7.518835639627379], 
     Hue[0.5642766063643037, 1, -7.335369139372559], 
     Hue[0.5642766070301328, 1, -7.144593215281197], 
     Hue[0.5642766079791256, 1, -6.9611267114131214`], 
     Hue[0.5642766094431027, 1, -6.770350781747718], 
     Hue[0.5642766115296796, 1, -6.586884269935072], 
     Hue[0.5642766147485665, 1, -6.396108328013871], 
     Hue[0.5642766195137486, 1, -6.206794259733942], 
     Hue[0.5642766265293893, 1, -6.019307531287652], 
     Hue[0.5642766368911797, 1, -5.832551721692885], 
     Hue[0.5642766523166715, 1, -5.645064934514595], 
     Hue[0.5642766750994461, 1, -5.458309038175265], 
     Hue[0.5642767090159458, 1, -5.270822121861213], 
     Hue[0.5642767591091621, 1, -5.084066034793992], 
     Hue[0.5642768336825308, 1, -4.896578834545072], 
     Hue[0.5642769438243626, 1, -4.709822328118063], 
     Hue[0.5642771189388148, 1, -4.5119184990894], 
     Hue[0.5642773545658559, 1, -4.332653274078779], 
     Hue[0.5642777134727791, 1, -4.146808708157491], 
     Hue[0.5642782530922061, 1, -3.9584045824699725`], 
     Hue[0.5642790958140764, 1, -3.762232079032538], 
     Hue[0.5642802399607502, 1, -3.5826864062488966`], 
     Hue[0.5642820886936449, 1, -3.3873748718088654`], 
     Hue[0.564284610089886, 1, -3.2076825306710184`], 
     Hue[0.564288670834539, 1, -3.01278954902474], 
     Hue[0.5642942288074564, 1, -2.8328247478453816`], 
     Hue[0.5643031525528857, 1, -2.6382233210410764`], 
     Hue[0.5643173403256423, 1, -2.4348481220173976`], 
     Hue[0.5643350122701515, 1, -2.263684332880193], 
     Hue[0.5643662352001128, 1, -2.0602646237826843`], 
     Hue[0.5644051589591023, 1, -1.888952826392187], 
     Hue[0.564473989085567, 1, -1.6852715575957433`], 
     Hue[0.5645599017247478, 1, -1.5136335865849484`], 
     Hue[0.5647121129637035, 1, -1.3093752559911123`], 
     Hue[0.5649026203695171, 1, -1.1370165081951924`], 
     Hue[0.5651938592979233, 1, -0.9555632413696518], 
     Hue[0.5656679259481783, 1, -0.7576701883276897], 
     Hue[0.5663022266435811, 1, -0.5792560260597963], 
     Hue[0.5672915616516835, 1, -0.39035992375939643`], 
     Hue[0.5687451780797401, 1, -0.20348917286078194`], 
     Hue[0.5709020787705272, 1, -0.016483910668582125`], 
     Hue[0.5741416444745808, 1, 0.17243484268663511`], 
     Hue[0.5788844785082987, 1, 0.3585396030846466], 
     Hue[0.5860300178953359, 1, 0.5468765782981044], 
     Hue[0.5966728927129574, 1, 0.734251538596167], 
     Hue[0.6127617295079021, 1, 0.9216924752975828], 
     Hue[0.6377895589341072, 1, 1.1097478994607024`], 
     Hue[0.679217284901268, 1, 1.2970300325780182`], 
     Hue[0.9492893771115851, 1, 1.297187681956238], 
     Hue[0.9908266121404385, 1, 1.1093702441679874`], 
     Hue[0.6896714061321216, 1, -17.264488266373966`], 
     Hue[0.6896714061321216, 1, -17.07736705803298], 
     Hue[0.6896714061321216, 1, -16.90742299186392], 
     Hue[0.6896714061321216, 1, -16.70312464135101], 
     Hue[0.6896714061321216, 1, -16.53318057518195], 
     Hue[0.6896714061321216, 1, -16.32888222466904], 
     Hue[0.6896714061321216, 1, -16.15893815849998], 
     Hue[0.6896714061321216, 1, -15.954639807987068`], 
     Hue[0.6896714061321216, 1, -15.784695741818005`], 
     Hue[0.6896714061321217, 1, -15.580397391305098`], 
     Hue[0.6896714061321219, 1, -15.407712291810729`], 
     Hue[0.6896714061321219, 1, -15.206154974623129`], 
     Hue[0.689671406132122, 1, -15.033469875128759`], 
     Hue[0.6896714061321221, 1, -14.831912557941154`], 
     Hue[0.6896714061321223, 1, -14.657856941784134`], 
     Hue[0.6896714061321226, 1, -14.457670141259184`], 
     Hue[0.6896714061321231, 1, -14.283614525102161`], 
     Hue[0.6896714061321239, 1, -14.08342772457721], 
     Hue[0.6896714061321247, 1, -13.908172906340367`], 
     Hue[0.6896714061321264, 1, -13.709185307895236`], 
     Hue[0.6896714061321289, 1, -13.5118309084731], 
     Hue[0.6896714061321321, 1, -13.33494289121326], 
     Hue[0.6896714061321374, 1, -13.137588491791119`], 
     Hue[0.6896714061321445, 1, -12.960700474531272`], 
     Hue[0.6896714061321564, 1, -12.763346075109125`], 
     Hue[0.689671406132172, 1, -12.586458057849269`], 
     Hue[0.689671406132198, 1, -12.389103658427103`], 
     Hue[0.6896714061322324, 1, -12.212215641167226`], 
     Hue[0.6896714061322894, 1, -12.014861241745026`], 
     Hue[0.689671406132365, 1, -11.837973224485099`], 
     Hue[0.6896714061324904, 1, -11.640618825062814`], 
     Hue[0.6896714061326568, 1, -11.46373080780278], 
     Hue[0.6896714061329325, 1, -11.266376408380317`], 
     Hue[0.6896714061332984, 1, -11.089488391120046`], 
     Hue[0.6896714061339044, 1, -10.892133991697191`], 
     Hue[0.6896714061347089, 1, -10.715245974436398`], 
     Hue[0.6896714061360416, 1, -10.51789157501268], 
     Hue[0.6896714061378102, 1, -10.34100355775074], 
     Hue[0.6896714061407403, 1, -10.143649158325122`], 
     Hue[0.6896714061449409, 1, -9.955066065538979], 
     Hue[0.6896714061512771, 1, -9.764290146090051], 
     Hue[0.6896714061603079, 1, -9.580823648838741], 
     Hue[0.6896714061742393, 1, -9.390047729380782], 
     Hue[0.6896714061940954, 1, -9.206581232116605], 
     Hue[0.6896714062247267, 1, -9.015805312638792], 
     Hue[0.6896714062683851, 1, -8.832338815346318], 
     Hue[0.689671406335735, 1, -8.641562895824858], 
     Hue[0.6896714064317275, 1, -8.45809639847017], 
     Hue[0.689671406579812, 1, -8.267320478852731], 
     Hue[0.6896714067908735, 1, -8.083853981361251], 
     Hue[0.6896714071164705, 1, -7.89307806153279], 
     Hue[0.6896714075805374, 1, -7.709611563740537], 
     Hue[0.6896714082964365, 1, -7.518835643448093], 
     Hue[0.689671409316793, 1, -7.335369144994529], 
     Hue[0.6896714108908601, 1, -7.144593223681906], 
     Hue[0.689671413134346, 1, -6.961126723774307], 
     Hue[0.6896714165952907, 1, -6.77035080021859], 
     Hue[0.689671421528105, 1, -6.586884297113954], 
     Hue[0.6896714291377797, 1, -6.396108368626289], 
     Hue[0.6896714404030039, 1, -6.206794320233124], 
     Hue[0.6896714569884679, 1, -6.019307621065546], 
     Hue[0.6896714814844597, 1, -5.832551854714144], 
     Hue[0.6896715179513845, 1, -5.6450651319118235`], 
     Hue[0.6896715718114148, 1, -5.458309330652996], 
     Hue[0.6896716519922894, 1, -5.270822555884431], 
     Hue[0.6896717704159165, 1, -5.0840666778739285`], 
     Hue[0.6896719467120258, 1, -4.896579788846298], 
     Hue[0.6896722070937849, 1, -4.7098237420809745`], 
     Hue[0.6896726210735971, 1, -4.511920643869464], 
     Hue[0.6896731781063545, 1, -4.332656402219724], 
     Hue[0.6896740265737792, 1, -4.146813334158222], 
     Hue[0.6896753022412612, 1, -3.9584114605268326`], 
     Hue[0.6896772944227432, 1, -3.762242474146748], 
     Hue[0.6896799991205869, 1, -3.5827015764578363`], 
     Hue[0.6896843693053724, 1, -3.387397757838829], 
     Hue[0.6896903293574805, 1, -3.2077159402032764`], 
     Hue[0.6896999275513731, 1, -3.012839907467182], 
     Hue[0.6897130715785197, 1, -2.832806928414225], 
     Hue[0.689734156644829, 1, -2.6382970065386893`], 
     Hue[0.689767672810347, 1, -2.4350181655379695`], 
     Hue[0.6898094141474445, 1, -2.2639281707282155`], 
     Hue[0.6898831313708536, 1, -2.060638879503755], 
     Hue[0.6899749735419916, 1, -1.8894897331201161`], 
     Hue[0.69013722706134, 1, -1.6860962660959464`], 
     Hue[0.6903394734496568, 1, -1.5148178466965938`], 
     Hue[0.6906970414754132, 1, -1.3111974028330244`], 
     Hue[0.6911432207449414, 1, -1.1396385793836876`], 
     Hue[0.6918780299707121, 1, -0.9472874159594935], 
     Hue[0.6929544502907663, 1, -0.758584861922049], 
     Hue[0.6945542858339859, 1, -0.5700677658208921], 
     Hue[0.6967865995231937, 1, -0.39131528233280655`], 
     Hue[0.6053722442552468, 1, 0.17173151513013807`], 
     Hue[0.7002160929803521, 1, -0.20464449942793395`], 
     Hue[0.705348159049632, 1, -0.016700802940585513`], 
     Hue[0.7134514922057793, 1, 0.5469136563949346], 
     Hue[0.7129790637754692, 1, 0.17075492350337507`], 
     Hue[0.7246066091307755, 1, 0.3608721178312344], 
     Hue[0.7816642712079255, 1, 0.9216636078521848], 
     Hue[0.7117578655712602, 1, 1.1093992919687956`], 
     Hue[0.7417901146170947, 1, 0.5461862470924621], 
     Hue[0.7689346850079041, 1, 0.7340500254675962], 
     Hue[0.8850098150070524, 1, 1.1093320833163236`], 
     Hue[0.8863789569305148, 1, 1.2971141328062772`], 
     Hue[0.8153615097591234, 1, 0.9224029716197956], 
     Hue[0.9518473880728726, 1, 1.1097586745173338`], 
     Hue[0.9872666986633636, 1, 1.109392084902321], 
     Hue[0.8150662072470534, 1, -17.264488266373966`], 
     Hue[0.8150662072470534, 1, -17.07736705803298], 
     Hue[0.8150662072470534, 1, -16.90742299186392], 
     Hue[0.8150662072470534, 1, -16.70312464135101], 
     Hue[0.8150662072470534, 1, -16.53318057518195], 
     Hue[0.8150662072470534, 1, -16.32888222466904], 
     Hue[0.8150662072470535, 1, -16.15893815849998], 
     Hue[0.8150662072470535, 1, -15.954639807987068`], 
     Hue[0.8150662072470535, 1, -15.784695741818005`], 
     Hue[0.8150662072470536, 1, -15.580397391305098`], 
     Hue[0.8150662072470536, 1, -15.407712291810729`], 
     Hue[0.8150662072470536, 1, -15.206154974623129`], 
     Hue[0.8150662072470537, 1, -15.033469875128759`], 
     Hue[0.8150662072470538, 1, -14.831912557941154`], 
     Hue[0.815066207247054, 1, -14.657856941784134`], 
     Hue[0.8150662072470544, 1, -14.457670141259184`], 
     Hue[0.8150662072470548, 1, -14.283614525102164`], 
     Hue[0.8150662072470556, 1, -14.083427724577216`], 
     Hue[0.8150662072470565, 1, -13.908172906340374`], 
     Hue[0.815066207247058, 1, -13.709185307895249`], 
     Hue[0.8150662072470605, 1, -13.511830908473115`], 
     Hue[0.8150662072470637, 1, -13.334942891213284`], 
     Hue[0.815066207247069, 1, -13.137588491791158`], 
     Hue[0.815066207247076, 1, -12.960700474531329`], 
     Hue[0.8150662072470877, 1, -12.76334607510921], 
     Hue[0.8150662072471031, 1, -12.586458057849393`], 
     Hue[0.8150662072471287, 1, -12.389103658427292`], 
     Hue[0.8150662072471627, 1, -12.2122156411675], 
     Hue[0.8150662072472191, 1, -12.01486124174544], 
     Hue[0.8150662072472938, 1, -11.837973224485697`], 
     Hue[0.8150662072474176, 1, -11.640618825063724`], 
     Hue[0.815066207247582, 1, -11.4637308078041], 
     Hue[0.8150662072478543, 1, -11.266376408382317`], 
     Hue[0.8150662072482157, 1, -11.089488391122947`], 
     Hue[0.8150662072488143, 1, -10.892133991701588`], 
     Hue[0.8150662072496088, 1, -10.715245974442778`], 
     Hue[0.815066207250925, 1, -10.517891575022345`], 
     Hue[0.815066207252672, 1, -10.341003557764767`], 
     Hue[0.8150662072555661, 1, -10.143649158346374`], 
     Hue[0.815066207259715, 1, -9.95506606557059], 
     Hue[0.8150662072659732, 1, -9.764290146137286], 
     Hue[0.815066207274893, 1, -9.580823648908247], 
     Hue[0.8150662072886531, 1, -9.39004772948464], 
     Hue[0.815066207308265, 1, -9.206581232269423], 
     Hue[0.8150662073385196, 1, -9.015805312867144], 
     Hue[0.8150662073816409, 1, -8.832338815682327], 
     Hue[0.8150662074481627, 1, -8.641562896326942], 
     Hue[0.8150662075429748, 1, -8.458096399208959], 
     Hue[0.8150662076892379, 1, -8.267320479956679], 
     Hue[0.8150662078977038, 1, -8.083853982985648], 
     Hue[0.8150662082192965, 1, -7.8930780639600675`], 
     Hue[0.8150662086776563, 1, -7.709611567312147], 
     Hue[0.8150662093847512, 1, -7.518835648785019], 
     Hue[0.8150662103925592, 1, -7.335369152847524], 
     Hue[0.8150662119472681, 1, -7.144593235416353], 
     Hue[0.8150662141631633, 1, -6.961126741040903], 
     Hue[0.8150662175815446, 1, -6.770350826019436], 
     Hue[0.8150662224536939, 1, -6.586884335078494], 
     Hue[0.8150662299697824, 1, -6.396108425355317], 
     Hue[0.8150662410964621, 1, -6.2067944047407595`], 
     Hue[0.8150662574779488, 1, -6.019307746470821], 
     Hue[0.81506628167267, 1, -5.832552040523405], 
     Hue[0.8150663176910852, 1, -5.645065407643844], 
     Hue[0.8150663708886617, 1, -5.458309739196912], 
     Hue[0.8150664500832929, 1, -5.270823162143984], 
     Hue[0.8150665670501613, 1, -5.0840675761506295`], 
     Hue[0.8150667411773417, 1, -4.896581121845761], 
     Hue[0.8150669983551031, 1, -4.709825717146475], 
     Hue[0.8150674072394621, 1, -4.511923639751082], 
     Hue[0.8150679574132317, 1, -4.332660771662359], 
     Hue[0.8150687954269918, 1, -4.146819795789077], 
     Hue[0.8150700553635365, 1, -3.958421067736599], 
     Hue[0.8150720229449857, 1, -3.7622569936938444`], 
     Hue[0.8150746941793074, 1, -3.5827227651866815`], 
     Hue[0.8150790101360396, 1, -3.3874297222638097`], 
     Hue[0.8150848959163771, 1, -3.207762600099807], 
     Hue[0.815094373735993, 1, -3.012910232271321], 
     Hue[0.8151073583120697, 1, -2.8328297207567124`], 
     Hue[0.8151281700987943, 1, -2.6384192423125556`], 
     Hue[0.8151612425323179, 1, -2.4352554854666844`], 
     Hue[0.8152024204349191, 1, -2.264268354591904], 
     Hue[0.8152750990665345, 1, -2.0611606694792695`], 
     Hue[0.8153655695883589, 1, -1.8902376797272507`], 
     Hue[0.8155251895679015, 1, -1.6872434787142725`], 
     Hue[0.8157237781471285, 1, -1.5164622449770293`], 
     Hue[0.8160738644523641, 1, -1.313719472310251], 
     Hue[0.8165088995098331, 1, -1.1432533992527933`], 
     Hue[0.8172210147513835, 1, -0.9526959662593824], 
     Hue[0.8182545545979921, 1, -0.7666076008008058], 
     Hue[0.8198273506400886, 1, -0.5761787386182411], 
     Hue[0.8221048715548589, 1, -0.3905707156923428], 
     Hue[0.825478959969102, 1, -0.20473867807183788`], 
     Hue[0.83058975921811, 1, -0.015472793139902796`], 
     Hue[0.8381086293122803, 1, 0.1712348479084802], 
     Hue[0.8494019541175428, 1, 0.3586588318238444], 
     Hue[0.8654499273261573, 1, 0.7343396557289783], 
     Hue[0.8665379682429436, 1, 0.5463419652619743], 
     Hue[0.9157348876529754, 1, 0.921742467111029], 
     Hue[0.893348039591656, 1, 0.7345009664565776], 
     Hue[0.9386072731920138, 1, 0.9218357109821598], 
     Hue[0.9404610083619849, 1, -17.264488266373966`], 
     Hue[0.9404610083619849, 1, -17.07736705803298], 
     Hue[0.9404610083619849, 1, -16.90742299186392], 
     Hue[0.9404610083619849, 1, -16.70312464135101], 
     Hue[0.9404610083619849, 1, -16.53318057518195], 
     Hue[0.9404610083619849, 1, -16.32888222466904], 
     Hue[0.9404610083619849, 1, -16.15893815849998], 
     Hue[0.9404610083619849, 1, -15.954639807987068`], 
     Hue[0.9404610083619849, 1, -15.784695741818005`], 
     Hue[0.9404610083619849, 1, -15.580397391305098`], 
     Hue[0.9404610083619849, 1, -15.407712291810729`], 
     Hue[0.940461008361985, 1, -15.206154974623129`], 
     Hue[0.940461008361985, 1, -15.033469875128759`], 
     Hue[0.940461008361985, 1, -14.831912557941154`], 
     Hue[0.9404610083619851, 1, -14.657856941784138`], 
     Hue[0.9404610083619852, 1, -14.457670141259188`], 
     Hue[0.9404610083619854, 1, -14.283614525102164`], 
     Hue[0.9404610083619858, 1, -14.08342772457722], 
     Hue[0.9404610083619861, 1, -13.908172906340381`], 
     Hue[0.9404610083619868, 1, -13.709185307895256`], 
     Hue[0.9404610083619876, 1, -13.51183090847313], 
     Hue[0.940461008361989, 1, -13.334942891213302`], 
     Hue[0.9404610083619911, 1, -13.137588491791185`], 
     Hue[0.9404610083619939, 1, -12.96070047453137], 
     Hue[0.9404610083619985, 1, -12.763346075109268`], 
     Hue[0.9404610083620046, 1, -12.586458057849478`], 
     Hue[0.9404610083620148, 1, -12.389103658427421`], 
     Hue[0.9404610083620284, 1, -12.21221564116769], 
     Hue[0.9404610083620508, 1, -12.014861241745725`], 
     Hue[0.9404610083620806, 1, -11.837973224486115`], 
     Hue[0.9404610083621299, 1, -11.640618825064355`], 
     Hue[0.9404610083621954, 1, -11.463730807805016`], 
     Hue[0.9404610083623038, 1, -11.266376408383707`], 
     Hue[0.9404610083624477, 1, -11.089488391124965`], 
     Hue[0.9404610083626861, 1, -10.892133991704641`], 
     Hue[0.9404610083630025, 1, -10.71524597444721], 
     Hue[0.9404610083635268, 1, -10.517891575029061`], 
     Hue[0.9404610083642224, 1, -10.341003557774513`], 
     Hue[0.940461008365375, 1, -10.143649158361141`], 
     Hue[0.9404610083670274, 1, -9.955066065592554], 
     Hue[0.9404610083695197, 1, -9.764290146170106], 
     Hue[0.9404610083730719, 1, -9.580823648956537], 
     Hue[0.940461008378552, 1, -9.3900477295568], 
     Hue[0.9404610083863624, 1, -9.206581232375601], 
     Hue[0.9404610083984113, 1, -9.015805313025803], 
     Hue[0.9404610084155843, 1, -8.832338815915785], 
     Hue[0.9404610084420766, 1, -8.64156289667579], 
     Hue[0.9404610084798355, 1, -8.458096399722269], 
     Hue[0.9404610085380848, 1, -8.2673204807237], 
     Hue[0.9404610086211063, 1, -8.08385398411428], 
     Hue[0.9404610087491806, 1, -7.893078065646541], 
     Hue[0.9404610089317222, 1, -7.7096115697937], 
     Hue[0.9404610092133227, 1, -7.51883565249311], 
     Hue[0.940461009614682, 1, -7.33536915830378], 
     Hue[0.9404610102338447, 1, -7.144593243569436], 
     Hue[0.9404610111163245, 1, -6.961126753037722], 
     Hue[0.9404610124776943, 1, -6.770350843945845], 
     Hue[0.9404610144180269, 1, -6.586884361456227], 
     Hue[0.9404610174113076, 1, -6.3961084647706015`], 
     Hue[0.9404610218425054, 1, -6.206794463456594], 
     Hue[0.9404610283664281, 1, -6.019307833602287], 
     Hue[0.9404610380019679, 1, -5.832552169623475], 
     Hue[0.9404610523462869, 1, -5.645065599222089], 
     Hue[0.9404610735321928, 1, -5.4583100230525545`], 
     Hue[0.9404611050713965, 1, -5.270823583371827], 
     Hue[0.9404611516533324, 1, -5.084068200270713], 
     Hue[0.9404612209992306, 1, -4.896582048008541], 
     Hue[0.9404613234197413, 1, -4.709827089411067], 
     Hue[0.9404614862566943, 1, -4.511925721265487], 
     Hue[0.9404617053609583, 1, -4.332663807501009], 
     Hue[0.9404620390945301, 1, -4.146824285222607], 
     Hue[0.940462540852284, 1, -3.958427742591068], 
     Hue[0.9404633244136604, 1, -3.762267081343391], 
     Hue[0.9404643881767838, 1, -3.582737485989174], 
     Hue[0.9404661068723109, 1, -3.387451928593457], 
     Hue[0.940468450613959, 1, -3.207795013970033], 
     Hue[0.9404722245085573, 1, -3.0129590816433813`], 
     Hue[0.9404782215716417, 1, -2.8095058025260498`], 
     Hue[0.940485679718169, 1, -2.6385220439056365`], 
     Hue[0.9404988430237959, 1, -2.4354202356926358`], 
     Hue[0.9405152282850681, 1, -2.26450442756489], 
     Hue[0.9405441361261574, 1, -2.061522535047315], 
     Hue[0.9405800992967731, 1, -1.8907559691902314`], 
     Hue[0.940643492564395, 1, -1.68803731115792], 
     Hue[0.9407222597766202, 1, -1.5175981051718372`], 
     Hue[0.9408608408957747, 1, -1.3154561680031096`], 
     Hue[0.9410440033736658, 1, -1.1363186334756203`], 
     Hue[0.9413229050845887, 1, -0.9506154024517037], 
     Hue[0.941735121269214, 1, -0.7649549023114268], 
     Hue[0.9423419596030836, 1, -0.5799353471251896], 
     Hue[0.9432849985997468, 1, -0.3869219280313829], 
     Hue[0.9446279096673366, 1, -0.20216591329918576`], 
     Hue[0.9466255473612883, 1, -0.016201093500291863`], 
     Hue[0.9496123849990975, 1, 0.17132411731864905`], 
     Hue[0.9540495346161291, 1, 0.35878634738443127`], 
     Hue[0.9606663914927697, 1, 0.5465304968939289], 
     Hue[0.9705549544644564, 1, 0.7342013862511452], 
     Hue[0.9854535530864501, 1, 0.9217235916141265], 
     Hue[1.0658558094769164`, 1, -17.264488266373966`], 
     Hue[1.0658558094769164`, 1, -17.07736705803298], 
     Hue[1.0658558094769164`, 1, -16.90742299186392], 
     Hue[1.0658558094769164`, 1, -16.70312464135101], 
     Hue[1.0658558094769164`, 1, -16.53318057518195], 
     Hue[1.0658558094769164`, 1, -16.32888222466904], 
     Hue[1.0658558094769164`, 1, -16.15893815849998], 
     Hue[1.0658558094769164`, 1, -15.954639807987068`], 
     Hue[1.0658558094769164`, 1, -15.784695741818005`], 
     Hue[1.0658558094769164`, 1, -15.580397391305098`], 
     Hue[1.0658558094769164`, 1, -15.407712291810729`], 
     Hue[1.0658558094769164`, 1, -15.206154974623129`], 
     Hue[1.0658558094769164`, 1, -15.033469875128759`], 
     Hue[1.0658558094769162`, 1, -14.831912557941154`], 
     Hue[1.0658558094769162`, 1, -14.657856941784138`], 
     Hue[1.065855809476916, 1, -14.457670141259188`], 
     Hue[1.065855809476916, 1, -14.283614525102164`], 
     Hue[1.0658558094769155`, 1, -14.08342772457722], 
     Hue[1.065855809476915, 1, -13.90817290634038], 
     Hue[1.0658558094769144`, 1, -13.709185307895256`], 
     Hue[1.0658558094769133`, 1, -13.511830908473128`], 
     Hue[1.065855809476912, 1, -13.334942891213302`], 
     Hue[1.0658558094769097`, 1, -13.137588491791183`], 
     Hue[1.0658558094769066`, 1, -12.960700474531368`], 
     Hue[1.0658558094769015`, 1, -12.763346075109267`], 
     Hue[1.0658558094768946`, 1, -12.586458057849477`], 
     Hue[1.0658558094768835`, 1, -12.389103658427418`], 
     Hue[1.0658558094768686`, 1, -12.212215641167685`], 
     Hue[1.0658558094768438`, 1, -12.014861241745717`], 
     Hue[1.0658558094768111`, 1, -11.837973224486102`], 
     Hue[1.065855809476757, 1, -11.640618825064339`], 
     Hue[1.0658558094766848`, 1, -11.463730807804989`], 
     Hue[1.0658558094765656`, 1, -11.266376408383666`], 
     Hue[1.0658558094764072`, 1, -11.089488391124906`], 
     Hue[1.0658558094761448`, 1, -10.892133991704554`], 
     Hue[1.0658558094757968`, 1, -10.715245974447084`], 
     Hue[1.06585580947522, 1, -10.51789157502887], 
     Hue[1.0658558094744546`, 1, -10.341003557774235`], 
     Hue[1.0658558094731863`, 1, -10.14364915836072], 
     Hue[1.0658558094713682`, 1, -9.955066065591925], 
     Hue[1.065855809468626, 1, -9.764290146169168], 
     Hue[1.0658558094647175`, 1, -9.580823648955157], 
     Hue[1.065855809458688, 1, -9.390047729554738], 
     Hue[1.0658558094500943`, 1, -9.206581232372569], 
     Hue[1.065855809436837, 1, -9.015805313021273], 
     Hue[1.0658558094179418`, 1, -8.832338815909116], 
     Hue[1.0658558093887927`, 1, -8.641562896665826], 
     Hue[1.0658558093472472`, 1, -8.458096399707609], 
     Hue[1.0658558092831563`, 1, -8.267320480701791], 
     Hue[1.065855809191809, 1, -8.08385398408204], 
     Hue[1.0658558090508907`, 1, -7.893078065598369], 
     Hue[1.0658558088500427`, 1, -7.709611569722818], 
     Hue[1.065855808540202, 1, -7.518835652387195], 
     Hue[1.065855808098592, 1, -7.335369158147933], 
     Hue[1.0658558074173365`, 1, -7.1445932433365575`], 
     Hue[1.0658558064463568`, 1, -6.961126752695054], 
     Hue[1.0658558049484617`, 1, -6.770350843433808], 
     Hue[1.065855802813542, 1, -6.586884360702792], 
     Hue[1.065855799520079, 1, -6.396108463644771], 
     Hue[1.065855794644497, 1, -6.206794461779476], 
     Hue[1.0658557874663201`, 1, -6.019307831113525], 
     Hue[1.0658557768644765`, 1, -5.832552165935952], 
     Hue[1.0658557610816322`, 1, -5.645065593749984], 
     Hue[1.065855737771089, 1, -5.458310014944705], 
     Hue[1.0658557030689635`, 1, -5.27082357134018], 
     Hue[1.0658556518155378`, 1, -5.084068182443805], 
     Hue[1.0658555755152537`, 1, -4.896582021554323], 
     Hue[1.065855462823449, 1, -4.709827050214769], 
     Hue[1.0658552836562951`, 1, -4.511925661810815], 
     Hue[1.0658550425790057`, 1, -4.332663720787972], 
     Hue[1.065854675376674, 1, -4.146824156990739], 
     Hue[1.0658541232995893`, 1, -3.9584275519377874`], 
     Hue[1.065853261157604, 1, -3.7622667932127563`], 
     Hue[1.06585209071286, 1, -3.582737065527107], 
     Hue[1.0658501996531229`, 1, -3.3874512943361648`], 
     Hue[1.0658476208600152`, 1, -3.2077940881842446`], 
     Hue[1.0658434684787244`, 1, -3.0129576864834062`], 
     Hue[1.0658368699488483`, 1, -2.8095036616024123`], 
     Hue[1.0658286637693695`, 1, -2.638518975722146], 
     Hue[1.0658141801398167`, 1, -2.435415531467404], 
     Hue[1.0657961512422476`, 1, -2.2644976877958083`], 
     Hue[1.0657643432247443`, 1, -2.061512206617526], 
     Hue[1.0657247713819074`, 1, -1.8907411808129229`], 
     Hue[1.065655015200824, 1, -1.6880146734553334`], 
     Hue[1.0655683387523047`, 1, -1.5175657365076465`], 
     Hue[1.065415833710481, 1, -1.3154067380236516`], 
     Hue[1.065214251238227, 1, -1.1362467693143221`], 
     Hue[1.0649072649517703`, 1, -0.9505096311537369], 
     Hue[1.064453460031463, 1, -0.764799577600503], 
     Hue[1.0637852266345347`, 1, -0.5797082947094692], 
     Hue[1.0627463834735225`, 1, -0.3865863084357479], 
     Hue[1.0612925518237828`, 1, -0.20441182740282549`], 
     Hue[1.0590735543786634`, 1, -0.016260894514989355`], 
     Hue[1.0557913360152589`, 1, 0.17104974678791862`], 
     Hue[1.0508606843339041`, 1, 0.3600522807591203], 
     Hue[1.0436295641347093`, 1, 0.5461458936943382], 
     Hue[1.0327254966973822`, 1, 0.7338634683102729], 
     Hue[1.0162083727552107`, 1, 0.9217067238369037], 
     Hue[1.1912506105918481`, 1, -17.264488266373966`], 
     Hue[1.1912506105918481`, 1, -17.07736705803298], 
     Hue[1.1912506105918481`, 1, -16.90742299186392], 
     Hue[1.1912506105918481`, 1, -16.70312464135101], 
     Hue[1.1912506105918481`, 1, -16.53318057518195], 
     Hue[1.1912506105918481`, 1, -16.32888222466904], 
     Hue[1.1912506105918481`, 1, -16.15893815849998], 
     Hue[1.1912506105918481`, 1, -15.954639807987068`], 
     Hue[1.191250610591848, 1, -15.784695741818005`], 
     Hue[1.191250610591848, 1, -15.580397391305098`], 
     Hue[1.191250610591848, 1, -15.407712291810729`], 
     Hue[1.191250610591848, 1, -15.206154974623129`], 
     Hue[1.191250610591848, 1, -15.033469875128759`], 
     Hue[1.1912506105918477`, 1, -14.831912557941154`], 
     Hue[1.1912506105918474`, 1, -14.657856941784134`], 
     Hue[1.191250610591847, 1, -14.457670141259184`], 
     Hue[1.1912506105918466`, 1, -14.283614525102161`], 
     Hue[1.191250610591846, 1, -14.083427724577215`], 
     Hue[1.191250610591845, 1, -13.908172906340374`], 
     Hue[1.1912506105918432`, 1, -13.709185307895247`], 
     Hue[1.1912506105918408`, 1, -13.511830908473115`], 
     Hue[1.1912506105918377`, 1, -13.334942891213283`], 
     Hue[1.1912506105918323`, 1, -13.137588491791156`], 
     Hue[1.191250610591825, 1, -12.960700474531327`], 
     Hue[1.1912506105918133`, 1, -12.763346075109206`], 
     Hue[1.1912506105917975`, 1, -12.586458057849388`], 
     Hue[1.1912506105917715`, 1, -12.389103658427281`], 
     Hue[1.1912506105917369`, 1, -12.212215641167488`], 
     Hue[1.1912506105916796`, 1, -12.014861241745418`], 
     Hue[1.1912506105916036`, 1, -11.837973224485669`], 
     Hue[1.191250610591478, 1, -11.64061882506368], 
     Hue[1.1912506105913108`, 1, -11.463730807804037`], 
     Hue[1.191250610591034, 1, -11.266376408382222`], 
     Hue[1.1912506105906668`, 1, -11.089488391122808`], 
     Hue[1.1912506105900582`, 1, -10.892133991701378`], 
     Hue[1.1912506105892509`, 1, -10.715245974442473`], 
     Hue[1.1912506105879128`, 1, -10.517891575021883`], 
     Hue[1.1912506105861373`, 1, -10.341003557764095`], 
     Hue[1.1912506105831957`, 1, -10.143649158345358`], 
     Hue[1.1912506105789786`, 1, -9.955066065569078], 
     Hue[1.191250610572618, 1, -9.764290146135027], 
     Hue[1.1912506105635519`, 1, -9.58082364890492], 
     Hue[1.1912506105495662`, 1, -9.39004772947967], 
     Hue[1.1912506105296325`, 1, -9.206581232262113], 
     Hue[1.1912506104988816`, 1, -9.01580531285622], 
     Hue[1.1912506104550529`, 1, -8.832338815666251], 
     Hue[1.19125061038744, 1, -8.64156289630292], 
     Hue[1.1912506102910727`, 1, -8.458096399173613], 
     Hue[1.1912506101424105`, 1, -8.267320479903862], 
     Hue[1.1912506099305251`, 1, -8.083853982907934], 
     Hue[1.1912506096036573`, 1, -7.893078063843942], 
     Hue[1.1912506091377792`, 1, -7.709611567141272], 
     Hue[1.191250608419086, 1, -7.518835648529689], 
     Hue[1.191250607394747, 1, -7.335369152471821], 
     Hue[1.1912506058145365`, 1, -7.144593234854951], 
     Hue[1.1912506035622943`, 1, -6.961126740214831], 
     Hue[1.1912506000878418`, 1, -6.770350824785066], 
     Hue[1.1912505951357755`, 1, -6.586884333262185], 
     Hue[1.1912505874964017`, 1, -6.396108422641275], 
     Hue[1.1912505761872128`, 1, -6.206794400697729], 
     Hue[1.1912505595370226`, 1, -6.019307740471157], 
     Hue[1.1912505349454385`, 1, -5.832552031633883], 
     Hue[1.1912504983362173`, 1, -5.6450653944522236`], 
     Hue[1.1912504442660456`, 1, -5.458309719651287], 
     Hue[1.1912503637723892`, 1, -5.270823133139225], 
     Hue[1.191250244886914, 1, -5.084067533175168], 
     Hue[1.1912500679035134`, 1, -4.8965810580722975`], 
     Hue[1.1912498065072192`, 1, -4.70982562265536], 
     Hue[1.191249390915787, 1, -4.511923496422359], 
     Hue[1.19124883171719, 1, -4.332660562620417], 
     Hue[1.1912479799566946`, 1, -4.146819486654411], 
     Hue[1.1912466993515392`, 1, -3.958420608115347], 
     Hue[1.1912446994913053`, 1, -3.762256299066906], 
     Hue[1.1912419844313884`, 1, -3.5827217515142182`], 
     Hue[1.1912375976572223`, 1, -3.3874281931132035`], 
     Hue[1.1912316152859974`, 1, -3.2077603679962303`], 
     Hue[1.1912219818897236`, 1, -3.012906868251841], 
     Hue[1.1912087851052637`, 1, -2.832836225913237], 
     Hue[1.1911876310072314`, 1, -2.6384164815561473`], 
     Hue[1.1911540141499435`, 1, -2.4352441369575315`], 
     Hue[1.191112158379678, 1, -2.2642520905390535`], 
     Hue[1.1910382812041338`, 1, -2.061135731989446], 
     Hue[1.1909463149633597`, 1, -1.8902019499108647`], 
     Hue[1.1907840458520058`, 1, -1.6871887195648794`], 
     Hue[1.1905821432563033`, 1, -1.5163838321188907`], 
     Hue[1.1902261658268096`, 1, -1.3135994190107778`], 
     Hue[1.1897837232732358`, 1, -1.143081705706826], 
     Hue[1.1890592752742324`, 1, -0.9524399954727418], 
     Hue[1.1880073798008666`, 1, -0.7662298855029699], 
     Hue[1.1864056199899404`, 1, -0.5756171031756374], 
     Hue[1.1840839708738753`, 1, -0.38974576765340285`], 
     Hue[1.180663580859948, 1, -0.20459403634940676`], 
     Hue[1.1755005190838526`, 1, -0.016341373487126276`], 
     Hue[1.1678009434416559`, 1, 0.17176913871821842`], 
     Hue[1.1563598575275507`, 1, 0.35842678277375895`], 
     Hue[1.138888399076997, 1, 0.5464699143259558], 
     Hue[1.1116506503899888`, 1, 0.7340430561883693], 
     Hue[1.0649959224894476`, 1, 0.9222172056974204], 
     Hue[1.3166454117067796`, 1, -17.264488266373966`], 
     Hue[1.3166454117067796`, 1, -17.07736705803298], 
     Hue[1.3166454117067796`, 1, -16.90742299186392], 
     Hue[1.3166454117067796`, 1, -16.70312464135101], 
     Hue[1.3166454117067794`, 1, -16.53318057518195], 
     Hue[1.3166454117067796`, 1, -16.32888222466904], 
     Hue[1.3166454117067794`, 1, -16.15893815849998], 
     Hue[1.3166454117067794`, 1, -15.954639807987068`], 
     Hue[1.3166454117067794`, 1, -15.784695741818005`], 
     Hue[1.3166454117067794`, 1, -15.580397391305098`], 
     Hue[1.3166454117067794`, 1, -15.407712291810729`], 
     Hue[1.3166454117067792`, 1, -15.206154974623129`], 
     Hue[1.3166454117067792`, 1, -15.033469875128759`], 
     Hue[1.3166454117067792`, 1, -14.831912557941154`], 
     Hue[1.316645411706779, 1, -14.657856941784134`], 
     Hue[1.3166454117067785`, 1, -14.457670141259184`], 
     Hue[1.316645411706778, 1, -14.283614525102157`], 
     Hue[1.3166454117067774`, 1, -14.08342772457721], 
     Hue[1.3166454117067765`, 1, -13.908172906340367`], 
     Hue[1.3166454117067747`, 1, -13.709185307895234`], 
     Hue[1.3166454117067725`, 1, -13.511830908473097`], 
     Hue[1.3166454117067692`, 1, -13.334942891213258`], 
     Hue[1.316645411706764, 1, -13.137588491791117`], 
     Hue[1.316645411706757, 1, -12.96070047453127], 
     Hue[1.3166454117067454`, 1, -12.763346075109121`], 
     Hue[1.3166454117067299`, 1, -12.586458057849262`], 
     Hue[1.3166454117067046`, 1, -12.389103658427095`], 
     Hue[1.3166454117066706`, 1, -12.212215641167214`], 
     Hue[1.3166454117066146`, 1, -12.014861241745004`], 
     Hue[1.3166454117065403`, 1, -11.83797322448507], 
     Hue[1.3166454117064168`, 1, -11.640618825062772`], 
     Hue[1.3166454117062534`, 1, -11.463730807802717`], 
     Hue[1.316645411705982, 1, -11.266376408380221`], 
     Hue[1.3166454117056223`, 1, -11.089488391119907`], 
     Hue[1.3166454117050264`, 1, -10.892133991696982`], 
     Hue[1.3166454117042352`, 1, -10.715245974436094`], 
     Hue[1.3166454117029247`, 1, -10.51789157501222], 
     Hue[1.3166454117011854`, 1, -10.341003557750073`], 
     Hue[1.3166454116983037`, 1, -10.143649158324111`], 
     Hue[1.3166454116941728`, 1, -9.955066065537475], 
     Hue[1.3166454116879418`, 1, -9.7642901460878], 
     Hue[1.316645411679061, 1, -9.58082364883543], 
     Hue[1.3166454116653608`, 1, -9.390047729375835], 
     Hue[1.3166454116458342`, 1, -9.206581232109324], 
     Hue[1.316645411615711, 1, -9.015805312627913], 
     Hue[1.316645411572777, 1, -8.83233881533031], 
     Hue[1.3166454115065447`, 1, -8.641562895800936], 
     Hue[1.3166454114121449`, 1, -8.45809639843497], 
     Hue[1.3166454112665176`, 1, -8.267320478800132], 
     Hue[1.316645411058958, 1, -8.083853981283855], 
     Hue[1.3166454107387635`, 1, -7.893078061417142], 
     Hue[1.3166454102823968`, 1, -7.709611563570367], 
     Hue[1.3166454095783762`, 1, -7.518835643193813], 
     Hue[1.31664540857495, 1, -7.335369144620372], 
     Hue[1.3166454070270006`, 1, -7.144593223122816], 
     Hue[1.3166454048207399`, 1, -6.961126722951636], 
     Hue[1.3166454014172209`, 1, -6.7703507989893], 
     Hue[1.3166453965662543`, 1, -6.586884295305124], 
     Hue[1.3166453890828436`, 1, -6.396108365923418], 
     Hue[1.3166453780045377`, 1, -6.206794316206732], 
     Hue[1.3166453616942682`, 1, -6.0193076150905735`], 
     Hue[1.316645337604726, 1, -5.832551845861206], 
     Hue[1.316645301742878, 1, -5.645065118774484], 
     Hue[1.3166452487765183`, 1, -5.458309311187786], 
     Hue[1.3166451699260393`, 1, -5.270822526998981], 
     Hue[1.3166450534673422`, 1, -5.0840666350751915`], 
     Hue[1.3166448800963924`, 1, -4.896579725334968], 
     Hue[1.3166446240349403`, 1, -4.709823647978], 
     Hue[1.3166442169238977`, 1, -4.511920501128879], 
     Hue[1.316643669133318, 1, -4.3326561940343655`], 
     Hue[1.3166428347432078`, 1, -4.146813026287571], 
     Hue[1.3166415802402542`, 1, -3.958411002778858], 
     Hue[1.3166396211093614`, 1, -3.7622417823365915`], 
     Hue[1.3166369612797697`, 1, -3.582700566867568], 
     Hue[1.3166326635844903`, 1, -3.3873962347772233`], 
     Hue[1.3166268023784955`, 1, -3.207713716850268], 
     Hue[1.316617363332146, 1, -3.012836556301875], 
     Hue[1.3166044371732406`, 1, -2.8328020326956542`], 
     Hue[1.3165837014259196`, 1, -2.6382896328832617`], 
     Hue[1.31655074008169, 1, -2.4350068524410036`], 
     Hue[1.3165096889595203`, 1, -2.2639119504027434`], 
     Hue[1.3164371886170043`, 1, -2.0606139900362157`], 
     Hue[1.316346858819493, 1, -1.8894540381339164`], 
     Hue[1.3161872670962727`, 1, -1.686041468274148], 
     Hue[1.3159883206114074`, 1, -1.5147392139926572`], 
     Hue[1.3156365378588506`, 1, -1.3110765670787037`], 
     Hue[1.3151974897750536`, 1, -1.1394649694479526`], 
     Hue[1.3144742118163466`, 1, -0.9470266243019203], 
     Hue[1.3134142029857663`, 1, -0.7581957682330245], 
     Hue[1.3118376969972139`, 1, -0.5694867312078384], 
     Hue[1.309654306104767, 1, -0.39171924733982166`], 
     Hue[1.3062481084813076`, 1, -0.20337321304174805`], 
     Hue[1.3011673031426159`, 1, -0.014791189078607658`], 
     Hue[1.293717107124373, 1, 0.17096273208800727`], 
     Hue[1.2823776663738387`, 1, 0.35980153798862025`], 
     Hue[1.134355275075474, 1, 0.7340001015567563], 
     Hue[1.2654286675057, 1, 0.5461348927028022], 
     Hue[1.2388334805432162`, 1, 0.7339438475611211], 
     Hue[1.084331289484006, 1, 0.9219658578068453], 
     Hue[1.1938436238285732`, 1, 0.9216477717443277], 
     Hue[1.4420402128217114`, 1, -17.264488266373966`], 
     Hue[1.4420402128217114`, 1, -17.07736705803298], 
     Hue[1.4420402128217114`, 1, -16.90742299186392], 
     Hue[1.4420402128217114`, 1, -16.70312464135101], 
     Hue[1.4420402128217114`, 1, -16.53318057518195], 
     Hue[1.4420402128217114`, 1, -16.32888222466904], 
     Hue[1.4420402128217114`, 1, -16.15893815849998], 
     Hue[1.4420402128217114`, 1, -15.954639807987068`], 
     Hue[1.4420402128217114`, 1, -15.784695741818005`], 
     Hue[1.4420402128217114`, 1, -15.580397391305098`], 
     Hue[1.4420402128217114`, 1, -15.407712291810729`], 
     Hue[1.4420402128217111`, 1, -15.206154974623129`], 
     Hue[1.4420402128217111`, 1, -15.033469875128759`], 
     Hue[1.4420402128217111`, 1, -14.831912557941154`], 
     Hue[1.442040212821711, 1, -14.65785694178413], 
     Hue[1.442040212821711, 1, -14.45767014125918], 
     Hue[1.4420402128217107`, 1, -14.283614525102157`], 
     Hue[1.4420402128217105`, 1, -14.083427724577206`], 
     Hue[1.44204021282171, 1, -13.90817290634036], 
     Hue[1.4420402128217096`, 1, -13.709185307895227`], 
     Hue[1.4420402128217085`, 1, -13.511830908473085`], 
     Hue[1.4420402128217074`, 1, -13.33494289121324], 
     Hue[1.4420402128217051`, 1, -13.13758849179109], 
     Hue[1.4420402128217025`, 1, -12.960700474531231`], 
     Hue[1.442040212821698, 1, -12.76334607510906], 
     Hue[1.4420402128216918`, 1, -12.586458057849176`], 
     Hue[1.442040212821682, 1, -12.389103658426965`], 
     Hue[1.4420402128216687`, 1, -12.212215641167026`], 
     Hue[1.442040212821647, 1, -12.014861241744722`], 
     Hue[1.4420402128216179`, 1, -11.837973224484656`], 
     Hue[1.44204021282157, 1, -11.640618825062147`], 
     Hue[1.4420402128215062`, 1, -11.46373080780181], 
     Hue[1.4420402128214005`, 1, -11.266376408378848`], 
     Hue[1.4420402128212602`, 1, -11.089488391117914`], 
     Hue[1.4420402128210277`, 1, -10.89213399169396], 
     Hue[1.4420402128207193`, 1, -10.715245974431708`], 
     Hue[1.4420402128202086`, 1, -10.517891575005573`], 
     Hue[1.4420402128195304`, 1, -10.341003557740427`], 
     Hue[1.4420402128184069`, 1, -10.143649158309497`], 
     Hue[1.4420402128167966`, 1, -9.955066065515737], 
     Hue[1.4420402128143672`, 1, -9.76429014605532], 
     Hue[1.4420402128109049`, 1, -9.580823648787637], 
     Hue[1.4420402128055638`, 1, -9.39004772930442], 
     Hue[1.442040212797951, 1, -9.20658123200424], 
     Hue[1.4420402127862073`, 1, -9.015805312470892], 
     Hue[1.4420402127694691`, 1, -8.832338815099261], 
     Hue[1.4420402127436478`, 1, -8.641562895455689], 
     Hue[1.442040212706845, 1, -8.458096397926957], 
     Hue[1.4420402126500709`, 1, -8.267320478041029], 
     Hue[1.4420402125691516`, 1, -8.083853980166875], 
     Hue[1.4420402124443208`, 1, -7.893078059748077], 
     Hue[1.4420402122664018`, 1, -7.709611561114431], 
     Hue[1.4420402119919324`, 1, -7.518835639523997], 
     Hue[1.442040211600737, 1, -7.335369139220437], 
     Hue[1.4420402109972537`, 1, -7.144593215053889], 
     Hue[1.4420402101371215`, 1, -6.961126711078649], 
     Hue[1.4420402088102262`, 1, -6.770350781247928], 
     Hue[1.4420402069190295`, 1, -6.586884269199659], 
     Hue[1.442040204001548, 1, -6.39610832691497], 
     Hue[1.4420401996825614`, 1, -6.206794258096939], 
     Hue[1.4420401933238414`, 1, -6.019307528858417], 
     Hue[1.442040183932294, 1, -5.832551718093559], 
     Hue[1.4420401699511929`, 1, -5.645064929173367], 
     Hue[1.4420401493017196`, 1, -5.458309030261321], 
     Hue[1.4420401185610447`, 1, -5.270822110117289], 
     Hue[1.4420400731583851`, 1, -5.084066017393344], 
     Hue[1.4420400055678082`, 1, -4.896578808723289], 
     Hue[1.4420399057392714`, 1, -4.709822289858571], 
     Hue[1.4420397470219117`, 1, -4.511918441055116], 
     Hue[1.4420395334581255`, 1, -4.332653189436158], 
     Hue[1.4420392081578886`, 1, -4.14680858298471], 
     Hue[1.4420387190662787`, 1, -3.958404396358958], 
     Hue[1.4420379552532814`, 1, -3.762231797752518], 
     Hue[1.442036918239121, 1, -3.582685995755983], 
     Hue[1.442035242611687, 1, -3.3873742525220836`], 
     Hue[1.4420329573031303`, 1, -3.2076816266019197`], 
     Hue[1.4420292767753036`, 1, -3.01278818626456], 
     Hue[1.4420242391966018`, 1, -2.8328227571809457`], 
     Hue[1.4420161509555403`, 1, -2.6382203220109073`], 
     Hue[1.4420032914720275`, 1, -2.4348435192435858`], 
     Hue[1.441987273890808, 1, -2.2636777315725958`], 
     Hue[1.441958973573285, 1, -2.060254488874956], 
     Hue[1.4419236926704198`, 1, -1.8889382817517582`], 
     Hue[1.4418613027179914`, 1, -1.6852492025780006`], 
     Hue[1.4417834257165791`, 1, -1.513601460370458], 
     Hue[1.4416454433176322`, 1, -1.3093257570912218`], 
     Hue[1.441472730451396, 1, -1.136945155702897], 
     Hue[1.4412086641573065`, 1, -0.9554582440166877], 
     Hue[1.44077874750093, 1, -0.7575098155229691], 
     Hue[1.4402033613348968`, 1, -0.5790203816318928], 
     Hue[1.4393055482399593`, 1, -0.3900041894536903], 
     Hue[1.392919538973589, 1, 0.17128965411441788`], 
     Hue[1.43798556521307, 1, -0.20295107817609215`], 
     Hue[1.4360344779872007`, 1, -0.016408186537108405`], 
     Hue[1.4330763117269376`, 1, 0.1736864766091203], 
     Hue[1.2857016323146948`, 1, 0.5461221288828831], 
     Hue[1.4288031950271587`, 1, 0.3585504679133813], 
     Hue[1.4222757655017957`, 1, 0.548288753362298], 
     Hue[1.2183185146763689`, 1, 0.9216183416731782], 
     Hue[1.2882119182153555`, 1, 1.1093211134730918`], 
     Hue[1.4127097739844874`, 1, 0.734320554055695], 
     Hue[1.3982215333800607`, 1, 0.9216774074077178], 
     Hue[1.3759214728672002`, 1, 1.10936217315865], 
     Hue[1.114987142495296, 1, 1.1092867530481119`], 
     Hue[1.1136232278509173`, 1, 1.2970876816406105`], 
     Hue[1.3397225033582432`, 1, 1.2973220806517616`], 
     Hue[1.0481769231470588`, 1, 1.1094603898369062`], 
     Hue[1.044321020064982, 1, 1.2971750084149711`], 
     Hue[1.0127398935413874`, 1, 1.1093783272191848`], 
     Hue[1.008232988837899, 1, 1.1098627798151672`], 
     Hue[0.5674350139366426, 1, -17.264488266373966`], 
     Hue[0.5674350139366426, 1, -17.07736705803298], 
     Hue[0.5674350139366426, 1, -16.90742299186392], 
     Hue[0.5674350139366426, 1, -16.70312464135101], 
     Hue[0.5674350139366426, 1, -16.53318057518195], 
     Hue[0.5674350139366426, 1, -16.32888222466904], 
     Hue[0.5674350139366426, 1, -16.15893815849998], 
     Hue[0.5674350139366426, 1, -15.954639807987068`], 
     Hue[0.5674350139366426, 1, -15.784695741818005`], 
     Hue[0.5674350139366426, 1, -15.580397391305098`], 
     Hue[0.5674350139366426, 1, -15.407712291810729`], 
     Hue[0.5674350139366426, 1, -15.206154974623129`], 
     Hue[0.5674350139366429, 1, -15.033469875128759`], 
     Hue[0.5674350139366429, 1, -14.831912557941154`], 
     Hue[0.5674350139366429, 1, -14.65785694178413], 
     Hue[0.5674350139366431, 1, -14.45767014125918], 
     Hue[0.5674350139366433, 1, -14.283614525102157`], 
     Hue[0.5674350139366435, 1, -14.083427724577206`], 
     Hue[0.567435013936644, 1, -13.908172906340361`], 
     Hue[0.5674350139366447, 1, -13.709185307895227`], 
     Hue[0.5674350139366457, 1, -13.511830908473087`], 
     Hue[0.5674350139366473, 1, -13.334942891213242`], 
     Hue[0.5674350139366496, 1, -13.137588491791092`], 
     Hue[0.5674350139366527, 1, -12.960700474531233`], 
     Hue[0.567435013936658, 1, -12.763346075109064`], 
     Hue[0.5674350139366648, 1, -12.586458057849182`], 
     Hue[0.5674350139366764, 1, -12.389103658426972`], 
     Hue[0.5674350139366917, 1, -12.212215641167035`], 
     Hue[0.5674350139367168, 1, -12.014861241744732`], 
     Hue[0.5674350139367503, 1, -11.837973224484674`], 
     Hue[0.5674350139368058, 1, -11.640618825062173`], 
     Hue[0.5674350139368796, 1, -11.463730807801848`], 
     Hue[0.5674350139370015, 1, -11.266376408378907`], 
     Hue[0.5674350139371633, 1, -11.089488391118], 
     Hue[0.5674350139374316, 1, -10.89213399169409], 
     Hue[0.5674350139377875, 1, -10.715245974431896`], 
     Hue[0.5674350139383775, 1, -10.51789157500586], 
     Hue[0.5674350139391602, 1, -10.341003557740843`], 
     Hue[0.5674350139404569, 1, -10.143649158310128`], 
     Hue[0.5674350139423159, 1, -9.955066065516679], 
     Hue[0.5674350139451201, 1, -9.764290146056728], 
     Hue[0.5674350139491167, 1, -9.580823648789707], 
     Hue[0.5674350139552822, 1, -9.390047729307511], 
     Hue[0.5674350139640696, 1, -9.206581232008789], 
     Hue[0.5674350139776257, 1, -9.01580531247769], 
     Hue[0.567435013996947, 1, -8.832338815109262], 
     Hue[0.5674350140267532, 1, -8.641562895470633], 
     Hue[0.5674350140692355, 1, -8.458096397948948], 
     Hue[0.5674350141347713, 1, -8.267320478073888], 
     Hue[0.5674350142281781, 1, -8.083853980215226], 
     Hue[0.5674350143722735, 1, -7.893078059820328], 
     Hue[0.5674350145776497, 1, -7.709611561220744], 
     Hue[0.5674350148944761, 1, -7.518835639682856], 
     Hue[0.5674350153460423, 1, -7.335369139454191], 
     Hue[0.5674350160426573, 1, -7.144593215403179], 
     Hue[0.5674350170355285, 1, -6.96112671159261], 
     Hue[0.5674350185671952, 1, -6.770350782015922], 
     Hue[0.5674350207502485, 1, -6.58688427032972], 
     Hue[0.5674350241179664, 1, -6.396108328603578], 
     Hue[0.5674350291034753, 1, -6.206794260612411], 
     Hue[0.5674350364434966, 1, -6.019307532591259], 
     Hue[0.5674350472843828, 1, -5.832551723624401], 
     Hue[0.5674350634230995, 1, -5.645064937380874], 
     Hue[0.5674350872592759, 1, -5.458309042422148], 
     Hue[0.5674351227439647, 1, -5.270822128163391], 
     Hue[0.5674351751533282, 1, -5.084066044131754], 
     Hue[0.5674352531747257, 1, -4.896578848401894], 
     Hue[0.5674353684091529, 1, -4.709822348649371], 
     Hue[0.5674355516203138, 1, -4.511918530232511], 
     Hue[0.5674357981419511, 1, -4.332653319500797], 
     Hue[0.5674361736434862, 1, -4.146808775329317], 
     Hue[0.5674367382129801, 1, -3.9584046823432395`], 
     Hue[0.5674376198991316, 1, -3.762232229976563], 
     Hue[0.5674388169465292, 1, -3.5826866265326798`], 
     Hue[0.5674407511566322, 1, -3.387375204137971], 
     Hue[0.5674433891295796, 1, -3.207683015822984], 
     Hue[0.5674476376191148, 1, -3.012790280323709], 
     Hue[0.5674534525527801, 1, -2.832825816094889], 
     Hue[0.5674627888508454, 1, -2.6382249304042578`], 
     Hue[0.5674776324930706, 1, -2.434850591981305], 
     Hue[0.5674961212973899, 1, -2.2636878752845693`], 
     Hue[0.5675287872575232, 1, -2.060270062331119], 
     Hue[0.5675695095904988, 1, -1.888960631160139], 
     Hue[0.5676415191988974, 1, -1.6852835531702464`], 
     Hue[0.5677313986306134, 1, -1.513650824782801], 
     Hue[0.5678906329469702, 1, -1.3094018144853232`], 
     Hue[0.5680899216008108, 1, -1.1370547894663317`], 
     Hue[0.5683945658128968, 1, -0.9556195672897434], 
     Hue[0.5688904032388267, 1, -0.7577562050512134], 
     Hue[0.5695537354755906, 1, -0.5793823843228088], 
     Hue[0.5705881241403319, 1, -0.3905506030949648], 
     Hue[0.5721074204061103, 1, -0.20377743039768115`], 
     Hue[0.5743605997581905, 1, -0.016923620949845786`], 
     Hue[0.5777419797117022, 1, 0.17175295023044468`], 
     Hue[0.5827284423799914, 1, 0.35879035243166235`], 
     Hue[0.59016664723972, 1, 0.5461642805657648], 
     Hue[0.601325457405187, 1, 0.7338886177452891], 
     Hue[0.6182249511948368, 1, 0.9215623870458222], 
     Hue[0.6445565651560405, 1, 1.1093157525605981`], 
     Hue[0.6890400293364302, 1, 1.2972135796979203`], 
     Hue[0.9458954425371987, 1, 1.2970096615661384`], 
     Hue[0.9902632180623768, 1, 1.1096004966483282`], 
     Hue[0.6928298150515741, 1, -17.264488266373966`], 
     Hue[0.6928298150515741, 1, -17.07736705803298], 
     Hue[0.6928298150515741, 1, -16.90742299186392], 
     Hue[0.6928298150515741, 1, -16.70312464135101], 
     Hue[0.6928298150515741, 1, -16.53318057518195], 
     Hue[0.6928298150515741, 1, -16.32888222466904], 
     Hue[0.6928298150515741, 1, -16.15893815849998], 
     Hue[0.6928298150515741, 1, -15.954639807987068`], 
     Hue[0.6928298150515741, 1, -15.784695741818005`], 
     Hue[0.6928298150515741, 1, -15.580397391305098`], 
     Hue[0.6928298150515743, 1, -15.407712291810729`], 
     Hue[0.6928298150515744, 1, -15.206154974623129`], 
     Hue[0.6928298150515744, 1, -15.033469875128759`], 
     Hue[0.6928298150515746, 1, -14.831912557941154`], 
     Hue[0.6928298150515748, 1, -14.657856941784134`], 
     Hue[0.692829815051575, 1, -14.457670141259184`], 
     Hue[0.6928298150515755, 1, -14.283614525102161`], 
     Hue[0.6928298150515763, 1, -14.08342772457721], 
     Hue[0.6928298150515773, 1, -13.908172906340367`], 
     Hue[0.6928298150515788, 1, -13.709185307895236`], 
     Hue[0.6928298150515813, 1, -13.5118309084731], 
     Hue[0.6928298150515846, 1, -13.33494289121326], 
     Hue[0.69282981505159, 1, -13.137588491791119`], 
     Hue[0.6928298150515972, 1, -12.960700474531274`], 
     Hue[0.692829815051609, 1, -12.763346075109126`], 
     Hue[0.6928298150516248, 1, -12.58645805784927], 
     Hue[0.692829815051651, 1, -12.389103658427109`], 
     Hue[0.6928298150516856, 1, -12.212215641167234`], 
     Hue[0.6928298150517431, 1, -12.014861241745034`], 
     Hue[0.6928298150518193, 1, -11.837973224485111`], 
     Hue[0.6928298150519456, 1, -11.640618825062836`], 
     Hue[0.6928298150521134, 1, -11.463730807802811`], 
     Hue[0.6928298150523912, 1, -11.266376408380365`], 
     Hue[0.6928298150527599, 1, -11.089488391120117`], 
     Hue[0.6928298150533706, 1, -10.892133991697298`], 
     Hue[0.6928298150541812, 1, -10.715245974436552`], 
     Hue[0.6928298150555241, 1, -10.517891575012912`], 
     Hue[0.6928298150573065, 1, -10.341003557751078`], 
     Hue[0.6928298150602592, 1, -10.143649158325635`], 
     Hue[0.6928298150644923, 1, -9.955066065539741], 
     Hue[0.6928298150708772, 1, -9.764290146091192], 
     Hue[0.6928298150799775, 1, -9.580823648840417], 
     Hue[0.6928298150940162, 1, -9.390047729383287], 
     Hue[0.6928298151140255, 1, -9.20658123212029], 
     Hue[0.6928298151448928, 1, -9.015805312644298], 
     Hue[0.6928298151888876, 1, -8.83233881535442], 
     Hue[0.6928298152567567, 1, -8.641562895836964], 
     Hue[0.6928298153534891, 1, -8.458096398487983], 
     Hue[0.6928298155027148, 1, -8.267320478879348], 
     Hue[0.6928298157154029, 1, -8.083853981400418], 
     Hue[0.6928298160435095, 1, -7.893078061591317], 
     Hue[0.6928298165111529, 1, -7.709611563826658], 
     Hue[0.6928298172325695, 1, -7.518835643576776], 
     Hue[0.6928298182607902, 1, -7.335369145183882], 
     Hue[0.6928298198469889, 1, -7.14459322396485], 
     Hue[0.6928298221077656, 1, -6.961126724190641], 
     Hue[0.6928298255953844, 1, -6.770350800840703], 
     Hue[0.6928298305662166, 1, -6.586884298029362], 
     Hue[0.6928298382345401, 1, -6.396108369994146], 
     Hue[0.692829849586587, 1, -6.206794322270783], 
     Hue[0.6928298662998775, 1, -6.019307624089335], 
     Hue[0.6928298909846633, 1, -5.832551859194404], 
     Hue[0.6928299277326433, 1, -5.645065138560314], 
     Hue[0.6928299820077792, 1, -5.458309340503869], 
     Hue[0.6928300628066157, 1, -5.270822570502659], 
     Hue[0.6928301821429425, 1, -5.084066699533334], 
     Hue[0.6928303597977724, 1, -4.896579820987846], 
     Hue[0.692830622186289, 1, -4.709823789704209], 
     Hue[0.692831039356601, 1, -4.511920716107003], 
     Hue[0.6928316006822841, 1, -4.332656507577249], 
     Hue[0.6928324556885053, 1, -4.146813489963988], 
     Hue[0.6928337411867009, 1, -3.958411692181718], 
     Hue[0.6928357487197678, 1, -3.7622428242544332`], 
     Hue[0.6928384742581861, 1, -3.5827020873855115`], 
     Hue[0.692842878112763, 1, -3.38739852861989], 
     Hue[0.6928488840759207, 1, -3.207717065380735], 
     Hue[0.6928585561870999, 1, -3.0128416033931833`], 
     Hue[0.6928718014008735, 1, -2.832809405980984], 
     Hue[0.6928930486952339, 1, -2.6383007380808072`], 
     Hue[0.69292682250251, 1, -2.43502389061842], 
     Hue[0.6929688843125736, 1, -2.2639363790219935`], 
     Hue[0.6930431664324495, 1, -2.060651474469659], 
     Hue[0.6931357104720195, 1, -1.8895077954483648`], 
     Hue[0.6932991987433841, 1, -1.6861239931357555`], 
     Hue[0.693502974911469, 1, -1.5148576308943265`], 
     Hue[0.6938632222306155, 1, -1.311258531475685], 
     Hue[0.6943126993206523, 1, -1.139726390849584], 
     Hue[0.6950528294883863, 1, -0.9474192872814651], 
     Hue[0.6961367960607049, 1, -0.7587815302025211], 
     Hue[0.6977472993288576, 1, -0.5703612726096563], 
     Hue[0.6999933966755065, 1, -0.3917449097148422], 
     Hue[0.6089189298708888, 1, 0.17080735625737842`], 
     Hue[0.7034749780244409, 1, -0.20379335851939873`], 
     Hue[0.7086180507806953, 1, -0.016992699366481068`], 
     Hue[0.7142161523376049, 1, 0.5461990176782618], 
     Hue[0.7163594603628839, 1, 0.171578124486098], 
     Hue[0.727953206463342, 1, 0.359735772897708], 
     Hue[0.7816946555365145, 1, 0.9215837105115378], 
     Hue[0.7117810925992638, 1, 1.1093391971785198`], 
     Hue[0.7455224441447552, 1, 0.5475520246032972], 
     Hue[0.7728154145227869, 1, 0.7343465473086225], 
     Hue[0.885005998451872, 1, 1.1093889823571998`], 
     Hue[0.8863834329120681, 1, 1.2971683007161667`], 
     Hue[0.8195738156929273, 1, 0.9218537610541808], 
     Hue[0.951829329621384, 1, 1.1095373577455074`], 
     Hue[0.987301753240486, 1, 1.1094650650331175`], 
     Hue[0.8182246161665059, 1, -17.264488266373966`], 
     Hue[0.8182246161665059, 1, -17.07736705803298], 
     Hue[0.8182246161665059, 1, -16.90742299186392], 
     Hue[0.8182246161665059, 1, -16.70312464135101], 
     Hue[0.8182246161665059, 1, -16.53318057518195], 
     Hue[0.8182246161665059, 1, -16.32888222466904], 
     Hue[0.8182246161665059, 1, -16.15893815849998], 
     Hue[0.8182246161665059, 1, -15.954639807987068`], 
     Hue[0.8182246161665059, 1, -15.784695741818005`], 
     Hue[0.8182246161665059, 1, -15.580397391305098`], 
     Hue[0.818224616166506, 1, -15.407712291810729`], 
     Hue[0.8182246161665061, 1, -15.206154974623129`], 
     Hue[0.8182246161665061, 1, -15.033469875128759`], 
     Hue[0.8182246161665063, 1, -14.831912557941154`], 
     Hue[0.8182246161665065, 1, -14.657856941784134`], 
     Hue[0.8182246161665068, 1, -14.457670141259184`], 
     Hue[0.8182246161665072, 1, -14.283614525102164`], 
     Hue[0.8182246161665079, 1, -14.083427724577216`], 
     Hue[0.8182246161665089, 1, -13.908172906340374`], 
     Hue[0.8182246161665105, 1, -13.709185307895249`], 
     Hue[0.8182246161665129, 1, -13.511830908473117`], 
     Hue[0.818224616166516, 1, -13.334942891213284`], 
     Hue[0.8182246161665213, 1, -13.137588491791158`], 
     Hue[0.8182246161665283, 1, -12.96070047453133], 
     Hue[0.8182246161665399, 1, -12.763346075109212`], 
     Hue[0.8182246161665552, 1, -12.586458057849397`], 
     Hue[0.8182246161665805, 1, -12.389103658427295`], 
     Hue[0.8182246161666142, 1, -12.212215641167507`], 
     Hue[0.81822461616667, 1, -12.014861241745448`], 
     Hue[0.8182246161667441, 1, -11.837973224485713`], 
     Hue[0.8182246161668669, 1, -11.640618825063745`], 
     Hue[0.8182246161670297, 1, -11.46373080780413], 
     Hue[0.8182246161672997, 1, -11.266376408382364`], 
     Hue[0.8182246161676578, 1, -11.089488391123016`], 
     Hue[0.8182246161682513, 1, -10.892133991701693`], 
     Hue[0.8182246161690387, 1, -10.715245974442928`], 
     Hue[0.8182246161703435, 1, -10.517891575022574`], 
     Hue[0.818224616172075, 1, -10.341003557765099`], 
     Hue[0.8182246161749437, 1, -10.143649158346877`], 
     Hue[0.8182246161790562, 1, -9.955066065571337], 
     Hue[0.8182246161852593, 1, -9.764290146138402], 
     Hue[0.8182246161941006, 1, -9.580823648909886], 
     Hue[0.8182246162077397, 1, -9.390047729487092], 
     Hue[0.8182246162271791, 1, -9.206581232273033], 
     Hue[0.8182246162571677, 1, -9.015805312872539], 
     Hue[0.8182246162999098, 1, -8.832338815690264], 
     Hue[0.8182246163658466, 1, -8.641562896338801], 
     Hue[0.8182246164598249, 1, -8.45809639922641], 
     Hue[0.8182246166048018, 1, -8.267320479982754], 
     Hue[0.8182246168114345, 1, -8.083853983024017], 
     Hue[0.8182246171301993, 1, -7.893078064017401], 
     Hue[0.8182246175845282, 1, -7.709611567396508], 
     Hue[0.8182246182854052, 1, -7.518835648911076], 
     Hue[0.8182246192843508, 1, -7.335369153033013], 
     Hue[0.8182246208253879, 1, -7.144593235693518], 
     Hue[0.8182246230217969, 1, -6.961126741448738], 
     Hue[0.8182246264101177, 1, -6.770350826628847], 
     Hue[0.8182246312394224, 1, -6.58688433597521], 
     Hue[0.818224638689416, 1, -6.396108426695249], 
     Hue[0.81822464971825, 1, -6.206794406736818], 
     Hue[0.8182246659556813, 1, -6.019307749432875], 
     Hue[0.8182246899376391, 1, -5.832552044912191], 
     Hue[0.8182247256393153, 1, -5.645065414156592], 
     Hue[0.818224778369082, 1, -5.458309748846656], 
     Hue[0.8182248568672889, 1, -5.2708231764637326`], 
     Hue[0.8182249728055673, 1, -5.084067597367761], 
     Hue[0.8182251454014919, 1, -4.896581153330935], 
     Hue[0.8182254003176459, 1, -4.709825763797053], 
     Hue[0.8182258056062643, 1, -4.511923710512938], 
     Hue[0.8182263509417255, 1, -4.332660874867022], 
     Hue[0.8182271815857269, 1, -4.146819948409786], 
     Hue[0.8182284304416652, 1, -3.9584212946528776`], 
     Hue[0.8182303807182901, 1, -3.7622573366328256`], 
     Hue[0.8182330284576554, 1, -3.582723265638699], 
     Hue[0.8182373064494937, 1, -3.3874304772071397`], 
     Hue[0.8182431404487485, 1, -3.207763702089353], 
     Hue[0.8182525348678322, 1, -3.012911893081844], 
     Hue[0.8182654051496199, 1, -2.832832147100812], 
     Hue[0.818286033657977, 1, -2.6384228955420586`], 
     Hue[0.818318814620915, 1, -2.435261088065098], 
     Hue[0.8183596292426274, 1, -2.2642763838005857`], 
     Hue[0.8184316656693398, 1, -2.061172980239128], 
     Hue[0.8185213349591136, 1, -1.8902553176798202`], 
     Hue[0.8186795363970526, 1, -1.6872705088417488`], 
     Hue[0.8188763513921828, 1, -1.516500948133525], 
     Hue[0.8192232875589962, 1, -1.3137787206721907`], 
     Hue[0.8196543663268276, 1, -1.143338119207992], 
     Hue[0.8203599058723282, 1, -0.9528222382749807], 
     Hue[0.8213836830341747, 1, -0.7667938588911847], 
     Hue[0.8229411287505455, 1, -0.5764555310334378], 
     Hue[0.8251953762860522, 1, -0.3909769412773134], 
     Hue[0.8286640193778506, 1, -0.19933072802993035`], 
     Hue[0.8335785308398357, 1, -0.0164801355655233], 
     Hue[0.8411644744486649, 1, 0.17332614461492568`], 
     Hue[0.852242512795583, 1, 0.3585048530210019], 
     Hue[0.8655944641358831, 1, 0.7340876644128103], 
     Hue[0.8692087823828915, 1, 0.5461735608472443], 
     Hue[0.9157679870900644, 1, 0.921630870629423], 
     Hue[0.8956522982465704, 1, 0.7339076345862732], 
     Hue[0.9403251586621744, 1, 0.921612533892277], 
     Hue[0.9436194172814373, 1, -17.264488266373966`], 
     Hue[0.9436194172814373, 1, -17.07736705803298], 
     Hue[0.9436194172814373, 1, -16.90742299186392], 
     Hue[0.9436194172814373, 1, -16.70312464135101], 
     Hue[0.9436194172814373, 1, -16.53318057518195], 
     Hue[0.9436194172814373, 1, -16.32888222466904], 
     Hue[0.9436194172814373, 1, -16.15893815849998], 
     Hue[0.9436194172814373, 1, -15.954639807987068`], 
     Hue[0.9436194172814373, 1, -15.784695741818005`], 
     Hue[0.9436194172814373, 1, -15.580397391305098`], 
     Hue[0.9436194172814374, 1, -15.407712291810729`], 
     Hue[0.9436194172814374, 1, -15.206154974623129`], 
     Hue[0.9436194172814374, 1, -15.033469875128759`], 
     Hue[0.9436194172814375, 1, -14.831912557941154`], 
     Hue[0.9436194172814375, 1, -14.657856941784138`], 
     Hue[0.9436194172814376, 1, -14.457670141259188`], 
     Hue[0.9436194172814378, 1, -14.283614525102164`], 
     Hue[0.943619417281438, 1, -14.08342772457722], 
     Hue[0.9436194172814385, 1, -13.908172906340381`], 
     Hue[0.943619417281439, 1, -13.709185307895256`], 
     Hue[0.9436194172814399, 1, -13.51183090847313], 
     Hue[0.9436194172814412, 1, -13.334942891213304`], 
     Hue[0.9436194172814432, 1, -13.137588491791185`], 
     Hue[0.9436194172814458, 1, -12.96070047453137], 
     Hue[0.9436194172814503, 1, -12.76334607510927], 
     Hue[0.943619417281456, 1, -12.58645805784948], 
     Hue[0.9436194172814658, 1, -12.389103658427423`], 
     Hue[0.9436194172814786, 1, -12.212215641167692`], 
     Hue[0.9436194172814999, 1, -12.014861241745729`], 
     Hue[0.9436194172815282, 1, -11.83797322448612], 
     Hue[0.943619417281575, 1, -11.640618825064363`], 
     Hue[0.9436194172816371, 1, -11.463730807805028`], 
     Hue[0.94361941728174, 1, -11.266376408383724`], 
     Hue[0.9436194172818766, 1, -11.089488391124991`], 
     Hue[0.943619417282103, 1, -10.892133991704682`], 
     Hue[0.9436194172824033, 1, -10.715245974447269`], 
     Hue[0.9436194172829009, 1, -10.51789157502915], 
     Hue[0.9436194172835614, 1, -10.341003557774643`], 
     Hue[0.9436194172846555, 1, -10.143649158361338`], 
     Hue[0.9436194172862239, 1, -9.955066065592845], 
     Hue[0.9436194172885898, 1, -9.764290146170541], 
     Hue[0.9436194172919617, 1, -9.580823648957177], 
     Hue[0.9436194172971637, 1, -9.390047729557756], 
     Hue[0.9436194173045778, 1, -9.20658123237701], 
     Hue[0.9436194173160153, 1, -9.015805313027906], 
     Hue[0.9436194173323169, 1, -8.83233881591888], 
     Hue[0.9436194173574649, 1, -8.641562896680414], 
     Hue[0.9436194173933078, 1, -8.458096399729074], 
     Hue[0.9436194174486013, 1, -8.267320480733867], 
     Hue[0.9436194175274101, 1, -8.083853984129236], 
     Hue[0.9436194176489854, 1, -7.893078065668893], 
     Hue[0.9436194178222643, 1, -7.7096115698265875`], 
     Hue[0.9436194180895754, 1, -7.518835652542255], 
     Hue[0.9436194184705685, 1, -7.335369158376095], 
     Hue[0.9436194190583127, 1, -7.144593243677492], 
     Hue[0.9436194198960127, 1, -6.96112675319672], 
     Hue[0.943619421188302, 1, -6.77035084418343], 
     Hue[0.9436194230301758, 1, -6.586884361805821], 
     Hue[0.9436194258715676, 1, -6.396108465292987], 
     Hue[0.9436194300779116, 1, -6.206794464234777], 
     Hue[0.9436194362707888, 1, -6.019307834757073], 
     Hue[0.9436194454173895, 1, -5.832552171334485], 
     Hue[0.9436194590338302, 1, -5.645065601761145], 
     Hue[0.9436194791446929, 1, -5.458310026814596], 
     Hue[0.9436195090834926, 1, -5.270823588954511], 
     Hue[0.9436195533017058, 1, -5.084068208542397], 
     Hue[0.9436196191287609, 1, -4.896582060283296], 
     Hue[0.9436197163521102, 1, -4.709827107598146], 
     Hue[0.943619870926163, 1, -4.511925748852448], 
     Hue[0.9436200789123224, 1, -4.332663847735847], 
     Hue[0.9436203957110829, 1, -4.1468243447221695`], 
     Hue[0.9436208720078412, 1, -3.958427831054135], 
     Hue[0.9436216158083751, 1, -3.762267215035883], 
     Hue[0.9436226255919418, 1, -3.582737681083315], 
     Hue[0.9436242570734948, 1, -3.387452222888257], 
     Hue[0.9436264818825527, 1, -3.207795443533402], 
     Hue[0.9436300642691405, 1, -3.012959728994809], 
     Hue[0.9436357570017536, 1, -2.809506795908036], 
     Hue[0.9436428366612445, 1, -2.638523467529275], 
     Hue[0.9436553319223556, 1, -2.435422418421437], 
     Hue[0.9436708855674261, 1, -2.2645075547527], 
     Hue[0.943698326071568, 1, -2.061527327286054], 
     Hue[0.9437324635144378, 1, -1.890762830684375], 
     Hue[0.9437926377980806, 1, -1.6880478143188078`], 
     Hue[0.9438674040841089, 1, -1.5176131227333947`], 
     Hue[0.9439989426279356, 1, -1.3154791000192423`], 
     Hue[0.9441727902367402, 1, -1.136351971061331], 
     Hue[0.9444374936165855, 1, -0.9506644643379187], 
     Hue[0.9448286927994038, 1, -0.7650269384876782], 
     Hue[0.9454045230166932, 1, -0.5800406257630351], 
     Hue[0.9462992171194429, 1, -0.3870774945789057], 
     Hue[0.9475729639108039, 1, -0.20239019986721485`], 
     Hue[0.9494670574424763, 1, -0.01652128672292652], 
     Hue[0.9522977261692113, 1, 0.1708747190698775], 
     Hue[0.9565400482546466, 1, 0.35963761088526913`], 
     Hue[0.962802177460387, 1, 0.5467225078606461], 
     Hue[0.9721494471187145, 1, 0.7338754570052526], 
     Hue[0.9863088992728566, 1, 0.9221355400629276], 
     Hue[1.0690142183963691`, 1, -17.264488266373966`], 
     Hue[1.0690142183963691`, 1, -17.07736705803298], 
     Hue[1.0690142183963691`, 1, -16.90742299186392], 
     Hue[1.0690142183963691`, 1, -16.70312464135101], 
     Hue[1.0690142183963691`, 1, -16.53318057518195], 
     Hue[1.0690142183963691`, 1, -16.32888222466904], 
     Hue[1.0690142183963691`, 1, -16.15893815849998], 
     Hue[1.0690142183963691`, 1, -15.954639807987068`], 
     Hue[1.069014218396369, 1, -15.784695741818005`], 
     Hue[1.069014218396369, 1, -15.580397391305098`], 
     Hue[1.069014218396369, 1, -15.407712291810729`], 
     Hue[1.069014218396369, 1, -15.206154974623129`], 
     Hue[1.069014218396369, 1, -15.033469875128759`], 
     Hue[1.069014218396369, 1, -14.831912557941154`], 
     Hue[1.0690142183963687`, 1, -14.657856941784138`], 
     Hue[1.0690142183963687`, 1, -14.457670141259188`], 
     Hue[1.0690142183963685`, 1, -14.283614525102164`], 
     Hue[1.069014218396368, 1, -14.08342772457722], 
     Hue[1.0690142183963676`, 1, -13.90817290634038], 
     Hue[1.069014218396367, 1, -13.709185307895256`], 
     Hue[1.0690142183963658`, 1, -13.511830908473128`], 
     Hue[1.0690142183963642`, 1, -13.334942891213302`], 
     Hue[1.069014218396362, 1, -13.137588491791183`], 
     Hue[1.0690142183963587`, 1, -12.960700474531368`], 
     Hue[1.0690142183963534`, 1, -12.763346075109267`], 
     Hue[1.0690142183963462`, 1, -12.586458057849475`], 
     Hue[1.0690142183963345`, 1, -12.389103658427416`], 
     Hue[1.069014218396319, 1, -12.212215641167681`], 
     Hue[1.0690142183962932`, 1, -12.014861241745713`], 
     Hue[1.069014218396259, 1, -11.837973224486095`], 
     Hue[1.0690142183962021`, 1, -11.640618825064328`], 
     Hue[1.069014218396127, 1, -11.463730807804977`], 
     Hue[1.0690142183960023`, 1, -11.266376408383646`], 
     Hue[1.0690142183958369`, 1, -11.089488391124876`], 
     Hue[1.0690142183955627`, 1, -10.892133991704508`], 
     Hue[1.069014218395199, 1, -10.715245974447015`], 
     Hue[1.069014218394596, 1, -10.517891575028768`], 
     Hue[1.0690142183937963`, 1, -10.341003557774085`], 
     Hue[1.0690142183924711`, 1, -10.143649158360494`], 
     Hue[1.0690142183905713`, 1, -9.95506606559159], 
     Hue[1.0690142183877056`, 1, -9.764290146168666], 
     Hue[1.0690142183836213`, 1, -9.58082364895442], 
     Hue[1.0690142183773204`, 1, -9.390047729553634], 
     Hue[1.06901421836834, 1, -9.206581232370946], 
     Hue[1.0690142183544864`, 1, -9.015805313018845], 
     Hue[1.069014218334741, 1, -8.832338815905544], 
     Hue[1.0690142183042806`, 1, -8.641562896660488], 
     Hue[1.0690142182608657`, 1, -8.458096399699755], 
     Hue[1.0690142181938915`, 1, -8.267320480690056], 
     Hue[1.0690142180984343`, 1, -8.083853984064776], 
     Hue[1.0690142179511761`, 1, -7.89307806557257], 
     Hue[1.0690142177412918`, 1, -7.709611569684854], 
     Hue[1.069014217417511, 1, -7.518835652330467], 
     Hue[1.0690142169560328`, 1, -7.335369158064458], 
     Hue[1.0690142162441272`, 1, -7.144593243211825], 
     Hue[1.0690142152294624`, 1, -6.961126752511519], 
     Hue[1.069014213664176, 1, -6.770350843159557], 
     Hue[1.0690142114332049`, 1, -6.586884360299247], 
     Hue[1.0690142079915668`, 1, -6.396108463041768], 
     Hue[1.0690142028966292`, 1, -6.206794460881201], 
     Hue[1.0690141953955015`, 1, -6.019307829780529], 
     Hue[1.0690141843166738`, 1, -5.832552163960891], 
     Hue[1.0690141678237484`, 1, -5.645065590819089], 
     Hue[1.0690141434644482`, 1, -5.45831001060209], 
     Hue[1.0690141072010502`, 1, -5.270823564895954], 
     Hue[1.069014053641697, 1, -5.084068172895602], 
     Hue[1.0690139739086086`, 1, -4.8965820073852795`], 
     Hue[1.0690138561467162`, 1, -4.709827029220985], 
     Hue[1.0690136689186926`, 1, -4.511925629966518], 
     Hue[1.0690134169951349`, 1, -4.332663674343919], 
     Hue[1.069013033272034, 1, -4.146824088308926], 
     Hue[1.069012456356428, 1, -3.9584274498226435`], 
     Hue[1.0690115554256174`, 1, -3.7622666388880557`], 
     Hue[1.0690103323208116`, 1, -3.582736840324708], 
     Hue[1.0690083561786943`, 1, -3.3874509546233256`], 
     Hue[1.0690056613592358`, 1, -3.207793592326146], 
     Hue[1.069001322148204, 1, -3.0129569392236935`], 
     Hue[1.0689944267186036`, 1, -2.809502514902488], 
     Hue[1.0689858512873034`, 1, -2.6385173323677256`], 
     Hue[1.0689707158970114`, 1, -2.4354130118168547`], 
     Hue[1.0689518756242733`, 1, -2.2644940778550016`], 
     Hue[1.0689186359032288`, 1, -2.0615066744617083`], 
     Hue[1.0688772825257071`, 1, -1.8907332596875552`], 
     Hue[1.0688043848911055`, 1, -1.688002547673914], 
     Hue[1.0687138031926906`, 1, -1.5175483978358526`], 
     Hue[1.0685544221438223`, 1, -1.3153802587885515`], 
     Hue[1.0683437415186827`, 1, -1.1362082694791817`], 
     Hue[1.068022879415978, 1, -0.9504529600124221], 
     Hue[1.0675485177549335`, 1, -0.7647163429277664], 
     Hue[1.0668499185644953`, 1, -0.5795865947018422], 
     Hue[1.0657636468089975`, 1, -0.3864063532655535], 
     Hue[1.064243001932468, 1, -0.20415351905141366`], 
     Hue[1.0619361601143251`, 1, -0.016899755553317686`], 
     Hue[1.0584847360225376`, 1, 0.1715705587415276], 
     Hue[1.0533188067543084`, 1, 0.3607618401574958], 
     Hue[1.0457784807830304`, 1, 0.5461968924418996], 
     Hue[1.0343452651002114`, 1, 0.7341957241582859], 
     Hue[1.017007023238606, 1, 0.9221048559130471], 
     Hue[1.1944090195113004`, 1, -17.264488266373966`], 
     Hue[1.1944090195113004`, 1, -17.07736705803298], 
     Hue[1.1944090195113004`, 1, -16.90742299186392], 
     Hue[1.1944090195113004`, 1, -16.70312464135101], 
     Hue[1.1944090195113004`, 1, -16.53318057518195], 
     Hue[1.1944090195113004`, 1, -16.32888222466904], 
     Hue[1.1944090195113004`, 1, -16.15893815849998], 
     Hue[1.1944090195113004`, 1, -15.954639807987068`], 
     Hue[1.1944090195113004`, 1, -15.784695741818005`], 
     Hue[1.1944090195113004`, 1, -15.580397391305098`], 
     Hue[1.1944090195113004`, 1, -15.407712291810729`], 
     Hue[1.1944090195113002`, 1, -15.206154974623129`], 
     Hue[1.1944090195113002`, 1, -15.033469875128759`], 
     Hue[1.1944090195113, 1, -14.831912557941154`], 
     Hue[1.1944090195112997`, 1, -14.657856941784134`], 
     Hue[1.1944090195112995`, 1, -14.457670141259184`], 
     Hue[1.194409019511299, 1, -14.283614525102161`], 
     Hue[1.1944090195112982`, 1, -14.083427724577215`], 
     Hue[1.1944090195112973`, 1, -13.908172906340374`], 
     Hue[1.1944090195112957`, 1, -13.709185307895247`], 
     Hue[1.1944090195112933`, 1, -13.511830908473115`], 
     Hue[1.19440901951129, 1, -13.334942891213283`], 
     Hue[1.1944090195112844`, 1, -13.137588491791155`], 
     Hue[1.1944090195112773`, 1, -12.960700474531325`], 
     Hue[1.1944090195112653`, 1, -12.763346075109204`], 
     Hue[1.1944090195112496`, 1, -12.586458057849384`], 
     Hue[1.1944090195112234`, 1, -12.38910365842728], 
     Hue[1.1944090195111885`, 1, -12.21221564116748], 
     Hue[1.1944090195111308`, 1, -12.014861241745407`], 
     Hue[1.1944090195110544`, 1, -11.837973224485655`], 
     Hue[1.1944090195109276`, 1, -11.640618825063658`], 
     Hue[1.1944090195107593`, 1, -11.463730807804005`], 
     Hue[1.1944090195104804`, 1, -11.266376408382172`], 
     Hue[1.1944090195101102`, 1, -11.08948839112274], 
     Hue[1.1944090195094974`, 1, -10.89213399170127], 
     Hue[1.1944090195086838`, 1, -10.715245974442317`], 
     Hue[1.1944090195073358`, 1, -10.51789157502165], 
     Hue[1.194409019505547, 1, -10.341003557763756`], 
     Hue[1.1944090195025834`, 1, -10.143649158344843`], 
     Hue[1.1944090194983348`, 1, -9.955066065568314], 
     Hue[1.1944090194919266`, 1, -9.764290146133884], 
     Hue[1.1944090194827925`, 1, -9.580823648903237], 
     Hue[1.1944090194687023`, 1, -9.390047729477159], 
     Hue[1.1944090194486194`, 1, -9.206581232258413], 
     Hue[1.1944090194176387`, 1, -9.015805312850693], 
     Hue[1.1944090193734822`, 1, -8.832338815658119], 
     Hue[1.1944090193053636`, 1, -8.64156289629077], 
     Hue[1.1944090192082755`, 1, -8.458096399155732], 
     Hue[1.1944090190585013`, 1, -8.267320479877144], 
     Hue[1.194409018845031, 1, -8.083853982868618], 
     Hue[1.1944090185157181`, 1, -7.893078063785194], 
     Hue[1.1944090180463554`, 1, -7.709611567054828], 
     Hue[1.1944090173222863`, 1, -7.518835648400516], 
     Hue[1.1944090162902854`, 1, -7.335369152281751], 
     Hue[1.194409014698255, 1, -7.144593234570936], 
     Hue[1.1944090124291664`, 1, -6.96112673979692], 
     Hue[1.1944090089287254`, 1, -6.7703508241605945`], 
     Hue[1.1944090039396178`, 1, -6.586884332343312], 
     Hue[1.1944089962431024`, 1, -6.396108421268234], 
     Hue[1.1944089848493213`, 1, -6.206794398652348], 
     Hue[1.1944089680745893`, 1, -6.019307737435911], 
     Hue[1.194408943299062, 1, -5.83255202713665], 
     Hue[1.1944089064160066`, 1, -5.645065387778547], 
     Hue[1.1944088519413931`, 1, -5.458309709763101], 
     Hue[1.1944087708456477`, 1, -5.270823118465637], 
     Hue[1.194408651070911, 1, -5.084067511433762], 
     Hue[1.194408472763671, 1, -4.896581025809122], 
     Hue[1.1944082094121125`, 1, -4.709825574852033], 
     Hue[1.1944077907119894`, 1, -4.511923423911934], 
     Hue[1.1944072273304278`, 1, -4.33266045686546], 
     Hue[1.1944063691983702`, 1, -4.146819330262187], 
     Hue[1.1944050790133518`, 1, -3.9584203755913645`], 
     Hue[1.194403064191874, 1, -3.7622559476524726`], 
     Hue[1.1944003288185867`, 1, -3.5827212386929093`], 
     Hue[1.1943959092197916`, 1, -3.387427419507997], 
     Hue[1.1943898820768462`, 1, -3.2077592387609615`], 
     Hue[1.1943801765658244`, 1, -3.012905166367073], 
     Hue[1.1943668809534231`, 1, -2.8328337395975645`], 
     Hue[1.1943455683451922`, 1, -2.638412737918145], 
     Hue[1.1943116993606502`, 1, -2.4352383955092733`], 
     Hue[1.1942695292729226`, 1, -2.2642438620861443`], 
     Hue[1.1941950962365662`, 1, -2.0611231150479377`], 
     Hue[1.1941024361092927`, 1, -1.8901838720516946`], 
     Hue[1.193938937480819, 1, -1.6871610119519918`], 
     Hue[1.193735495812213, 1, -1.5163441529766597`], 
     Hue[1.1933767798587336`, 1, -1.3135386605954384`], 
     Hue[1.192930889272359, 1, -1.1429947981712647`], 
     Hue[1.192200689674755, 1, -0.9523103939910731], 
     Hue[1.1911402097598756`, 1, -0.7660385692378151], 
     Hue[1.189524850672032, 1, -0.5753324635548223], 
     Hue[1.1871823696553956`, 1, -0.38932733014560483`], 
     Hue[1.1837289054588065`, 1, -0.20398187011846924`], 
     Hue[1.1785106604421345`, 1, -0.015445162688783487`], 
     Hue[1.170717491146731, 1, 0.17306780316192227`], 
     Hue[1.1592235777618916`, 1, 0.3588173201831134], 
     Hue[1.1416783297923843`, 1, 0.5461391806735716], 
     Hue[1.1141923433293153`, 1, 0.7338559473848568], 
     Hue[1.0671541925205783`, 1, 0.9215973133024502], 
     Hue[1.319803820626232, 1, -17.264488266373966`], 
     Hue[1.319803820626232, 1, -17.07736705803298], 
     Hue[1.319803820626232, 1, -16.90742299186392], 
     Hue[1.319803820626232, 1, -16.70312464135101], 
     Hue[1.319803820626232, 1, -16.53318057518195], 
     Hue[1.319803820626232, 1, -16.32888222466904], 
     Hue[1.319803820626232, 1, -16.15893815849998], 
     Hue[1.319803820626232, 1, -15.954639807987068`], 
     Hue[1.319803820626232, 1, -15.784695741818005`], 
     Hue[1.319803820626232, 1, -15.580397391305098`], 
     Hue[1.3198038206262317`, 1, -15.407712291810729`], 
     Hue[1.3198038206262317`, 1, -15.206154974623129`], 
     Hue[1.3198038206262317`, 1, -15.033469875128759`], 
     Hue[1.3198038206262315`, 1, -14.831912557941154`], 
     Hue[1.3198038206262312`, 1, -14.657856941784134`], 
     Hue[1.319803820626231, 1, -14.457670141259184`], 
     Hue[1.3198038206262306`, 1, -14.283614525102157`], 
     Hue[1.31980382062623, 1, -14.08342772457721], 
     Hue[1.319803820626229, 1, -13.908172906340367`], 
     Hue[1.3198038206262273`, 1, -13.709185307895234`], 
     Hue[1.319803820626225, 1, -13.511830908473097`], 
     Hue[1.3198038206262217`, 1, -13.334942891213258`], 
     Hue[1.3198038206262166`, 1, -13.137588491791115`], 
     Hue[1.3198038206262095`, 1, -12.960700474531269`], 
     Hue[1.3198038206261982`, 1, -12.76334607510912], 
     Hue[1.3198038206261828`, 1, -12.58645805784926], 
     Hue[1.3198038206261575`, 1, -12.38910365842709], 
     Hue[1.319803820626124, 1, -12.212215641167207`], 
     Hue[1.3198038206260685`, 1, -12.014861241744995`], 
     Hue[1.3198038206259948`, 1, -11.837973224485054`], 
     Hue[1.3198038206258724`, 1, -11.64061882506275], 
     Hue[1.3198038206257103`, 1, -11.463730807802685`], 
     Hue[1.3198038206254417`, 1, -11.266376408380173`], 
     Hue[1.3198038206250853`, 1, -11.08948839111984], 
     Hue[1.3198038206244946`, 1, -10.892133991696879`], 
     Hue[1.3198038206237106`, 1, -10.715245974435943`], 
     Hue[1.3198038206224119`, 1, -10.517891575011992`], 
     Hue[1.3198038206206884`, 1, -10.341003557749742`], 
     Hue[1.3198038206178326`, 1, -10.14364915832361], 
     Hue[1.319803820613739, 1, -9.95506606553673], 
     Hue[1.3198038206075644`, 1, -9.76429014608669], 
     Hue[1.3198038205987637`, 1, -9.580823648833796], 
     Hue[1.3198038205851872`, 1, -9.390047729373393], 
     Hue[1.3198038205658367`, 1, -9.20658123210573], 
     Hue[1.3198038205359857`, 1, -9.015805312622543], 
     Hue[1.3198038204934395`, 1, -8.832338815322409], 
     Hue[1.3198038204278049`, 1, -8.64156289578913], 
     Hue[1.3198038203342572`, 1, -8.458096398417597], 
     Hue[1.3198038201899451`, 1, -8.267320478774174], 
     Hue[1.3198038199842594`, 1, -8.083853981245657], 
     Hue[1.319803819666956, 1, -7.8930780613600655`], 
     Hue[1.3198038192147095`, 1, -7.709611563486384], 
     Hue[1.319803818517045, 1, -7.5188356430683205`], 
     Hue[1.3198038175226787`, 1, -7.335369144435714], 
     Hue[1.319803815988705, 1, -7.144593222846889], 
     Hue[1.319803813802364, 1, -6.961126722545623], 
     Hue[1.3198038104295742`, 1, -6.7703507983826094`], 
     Hue[1.3198038056224053`, 1, -6.58688429441241], 
     Hue[1.3198037982065594`, 1, -6.396108364589469], 
     Hue[1.3198037872282757`, 1, -6.206794314219586], 
     Hue[1.3198037710652657`, 1, -6.019307612141744], 
     Hue[1.3198037471932196`, 1, -5.832551841492012], 
     Hue[1.3198037116551549`, 1, -5.645065112290809], 
     Hue[1.3198036591670081`, 1, -5.458309301581115], 
     Hue[1.3198035810284388`, 1, -5.270822512743135], 
     Hue[1.319803465621198, 1, -5.084066613952715], 
     Hue[1.3198032938155355`, 1, -4.896579693990197], 
     Hue[1.3198030400659317`, 1, -4.709823601535318], 
     Hue[1.3198026366304538`, 1, -4.5119204306820455`], 
     Hue[1.3198020937854873`, 1, -4.332656091288518], 
     Hue[1.319801266928352, 1, -4.146812874343933], 
     Hue[1.3198000237508807`, 1, -3.9584107768660424`], 
     Hue[1.3197980823059812`, 1, -3.7622414409065836`], 
     Hue[1.319795446486407, 1, -3.5827000686026116`], 
     Hue[1.3197911875823178`, 1, -3.3873954830965918`], 
     Hue[1.3197853792725063`, 1, -3.2077126195505494`], 
     Hue[1.3197760253938484`, 1, -3.012834902382873], 
     Hue[1.3197632158309793`, 1, -2.8327996164730695`], 
     Hue[1.3197426670375567`, 1, -2.63828599367661], 
     Hue[1.3197100026556385`, 1, -2.4350012688863973`], 
     Hue[1.3196693210059576`, 1, -2.263903944772566], 
     Hue[1.3195974721748274`, 1, -2.0606017053687804`], 
     Hue[1.3195079522982895`, 1, -1.8894364195997497`], 
     Hue[1.319349786601025, 1, -1.6860144192289932`], 
     Hue[1.3191526089958527`, 1, -1.5147003967747172`], 
     Hue[1.318803930092644, 1, -1.3110169083083851`], 
     Hue[1.318368712840729, 1, -1.1393792408921841`], 
     Hue[1.3176516413437425`, 1, -0.9468978101024246], 
     Hue[1.3166004928042025`, 1, -0.758003503525611], 
     Hue[1.3150366429235754`, 1, -0.5691994482904883], 
     Hue[1.3128697415082413`, 1, -0.391299144048993], 
     Hue[1.3094868307430474`, 1, -0.20274327782003176`], 
     Hue[1.304521666514172, 1, -0.016516190808324227`], 
     Hue[1.2970706121190492`, 1, 0.17123964909109146`], 
     Hue[1.2858356279093655`, 1, 0.3600032225697427], 
     Hue[1.1343385224700262`, 1, 0.7339709229844333], 
     Hue[1.2690424935846434`, 1, 0.5463465629071804], 
     Hue[1.242682625661346, 1, 0.7343564111819486], 
     Hue[1.0842181770112687`, 1, 0.9215842489252276], 
     Hue[1.1983166288479576`, 1, 0.9218890083323162], 
     Hue[1.4451986217411636`, 1, -17.264488266373966`], 
     Hue[1.4451986217411636`, 1, -17.07736705803298], 
     Hue[1.4451986217411636`, 1, -16.90742299186392], 
     Hue[1.4451986217411636`, 1, -16.70312464135101], 
     Hue[1.4451986217411636`, 1, -16.53318057518195], 
     Hue[1.4451986217411636`, 1, -16.32888222466904], 
     Hue[1.4451986217411636`, 1, -16.15893815849998], 
     Hue[1.4451986217411636`, 1, -15.954639807987068`], 
     Hue[1.4451986217411636`, 1, -15.784695741818005`], 
     Hue[1.4451986217411636`, 1, -15.580397391305098`], 
     Hue[1.4451986217411636`, 1, -15.407712291810729`], 
     Hue[1.4451986217411636`, 1, -15.206154974623129`], 
     Hue[1.4451986217411634`, 1, -15.033469875128759`], 
     Hue[1.4451986217411634`, 1, -14.831912557941154`], 
     Hue[1.4451986217411634`, 1, -14.65785694178413], 
     Hue[1.4451986217411634`, 1, -14.45767014125918], 
     Hue[1.4451986217411632`, 1, -14.283614525102157`], 
     Hue[1.445198621741163, 1, -14.083427724577206`], 
     Hue[1.4451986217411625`, 1, -13.90817290634036], 
     Hue[1.445198621741162, 1, -13.709185307895227`], 
     Hue[1.4451986217411612`, 1, -13.511830908473085`], 
     Hue[1.4451986217411599`, 1, -13.33494289121324], 
     Hue[1.445198621741158, 1, -13.13758849179109], 
     Hue[1.4451986217411554`, 1, -12.960700474531231`], 
     Hue[1.445198621741151, 1, -12.76334607510906], 
     Hue[1.4451986217411454`, 1, -12.586458057849176`], 
     Hue[1.445198621741136, 1, -12.389103658426963`], 
     Hue[1.4451986217411235`, 1, -12.212215641167024`], 
     Hue[1.4451986217411028`, 1, -12.014861241744716`], 
     Hue[1.4451986217410753`, 1, -11.837973224484651`], 
     Hue[1.4451986217410298`, 1, -11.640618825062138`], 
     Hue[1.4451986217409694`, 1, -11.463730807801797`], 
     Hue[1.445198621740869, 1, -11.266376408378829`], 
     Hue[1.4451986217407362`, 1, -11.089488391117886`], 
     Hue[1.445198621740516, 1, -10.89213399169392], 
     Hue[1.4451986217402235`, 1, -10.715245974431651`], 
     Hue[1.4451986217397392`, 1, -10.517891575005486`], 
     Hue[1.4451986217390966`, 1, -10.341003557740299`], 
     Hue[1.4451986217380322`, 1, -10.143649158309305`], 
     Hue[1.4451986217365056`, 1, -9.955066065515453], 
     Hue[1.4451986217342034`, 1, -9.764290146054897], 
     Hue[1.445198621730922, 1, -9.580823648787016], 
     Hue[1.44519862172586, 1, -9.390047729303488], 
     Hue[1.4451986217186452`, 1, -9.20658123200287], 
     Hue[1.445198621707515, 1, -9.015805312468844], 
     Hue[1.4451986216916515`, 1, -8.832338815096248], 
     Hue[1.4451986216671795`, 1, -8.641562895451186], 
     Hue[1.4451986216322998`, 1, -8.45809639792033], 
     Hue[1.4451986215784927`, 1, -8.267320478031127], 
     Hue[1.445198621501802, 1, -8.083853980152305], 
     Hue[1.4451986213834942`, 1, -7.893078059726309], 
     Hue[1.4451986212148724`, 1, -7.7096115610824], 
     Hue[1.4451986209547458`, 1, -7.518835639476133], 
     Hue[1.4451986205839926`, 1, -7.335369139150008], 
     Hue[1.445198620012045, 1, -7.14459321494865], 
     Hue[1.4451986191968598`, 1, -6.961126710923797], 
     Hue[1.4451986179393028`, 1, -6.770350781016539], 
     Hue[1.4451986161469326`, 1, -6.5868842688591815`], 
     Hue[1.4451986133819072`, 1, -6.396108326406208], 
     Hue[1.4451986092886138`, 1, -6.206794257339051], 
     Hue[1.4451986032621753`, 1, -6.019307527733746], 
     Hue[1.445198594361393, 1, -5.832551716427169], 
     Hue[1.4451985811108885`, 1, -5.645064926700522], 
     Hue[1.4451985615404748`, 1, -5.458309026597378], 
     Hue[1.4451985324061853`, 1, -5.2708221046801675`], 
     Hue[1.4451984893760876`, 1, -5.0840660093373105`], 
     Hue[1.4451984253175238`, 1, -4.896578796768496], 
     Hue[1.445198330705625, 1, -4.709822272145453], 
     Hue[1.445198180282192, 1, -4.511918414186797], 
     Hue[1.4451979778783752`, 1, -4.332653150248889], 
     Hue[1.4451976695769773`, 1, -4.146808525033056], 
     Hue[1.4451972060432172`, 1, -3.9584043101945117`], 
     Hue[1.4451964821437326`, 1, -3.7622316675273186`], 
     Hue[1.4451954993191625`, 1, -3.58268580570856], 
     Hue[1.445193911251788, 1, -3.3873739658084077`], 
     Hue[1.4451917453611898`, 1, -3.207681208041068], 
     Hue[1.445188257155464, 1, -3.0127875553405863`], 
     Hue[1.4451834828050691`, 1, -2.832821835551181], 
     Hue[1.4451758171861722`, 1, -2.6382189335277433`], 
     Hue[1.4451636295980375`, 1, -2.434841388252849], 
     Hue[1.4451484488663973`, 1, -2.2636746752825188`], 
     Hue[1.445121626973862, 1, -2.060249796538689], 
     Hue[1.4450881889069178`, 1, -1.8889315476726167`], 
     Hue[1.4450290570796813`, 1, -1.685238852093163], 
     Hue[1.4449552457024861`, 1, -1.513586585325055], 
     Hue[1.444824463313116, 1, -1.3093028369371738`], 
     Hue[1.444660756454676, 1, -1.1369121141562413`], 
     Hue[1.4444104461980358`, 1, -0.9554096173406095], 
     Hue[1.4440289750472952`, 1, -0.7679122681209416], 
     Hue[1.443457360582397, 1, -0.5789112053671994], 
     Hue[1.4426059730304779`, 1, -0.3898393134134073], 
     Hue[1.3909669126498745`, 1, 0.17077717934913494`], 
     Hue[1.4413538766133045`, 1, -0.20270154133012985`], 
     Hue[1.4395022951022756`, 1, -0.016027511119746096`], 
     Hue[1.4366929738542755`, 1, 0.1742794948798322], 
     Hue[1.2862020361987838`, 1, 0.546589957819469], 
     Hue[1.4326478292173586`, 1, 0.3588135773794091], 
     Hue[1.426556990273669, 1, 0.5461358194378877], 
     Hue[1.218309908124326, 1, 0.921595710571526], 
     Hue[1.2882039798684748`, 1, 1.1093005735094728`], 
     Hue[1.4174427464754713`, 1, 0.7338860671335313], 
     Hue[1.4037233250986203`, 1, 0.9216917360344973], 
     Hue[1.3827373216729473`, 1, 1.1093119871564916`], 
     Hue[1.1149873442054035`, 1, 1.1092897575448346`], 
     Hue[1.1136142882791724`, 1, 1.2971958668698969`], 
     Hue[1.3490141496502823`, 1, 1.2973612883062409`], 
     Hue[1.04817900420469, 1, 1.109434734488475], 
     Hue[1.0413027427360426`, 1, 1.2970138205300155`], 
     Hue[1.0127748858784458`, 1, 1.1093051221391974`], 
     Hue[1.0076761523938198`, 1, 1.1094289961986854`], 
     Hue[0.570593422856095, 1, -17.264488266373966`], 
     Hue[0.570593422856095, 1, -17.07736705803298], 
     Hue[0.570593422856095, 1, -16.90742299186392], 
     Hue[0.570593422856095, 1, -16.70312464135101], 
     Hue[0.570593422856095, 1, -16.53318057518195], 
     Hue[0.570593422856095, 1, -16.32888222466904], 
     Hue[0.570593422856095, 1, -16.15893815849998], 
     Hue[0.5705934228560952, 1, -15.954639807987068`], 
     Hue[0.5705934228560952, 1, -15.784695741818005`], 
     Hue[0.5705934228560952, 1, -15.580397391305098`], 
     Hue[0.5705934228560952, 1, -15.407712291810729`], 
     Hue[0.5705934228560952, 1, -15.206154974623129`], 
     Hue[0.5705934228560952, 1, -15.033469875128759`], 
     Hue[0.5705934228560953, 1, -14.831912557941154`], 
     Hue[0.5705934228560954, 1, -14.65785694178413], 
     Hue[0.5705934228560956, 1, -14.45767014125918], 
     Hue[0.5705934228560957, 1, -14.283614525102157`], 
     Hue[0.570593422856096, 1, -14.083427724577206`], 
     Hue[0.5705934228560965, 1, -13.908172906340361`], 
     Hue[0.5705934228560973, 1, -13.709185307895227`], 
     Hue[0.5705934228560984, 1, -13.511830908473087`], 
     Hue[0.5705934228560998, 1, -13.334942891213242`], 
     Hue[0.5705934228561023, 1, -13.137588491791092`], 
     Hue[0.5705934228561056, 1, -12.960700474531235`], 
     Hue[0.5705934228561111, 1, -12.763346075109064`], 
     Hue[0.5705934228561182, 1, -12.586458057849182`], 
     Hue[0.5705934228561302, 1, -12.389103658426974`], 
     Hue[0.5705934228561462, 1, -12.212215641167038`], 
     Hue[0.5705934228561725, 1, -12.014861241744738`], 
     Hue[0.5705934228562075, 1, -11.83797322448468], 
     Hue[0.5705934228562655, 1, -11.640618825062182`], 
     Hue[0.5705934228563423, 1, -11.463730807801863`], 
     Hue[0.5705934228564696, 1, -11.266376408378928`], 
     Hue[0.5705934228566387, 1, -11.089488391118032`], 
     Hue[0.5705934228569186, 1, -10.89213399169414], 
     Hue[0.5705934228572902, 1, -10.715245974431966`], 
     Hue[0.5705934228579058, 1, -10.517891575005965`], 
     Hue[0.5705934228587228, 1, -10.341003557740997`], 
     Hue[0.5705934228600764, 1, -10.143649158310359`], 
     Hue[0.5705934228620169, 1, -9.955066065517022], 
     Hue[0.5705934228649439, 1, -9.764290146057242], 
     Hue[0.5705934228691154, 1, -9.580823648790462], 
     Hue[0.5705934228755509, 1, -9.390047729308641], 
     Hue[0.5705934228847234, 1, -9.206581232010448], 
     Hue[0.5705934228988732, 1, -9.015805312480168], 
     Hue[0.5705934229190407, 1, -8.832338815112912], 
     Hue[0.5705934229501525, 1, -8.641562895476088], 
     Hue[0.5705934229944953, 1, -8.458096397956973], 
     Hue[0.5705934230629016, 1, -8.267320478085882], 
     Hue[0.5705934231603996, 1, -8.083853980232872], 
     Hue[0.5705934233108063, 1, -7.893078059846695], 
     Hue[0.570593423525178, 1, -7.7096115612595435`], 
     Hue[0.5705934238558812, 1, -7.518835639740831], 
     Hue[0.5705934243272259, 1, -7.3353691395394955`], 
     Hue[0.5705934250543524, 1, -7.144593215530647], 
     Hue[0.570593426090711, 1, -6.961126711780174], 
     Hue[0.570593427689464, 1, -6.770350782296192], 
     Hue[0.5705934299681343, 1, -6.5868842707421225`], 
     Hue[0.5705934334833569, 1, -6.396108329219816], 
     Hue[0.5705934386872291, 1, -6.206794261530405], 
     Hue[0.5705934463487405, 1, -6.019307533953516], 
     Hue[0.5705934576644532, 1, -5.832551725642817], 
     Hue[0.5705934745100392, 1, -5.64506494037611], 
     Hue[0.5705934993902306, 1, -5.458309046860102], 
     Hue[0.5705935364291342, 1, -5.270822134749107], 
     Hue[0.5705935911340058, 1, -5.084066053889629], 
     Hue[0.5705936725727061, 1, -4.8965788628821425`], 
     Hue[0.5705937928543476, 1, -4.7098223701043915`], 
     Hue[0.570593984090065, 1, -4.511918562776767], 
     Hue[0.5705942414092116, 1, -4.332653366966374], 
     Hue[0.5705946333574717, 1, -4.146808845523229], 
     Hue[0.5705952226546749, 1, -3.958404786709826], 
     Hue[0.5705961429578315, 1, -3.762232387711558], 
     Hue[0.5705973924344225, 1, -3.5826868567269594`], 
     Hue[0.5705994113597267, 1, -3.3873755514182875`], 
     Hue[0.5706021648699187, 1, -3.207683522801199], 
     Hue[0.5706065994297874, 1, -3.0127910445218964`], 
     Hue[0.5706126690312727, 1, -2.8328269324005158`], 
     Hue[0.5706224141981833, 1, -2.6382266121621027`], 
     Hue[0.5706379078471622, 1, -2.434853173043078], 
     Hue[0.5706572061987161, 1, -2.2636915770076103`], 
     Hue[0.5706913022416515, 1, -2.060275745430384], 
     Hue[0.5707338069587709, 1, -1.8889687867957303`], 
     Hue[0.570808967286505, 1, -1.6852960877862568`], 
     Hue[0.570902777369993, 1, -1.5136688372018103`], 
     Hue[0.5710689700782277, 1, -1.3094295646908038`], 
     Hue[0.5712769578364998, 1, -1.1370947864453156`], 
     Hue[0.5715952696374027, 1, -0.9554932642979719], 
     Hue[0.5721125143433425, 1, -0.7577703377809952], 
     Hue[0.5728043350354415, 1, -0.5795143557352056], 
     Hue[0.5738832779281006, 1, -0.39074969778012414`], 
     Hue[0.5754674526287753, 1, -0.20407828347111745`], 
     Hue[0.577821224188314, 1, -0.01701075265650598], 
     Hue[0.5813366722055494, 1, 0.17105453825467787`], 
     Hue[0.586595312388956, 1, 0.35986864103863037`], 
     Hue[0.5944134289001284, 1, 0.547858583212299], 
     Hue[0.605994422346082, 1, 0.7339116904660017], 
     Hue[0.6237371056840326, 1, 0.9219482180637586], 
     Hue[0.6514691816114175, 1, 1.1096460453217456`], 
     Hue[0.6992554002232427, 1, 1.2978846767308663`], 
     Hue[0.9422123911513253, 1, 1.2970824980431137`], 
     Hue[0.9897795058509798, 1, 1.1093144993386312`], 
     Hue[0.6959882239710269, 1, -17.264488266373966`], 
     Hue[0.6959882239710269, 1, -17.07736705803298], 
     Hue[0.6959882239710269, 1, -16.90742299186392], 
     Hue[0.6959882239710269, 1, -16.70312464135101], 
     Hue[0.6959882239710269, 1, -16.53318057518195], 
     Hue[0.6959882239710269, 1, -16.32888222466904], 
     Hue[0.6959882239710269, 1, -16.15893815849998], 
     Hue[0.6959882239710269, 1, -15.954639807987068`], 
     Hue[0.6959882239710269, 1, -15.784695741818005`], 
     Hue[0.6959882239710269, 1, -15.580397391305098`], 
     Hue[0.6959882239710269, 1, -15.407712291810729`], 
     Hue[0.6959882239710271, 1, -15.206154974623129`], 
     Hue[0.6959882239710271, 1, -15.033469875128759`], 
     Hue[0.6959882239710273, 1, -14.831912557941154`], 
     Hue[0.6959882239710274, 1, -14.657856941784134`], 
     Hue[0.6959882239710278, 1, -14.457670141259184`], 
     Hue[0.6959882239710282, 1, -14.283614525102161`], 
     Hue[0.695988223971029, 1, -14.083427724577211`], 
     Hue[0.69598822397103, 1, -13.908172906340367`], 
     Hue[0.6959882239710315, 1, -13.709185307895236`], 
     Hue[0.6959882239710341, 1, -13.5118309084731], 
     Hue[0.6959882239710373, 1, -13.33494289121326], 
     Hue[0.6959882239710429, 1, -13.13758849179112], 
     Hue[0.69598822397105, 1, -12.960700474531274`], 
     Hue[0.695988223971062, 1, -12.763346075109128`], 
     Hue[0.695988223971078, 1, -12.586458057849274`], 
     Hue[0.6959882239711043, 1, -12.389103658427112`], 
     Hue[0.6959882239711392, 1, -12.21221564116724], 
     Hue[0.695988223971197, 1, -12.014861241745045`], 
     Hue[0.6959882239712738, 1, -11.837973224485127`], 
     Hue[0.6959882239714011, 1, -11.640618825062857`], 
     Hue[0.69598822397157, 1, -11.463730807802843`], 
     Hue[0.6959882239718498, 1, -11.266376408380413`], 
     Hue[0.6959882239722212, 1, -11.089488391120186`], 
     Hue[0.6959882239728363, 1, -10.892133991697404`], 
     Hue[0.6959882239736528, 1, -10.715245974436707`], 
     Hue[0.6959882239750055, 1, -10.517891575013147`], 
     Hue[0.6959882239768007, 1, -10.341003557751419`], 
     Hue[0.695988223979775, 1, -10.14364915832615], 
     Hue[0.6959882239840387, 1, -9.95506606554051], 
     Hue[0.6959882239904699, 1, -9.764290146092339], 
     Hue[0.6959882239996362, 1, -9.580823648842106], 
     Hue[0.6959882240137769, 1, -9.39004772938581], 
     Hue[0.6959882240339312, 1, -9.206581232124002], 
     Hue[0.6959882240650226, 1, -9.015805312649846], 
     Hue[0.6959882241093365, 1, -8.832338815362583], 
     Hue[0.6959882241776979, 1, -8.64156289584916], 
     Hue[0.6959882242751321, 1, -8.45809639850593], 
     Hue[0.6959882244254403, 1, -8.267320478906168], 
     Hue[0.6959882246396714, 1, -8.083853981439878], 
     Hue[0.6959882249701581, 1, -7.893078061650281], 
     Hue[0.695988225441194, 1, -7.709611563913421], 
     Hue[0.6959882261678441, 1, -7.518835643706425], 
     Hue[0.6959882272035238, 1, -7.335369145374652], 
     Hue[0.6959882288012293, 1, -7.144593224249909], 
     Hue[0.6959882310784067, 1, -6.96112672461009], 
     Hue[0.6959882345913261, 1, -6.77035080146747], 
     Hue[0.6959882395982186, 1, -6.586884298951613], 
     Hue[0.6959882473221712, 1, -6.396108371372237], 
     Hue[0.6959882587565703, 1, -6.206794324323685], 
     Hue[0.6959882755911057, 1, -6.019307627135742], 
     Hue[0.6959883004549642, 1, -5.832551863708175], 
     Hue[0.6959883374695279, 1, -5.645065145258536], 
     Hue[0.6959883921383954, 1, -5.458309350428426], 
     Hue[0.6959884735233747, 1, -5.27082258523023], 
     Hue[0.6959885937254056, 1, -5.084066721354749], 
     Hue[0.6959887726689942, 1, -4.896579853369805], 
     Hue[0.6959890369609372, 1, -4.70982383768365], 
     Hue[0.6959894571574623, 1, -4.511920788884849], 
     Hue[0.6959900225550131, 1, -4.332656613722791], 
     Hue[0.695990883763314, 1, -4.146813646935064], 
     Hue[0.6959921785859627, 1, -3.9584119255691315`], 
     Hue[0.6959942006799813, 1, -3.762243176980369], 
     Hue[0.69599694598553, 1, -3.5827026021337662`], 
     Hue[0.6960013817753681, 1, -3.387399305163793], 
     Hue[0.696007431283854, 1, -3.207718198969025], 
     Hue[0.6960171735020972, 1, -3.0128433119923077`], 
     Hue[0.6960305146838457, 1, -2.8328119020535745`], 
     Hue[0.6960519158327239, 1, -2.6383044974752226`], 
     Hue[0.6960859339663756, 1, -2.43502965838238], 
     Hue[0.6961282996576083, 1, -2.263944648426169], 
     Hue[0.6962031173485156, 1, -2.0606641629693216`], 
     Hue[0.6962963266789081, 1, -1.889525991492117], 
     Hue[0.6964609849691744, 1, -1.6861519242981917`], 
     Hue[0.6966662100273946, 1, -1.5148977059359565`], 
     Hue[0.697028993088771, 1, -1.3113201014484879`], 
     Hue[0.6974815879210676, 1, -1.1398148263172743`], 
     Hue[0.6982267402086628, 1, -0.9475520709850296], 
     Hue[0.6993178104049085, 1, -0.7589795049919674], 
     Hue[0.7009383134062961, 1, -0.5706566084558149], 
     Hue[0.7031972438326187, 1, -0.39217696617619424`], 
     Hue[0.6091650926471117, 1, 0.17074225116772512`], 
     Hue[0.7066961354408682, 1, -0.20443925474195002`], 
     Hue[0.7119031983785737, 1, -0.016640868648845064`], 
     Hue[0.7139248383015024, 1, 0.546471377674219], 
     Hue[0.719654751514412, 1, 0.17087977890185413`], 
     Hue[0.731334156192009, 1, 0.3592532901058342], 
     Hue[0.7816730521256092, 1, 0.9216405173623221], 
     Hue[0.711771602051128, 1, 1.1093637523243025`], 
     Hue[0.749039551824682, 1, 0.5472217453387062], 
     Hue[0.7765159355785141, 1, 0.7338449725222205], 
     Hue[0.8850113667856512, 1, 1.1093089601342097`], 
     Hue[0.886369838992648, 1, 1.2970036933691707`], 
     Hue[0.8238698723831245, 1, 0.921718437522208], 
     Hue[0.951811390193093, 1, 1.1093160639310944`], 
     Hue[0.9872415734436376, 1, 1.1093395927854632`], 
     Hue[0.821383025085958, 1, -17.264488266373966`], 
     Hue[0.821383025085958, 1, -17.07736705803298], 
     Hue[0.821383025085958, 1, -16.90742299186392], 
     Hue[0.821383025085958, 1, -16.70312464135101], 
     Hue[0.821383025085958, 1, -16.53318057518195], 
     Hue[0.821383025085958, 1, -16.32888222466904], 
     Hue[0.821383025085958, 1, -16.15893815849998], 
     Hue[0.8213830250859581, 1, -15.954639807987068`], 
     Hue[0.8213830250859581, 1, -15.784695741818005`], 
     Hue[0.8213830250859581, 1, -15.580397391305098`], 
     Hue[0.8213830250859581, 1, -15.407712291810729`], 
     Hue[0.8213830250859582, 1, -15.206154974623129`], 
     Hue[0.8213830250859583, 1, -15.033469875128759`], 
     Hue[0.8213830250859584, 1, -14.831912557941154`], 
     Hue[0.8213830250859586, 1, -14.657856941784134`], 
     Hue[0.821383025085959, 1, -14.457670141259184`], 
     Hue[0.8213830250859593, 1, -14.283614525102164`], 
     Hue[0.8213830250859601, 1, -14.083427724577216`], 
     Hue[0.8213830250859611, 1, -13.908172906340376`], 
     Hue[0.8213830250859626, 1, -13.709185307895249`], 
     Hue[0.821383025085965, 1, -13.511830908473117`], 
     Hue[0.8213830250859682, 1, -13.334942891213286`], 
     Hue[0.8213830250859733, 1, -13.13758849179116], 
     Hue[0.8213830250859802, 1, -12.960700474531333`], 
     Hue[0.8213830250859917, 1, -12.763346075109215`], 
     Hue[0.8213830250860068, 1, -12.586458057849399`], 
     Hue[0.8213830250860319, 1, -12.3891036584273], 
     Hue[0.8213830250860654, 1, -12.212215641167512`], 
     Hue[0.8213830250861207, 1, -12.014861241745457`], 
     Hue[0.8213830250861941, 1, -11.837973224485726`], 
     Hue[0.8213830250863157, 1, -11.640618825063767`], 
     Hue[0.8213830250864771, 1, -11.463730807804161`], 
     Hue[0.8213830250867444, 1, -11.26637640838241], 
     Hue[0.8213830250870993, 1, -11.089488391123083`], 
     Hue[0.8213830250876872, 1, -10.892133991701796`], 
     Hue[0.8213830250884674, 1, -10.715245974443079`], 
     Hue[0.82138302508976, 1, -10.5178915750228], 
     Hue[0.8213830250914755, 1, -10.341003557765427`], 
     Hue[0.8213830250943177, 1, -10.143649158347374`], 
     Hue[0.821383025098392, 1, -9.955066065572076], 
     Hue[0.8213830251045378, 1, -9.764290146139508], 
     Hue[0.821383025113297, 1, -9.580823648911514], 
     Hue[0.8213830251268097, 1, -9.390047729489524], 
     Hue[0.8213830251460691, 1, -9.20658123227661], 
     Hue[0.8213830251757799, 1, -9.015805312877884], 
     Hue[0.821383025218126, 1, -8.832338815698128], 
     Hue[0.8213830252834518, 1, -8.641562896350553], 
     Hue[0.8213830253765593, 1, -8.458096399243702], 
     Hue[0.8213830255201929, 1, -8.267320480008593], 
     Hue[0.8213830257249111, 1, -8.083853983062038], 
     Hue[0.8213830260407222, 1, -7.893078064074214], 
     Hue[0.8213830264908416, 1, -7.709611567480107], 
     Hue[0.8213830271852244, 1, -7.518835649035997], 
     Hue[0.8213830281749142, 1, -7.335369153216825], 
     Hue[0.8213830297016727, 1, -7.144593235968181], 
     Hue[0.8213830318777307, 1, -6.961126741852891], 
     Hue[0.8213830352346566, 1, -6.770350827232758], 
     Hue[0.8213830400192148, 1, -6.586884336863831], 
     Hue[0.8213830474001796, 1, -6.396108428023083], 
     Hue[0.8213830583268248, 1, -6.206794408714854], 
     Hue[0.8213830744138064, 1, -6.019307752368187], 
     Hue[0.8213830981735564, 1, -5.832552049261354], 
     Hue[0.821383133544434, 1, -5.64506542061054], 
     Hue[0.8213831857856259, 1, -5.458309758409274], 
     Hue[0.8213832635564953, 1, -5.270823190654192], 
     Hue[0.8213833784205269, 1, -5.084067618393328], 
     Hue[0.8213835494172269, 1, -4.896581184531836], 
     Hue[0.8213838019713872, 1, -4.70982581002643], 
     Hue[0.8213842035046628, 1, -4.51192378063589], 
     Hue[0.8213847437870645, 1, -4.332660977139843], 
     Hue[0.821385566734207, 1, -4.14682009965244], 
     Hue[0.8213868040177588, 1, -3.9584215195201944`], 
     Hue[0.8213887362215926, 1, -3.7622576764750404`], 
     Hue[0.8213913594234333, 1, -3.5827237615712697`], 
     Hue[0.8213955977659857, 1, -3.3874312253319827`], 
     Hue[0.8214013776873124, 1, -3.207764794124375], 
     Hue[0.821410685007767, 1, -3.0129135388860284`], 
     Hue[0.8214234359298739, 1, -2.83283455151384], 
     Hue[0.8214438730433931, 1, -2.6384265157323874`], 
     Hue[0.8214763496437337, 1, -2.4352666399492193`], 
     Hue[0.8215167849433085, 1, -2.2642843402485626`], 
     Hue[0.8215881508805545, 1, -2.0611851792199367`], 
     Hue[0.8216769837798094, 1, -1.890272795093342], 
     Hue[0.8218337047811981, 1, -1.6872972918891487`], 
     Hue[0.8220286694304766, 1, -1.5165392956317445`], 
     Hue[0.8223723208005151, 1, -1.3138374195239428`], 
     Hue[0.8228277676027292, 1, -1.1339616593481348`], 
     Hue[0.823497971904827, 1, -0.9529473040306324], 
     Hue[0.8245116023416141, 1, -0.7669782913346155], 
     Hue[0.8260531284815658, 1, -0.5767295065244644], 
     Hue[0.8282833120090436, 1, -0.39137881491961], 
     Hue[0.8317126087850981, 1, -0.19992524992046223`], 
     Hue[0.8366374672519757, 1, -0.015136301129347496`], 
     Hue[0.8440491168940473, 1, 0.17208410626083448`], 
     Hue[0.8550975377542851, 1, 0.35873572434009027`], 
     Hue[0.865577709548445, 1, 0.7341168610794568], 
     Hue[0.8718777787981534, 1, 0.5461698288132831], 
     Hue[0.915634009554274, 1, 0.9220831406745365], 
     Hue[0.8980859166358786, 1, 0.7342166836567786], 
     Hue[0.9420793634651273, 1, 0.9216491902299361], 
     Hue[0.9467778262008897, 1, -17.264488266373966`], 
     Hue[0.9467778262008897, 1, -17.07736705803298], 
     Hue[0.9467778262008897, 1, -16.90742299186392], 
     Hue[0.9467778262008897, 1, -16.70312464135101], 
     Hue[0.9467778262008897, 1, -16.53318057518195], 
     Hue[0.9467778262008897, 1, -16.32888222466904], 
     Hue[0.9467778262008897, 1, -16.15893815849998], 
     Hue[0.9467778262008897, 1, -15.954639807987068`], 
     Hue[0.9467778262008897, 1, -15.784695741818005`], 
     Hue[0.9467778262008898, 1, -15.580397391305098`], 
     Hue[0.9467778262008898, 1, -15.407712291810729`], 
     Hue[0.9467778262008898, 1, -15.206154974623129`], 
     Hue[0.9467778262008898, 1, -15.033469875128759`], 
     Hue[0.9467778262008899, 1, -14.831912557941154`], 
     Hue[0.9467778262008899, 1, -14.657856941784138`], 
     Hue[0.9467778262008901, 1, -14.457670141259188`], 
     Hue[0.9467778262008902, 1, -14.283614525102164`], 
     Hue[0.9467778262008905, 1, -14.08342772457722], 
     Hue[0.9467778262008908, 1, -13.908172906340381`], 
     Hue[0.9467778262008913, 1, -13.709185307895257`], 
     Hue[0.9467778262008922, 1, -13.51183090847313], 
     Hue[0.9467778262008935, 1, -13.334942891213304`], 
     Hue[0.9467778262008952, 1, -13.137588491791185`], 
     Hue[0.9467778262008978, 1, -12.96070047453137], 
     Hue[0.946777826200902, 1, -12.76334607510927], 
     Hue[0.9467778262009076, 1, -12.586458057849482`], 
     Hue[0.9467778262009167, 1, -12.389103658427425`], 
     Hue[0.9467778262009289, 1, -12.212215641167694`], 
     Hue[0.946777826200949, 1, -12.014861241745734`], 
     Hue[0.9467778262009757, 1, -11.837973224486126`], 
     Hue[0.94677782620102, 1, -11.640618825064372`], 
     Hue[0.9467778262010788, 1, -11.463730807805039`], 
     Hue[0.9467778262011761, 1, -11.266376408383742`], 
     Hue[0.9467778262013055, 1, -11.089488391125016`], 
     Hue[0.9467778262015195, 1, -10.892133991704721`], 
     Hue[0.9467778262018037, 1, -10.715245974447324`], 
     Hue[0.9467778262022746, 1, -10.517891575029235`], 
     Hue[0.9467778262028994, 1, -10.341003557774764`], 
     Hue[0.9467778262039346, 1, -10.143649158361523`], 
     Hue[0.9467778262054186, 1, -9.95506606559312], 
     Hue[0.946777826207657, 1, -9.764290146170952], 
     Hue[0.9467778262108475, 1, -9.580823648957784], 
     Hue[0.9467778262157692, 1, -9.390047729558663], 
     Hue[0.9467778262227842, 1, -9.206581232378344], 
     Hue[0.9467778262336057, 1, -9.0158053130299], 
     Hue[0.9467778262490295, 1, -8.83233881592181], 
     Hue[0.9467778262728233, 1, -8.641562896684796], 
     Hue[0.946777826306736, 1, -8.458096399735522], 
     Hue[0.946777826359052, 1, -8.2673204807435], 
     Hue[0.946777826433617, 1, -8.083853984143413], 
     Hue[0.9467778265486455, 1, -7.893078065690076], 
     Hue[0.9467778267125934, 1, -7.709611569857759], 
     Hue[0.9467778269655099, 1, -7.518835652588833], 
     Hue[0.9467778273259866, 1, -7.335369158444629], 
     Hue[0.9467778278820811, 1, -7.1445932437799025`], 
     Hue[0.9467778286746712, 1, -6.96112675334741], 
     Hue[0.9467778298973712, 1, -6.7703508444086005`], 
     Hue[0.9467778316400607, 1, -6.586884362137147], 
     Hue[0.9467778343284445, 1, -6.396108465788075], 
     Hue[0.9467778383082784, 1, -6.206794464972295], 
     Hue[0.9467778441676715, 1, -6.019307835851514], 
     Hue[0.946777852821731, 1, -5.832552172956086], 
     Hue[0.9467778657049312, 1, -5.645065604167521], 
     Hue[0.9467778847328311, 1, -5.458310030380049], 
     Hue[0.9467779130594366, 1, -5.270823594245466], 
     Hue[0.946777954896514, 1, -5.084068216381836], 
     Hue[0.9467780171788035, 1, -4.896582071916621], 
     Hue[0.946778109166705, 1, -4.70982712483484], 
     Hue[0.9467782554169877, 1, -4.511925774997821], 
     Hue[0.9467784522031413, 1, -4.332663885868165], 
     Hue[0.9467787519423437, 1, -4.146824401112505], 
     Hue[0.9467792025905611, 1, -3.9584279148944432`], 
     Hue[0.9467799063373938, 1, -3.7622673417420662`], 
     Hue[0.9467808617438547, 1, -3.5827378659824616`], 
     Hue[0.9467824053692102, 1, -3.3874525018040407`], 
     Hue[0.9467845103700665, 1, -3.2077958506487727`], 
     Hue[0.9467878998391519, 1, -3.0129603425165863`], 
     Hue[0.9467932860025445, 1, -2.809507737375979], 
     Hue[0.9467999843926345, 1, -2.6385248167521054`], 
     Hue[0.9468118067033945, 1, -2.4354244870709607`], 
     Hue[0.9468265226344041, 1, -2.2645105184880556`], 
     Hue[0.9468524850670954, 1, -2.0615318690121294`], 
     Hue[0.9468847834700174, 1, -1.890769333441049], 
     Hue[0.9469417154176811, 1, -1.6880577681974074`], 
     Hue[0.947012451964214, 1, -1.5176273546602623`], 
     Hue[0.9471368977811513, 1, -1.315500831655539], 
     Hue[0.9473013652918768, 1, -1.1363835622382845`], 
     Hue[0.9475517733133706, 1, -0.9507109530916906], 
     Hue[0.9479218171246165, 1, -0.7650951901780516], 
     Hue[0.9484664463235293, 1, -0.5801403599011701], 
     Hue[0.9493125207906448, 1, -0.38722483784355144`], 
     Hue[0.9505167631035213, 1, -0.20260257079040733`], 
     Hue[0.9523069122800489, 1, -0.016824350002166755`], 
     Hue[0.9549917684661632, 1, 0.1710702789938211], 
     Hue[0.9589869605704732, 1, 0.3590821108810188], 
     Hue[0.9649133358020381, 1, 0.5464712633091227], 
     Hue[0.9737609103700149, 1, 0.7339575908190112], 
     Hue[0.9870945819509931, 1, 0.9218838721169591], 
     Hue[1.0721726273158214`, 1, -17.264488266373966`], 
     Hue[1.0721726273158214`, 1, -17.07736705803298], 
     Hue[1.0721726273158214`, 1, -16.90742299186392], 
     Hue[1.0721726273158214`, 1, -16.70312464135101], 
     Hue[1.0721726273158214`, 1, -16.53318057518195], 
     Hue[1.0721726273158214`, 1, -16.32888222466904], 
     Hue[1.0721726273158214`, 1, -16.15893815849998], 
     Hue[1.0721726273158214`, 1, -15.954639807987068`], 
     Hue[1.0721726273158214`, 1, -15.784695741818005`], 
     Hue[1.0721726273158214`, 1, -15.580397391305098`], 
     Hue[1.0721726273158214`, 1, -15.407712291810729`], 
     Hue[1.0721726273158214`, 1, -15.206154974623129`], 
     Hue[1.0721726273158214`, 1, -15.033469875128759`], 
     Hue[1.0721726273158212`, 1, -14.831912557941154`], 
     Hue[1.0721726273158212`, 1, -14.657856941784138`], 
     Hue[1.072172627315821, 1, -14.457670141259188`], 
     Hue[1.0721726273158207`, 1, -14.283614525102164`], 
     Hue[1.0721726273158205`, 1, -14.08342772457722], 
     Hue[1.07217262731582, 1, -13.90817290634038], 
     Hue[1.0721726273158192`, 1, -13.709185307895256`], 
     Hue[1.072172627315818, 1, -13.511830908473128`], 
     Hue[1.0721726273158165`, 1, -13.334942891213302`], 
     Hue[1.072172627315814, 1, -13.137588491791183`], 
     Hue[1.0721726273158108`, 1, -12.960700474531366`], 
     Hue[1.0721726273158052`, 1, -12.763346075109265`], 
     Hue[1.0721726273157977`, 1, -12.586458057849473`], 
     Hue[1.0721726273157854`, 1, -12.389103658427414`], 
     Hue[1.0721726273157692`, 1, -12.212215641167678`], 
     Hue[1.0721726273157424`, 1, -12.01486124174571], 
     Hue[1.0721726273157066`, 1, -11.83797322448609], 
     Hue[1.0721726273156476`, 1, -11.640618825064317`], 
     Hue[1.0721726273155692`, 1, -11.46373080780496], 
     Hue[1.072172627315439, 1, -11.266376408383623`], 
     Hue[1.0721726273152665`, 1, -11.089488391124844`], 
     Hue[1.0721726273149808`, 1, -10.89213399170446], 
     Hue[1.0721726273146015`, 1, -10.715245974446944`], 
     Hue[1.072172627313973, 1, -10.51789157502866], 
     Hue[1.072172627313139, 1, -10.34100355777393], 
     Hue[1.072172627311757, 1, -10.143649158360258`], 
     Hue[1.0721726273097762`, 1, -9.95506606559124], 
     Hue[1.0721726273067884`, 1, -9.764290146168142], 
     Hue[1.0721726273025298`, 1, -9.580823648953649], 
     Hue[1.0721726272959602`, 1, -9.390047729552482], 
     Hue[1.0721726272865968`, 1, -9.206581232369249], 
     Hue[1.0721726272721521`, 1, -9.015805313016312], 
     Hue[1.0721726272515644`, 1, -8.832338815901817], 
     Hue[1.0721726272198044`, 1, -8.641562896654918], 
     Hue[1.0721726271745378`, 1, -8.458096399691557], 
     Hue[1.0721726271047063`, 1, -8.267320480677808], 
     Hue[1.072172627005177, 1, -8.083853984046753], 
     Hue[1.0721726268516367`, 1, -7.893078065545638], 
     Hue[1.0721726266327989`, 1, -7.709611569645227], 
     Hue[1.0721726262952056`, 1, -7.518835652271252], 
     Hue[1.0721726258140407`, 1, -7.33536915797733], 
     Hue[1.0721726250717654`, 1, -7.144593243081631], 
     Hue[1.0721726240138152`, 1, -6.961126752319944], 
     Hue[1.0721726223817538`, 1, -6.770350842873294], 
     Hue[1.0721726200556099`, 1, -6.586884359878027], 
     Hue[1.0721726164671521`, 1, -6.396108462412356], 
     Hue[1.072172611154865, 1, -6.206794459943582], 
     Hue[1.0721726033337404`, 1, -6.019307828389148], 
     Hue[1.0721725917822915`, 1, -5.832552161899324], 
     Hue[1.0721725745857804`, 1, -5.645065587759825], 
     Hue[1.072172549187316, 1, -5.4583100060692695`], 
     Hue[1.072172511376926, 1, -5.270823558169473], 
     Hue[1.0721724555327372`, 1, -5.084068162929192], 
     Hue[1.0721723723982435`, 1, -4.896581992595636], 
     Hue[1.0721722496126374`, 1, -4.709827007307682], 
     Hue[1.0721720543974729`, 1, -4.5119255967274485`], 
     Hue[1.07217179172685, 1, -4.332663625865623], 
     Hue[1.0721713916340803`, 1, -4.146824016618856], 
     Hue[1.0721707901071187`, 1, -3.95842734323485], 
     Hue[1.0721698507422106`, 1, -3.7622664778038866`], 
     Hue[1.0721685754588806`, 1, -3.5827366052583027`], 
     Hue[1.0721665150122903`, 1, -3.387450600030677], 
     Hue[1.072163705227094, 1, -3.207793074748551], 
     Hue[1.0721591808936362`, 1, -3.012956159231787], 
     Hue[1.0721519912761597`, 1, -2.8095013179716437`], 
     Hue[1.0721430499634752`, 1, -2.638515617022886], 
     Hue[1.0721272687554189`, 1, -2.4354103817780706`], 
     Hue[1.0721076244949728`, 1, -2.264490309741653], 
     Hue[1.072072966076304, 1, -2.0615008998621454`], 
     Hue[1.0720298472953442`, 1, -1.8907249913381483`], 
     Hue[1.071953836510224, 1, -1.6879898901275558`], 
     Hue[1.0718593844944944`, 1, -1.517530298386642], 
     Hue[1.071693188268854, 1, -1.315352616623816], 
     Hue[1.0714734886622912`, 1, -1.136168076708002], 
     Hue[1.0711388686238816`, 1, -0.9503937922694548], 
     Hue[1.070644118574303, 1, -0.7646294314822337], 
     Hue[1.0699153887941437`, 1, -0.5794594977271799], 
     Hue[1.0687820245354474`, 1, -0.3862183705726543], 
     Hue[1.0671949778404295`, 1, -0.20388359689123337`], 
     Hue[1.06478639105827, 1, -0.01651293338475579], 
     Hue[1.0611806385599656`, 1, 0.17211540302815798`], 
     Hue[1.0558849539155195`, 1, 0.3584535589173736], 
     Hue[1.0479396541005617`, 1, 0.5461664000707254], 
     Hue[1.0360015606145347`, 1, 0.7341660392188121], 
     Hue[1.0178905344209186`, 1, 0.9218361970029385], 
     Hue[1.1975674284307531`, 1, -17.264488266373966`], 
     Hue[1.1975674284307531`, 1, -17.07736705803298], 
     Hue[1.1975674284307531`, 1, -16.90742299186392], 
     Hue[1.1975674284307531`, 1, -16.70312464135101], 
     Hue[1.1975674284307531`, 1, -16.53318057518195], 
     Hue[1.1975674284307531`, 1, -16.32888222466904], 
     Hue[1.1975674284307531`, 1, -16.15893815849998], 
     Hue[1.1975674284307531`, 1, -15.954639807987068`], 
     Hue[1.1975674284307531`, 1, -15.784695741818005`], 
     Hue[1.1975674284307531`, 1, -15.580397391305098`], 
     Hue[1.1975674284307531`, 1, -15.407712291810729`], 
     Hue[1.197567428430753, 1, -15.206154974623129`], 
     Hue[1.197567428430753, 1, -15.033469875128759`], 
     Hue[1.1975674284307527`, 1, -14.831912557941154`], 
     Hue[1.1975674284307525`, 1, -14.657856941784134`], 
     Hue[1.1975674284307523`, 1, -14.457670141259184`], 
     Hue[1.1975674284307518`, 1, -14.283614525102161`], 
     Hue[1.197567428430751, 1, -14.083427724577215`], 
     Hue[1.19756742843075, 1, -13.908172906340374`], 
     Hue[1.1975674284307485`, 1, -13.709185307895247`], 
     Hue[1.1975674284307458`, 1, -13.511830908473113`], 
     Hue[1.1975674284307425`, 1, -13.334942891213283`], 
     Hue[1.1975674284307372`, 1, -13.137588491791155`], 
     Hue[1.1975674284307298`, 1, -12.960700474531324`], 
     Hue[1.1975674284307178`, 1, -12.763346075109201`], 
     Hue[1.1975674284307019`, 1, -12.58645805784938], 
     Hue[1.1975674284306754`, 1, -12.389103658427274`], 
     Hue[1.1975674284306403`, 1, -12.212215641167473`], 
     Hue[1.1975674284305824`, 1, -12.014861241745399`], 
     Hue[1.1975674284305053`, 1, -11.83797322448564], 
     Hue[1.1975674284303777`, 1, -11.640618825063635`], 
     Hue[1.197567428430208, 1, -11.463730807803973`], 
     Hue[1.1975674284299274`, 1, -11.266376408382124`], 
     Hue[1.1975674284295548`, 1, -11.08948839112267], 
     Hue[1.1975674284289375`, 1, -10.892133991701163`], 
     Hue[1.1975674284281181`, 1, -10.715245974442162`], 
     Hue[1.1975674284267608`, 1, -10.517891575021414`], 
     Hue[1.1975674284249593`, 1, -10.341003557763413`], 
     Hue[1.1975674284219748`, 1, -10.143649158344326`], 
     Hue[1.1975674284176965`, 1, -9.955066065567543], 
     Hue[1.197567428411243, 1, -9.764290146132732], 
     Hue[1.197567428402045, 1, -9.580823648901543], 
     Hue[1.1975674283878555`, 1, -9.390047729474626], 
     Hue[1.1975674283676316`, 1, -9.206581232254688], 
     Hue[1.1975674283364328`, 1, -9.015805312845126], 
     Hue[1.197567428291966, 1, -8.832338815649926], 
     Hue[1.1975674282233684`, 1, -8.64156289627853], 
     Hue[1.1975674281255977`, 1, -8.458096399137721], 
     Hue[1.1975674279747706`, 1, -8.26732047985023], 
     Hue[1.1975674277597994`, 1, -8.083853982829016], 
     Hue[1.1975674274281713`, 1, -7.893078063726018], 
     Hue[1.1975674269555088`, 1, -7.709611566967754], 
     Hue[1.1975674262263492`, 1, -7.518835648270406], 
     Hue[1.1975674251870927`, 1, -7.335369152090302], 
     Hue[1.1975674235838694`, 1, -7.144593234284861], 
     Hue[1.1975674212988277`, 1, -6.961126739375975], 
     Hue[1.1975674177737765`, 1, -6.770350823531594], 
     Hue[1.1975674127495928`, 1, -6.586884331417771], 
     Hue[1.1975674049989662`, 1, -6.396108419885233], 
     Hue[1.1975673935250806`, 1, -6.206794396592129], 
     Hue[1.1975673766324124`, 1, -6.019307734378646], 
     Hue[1.1975673516826988`, 1, -5.832552022606791], 
     Hue[1.1975673145403336`, 1, -5.6450653810564555`], 
     Hue[1.197567259682731, 1, -5.4583096998031815`], 
     Hue[1.1975671780168322`, 1, -5.270823103685601], 
     Hue[1.197567057400002, 1, -5.084067489534633], 
     Hue[1.1975668778391402`, 1, -4.896580993311892], 
     Hue[1.197566612636026, 1, -4.709825526701912], 
     Hue[1.1975661909920963`, 1, -4.511923350875468], 
     Hue[1.1975656236494285`, 1, -4.332660350343265], 
     Hue[1.1975647594837358`, 1, -4.146819172735328], 
     Hue[1.197563460226914, 1, -3.95842014138033], 
     Hue[1.1975614312375868`, 1, -3.762255593688213], 
     Hue[1.1975586766280268`, 1, -3.5827207221502713`], 
     Hue[1.1975542259448064`, 1, -3.3874266402882025`], 
     Hue[1.1975481564031392`, 1, -3.2077581013283405`], 
     Hue[1.197538382598197, 1, -3.0129034521238243`], 
     Hue[1.197524993391192, 1, -2.832831235218852], 
     Hue[1.1975035306597026`, 1, -2.6384089670626434`], 
     Hue[1.197469422870967, 1, -2.4352326122699433`], 
     Hue[1.1974269550455432`, 1, -2.264235573652546], 
     Hue[1.1973519953891665`, 1, -2.0611104059004877`], 
     Hue[1.1972586777344074`, 1, -1.8901656616573599`], 
     Hue[1.197094013629467, 1, -1.6871331000689007`], 
     Hue[1.196889112368045, 1, -1.5163041792834513`], 
     Hue[1.1965277974714486`, 1, -1.3134774456971858`], 
     Hue[1.1960786313418437`, 1, -1.1429072280132477`], 
     Hue[1.1953429601476844`, 1, -0.9521797807955477], 
     Hue[1.194274296827467, 1, -0.7658457091674755], 
     Hue[1.1926459360367472`, 1, -0.575045413771959], 
     Hue[1.1902834595763556`, 1, -0.3889051105407175], 
     Hue[1.1867980845946824`, 1, -0.20336366375065973`], 
     Hue[1.1815262418536645`, 1, -0.01453901864500673], 
     Hue[1.1738127927678517`, 1, 0.17099417552927143`], 
     Hue[1.1620553500777477`, 1, 0.35980629489926585`], 
     Hue[1.1444213338223095`, 1, 0.5464001821301475], 
     Hue[1.116594244647645, 1, 0.7345989612017314], 
     Hue[1.0691284935119547`, 1, 0.9216792751476153], 
     Hue[1.3229622295456849`, 1, -17.264488266373966`], 
     Hue[1.3229622295456849`, 1, -17.07736705803298], 
     Hue[1.3229622295456849`, 1, -16.90742299186392], 
     Hue[1.3229622295456849`, 1, -16.70312464135101], 
     Hue[1.3229622295456849`, 1, -16.53318057518195], 
     Hue[1.3229622295456849`, 1, -16.32888222466904], 
     Hue[1.3229622295456849`, 1, -16.15893815849998], 
     Hue[1.3229622295456849`, 1, -15.954639807987068`], 
     Hue[1.3229622295456849`, 1, -15.784695741818005`], 
     Hue[1.3229622295456849`, 1, -15.580397391305098`], 
     Hue[1.3229622295456849`, 1, -15.407712291810729`], 
     Hue[1.3229622295456847`, 1, -15.206154974623129`], 
     Hue[1.3229622295456847`, 1, -15.033469875128759`], 
     Hue[1.3229622295456844`, 1, -14.831912557941154`], 
     Hue[1.3229622295456842`, 1, -14.657856941784134`], 
     Hue[1.322962229545684, 1, -14.457670141259184`], 
     Hue[1.3229622295456835`, 1, -14.283614525102157`], 
     Hue[1.3229622295456829`, 1, -14.08342772457721], 
     Hue[1.322962229545682, 1, -13.908172906340365`], 
     Hue[1.3229622295456804`, 1, -13.709185307895234`], 
     Hue[1.322962229545678, 1, -13.511830908473097`], 
     Hue[1.3229622295456749`, 1, -13.334942891213256`], 
     Hue[1.3229622295456698`, 1, -13.137588491791115`], 
     Hue[1.322962229545663, 1, -12.960700474531269`], 
     Hue[1.3229622295456513`, 1, -12.763346075109117`], 
     Hue[1.3229622295456362`, 1, -12.586458057849258`], 
     Hue[1.3229622295456114`, 1, -12.389103658427086`], 
     Hue[1.322962229545578, 1, -12.212215641167202`], 
     Hue[1.322962229545523, 1, -12.014861241744986`], 
     Hue[1.32296222954545, 1, -11.83797322448504], 
     Hue[1.322962229545329, 1, -11.640618825062727`], 
     Hue[1.3229622295451684`, 1, -11.463730807802655`], 
     Hue[1.3229622295449022`, 1, -11.266376408380129`], 
     Hue[1.3229622295445491`, 1, -11.089488391119772`], 
     Hue[1.322962229543964, 1, -10.892133991696776`], 
     Hue[1.3229622295431875`, 1, -10.715245974435796`], 
     Hue[1.3229622295419012`, 1, -10.517891575011767`], 
     Hue[1.322962229540194, 1, -10.341003557749415`], 
     Hue[1.3229622295373655`, 1, -10.143649158323115`], 
     Hue[1.322962229533311, 1, -9.955066065535995], 
     Hue[1.322962229527195, 1, -9.76429014608559], 
     Hue[1.3229622295184778`, 1, -9.580823648832178], 
     Hue[1.3229622295050303`, 1, -9.390047729370973], 
     Hue[1.3229622294858638`, 1, -9.20658123210217], 
     Hue[1.3229622294562964`, 1, -9.015805312617223], 
     Hue[1.3229622294141545`, 1, -8.83233881531458], 
     Hue[1.3229622293491439`, 1, -8.641562895777433], 
     Hue[1.3229622292564855`, 1, -8.458096398400386], 
     Hue[1.3229622291135448`, 1, -8.267320478748456], 
     Hue[1.3229622289098142`, 1, -8.083853981207817], 
     Hue[1.3229622285955265`, 1, -7.893078061303519], 
     Hue[1.3229622281475786`, 1, -7.709611563403178], 
     Hue[1.3229622274565453`, 1, -7.518835642943986], 
     Hue[1.3229622264716299`, 1, -7.335369144252765], 
     Hue[1.3229622249522364`, 1, -7.1445932225735165`], 
     Hue[1.3229622227866757`, 1, -6.96112672214337], 
     Hue[1.3229622194459434`, 1, -6.770350797781541], 
     Hue[1.3229622146844655`, 1, -6.5868842935279694`], 
     Hue[1.322962207339105, 1, -6.396108363267881], 
     Hue[1.3229621964651668`, 1, -6.206794312250852], 
     Hue[1.3229621804557814`, 1, -6.019307609220236], 
     Hue[1.322962156810632, 1, -5.832551837163301], 
     Hue[1.3229621216103458`, 1, -5.645065105867209], 
     Hue[1.3229620696210822`, 1, -5.458309292063454], 
     Hue[1.322961992225194, 1, -5.270822498619378], 
     Hue[1.3229618779148584`, 1, -5.08406659302595], 
     Hue[1.3229617077421412`, 1, -4.89657966293585], 
     Hue[1.3229614564043153`, 1, -4.709823555522947], 
     Hue[1.3229610568032801`, 1, -4.511920360887923], 
     Hue[1.3229605191177074`, 1, -4.33265598949463], 
     Hue[1.3229597001191808`, 1, -4.14681272380805], 
     Hue[1.32295846875679, 1, -3.9584105530462352`], 
     Hue[1.3229565457625003`, 1, -3.7622411026396483`], 
     Hue[1.3229539349910746`, 1, -3.5826995749533515`], 
     Hue[1.3229497165556685`, 1, -3.387394738378391], 
     Hue[1.3229439634300146`, 1, -3.2077115324129775`], 
     Hue[1.3229346984041663`, 1, -3.0128332637770745`], 
     Hue[1.3229220104848636`, 1, -2.8327972226140092`], 
     Hue[1.322901656744849, 1, -2.63828238813442], 
     Hue[1.3228693022062705`, 1, -2.4349957369373554`], 
     Hue[1.3228290060820318`, 1, -2.2638960130532784`], 
     Hue[1.3227578371418174`, 1, -2.060589533899577], 
     Hue[1.3226691625956315`, 1, -1.8894189630229852`], 
     Hue[1.322512485621479, 1, -1.6859876177713284`], 
     Hue[1.3223171552980517`, 1, -1.5146619329643765`], 
     Hue[1.321971719535026, 1, -1.3109577875306793`], 
     Hue[1.3215405081271017`, 1, -1.1392942761364304`], 
     Hue[1.320829934187548, 1, -0.946770120509693], 
     Hue[1.3198539508719955`, 1, -0.7677728279805907], 
     Hue[1.3182375414456449`, 1, -0.5689144841247173], 
     Hue[1.316088062932789, 1, -0.39088219917274514`], 
     Hue[1.3127299459848634`, 1, -0.20211752730972687`], 
     Hue[1.3077957709940713`, 1, -0.015578571964192323`], 
     Hue[1.3004704802721887`, 1, 0.17073799255745536`], 
     Hue[1.2892333703828847`, 1, 0.3612317398232262], 
     Hue[1.1344830421655148`, 1, 0.734222758160589], 
     Hue[1.2726803314379833`, 1, 0.5465277412388269], 
     Hue[1.2467038470482128`, 1, 0.7339687667026227], 
     Hue[1.084230388191764, 1, 0.9216253951316109], 
     Hue[1.2028753217333412`, 1, 0.922018794312693], 
     Hue[1.4483570306606162`, 1, -17.264488266373966`], 
     Hue[1.4483570306606162`, 1, -17.07736705803298], 
     Hue[1.4483570306606162`, 1, -16.90742299186392], 
     Hue[1.4483570306606162`, 1, -16.70312464135101], 
     Hue[1.4483570306606162`, 1, -16.53318057518195], 
     Hue[1.4483570306606162`, 1, -16.32888222466904], 
     Hue[1.4483570306606162`, 1, -16.15893815849998], 
     Hue[1.4483570306606162`, 1, -15.954639807987068`], 
     Hue[1.4483570306606162`, 1, -15.784695741818005`], 
     Hue[1.4483570306606162`, 1, -15.580397391305098`], 
     Hue[1.4483570306606162`, 1, -15.407712291810729`], 
     Hue[1.448357030660616, 1, -15.206154974623129`], 
     Hue[1.448357030660616, 1, -15.033469875128759`], 
     Hue[1.448357030660616, 1, -14.831912557941154`], 
     Hue[1.448357030660616, 1, -14.65785694178413], 
     Hue[1.4483570306606157`, 1, -14.45767014125918], 
     Hue[1.4483570306606155`, 1, -14.283614525102157`], 
     Hue[1.4483570306606155`, 1, -14.083427724577206`], 
     Hue[1.448357030660615, 1, -13.90817290634036], 
     Hue[1.4483570306606144`, 1, -13.709185307895225`], 
     Hue[1.4483570306606137`, 1, -13.511830908473085`], 
     Hue[1.4483570306606126`, 1, -13.33494289121324], 
     Hue[1.4483570306606106`, 1, -13.13758849179109], 
     Hue[1.4483570306606082`, 1, -12.960700474531231`], 
     Hue[1.4483570306606042`, 1, -12.763346075109059`], 
     Hue[1.4483570306605988`, 1, -12.586458057849175`], 
     Hue[1.44835703066059, 1, -12.389103658426961`], 
     Hue[1.4483570306605782`, 1, -12.21221564116702], 
     Hue[1.4483570306605587`, 1, -12.014861241744713`], 
     Hue[1.4483570306605327`, 1, -11.837973224484646`], 
     Hue[1.4483570306604896`, 1, -11.64061882506213], 
     Hue[1.4483570306604325`, 1, -11.463730807801785`], 
     Hue[1.448357030660338, 1, -11.266376408378813`], 
     Hue[1.4483570306602123`, 1, -11.089488391117863`], 
     Hue[1.4483570306600042`, 1, -10.892133991693882`], 
     Hue[1.4483570306597282`, 1, -10.715245974431596`], 
     Hue[1.4483570306592708`, 1, -10.517891575005404`], 
     Hue[1.448357030658664, 1, -10.341003557740182`], 
     Hue[1.4483570306576583`, 1, -10.143649158309126`], 
     Hue[1.4483570306562168`, 1, -9.955066065515185], 
     Hue[1.4483570306540423`, 1, -9.764290146054497], 
     Hue[1.4483570306509432`, 1, -9.580823648786424], 
     Hue[1.4483570306461622`, 1, -9.390047729302607], 
     Hue[1.448357030639348, 1, -9.206581232001573], 
     Hue[1.448357030628836, 1, -9.015805312466906], 
     Hue[1.4483570306138533`, 1, -8.832338815093395], 
     Hue[1.4483570305907403`, 1, -8.641562895446926], 
     Hue[1.4483570305577977`, 1, -8.458096397914064], 
     Hue[1.4483570305069784`, 1, -8.26732047802176], 
     Hue[1.4483570304345463`, 1, -8.083853980138523], 
     Hue[1.4483570303228084`, 1, -7.893078059705712], 
     Hue[1.4483570301635504`, 1, -7.709611561052093], 
     Hue[1.4483570299178687`, 1, -7.518835639430848], 
     Hue[1.448357029567704, 1, -7.335369139083373], 
     Hue[1.4483570290275174`, 1, -7.14459321484908], 
     Hue[1.4483570282576002`, 1, -6.961126710777283], 
     Hue[1.448357027069877, 1, -6.770350780797609], 
     Hue[1.4483570253770388`, 1, -6.586884268537041], 
     Hue[1.4483570227655584`, 1, -6.396108325924843], 
     Hue[1.44835701889957, 1, -6.206794256621975], 
     Hue[1.4483570132077863`, 1, -6.01930752666964], 
     Hue[1.4483570048012742`, 1, -5.832551714850513], 
     Hue[1.4483569922865849`, 1, -5.645064924360839], 
     Hue[1.4483569738029374`, 1, -5.458309023130737], 
     Hue[1.4483569462865067`, 1, -5.270822099535834], 
     Hue[1.4483569056459165`, 1, -5.084066001715093], 
     Hue[1.448356845144593, 1, -4.896578785457464], 
     Hue[1.4483567557865922`, 1, -4.709822255386179], 
     Hue[1.4483566137163253`, 1, -4.511918388765325], 
     Hue[1.4483564225521905`, 1, -4.332653113171835], 
     Hue[1.4483561313710527`, 1, -4.146808470202065], 
     Hue[1.4483556935777075`, 1, -3.958404228669962], 
     Hue[1.4483550098768645`, 1, -3.762231544314634], 
     Hue[1.448354081629034, 1, -3.5826856258949817`], 
     Hue[1.4483525817473666`, 1, -3.3873736945338395`], 
     Hue[1.4483505361281868`, 1, -3.2076808120188867`], 
     Hue[1.4483472416194827`, 1, -3.0127869583900964`], 
     Hue[1.4483427323800828`, 1, -2.832820963547552], 
     Hue[1.4483354924081375`, 1, -2.638217619806422], 
     Hue[1.44832398152951, 1, -2.4348393719975867`], 
     Hue[1.4483096436524852`, 1, -2.263671783536343], 
     Hue[1.4482843108182166`, 1, -2.060245356797674], 
     Hue[1.4482527288851894`, 1, -1.888925176045399], 
     Hue[1.4481968788129809`, 1, -1.6852290585628629`], 
     Hue[1.4481271627600911`, 1, -1.5135725104376563`], 
     Hue[1.448003633562265, 1, -1.3092811489884546`], 
     Hue[1.4478490002910223`, 1, -1.1368808476521528`], 
     Hue[1.447612551581589, 1, -0.9553636000253445], 
     Hue[1.447252319417249, 1, -0.7679047894466369], 
     Hue[1.4467121093448296`, 1, -0.5788078619781916], 
     Hue[1.4459075613660195`, 1, -0.38968321043759135`], 
     Hue[1.3912130954739783`, 1, 0.1708422231103891], 
     Hue[1.4447240191059245`, 1, -0.20246520032196913`], 
     Hue[1.4429730625407347`, 1, -0.015666772303767784`], 
     Hue[1.4403145985388683`, 1, 0.17484194588316304`], 
     Hue[1.2859106441925678`, 1, 0.5463175797761701], 
     Hue[1.436504734427545, 1, 0.35880528004853784`], 
     Hue[1.4307140606058235`, 1, 0.5472336533194785], 
     Hue[1.2182980529571972`, 1, 0.9215645378894483], 
     Hue[1.2882647658292652`, 1, 1.1094578420849248`], 
     Hue[1.422144711473328, 1, 0.7341062994848904], 
     Hue[1.4092411495013994`, 1, 0.921606043505818], 
     Hue[1.3894908714004521`, 1, 1.10966821835764], 
     Hue[1.115002463986056, 1, 1.1095152879966117`], 
     Hue[1.1136246004099175`, 1, 1.2970710603151687`], 
     Hue[1.3582624075601109`, 1, 1.2970599399846405`], 
     Hue[1.0481610009630407`, 1, 1.1096560406825233`], 
     Hue[1.0384581662487113`, 1, 1.2970905255786778`], 
     Hue[1.0126829700233524`, 1, 1.1094967764155095`], 
     Hue[1.0071816956904527`, 1, 1.1093486807067687`], 
     Hue[0.5737518317755478, 1, -17.264488266373966`], 
     Hue[0.5737518317755478, 1, -17.07736705803298], 
     Hue[0.5737518317755478, 1, -16.90742299186392], 
     Hue[0.5737518317755478, 1, -16.70312464135101], 
     Hue[0.5737518317755478, 1, -16.53318057518195], 
     Hue[0.5737518317755478, 1, -16.32888222466904], 
     Hue[0.5737518317755478, 1, -16.15893815849998], 
     Hue[0.5737518317755478, 1, -15.954639807987068`], 
     Hue[0.5737518317755478, 1, -15.784695741818005`], 
     Hue[0.5737518317755479, 1, -15.580397391305098`], 
     Hue[0.5737518317755479, 1, -15.407712291810729`], 
     Hue[0.5737518317755479, 1, -15.206154974623129`], 
     Hue[0.5737518317755479, 1, -15.033469875128759`], 
     Hue[0.573751831775548, 1, -14.831912557941154`], 
     Hue[0.5737518317755481, 1, -14.65785694178413], 
     Hue[0.5737518317755482, 1, -14.45767014125918], 
     Hue[0.5737518317755484, 1, -14.283614525102157`], 
     Hue[0.5737518317755488, 1, -14.083427724577206`], 
     Hue[0.5737518317755492, 1, -13.908172906340361`], 
     Hue[0.5737518317755501, 1, -13.709185307895227`], 
     Hue[0.5737518317755512, 1, -13.511830908473087`], 
     Hue[0.5737518317755528, 1, -13.334942891213242`], 
     Hue[0.5737518317755554, 1, -13.137588491791092`], 
     Hue[0.5737518317755588, 1, -12.960700474531235`], 
     Hue[0.5737518317755645, 1, -12.763346075109066`], 
     Hue[0.5737518317755721, 1, -12.586458057849184`], 
     Hue[0.5737518317755845, 1, -12.389103658426976`], 
     Hue[0.573751831775601, 1, -12.21221564116704], 
     Hue[0.5737518317756285, 1, -12.014861241744741`], 
     Hue[0.5737518317756649, 1, -11.837973224484688`], 
     Hue[0.5737518317757252, 1, -11.640618825062193`], 
     Hue[0.5737518317758052, 1, -11.463730807801879`], 
     Hue[0.5737518317759378, 1, -11.266376408378951`], 
     Hue[0.5737518317761139, 1, -11.089488391118064`], 
     Hue[0.5737518317764055, 1, -10.892133991694188`], 
     Hue[0.5737518317767927, 1, -10.715245974432039`], 
     Hue[0.5737518317774337, 1, -10.517891575006075`], 
     Hue[0.5737518317782848, 1, -10.341003557741155`], 
     Hue[0.5737518317796946, 1, -10.1436491583106], 
     Hue[0.5737518317817157, 1, -9.95506606551738], 
     Hue[0.5737518317847643, 1, -9.764290146057776], 
     Hue[0.5737518317891094, 1, -9.580823648791249], 
     Hue[0.5737518317958124, 1, -9.390047729309817], 
     Hue[0.573751831805366, 1, -9.20658123201218], 
     Hue[0.573751831820104, 1, -9.015805312482755], 
     Hue[0.5737518318411099, 1, -8.832338815116717], 
     Hue[0.573751831873515, 1, -8.641562895481774], 
     Hue[0.5737518319197011, 1, -8.45809639796534], 
     Hue[0.5737518319909509, 1, -8.267320478098384], 
     Hue[0.5737518320925017, 1, -8.08385398025127], 
     Hue[0.5737518322491604, 1, -7.893078059874187], 
     Hue[0.5737518324724431, 1, -7.709611561299995], 
     Hue[0.5737518328168929, 1, -7.518835639801279], 
     Hue[0.5737518333078304, 1, -7.335369139628441], 
     Hue[0.573751834065182, 1, -7.144593215663554], 
     Hue[0.5737518351446199, 1, -6.96112671197574], 
     Hue[0.5737518368098298, 1, -6.770350782588418], 
     Hue[0.5737518391832196, 1, -6.586884271172118], 
     Hue[0.5737518428445627, 1, -6.396108329862343], 
     Hue[0.5737518482647488, 1, -6.206794262487558], 
     Hue[0.5737518562447331, 1, -6.019307535373887], 
     Hue[0.5737518680308161, 1, -5.832551727747339], 
     Hue[0.5737518855766377, 1, -5.645064943499121], 
     Hue[0.5737519114910461, 1, -5.458309051487378], 
     Hue[0.573751950069578, 1, -5.27082214161577], 
     Hue[0.5737520070484144, 1, -5.084066064063772], 
     Hue[0.573752091872346, 1, -4.896578877980116], 
     Hue[0.5737522171538332, 1, -4.709822392474679], 
     Hue[0.5737524163387944, 1, -4.51191859670935], 
     Hue[0.5737526843541105, 1, -4.332653416456814], 
     Hue[0.5737530925947321, 1, -4.146808918711581], 
     Hue[0.573753706387548, 1, -3.9584048955286253`], 
     Hue[0.5737546649452241, 1, -3.7622325521753917`], 
     Hue[0.5737559663588268, 1, -3.5826870967410525`], 
     Hue[0.5737580692039533, 1, -3.3873759135129875`], 
     Hue[0.5737609371664075, 1, -3.207684051405873], 
     Hue[0.5737655560487356, 1, -3.012791841318041], 
     Hue[0.5737718779247216, 1, -2.83282809632198], 
     Hue[0.5737820281154282, 1, -2.638228365650794], 
     Hue[0.5737981656518811, 1, -2.4348558641826736`], 
     Hue[0.5738182659182098, 1, -2.2636954365841397`], 
     Hue[0.5738537785305544, 1, -2.060281670824966], 
     Hue[0.5738980487348324, 1, -1.8889772900512407`], 
     Hue[0.5739763297647313, 1, -1.6853091564225953`], 
     Hue[0.5740740327859462, 1, -1.5136876165731705`], 
     Hue[0.5742471163932206, 1, -1.3094584952632962`], 
     Hue[0.5744637175630183, 1, -1.1371364825174608`], 
     Hue[0.5747951890088556, 1, -0.9555546291413333], 
     Hue[0.5753337587645713, 1, -0.7578640033446717], 
     Hue[0.5760539865514249, 1, -0.5796518789804179], 
     Hue[0.5771769637773176, 1, -0.3909571082351324], 
     Hue[0.5788251837823868, 1, -0.2043915655785944], 
     Hue[0.5813734119451257, 1, -0.011176243151417742`], 
     Hue[0.5850004995386484, 1, 0.17351113257575423`], 
     Hue[0.5903803962045444, 1, 0.3587064763509845], 
     Hue[0.598529358854647, 1, 0.5470878625541177], 
     Hue[0.6106523063253309, 1, 0.7339313450690228], 
     Hue[0.6291634133317994, 1, 0.9216772877712237], 
     Hue[0.6582823975167689, 1, 1.1093708839549703`], 
     Hue[0.7094604956477336, 1, 1.297757848804927], 
     Hue[0.9383125563531036, 1, 1.2970541698433624`], 
     Hue[0.9891451938544735, 1, 1.1097571708449396`], 
     Hue[0.6991466328904795, 1, -17.264488266373966`], 
     Hue[0.6991466328904795, 1, -17.07736705803298], 
     Hue[0.6991466328904795, 1, -16.90742299186392], 
     Hue[0.6991466328904795, 1, -16.70312464135101], 
     Hue[0.6991466328904795, 1, -16.53318057518195], 
     Hue[0.6991466328904795, 1, -16.32888222466904], 
     Hue[0.6991466328904795, 1, -16.15893815849998], 
     Hue[0.6991466328904796, 1, -15.954639807987068`], 
     Hue[0.6991466328904796, 1, -15.784695741818005`], 
     Hue[0.6991466328904796, 1, -15.580397391305098`], 
     Hue[0.6991466328904796, 1, -15.407712291810729`], 
     Hue[0.6991466328904797, 1, -15.206154974623129`], 
     Hue[0.6991466328904798, 1, -15.033469875128759`], 
     Hue[0.69914663289048, 1, -14.831912557941154`], 
     Hue[0.6991466328904802, 1, -14.657856941784134`], 
     Hue[0.6991466328904805, 1, -14.457670141259184`], 
     Hue[0.699146632890481, 1, -14.283614525102161`], 
     Hue[0.6991466328904817, 1, -14.083427724577211`], 
     Hue[0.6991466328904827, 1, -13.908172906340367`], 
     Hue[0.6991466328904843, 1, -13.709185307895236`], 
     Hue[0.6991466328904868, 1, -13.511830908473101`], 
     Hue[0.6991466328904902, 1, -13.334942891213261`], 
     Hue[0.6991466328904956, 1, -13.137588491791123`], 
     Hue[0.6991466328905029, 1, -12.960700474531276`], 
     Hue[0.6991466328905149, 1, -12.76334607510913], 
     Hue[0.6991466328905309, 1, -12.586458057849278`], 
     Hue[0.6991466328905575, 1, -12.389103658427116`], 
     Hue[0.6991466328905926, 1, -12.212215641167248`], 
     Hue[0.6991466328906508, 1, -12.014861241745056`], 
     Hue[0.6991466328907283, 1, -11.837973224485141`], 
     Hue[0.6991466328908564, 1, -11.64061882506288], 
     Hue[0.6991466328910264, 1, -11.463730807802875`], 
     Hue[0.6991466328913081, 1, -11.266376408380463`], 
     Hue[0.699146632891682, 1, -11.089488391120257`], 
     Hue[0.6991466328923014, 1, -10.892133991697513`], 
     Hue[0.6991466328931235, 1, -10.715245974436863`], 
     Hue[0.6991466328944853, 1, -10.517891575013383`], 
     Hue[0.6991466328962928, 1, -10.341003557751762`], 
     Hue[0.6991466328992872, 1, -10.14364915832667], 
     Hue[0.6991466329035799, 1, -9.955066065541283], 
     Hue[0.6991466329100551, 1, -9.764290146093494], 
     Hue[0.6991466329192837, 1, -9.580823648843806], 
     Hue[0.6991466329335206, 1, -9.390047729388352], 
     Hue[0.6991466329538123, 1, -9.20658123212774], 
     Hue[0.6991466329851153, 1, -9.015805312655433], 
     Hue[0.6991466330297309, 1, -8.832338815370802], 
     Hue[0.6991466330985577, 1, -8.641562895861444], 
     Hue[0.6991466331966552, 1, -8.458096398524004], 
     Hue[0.6991466333479868, 1, -8.267320478933172], 
     Hue[0.6991466335636765, 1, -8.083853981479617], 
     Hue[0.6991466338964132, 1, -7.893078061709661], 
     Hue[0.699146634370656, 1, -7.7096115640007925`], 
     Hue[0.6991466351022535, 1, -7.518835643836984], 
     Hue[0.6991466361449845, 1, -7.335369145566761], 
     Hue[0.6991466377535678, 1, -7.14459322453697], 
     Hue[0.6991466400462489, 1, -6.961126725032487], 
     Hue[0.6991466435830855, 1, -6.770350802098643], 
     Hue[0.6991466486240667, 1, -6.58688429988035], 
     Hue[0.6991466564006066, 1, -6.396108372760015], 
     Hue[0.699146667912855, 1, -6.206794326391019], 
     Hue[0.6991466848620054, 1, -6.019307630203567], 
     Hue[0.6991467098951453, 1, -5.83255186825368], 
     Hue[0.6991467471617161, 1, -5.6450651520038475`], 
     Hue[0.6991468022027862, 1, -5.458309360422756], 
     Hue[0.6991468841418583, 1, -5.270822600061343], 
     Hue[0.6991470051622568, 1, -5.084066743329579], 
     Hue[0.6991471853241348, 1, -4.896579885979422], 
     Hue[0.6991474514154233, 1, -4.709823886000404], 
     Hue[0.6991478744726836, 1, -4.5119208621743425`], 
     Hue[0.6991484437194408, 1, -4.3326567206145485`], 
     Hue[0.6991493107906622, 1, -4.14681380500963], 
     Hue[0.699150614427833, 1, -3.9584121605971596`], 
     Hue[0.6991526502864379, 1, -3.7622435321856376`], 
     Hue[0.699155414277894, 1, -3.5827031204998665`], 
     Hue[0.6991598802558989, 1, -3.3874000871646732`], 
     Hue[0.6991659709268683, 1, -3.2077193405216153`], 
     Hue[0.6991757794144041, 1, -3.0128450325914304`], 
     Hue[0.6991892113078032, 1, -2.8328144156484587`], 
     Hue[0.6992107578773645, 1, -2.6383082832401756`], 
     Hue[0.6992450069264897, 1, -2.4350354665554397`], 
     Hue[0.699287659788706, 1, -2.263952975677981], 
     Hue[0.6993629835176816, 1, -2.0606769399913123`], 
     Hue[0.6994568213055125, 1, -1.8895443140556523`], 
     Hue[0.6996225844372648, 1, -1.6861800485133582`], 
     Hue[0.6998291769557666, 1, -1.5149380558953764`], 
     Hue[0.7001943512903122, 1, -1.3113820881670504`], 
     Hue[0.700649882708615, 1, -1.139903850270963], 
     Hue[0.7013997566842334, 1, -0.9476857132527183], 
     Hue[0.7024974858983879, 1, -0.7591787050240537], 
     Hue[0.7041273185636856, 1, -0.5709536500054655], 
     Hue[0.7064076807826494, 1, -0.3919865256865571], 
     Hue[0.6072126244290277, 1, 0.1712552153812814], 
     Hue[0.7099297243087545, 1, -0.2043440021538614], 
     Hue[0.7151708340613581, 1, -0.01662592689720488], 
     Hue[0.7142932396006516, 1, 0.5461269250214297], 
     Hue[0.7230157856556744, 1, 0.17167611262784932`], 
     Hue[0.7346998997795089, 1, 0.3587623380606101], 
     Hue[0.7815474323508544, 1, 0.9219708932037533], 
     Hue[0.7117608582965544, 1, 1.1093915491661497`], 
     Hue[0.7525323237315167, 1, 0.5468710297241224], 
     Hue[0.780280367370306, 1, 0.733871671622147], 
     Hue[0.8850075493634347, 1, 1.10936585577596], 
     Hue[0.8863748588432626, 1, 1.2970645112210897`], 
     Hue[0.82840864947081, 1, 0.9224343216848462], 
     Hue[0.9518134638560861, 1, 1.1093417178292615`], 
     Hue[0.9872448667022297, 1, 1.1093464818922711`], 
     Hue[0.8245414340054112, 1, -17.264488266373966`], 
     Hue[0.8245414340054112, 1, -17.07736705803298], 
     Hue[0.8245414340054112, 1, -16.90742299186392], 
     Hue[0.8245414340054112, 1, -16.70312464135101], 
     Hue[0.8245414340054112, 1, -16.53318057518195], 
     Hue[0.8245414340054112, 1, -16.32888222466904], 
     Hue[0.8245414340054112, 1, -16.15893815849998], 
     Hue[0.8245414340054114, 1, -15.954639807987068`], 
     Hue[0.8245414340054114, 1, -15.784695741818005`], 
     Hue[0.8245414340054114, 1, -15.580397391305098`], 
     Hue[0.8245414340054114, 1, -15.407712291810729`], 
     Hue[0.8245414340054115, 1, -15.206154974623129`], 
     Hue[0.8245414340054116, 1, -15.033469875128759`], 
     Hue[0.8245414340054117, 1, -14.831912557941154`], 
     Hue[0.8245414340054119, 1, -14.657856941784134`], 
     Hue[0.8245414340054122, 1, -14.457670141259184`], 
     Hue[0.8245414340054126, 1, -14.283614525102164`], 
     Hue[0.8245414340054134, 1, -14.083427724577216`], 
     Hue[0.8245414340054142, 1, -13.908172906340376`], 
     Hue[0.8245414340054158, 1, -13.709185307895249`], 
     Hue[0.8245414340054181, 1, -13.511830908473117`], 
     Hue[0.8245414340054212, 1, -13.334942891213286`], 
     Hue[0.8245414340054265, 1, -13.137588491791162`], 
     Hue[0.8245414340054332, 1, -12.960700474531334`], 
     Hue[0.8245414340054446, 1, -12.763346075109217`], 
     Hue[0.8245414340054597, 1, -12.5864580578494], 
     Hue[0.8245414340054845, 1, -12.389103658427306`], 
     Hue[0.8245414340055176, 1, -12.21221564116752], 
     Hue[0.8245414340055723, 1, -12.014861241745468`], 
     Hue[0.8245414340056451, 1, -11.83797322448574], 
     Hue[0.8245414340057655, 1, -11.640618825063788`], 
     Hue[0.8245414340059253, 1, -11.463730807804192`], 
     Hue[0.8245414340061901, 1, -11.266376408382458`], 
     Hue[0.8245414340065415, 1, -11.089488391123151`], 
     Hue[0.8245414340071237, 1, -10.892133991701897`], 
     Hue[0.8245414340078963, 1, -10.715245974443226`], 
     Hue[0.8245414340091762, 1, -10.517891575023025`], 
     Hue[0.824541434010875, 1, -10.341003557765752`], 
     Hue[0.8245414340136895, 1, -10.143649158347868`], 
     Hue[0.8245414340177242, 1, -9.95506606557281], 
     Hue[0.8245414340238099, 1, -9.764290146140604], 
     Hue[0.8245414340324838, 1, -9.580823648913125], 
     Hue[0.8245414340458649, 1, -9.390047729491933], 
     Hue[0.8245414340649365, 1, -9.206581232280152], 
     Hue[0.8245414340943577, 1, -9.015805312883177], 
     Hue[0.8245414341362911, 1, -8.832338815705917], 
     Hue[0.8245414342009802, 1, -8.641562896362194], 
     Hue[0.8245414342931803, 1, -8.45809639926083], 
     Hue[0.8245414344354141, 1, -8.267320480034188], 
     Hue[0.824541434638137, 1, -8.083853983099697], 
     Hue[0.8245414349508704, 1, -7.893078064130489], 
     Hue[0.8245414353966027, 1, -7.709611567562912], 
     Hue[0.824541436084218, 1, -7.518835649159729], 
     Hue[0.8245414370642623, 1, -7.335369153398889], 
     Hue[0.8245414385761409, 1, -7.144593236240234], 
     Hue[0.8245414407309909, 1, -6.961126742253202], 
     Hue[0.8245414440551999, 1, -6.770350827830928], 
     Hue[0.8245414487931275, 1, -6.586884337744006], 
     Hue[0.8245414561021569, 1, -6.3961084293382955`], 
     Hue[0.8245414669223102, 1, -6.206794410674091], 
     Hue[0.8245414828525068, 1, -6.019307755275598], 
     Hue[0.8245415063806923, 1, -5.832552053569179], 
     Hue[0.8245415414068424, 1, -5.645065427003144], 
     Hue[0.8245415931388864, 1, -5.458309767881002], 
     Hue[0.824541670151792, 1, -5.270823204709775], 
     Hue[0.8245417838963429, 1, -5.084067639219052], 
     Hue[0.8245419532264793, 1, -4.896581215436178], 
     Hue[0.8245422033191897, 1, -4.7098258558164], 
     Hue[0.8245426009389991, 1, -4.51192385009232], 
     Hue[0.8245431359555805, 1, -4.332661078440546], 
     Hue[0.8245439508817951, 1, -4.1468202494574795`], 
     Hue[0.824545176105739, 1, -3.9584217422500014`], 
     Hue[0.8245470894759338, 1, -3.7622580130866723`], 
     Hue[0.8245496871073494, 1, -3.582724252789119], 
     Hue[0.824553884131848, 1, -3.3874319663437857`], 
     Hue[0.8245596076997181, 1, -3.207765875774963], 
     Hue[0.8245688242577964, 1, -3.0129151690360665`], 
     Hue[0.8245814508019359, 1, -2.832836933049605], 
     Hue[0.8246016884797582, 1, -2.6384301014594316`], 
     Hue[0.824633847945929, 1, -2.4352721389363143`], 
     Hue[0.8246738880325574, 1, -2.264292220809997], 
     Hue[0.8247445554626048, 1, -2.0611972616352245`], 
     Hue[0.8248325171473464, 1, -1.8902901051212073`], 
     Hue[0.8249876964136061, 1, -1.6873238173941603`], 
     Hue[0.8251807347082845, 1, -1.516577272545088], 
     Hue[0.8255209679801202, 1, -1.3138955461617738`], 
     Hue[0.8259718403043027, 1, -1.1340464215432375`], 
     Hue[0.8266352213542102, 1, -0.9530711161828085], 
     Hue[0.8276383255825217, 1, -0.7671608297216361], 
     Hue[0.8291633703708562, 1, -0.5770005667512839], 
     Hue[0.8313687111254411, 1, -0.3917761996454918], 
     Hue[0.8347575464034838, 1, -0.20051265760141823`], 
     Hue[0.8396196439752782, 1, -0.01598704199793155], 
     Hue[0.8469269997360191, 1, 0.17086024313840098`], 
     Hue[0.8578987262341365, 1, 0.3584032259054072], 
     Hue[0.8657222137474744, 1, 0.7338651673761729], 
     Hue[0.8745256573151721, 1, 0.5461563557624245], 
     Hue[0.9157088497674164, 1, 0.9218303186914913], 
     Hue[0.9004558603801114, 1, 0.7343427336569817], 
     Hue[0.9437516847867234, 1, 0.9215753674209051], 
     Hue[0.9499362351203424, 1, -17.264488266373966`], 
     Hue[0.9499362351203424, 1, -17.07736705803298], 
     Hue[0.9499362351203424, 1, -16.90742299186392], 
     Hue[0.9499362351203424, 1, -16.70312464135101], 
     Hue[0.9499362351203424, 1, -16.53318057518195], 
     Hue[0.9499362351203424, 1, -16.32888222466904], 
     Hue[0.9499362351203424, 1, -16.15893815849998], 
     Hue[0.9499362351203424, 1, -15.954639807987068`], 
     Hue[0.9499362351203424, 1, -15.784695741818005`], 
     Hue[0.9499362351203424, 1, -15.580397391305098`], 
     Hue[0.9499362351203425, 1, -15.407712291810729`], 
     Hue[0.9499362351203425, 1, -15.206154974623129`], 
     Hue[0.9499362351203425, 1, -15.033469875128759`], 
     Hue[0.9499362351203426, 1, -14.831912557941154`], 
     Hue[0.9499362351203426, 1, -14.657856941784138`], 
     Hue[0.9499362351203428, 1, -14.457670141259188`], 
     Hue[0.949936235120343, 1, -14.283614525102164`], 
     Hue[0.9499362351203432, 1, -14.08342772457722], 
     Hue[0.9499362351203435, 1, -13.908172906340381`], 
     Hue[0.949936235120344, 1, -13.709185307895257`], 
     Hue[0.9499362351203449, 1, -13.51183090847313], 
     Hue[0.9499362351203459, 1, -13.334942891213304`], 
     Hue[0.9499362351203477, 1, -13.137588491791186`], 
     Hue[0.9499362351203501, 1, -12.96070047453137], 
     Hue[0.949936235120354, 1, -12.763346075109272`], 
     Hue[0.9499362351203592, 1, -12.586458057849482`], 
     Hue[0.9499362351203678, 1, -12.389103658427427`], 
     Hue[0.9499362351203793, 1, -12.212215641167695`], 
     Hue[0.9499362351203983, 1, -12.014861241745738`], 
     Hue[0.9499362351204235, 1, -11.83797322448613], 
     Hue[0.9499362351204652, 1, -11.64061882506438], 
     Hue[0.9499362351205207, 1, -11.463730807805051`], 
     Hue[0.9499362351206124, 1, -11.266376408383758`], 
     Hue[0.9499362351207343, 1, -11.08948839112504], 
     Hue[0.9499362351209362, 1, -10.892133991704757`], 
     Hue[0.9499362351212041, 1, -10.71524597444738], 
     Hue[0.9499362351216479, 1, -10.517891575029314`], 
     Hue[0.9499362351222369, 1, -10.341003557774881`], 
     Hue[0.9499362351232128, 1, -10.143649158361697`], 
     Hue[0.9499362351246118, 1, -9.955066065593382], 
     Hue[0.949936235126722, 1, -9.764290146171342], 
     Hue[0.9499362351297296, 1, -9.580823648958356], 
     Hue[0.9499362351343692, 1, -9.390047729559518], 
     Hue[0.9499362351409821, 1, -9.206581232379603], 
     Hue[0.9499362351511835, 1, -9.015805313031782], 
     Hue[0.9499362351657235, 1, -8.83233881592458], 
     Hue[0.9499362351881536, 1, -8.641562896688933], 
     Hue[0.9499362352201229, 1, -8.45809639974161], 
     Hue[0.9499362352694407, 1, -8.2673204807526], 
     Hue[0.9499362353397325, 1, -8.083853984156802], 
     Hue[0.949936235448169, 1, -7.893078065710083], 
     Hue[0.9499362356027212, 1, -7.709611569887197], 
     Hue[0.9499362358411435, 1, -7.518835652632821], 
     Hue[0.949936236180962, 1, -7.335369158509358], 
     Hue[0.9499362367051877, 1, -7.144593243876623], 
     Hue[0.9499362374523558, 1, -6.961126753489732], 
     Hue[0.949936238604985, 1, -6.770350844621266], 
     Hue[0.9499362402478039, 1, -6.586884362450073], 
     Hue[0.9499362427821212, 1, -6.3961084662556695`], 
     Hue[0.9499362465338776, 1, -6.206794465668858], 
     Hue[0.9499362520574791, 1, -6.019307836885179], 
     Hue[0.9499362602155894, 1, -5.8325521744876365`], 
     Hue[0.9499362723604756, 1, -5.645065606440268], 
     Hue[0.9499362902979193, 1, -5.458310033747508], 
     Hue[0.9499363170011758, 1, -5.2708235992426085`], 
     Hue[0.9499363564406416, 1, -5.084068223785942], 
     Hue[0.9499364151536389, 1, -4.896582082903933], 
     Hue[0.9499365018698682, 1, -4.70982714111436], 
     Hue[0.9499366397387888, 1, -4.511925799691311], 
     Hue[0.9499368252474454, 1, -4.332663921882948], 
     Hue[0.9499371078090606, 1, -4.146824454371412], 
     Hue[0.9499375326312914, 1, -3.9584279940789795`], 
     Hue[0.9499381960473354, 1, -3.762267461412053], 
     Hue[0.9499390967005501, 1, -3.5827380406138216`], 
     Hue[0.9499405518620704, 1, -3.3874527652310222`], 
     Hue[0.9499425362262698, 1, -3.2077962351559375`], 
     Hue[0.9499457314442732, 1, -3.012960921967367], 
     Hue[0.9499508089202796, 1, -2.809508626559742], 
     Hue[0.9499571234084843, 1, -2.638526091044066], 
     Hue[0.9499682681273687, 1, -2.435426440829551], 
     Hue[0.9499821405750707, 1, -2.2645133176099597`], 
     Hue[0.9500066147804996, 1, -2.0615361584514], 
     Hue[0.9500370615493021, 1, -1.8907754749289925`], 
     Hue[0.9500907290695524, 1, -1.6880671689431013`], 
     Hue[0.9501574086204483, 1, -1.5176407954894804`], 
     Hue[0.9502747142740205, 1, -1.3155213546843678`], 
     Hue[0.9504297399981579, 1, -1.1364133952642843`], 
     Hue[0.9506657609199693, 1, -0.9507548519194462], 
     Hue[0.9510145185697779, 1, -0.7651596337714752], 
     Hue[0.9515301398700274, 1, -0.5795261286648041], 
     Hue[0.9523261653340658, 1, -0.3871243020540549], 
     Hue[0.9534593769511399, 1, -0.2028029742967945], 
     Hue[0.9551506667770201, 1, -0.01661261483775678], 
     Hue[0.9576775801980513, 1, 0.17097909817136914`], 
     Hue[0.9614314918632131, 1, 0.3585488930163774], 
     Hue[0.967016372571671, 1, 0.5461411632672375], 
     Hue[0.9753540641856029, 1, 0.7338613108434213], 
     Hue[0.9878715180068007, 1, 0.9215806124010153], 
     Hue[1.0753310362352742`, 1, -17.264488266373966`], 
     Hue[1.0753310362352742`, 1, -17.07736705803298], 
     Hue[1.0753310362352742`, 1, -16.90742299186392], 
     Hue[1.0753310362352742`, 1, -16.70312464135101], 
     Hue[1.0753310362352742`, 1, -16.53318057518195], 
     Hue[1.0753310362352742`, 1, -16.32888222466904], 
     Hue[1.0753310362352742`, 1, -16.15893815849998], 
     Hue[1.0753310362352742`, 1, -15.954639807987068`], 
     Hue[1.0753310362352742`, 1, -15.784695741818005`], 
     Hue[1.0753310362352742`, 1, -15.580397391305098`], 
     Hue[1.0753310362352742`, 1, -15.407712291810729`], 
     Hue[1.0753310362352742`, 1, -15.206154974623129`], 
     Hue[1.075331036235274, 1, -15.033469875128759`], 
     Hue[1.075331036235274, 1, -14.831912557941154`], 
     Hue[1.075331036235274, 1, -14.657856941784138`], 
     Hue[1.0753310362352737`, 1, -14.457670141259188`], 
     Hue[1.0753310362352735`, 1, -14.283614525102164`], 
     Hue[1.075331036235273, 1, -14.08342772457722], 
     Hue[1.0753310362352726`, 1, -13.90817290634038], 
     Hue[1.075331036235272, 1, -13.709185307895256`], 
     Hue[1.0753310362352706`, 1, -13.511830908473128`], 
     Hue[1.075331036235269, 1, -13.334942891213302`], 
     Hue[1.0753310362352664`, 1, -13.137588491791183`], 
     Hue[1.075331036235263, 1, -12.960700474531366`], 
     Hue[1.075331036235257, 1, -12.763346075109265`], 
     Hue[1.0753310362352495`, 1, -12.586458057849471`], 
     Hue[1.0753310362352368`, 1, -12.389103658427413`], 
     Hue[1.07533103623522, 1, -12.212215641167676`], 
     Hue[1.075331036235192, 1, -12.014861241745704`], 
     Hue[1.0753310362351547`, 1, -11.837973224486083`], 
     Hue[1.0753310362350932`, 1, -11.640618825064307`], 
     Hue[1.0753310362350117`, 1, -11.463730807804946`], 
     Hue[1.0753310362348762`, 1, -11.2663764083836], 
     Hue[1.0753310362346968`, 1, -11.08948839112481], 
     Hue[1.0753310362343995`, 1, -10.892133991704409`], 
     Hue[1.0753310362340047`, 1, -10.715245974446873`], 
     Hue[1.0753310362333508`, 1, -10.517891575028548`], 
     Hue[1.075331036232483, 1, -10.34100355777377], 
     Hue[1.075331036231045, 1, -10.143649158360013`], 
     Hue[1.075331036228984, 1, -9.955066065590874], 
     Hue[1.075331036225875, 1, -9.764290146167596], 
     Hue[1.0753310362214439`, 1, -9.580823648952844], 
     Hue[1.0753310362146082`, 1, -9.39004772955128], 
     Hue[1.0753310362048654`, 1, -9.206581232367483], 
     Hue[1.0753310361898354`, 1, -9.015805313013672], 
     Hue[1.0753310361684134`, 1, -8.832338815897934], 
     Hue[1.0753310361353665`, 1, -8.641562896649116], 
     Hue[1.0753310360882655`, 1, -8.45809639968302], 
     Hue[1.0753310360156045`, 1, -8.26732048066505], 
     Hue[1.075331035912042, 1, -8.08385398402798], 
     Hue[1.0753310357522803`, 1, -7.893078065517588], 
     Hue[1.075331035524575, 1, -7.709611569603951], 
     Hue[1.0753310351733023`, 1, -7.518835652209579], 
     Hue[1.0753310346726404`, 1, -7.335369157886578], 
     Hue[1.0753310339002875`, 1, -7.1445932429460255`], 
     Hue[1.0753310327994685`, 1, -6.961126752120406], 
     Hue[1.075331031101275, 1, -6.770350842575132], 
     Hue[1.0753310286808742`, 1, -6.586884359439299], 
     Hue[1.0753310249470098`, 1, -6.396108461756779], 
     Hue[1.0753310194194656`, 1, -6.206794458966989], 
     Hue[1.0753310112814238`, 1, -6.019307826939929], 
     Hue[1.075330999261903, 1, -5.832552159752061], 
     Hue[1.075330981368578, 1, -5.645065584573391], 
     Hue[1.075330954940951, 1, -5.458310001348031], 
     Hue[1.0753309155984592`, 1, -5.270823551163388], 
     Hue[1.0753308574914264`, 1, -5.084068152548498], 
     Hue[1.0753307709882653`, 1, -4.896581977191216], 
     Hue[1.0753306432272984`, 1, -4.709826984483485], 
     Hue[1.075330440101867, 1, -4.511925562106696], 
     Hue[1.0753301667876147`, 1, -4.332663575372175], 
     Hue[1.0753297504827224`, 1, -4.146823941948756], 
     Hue[1.0753291245812617`, 1, -3.9584272322163736`], 
     Hue[1.0753281471521177`, 1, -3.7622663100236693`], 
     Hue[1.075326820192345, 1, -3.5827363604204345`], 
     Hue[1.0753246762523787`, 1, -3.3874502306977936`], 
     Hue[1.0753217526073116`, 1, -3.20779253565514], 
     Hue[1.0753170449315952`, 1, -3.012955346814529], 
     Hue[1.075309563953825, 1, -2.809500071280482], 
     Hue[1.0753002602740616`, 1, -2.63851383036159], 
     Hue[1.0752838394449697`, 1, -2.4354076423831277`], 
     Hue[1.07526339889984, 1, -2.2644863849321766`], 
     Hue[1.0752273353453845`, 1, -2.061494885075314], 
     Hue[1.0751824679823816`, 1, -1.8907163789847454`], 
     Hue[1.0751033735623554`, 1, -1.6879767057162909`], 
     Hue[1.075005087661577, 1, -1.5175114451146745`], 
     Hue[1.0748321397090046`, 1, -1.315323822011296], 
     Hue[1.0746035037174502`, 1, -1.1361262059744928`], 
     Hue[1.0742552487567034`, 1, -0.9503321493714456], 
     Hue[1.073740286072515, 1, -0.764538873482395], 
     Hue[1.0729816713945604`, 1, -0.5793270452432362], 
     Hue[1.0718015660332898`, 1, -0.3860224155096261], 
     Hue[1.070148548258052, 1, -0.2036021280887177], 
     Hue[1.0676387387818416`, 1, -0.01610936085258352], 
     Hue[1.0638791623841437`, 1, 0.1726842274211241], 
     Hue[1.0583764775702589`, 1, 0.35857752814164534`], 
     Hue[1.050054922067823, 1, 0.5471563249781531], 
     Hue[1.0376802850052438`, 1, 0.7340001958781793], 
     Hue[1.0187857256415225`, 1, 0.9215810328739389], 
     Hue[1.2007258373502059`, 1, -17.264488266373966`], 
     Hue[1.2007258373502059`, 1, -17.07736705803298], 
     Hue[1.2007258373502059`, 1, -16.90742299186392], 
     Hue[1.2007258373502059`, 1, -16.70312464135101], 
     Hue[1.2007258373502059`, 1, -16.53318057518195], 
     Hue[1.2007258373502059`, 1, -16.32888222466904], 
     Hue[1.2007258373502059`, 1, -16.15893815849998], 
     Hue[1.2007258373502059`, 1, -15.954639807987068`], 
     Hue[1.2007258373502059`, 1, -15.784695741818005`], 
     Hue[1.2007258373502059`, 1, -15.580397391305098`], 
     Hue[1.2007258373502059`, 1, -15.407712291810729`], 
     Hue[1.2007258373502057`, 1, -15.206154974623129`], 
     Hue[1.2007258373502057`, 1, -15.033469875128759`], 
     Hue[1.2007258373502054`, 1, -14.831912557941154`], 
     Hue[1.2007258373502052`, 1, -14.657856941784134`], 
     Hue[1.200725837350205, 1, -14.457670141259184`], 
     Hue[1.2007258373502046`, 1, -14.283614525102161`], 
     Hue[1.2007258373502037`, 1, -14.083427724577215`], 
     Hue[1.2007258373502028`, 1, -13.908172906340374`], 
     Hue[1.200725837350201, 1, -13.709185307895247`], 
     Hue[1.2007258373501986`, 1, -13.511830908473113`], 
     Hue[1.2007258373501952`, 1, -13.334942891213283`], 
     Hue[1.2007258373501897`, 1, -13.137588491791153`], 
     Hue[1.2007258373501823`, 1, -12.960700474531322`], 
     Hue[1.2007258373501704`, 1, -12.7633460751092], 
     Hue[1.2007258373501544`, 1, -12.586458057849377`], 
     Hue[1.2007258373501277`, 1, -12.389103658427269`], 
     Hue[1.2007258373500924`, 1, -12.212215641167466`], 
     Hue[1.200725837350034, 1, -12.014861241745388`], 
     Hue[1.2007258373499563`, 1, -11.837973224485625`], 
     Hue[1.2007258373498277`, 1, -11.640618825063614`], 
     Hue[1.2007258373496572`, 1, -11.46373080780394], 
     Hue[1.2007258373493745`, 1, -11.266376408382074`], 
     Hue[1.2007258373489995`, 1, -11.089488391122599`], 
     Hue[1.200725837348378, 1, -10.892133991701057`], 
     Hue[1.2007258373475533`, 1, -10.715245974442007`], 
     Hue[1.200725837346187, 1, -10.517891575021178`], 
     Hue[1.2007258373443739`, 1, -10.34100355776307], 
     Hue[1.2007258373413698`, 1, -10.143649158343804`], 
     Hue[1.200725837337063, 1, -9.955066065566767], 
     Hue[1.2007258373305671`, 1, -9.764290146131572], 
     Hue[1.2007258373213086`, 1, -9.580823648899838], 
     Hue[1.2007258373070255`, 1, -9.390047729472077], 
     Hue[1.2007258372866685`, 1, -9.206581232250937], 
     Hue[1.2007258372552643`, 1, -9.015805312839522], 
     Hue[1.2007258372105043`, 1, -8.832338815641679], 
     Hue[1.2007258371414549`, 1, -8.641562896266205], 
     Hue[1.20072583704304, 1, -8.458096399119588], 
     Hue[1.2007258368912193`, 1, -8.267320479823134], 
     Hue[1.2007258366748321`, 1, -8.083853982789146], 
     Hue[1.2007258363410194`, 1, -7.893078063666441], 
     Hue[1.200725835865243, 1, -7.709611566880091], 
     Hue[1.20072583513128, 1, -7.518835648139411], 
     Hue[1.2007258340851772`, 1, -7.33536915189755], 
     Hue[1.2007258324713923`, 1, -7.144593233996839], 
     Hue[1.2007258301712975`, 1, -6.961126738952166], 
     Hue[1.2007258266230245`, 1, -6.770350822898311], 
     Hue[1.200725821565743, 1, -6.586884330485929], 
     Hue[1.200725813764058, 1, -6.3961084184928145`], 
     Hue[1.200725802214586, 1, -6.2067943945178845`], 
     Hue[1.2007257852106341`, 1, -6.019307731300565], 
     Hue[1.2007257600965595`, 1, -5.832552018046092], 
     Hue[1.2007257227095114`, 1, -5.645065374288598], 
     Hue[1.2007256674905227`, 1, -5.458309689775452], 
     Hue[1.200725585286631, 1, -5.270823088804934], 
     Hue[1.2007254638752065`, 1, -5.084067467486406], 
     Hue[1.200725283131435, 1, -4.896580960593405], 
     Hue[1.2007250161812029`, 1, -4.709825478223958], 
     Hue[1.20072459175951, 1, -4.5119232773417215`], 
     Hue[1.2007240206791545`, 1, -4.332660243095784], 
     Hue[1.2007231508201304`, 1, -4.146819014135866], 
     Hue[1.2007218430031381`, 1, -3.9584199055744733`], 
     Hue[1.2007198006449384`, 1, -3.762255237313509], 
     Hue[1.200717027883784, 1, -3.582720202089697], 
     Hue[1.2007125478685954`, 1, -3.3874258557606263`], 
     Hue[1.2007064383179273`, 1, -3.2077569561461816`], 
     Hue[1.2006966000668475`, 1, -3.0129017261969144`], 
     Hue[1.2006831225355565`, 1, -2.8328287137627832`], 
     Hue[1.2006615181271603`, 1, -2.6384051704733658`], 
     Hue[1.2006271849520402`, 1, -2.4352267895140463`], 
     Hue[1.2005844360872298`, 1, -2.264227228496197], 
     Hue[1.2005089792624128`, 1, -2.0610976095376685`], 
     Hue[1.200415040704346, 1, -1.8901473258696673`], 
     Hue[1.2002492756389056`, 1, -1.6871049948377708`], 
     Hue[1.2000429948693667`, 1, -1.516263926637501], 
     Hue[1.1996792217118952`, 1, -1.3134157980831331`], 
     Hue[1.1992269539597078`, 1, -1.142819029016137], 
     Hue[1.1984860936603403`, 1, -0.9520482057340518], 
     Hue[1.1974096518993091`, 1, -0.7656513776962619], 
     Hue[1.195768893643376, 1, -0.5747560587403884], 
     Hue[1.1933872692090028`, 1, -0.3884792566708031], 
     Hue[1.1899036938829661`, 1, -0.2041629864094643], 
     Hue[1.1845645258758086`, 1, -0.014126202570421409`], 
     Hue[1.1767808872490289`, 1, 0.17163725881887848`], 
     Hue[1.1650720340222933`, 1, 0.3585476845457829], 
     Hue[1.1471826238670835`, 1, 0.5466839836913586], 
     Hue[1.1192338533091615`, 1, 0.7342456031781242], 
     Hue[1.0709813148498528`, 1, 0.9222615996809735], 
     Hue[1.3261206384651372`, 1, -17.264488266373966`], 
     Hue[1.3261206384651372`, 1, -17.07736705803298], 
     Hue[1.326120638465137, 1, -16.90742299186392], 
     Hue[1.3261206384651372`, 1, -16.70312464135101], 
     Hue[1.3261206384651372`, 1, -16.53318057518195], 
     Hue[1.3261206384651372`, 1, -16.32888222466904], 
     Hue[1.326120638465137, 1, -16.15893815849998], 
     Hue[1.326120638465137, 1, -15.954639807987068`], 
     Hue[1.326120638465137, 1, -15.784695741818005`], 
     Hue[1.326120638465137, 1, -15.580397391305098`], 
     Hue[1.326120638465137, 1, -15.407712291810729`], 
     Hue[1.326120638465137, 1, -15.206154974623129`], 
     Hue[1.3261206384651367`, 1, -15.033469875128759`], 
     Hue[1.3261206384651367`, 1, -14.831912557941154`], 
     Hue[1.3261206384651365`, 1, -14.657856941784134`], 
     Hue[1.3261206384651363`, 1, -14.457670141259184`], 
     Hue[1.3261206384651358`, 1, -14.283614525102157`], 
     Hue[1.326120638465135, 1, -14.08342772457721], 
     Hue[1.326120638465134, 1, -13.908172906340365`], 
     Hue[1.3261206384651325`, 1, -13.709185307895234`], 
     Hue[1.3261206384651303`, 1, -13.511830908473097`], 
     Hue[1.3261206384651272`, 1, -13.334942891213256`], 
     Hue[1.326120638465122, 1, -13.137588491791114`], 
     Hue[1.3261206384651152`, 1, -12.960700474531267`], 
     Hue[1.3261206384651039`, 1, -12.763346075109116`], 
     Hue[1.326120638465089, 1, -12.586458057849255`], 
     Hue[1.3261206384650641`, 1, -12.38910365842708], 
     Hue[1.3261206384650313`, 1, -12.212215641167194`], 
     Hue[1.3261206384649769`, 1, -12.014861241744976`], 
     Hue[1.3261206384649045`, 1, -11.837973224485028`], 
     Hue[1.3261206384647846`, 1, -11.640618825062708`], 
     Hue[1.3261206384646256`, 1, -11.463730807802625`], 
     Hue[1.3261206384643622`, 1, -11.266376408380083`], 
     Hue[1.3261206384640125`, 1, -11.089488391119705`], 
     Hue[1.3261206384634334`, 1, -10.892133991696674`], 
     Hue[1.3261206384626647`, 1, -10.715245974435648`], 
     Hue[1.3261206384613913`, 1, -10.517891575011543`], 
     Hue[1.326120638459701, 1, -10.341003557749092`], 
     Hue[1.3261206384569009`, 1, -10.143649158322624`], 
     Hue[1.3261206384528865`, 1, -9.955066065535265], 
     Hue[1.3261206384468318`, 1, -9.7642901460845], 
     Hue[1.3261206384382016`, 1, -9.580823648830574], 
     Hue[1.3261206384248885`, 1, -9.390047729368577], 
     Hue[1.3261206384059134`, 1, -9.206581232098644], 
     Hue[1.3261206383766415`, 1, -9.015805312611954], 
     Hue[1.3261206383349207`, 1, -8.83233881530683], 
     Hue[1.3261206382705595`, 1, -8.64156289576585], 
     Hue[1.3261206381788266`, 1, -8.458096398383342], 
     Hue[1.3261206380373138`, 1, -8.267320478722988], 
     Hue[1.3261206378356185`, 1, -8.083853981170341], 
     Hue[1.3261206375244705`, 1, -7.893078061247521], 
     Hue[1.3261206370809973`, 1, -7.709611563320782], 
     Hue[1.3261206363968676`, 1, -7.518835642820867], 
     Hue[1.3261206354217911`, 1, -7.335369144071602], 
     Hue[1.326120633917576, 1, -7.144593222302809], 
     Hue[1.3261206317736485`, 1, -6.96112672174504], 
     Hue[1.3261206284662892`, 1, -6.770350797186327], 
     Hue[1.3261206237523773`, 1, -6.586884292652147], 
     Hue[1.326120616480395, 1, -6.396108361959171], 
     Hue[1.3261206057150843`, 1, -6.206794310301305], 
     Hue[1.3261205898656283`, 1, -6.019307606327203], 
     Hue[1.3261205664566869`, 1, -5.832551832876779], 
     Hue[1.3261205316080413`, 1, -5.645065099506214], 
     Hue[1.3261204801381348`, 1, -5.458309282638553], 
     Hue[1.3261204035154068`, 1, -5.27082248463327], 
     Hue[1.3261202903469922`, 1, -5.084066572303137], 
     Hue[1.3261201218742364`, 1, -4.896579632184157], 
     Hue[1.3261198730471677`, 1, -4.709823509959007], 
     Hue[1.3261194774379435`, 1, -4.511920291773999], 
     Hue[1.326118945123514, 1, -4.332655888692789], 
     Hue[1.326118134306135, 1, -4.146812574739204], 
     Hue[1.3261169152437708`, 1, -3.958410331407583], 
     Hue[1.3261150114574443`, 1, -3.7622407676690086`], 
     Hue[1.3261124267624376`, 1, -3.582699086114218], 
     Hue[1.3261082504572808`, 1, -3.387394000915962], 
     Hue[1.3261025547820477`, 1, -3.207710455865816], 
     Hue[1.3260933822591845`, 1, -3.012831641130094], 
     Hue[1.3260808209831723`, 1, -2.8327948520618795`], 
     Hue[1.3260606703194975`, 1, -2.6382788176781418`], 
     Hue[1.3260286383838373`, 1, -2.4349902587760743`], 
     Hue[1.3259887436872182`, 1, -2.263888158376007], 
     Hue[1.3259182827524665`, 1, -2.0605774804396058`], 
     Hue[1.325830488618199, 1, -1.8894016753146905`], 
     Hue[1.3256753624915187`, 1, -1.6859610745416769`], 
     Hue[1.3254819571493197`, 1, -1.5146238378853243`], 
     Hue[1.3251399026065434`, 1, -1.3108992284419199`], 
     Hue[1.3247128706010063`, 1, -1.1392101094892213`], 
     Hue[1.3240090830620674`, 1, -0.9466436077012634], 
     Hue[1.323042215846316, 1, -0.7675878559230758], 
     Hue[1.3214403786507334`, 1, -0.5686319599045575], 
     Hue[1.3193092530009696`, 1, -0.39046859530362776`], 
     Hue[1.3160415521196307`, 1, -0.20450426797599275`], 
     Hue[1.311120255121248, 1, -0.01602393767514787], 
     Hue[1.3038432491506888`, 1, 0.17098825985331567`], 
     Hue[1.292927562841608, 1, 0.35850716074681444`], 
     Hue[1.1342647091549485`, 1, 0.7338424034611435], 
     Hue[1.2763420735139583`, 1, 0.546676359823929], 
     Hue[1.2506536327593483`, 1, 0.7341637268643935], 
     Hue[1.0842164823383107`, 1, 0.9215785396069143], 
     Hue[1.207519860229497, 1, 0.9220253148573181], 
     Hue[1.451515439580069, 1, -17.264488266373966`], 
     Hue[1.451515439580069, 1, -17.07736705803298], 
     Hue[1.451515439580069, 1, -16.90742299186392], 
     Hue[1.451515439580069, 1, -16.70312464135101], 
     Hue[1.451515439580069, 1, -16.53318057518195], 
     Hue[1.451515439580069, 1, -16.32888222466904], 
     Hue[1.451515439580069, 1, -16.15893815849998], 
     Hue[1.451515439580069, 1, -15.954639807987068`], 
     Hue[1.451515439580069, 1, -15.784695741818005`], 
     Hue[1.451515439580069, 1, -15.580397391305098`], 
     Hue[1.451515439580069, 1, -15.407712291810729`], 
     Hue[1.451515439580069, 1, -15.206154974623129`], 
     Hue[1.4515154395800687`, 1, -15.033469875128759`], 
     Hue[1.4515154395800687`, 1, -14.831912557941154`], 
     Hue[1.4515154395800687`, 1, -14.65785694178413], 
     Hue[1.4515154395800685`, 1, -14.45767014125918], 
     Hue[1.4515154395800685`, 1, -14.283614525102157`], 
     Hue[1.451515439580068, 1, -14.083427724577206`], 
     Hue[1.4515154395800678`, 1, -13.90817290634036], 
     Hue[1.4515154395800673`, 1, -13.709185307895225`], 
     Hue[1.4515154395800665`, 1, -13.511830908473085`], 
     Hue[1.4515154395800653`, 1, -13.33494289121324], 
     Hue[1.4515154395800638`, 1, -13.137588491791089`], 
     Hue[1.4515154395800614`, 1, -12.96070047453123], 
     Hue[1.4515154395800576`, 1, -12.763346075109059`], 
     Hue[1.4515154395800525`, 1, -12.586458057849175`], 
     Hue[1.451515439580044, 1, -12.389103658426961`], 
     Hue[1.4515154395800332`, 1, -12.212215641167019`], 
     Hue[1.4515154395800147`, 1, -12.01486124174471], 
     Hue[1.4515154395799903`, 1, -11.83797322448464], 
     Hue[1.4515154395799497`, 1, -11.640618825062122`], 
     Hue[1.4515154395798961`, 1, -11.463730807801776`], 
     Hue[1.451515439579807, 1, -11.266376408378795`], 
     Hue[1.451515439579689, 1, -11.08948839111784], 
     Hue[1.4515154395794934`, 1, -10.892133991693846`], 
     Hue[1.4515154395792336`, 1, -10.715245974431546`], 
     Hue[1.4515154395788032`, 1, -10.517891575005326`], 
     Hue[1.4515154395782321`, 1, -10.341003557740068`], 
     Hue[1.4515154395772862`, 1, -10.143649158308955`], 
     Hue[1.45151543957593, 1, -9.955066065514934], 
     Hue[1.4515154395738843`, 1, -9.764290146054119], 
     Hue[1.4515154395709684`, 1, -9.58082364878587], 
     Hue[1.4515154395664704`, 1, -9.390047729301777], 
     Hue[1.4515154395600596`, 1, -9.206581232000351], 
     Hue[1.4515154395501697`, 1, -9.015805312465078], 
     Hue[1.4515154395360739`, 1, -8.832338815090708], 
     Hue[1.451515439514329, 1, -8.64156289544291], 
     Hue[1.4515154394833363`, 1, -8.458096397908154], 
     Hue[1.4515154394355247`, 1, -8.26732047801293], 
     Hue[1.4515154393673801`, 1, -8.083853980125529], 
     Hue[1.4515154392622558`, 1, -7.893078059686297], 
     Hue[1.4515154391124243`, 1, -7.709611561023524], 
     Hue[1.4515154388812848`, 1, -7.518835639388159], 
     Hue[1.451515438551846, 1, -7.335369139020556], 
     Hue[1.451515438043633, 1, -7.144593214755218], 
     Hue[1.4515154373192871`, 1, -6.961126710639166], 
     Hue[1.451515436201865, 1, -6.770350780591227], 
     Hue[1.451515434609226, 1, -6.5868842682333595`], 
     Hue[1.451515432152319, 1, -6.396108325471063], 
     Hue[1.4515154285151581`, 1, -6.206794255945992], 
     Hue[1.4515154231602705`, 1, -6.019307525666514], 
     Hue[1.4515154152513392`, 1, -5.832551713364212], 
     Hue[1.4515154034773932`, 1, -5.645064922155239], 
     Hue[1.4515153860877912`, 1, -5.458309019862763], 
     Hue[1.4515153602000554`, 1, -5.270822094686312], 
     Hue[1.4515153219649777`, 1, -5.08406599452969], 
     Hue[1.4515152650447205`, 1, -4.896578774794648], 
     Hue[1.451515180975808, 1, -4.709822239587348], 
     Hue[1.451515047314658, 1, -4.511918364800711], 
     Hue[1.451514867465491, 1, -4.3326530782195976`], 
     Hue[1.4515145935192917`, 1, -4.14680841851333], 
     Hue[1.4515141816387889`, 1, -3.958404151817417], 
     Hue[1.4515135384058833`, 1, -3.7622314281629956`], 
     Hue[1.4515126651004433`, 1, -3.5826854563860833`], 
     Hue[1.4515112539953905`, 1, -3.3873734388052634`], 
     Hue[1.4515093294537, 1, -3.2076804386914466`], 
     Hue[1.451506229940598, 1, -3.0127863956484315`], 
     Hue[1.4515019875903552`, 1, -2.8328201415140084`], 
     Hue[1.4514951761222321`, 1, -2.638216381365538], 
     Hue[1.451484346500034, 1, -2.4348374712747454`], 
     Hue[1.4514708571494286`, 1, -2.2636690574788876`], 
     Hue[1.451447023416847, 1, -2.060241171414522], 
     Hue[1.451417310178422, 1, -1.8889191694085639`], 
     Hue[1.451364764181918, 1, -1.6852198259129996`], 
     Hue[1.4512991715097625`, 1, -1.513559241393829], 
     Hue[1.4511829457472458`, 1, -1.309260702124824], 
     Hue[1.4510374499180954`, 1, -1.1368513692076283`], 
     Hue[1.4508149624707356`, 1, -0.9553202117167581], 
     Hue[1.4504759752439589`, 1, -0.7678399776915961], 
     Hue[1.4499675666170522`, 1, -0.5787103998263063], 
     Hue[1.4492102500790163`, 1, -0.38953595944207997`], 
     Hue[1.394760066256171, 1, 0.17176548624051569`], 
     Hue[1.4480958944532356`, 1, -0.20224218804437855`], 
     Hue[1.4464625594683909`, 1, -0.01682128085880019], 
     Hue[1.4439417110887538`, 1, 0.17532459206072515`], 
     Hue[1.2866755090987798`, 1, 0.5470322649100446], 
     Hue[1.44034631809485, 1, 0.35963598167917976`], 
     Hue[1.4349140118076948`, 1, 0.5474237221308667], 
     Hue[1.2183836826433747`, 1, 0.921789716376895], 
     Hue[1.2882000149706558`, 1, 1.1092903144260768`], 
     Hue[1.4268771402732408`, 1, 0.7339230186686941], 
     Hue[1.414761078990764, 1, 0.9215707462887497], 
     Hue[1.3963274733129472`, 1, 1.1093246819609086`], 
     Hue[1.1149986521676745`, 1, 1.109458370391243], 
     Hue[1.1136159846122586`, 1, 1.2971753475275822`], 
     Hue[1.367342278545617, 1, 1.2970405705535737`], 
     Hue[1.048188155199743, 1, 1.1093216896761913`], 
     Hue[1.0356858546287833`, 1, 1.2970265467916346`], 
     Hue[1.012781466352348, 1, 1.1092913221677714`], 
     Hue[1.0067630123733722`, 1, 1.1098166950787411`], 
     Hue[0.5769102406950004, 1, -17.264488266373966`], 
     Hue[0.5769102406950004, 1, -17.07736705803298], 
     Hue[0.5769102406950004, 1, -16.90742299186392], 
     Hue[0.5769102406950004, 1, -16.70312464135101], 
     Hue[0.5769102406950004, 1, -16.53318057518195], 
     Hue[0.5769102406950004, 1, -16.32888222466904], 
     Hue[0.5769102406950004, 1, -16.15893815849998], 
     Hue[0.5769102406950006, 1, -15.954639807987068`], 
     Hue[0.5769102406950006, 1, -15.784695741818005`], 
     Hue[0.5769102406950006, 1, -15.580397391305098`], 
     Hue[0.5769102406950006, 1, -15.407712291810729`], 
     Hue[0.5769102406950006, 1, -15.206154974623129`], 
     Hue[0.5769102406950006, 1, -15.033469875128759`], 
     Hue[0.5769102406950006, 1, -14.831912557941154`], 
     Hue[0.5769102406950009, 1, -14.65785694178413], 
     Hue[0.576910240695001, 1, -14.45767014125918], 
     Hue[0.5769102406950012, 1, -14.283614525102157`], 
     Hue[0.5769102406950016, 1, -14.083427724577206`], 
     Hue[0.576910240695002, 1, -13.908172906340361`], 
     Hue[0.5769102406950029, 1, -13.709185307895227`], 
     Hue[0.5769102406950041, 1, -13.511830908473087`], 
     Hue[0.5769102406950057, 1, -13.334942891213242`], 
     Hue[0.5769102406950084, 1, -13.137588491791092`], 
     Hue[0.576910240695012, 1, -12.960700474531235`], 
     Hue[0.5769102406950178, 1, -12.763346075109068`], 
     Hue[0.5769102406950257, 1, -12.586458057849185`], 
     Hue[0.5769102406950386, 1, -12.389103658426976`], 
     Hue[0.5769102406950558, 1, -12.212215641167044`], 
     Hue[0.5769102406950843, 1, -12.014861241744747`], 
     Hue[0.5769102406951223, 1, -11.837973224484696`], 
     Hue[0.5769102406951849, 1, -11.640618825062203`], 
     Hue[0.5769102406952682, 1, -11.463730807801893`], 
     Hue[0.5769102406954061, 1, -11.266376408378974`], 
     Hue[0.576910240695589, 1, -11.089488391118097`], 
     Hue[0.5769102406958921, 1, -10.89213399169424], 
     Hue[0.5769102406962945, 1, -10.715245974432115`], 
     Hue[0.5769102406969611, 1, -10.517891575006189`], 
     Hue[0.5769102406978457, 1, -10.34100355774132], 
     Hue[0.5769102406993112, 1, -10.14364915831085], 
     Hue[0.5769102407014122, 1, -9.955066065517752], 
     Hue[0.5769102407045812, 1, -9.76429014605833], 
     Hue[0.576910240709098, 1, -9.580823648792068], 
     Hue[0.5769102407160658, 1, -9.39004772931104], 
     Hue[0.576910240725997, 1, -9.206581232013981], 
     Hue[0.5769102407413174, 1, -9.015805312485448], 
     Hue[0.5769102407631533, 1, -8.832338815120679], 
     Hue[0.576910240796839, 1, -8.641562895487692], 
     Hue[0.5769102408448501, 1, -8.458096397974048], 
     Hue[0.5769102409189153, 1, -8.267320478111396], 
     Hue[0.5769102410244789, 1, -8.083853980270414], 
     Hue[0.576910241187328, 1, -7.893078059902792], 
     Hue[0.5769102414194336, 1, -7.709611561342087], 
     Hue[0.5769102417774945, 1, -7.518835639864174], 
     Hue[0.5769102422878316, 1, -7.3353691397209895`], 
     Hue[0.5769102430751101, 1, -7.144593215801849], 
     Hue[0.576910244197202, 1, -6.96112671217923], 
     Hue[0.5769102459282129, 1, -6.7703507828924865`], 
     Hue[0.5769102483953876, 1, -6.586884271619537], 
     Hue[0.5769102522014093, 1, -6.396108330530906], 
     Hue[0.576910257835775, 1, -6.206794263483498], 
     Hue[0.5769102661310896, 1, -6.019307536851812], 
     Hue[0.5769102783829015, 1, -5.832551729937138], 
     Hue[0.5769102966220488, 1, -5.645064946748679], 
     Hue[0.5769103235604689, 1, -5.458309056302155], 
     Hue[0.576910363663437, 1, -5.270822148760673], 
     Hue[0.576910422893799, 1, -5.0840660746501785`], 
     Hue[0.5769105110695574, 1, -4.896578893689868], 
     Hue[0.5769106413015521, 1, -4.7098224157514235`], 
     Hue[0.5769108483573141, 1, -4.5119186320169], 
     Hue[0.5769111269632485, 1, -4.332653467952626], 
     Hue[0.5769115513354508, 1, -4.1468089948655456`], 
     Hue[0.5769121893821357, 1, -3.9584050087567793`], 
     Hue[0.5769131858167786, 1, -3.762232723303283], 
     Hue[0.5769145386547537, 1, -3.5826873464804123`], 
     Hue[0.576916724591266, 1, -3.3873762902794073`], 
     Hue[0.5769197058759085, 1, -3.2076846014286957`], 
     Hue[0.5769245072601864, 1, -3.012792670398034], 
     Hue[0.5769310789179094, 1, -2.8328293074002238`], 
     Hue[0.5769416301276309, 1, -2.6382301901782164`], 
     Hue[0.5769584051781509, 1, -2.434858664336584], 
     Hue[0.5769792994099672, 1, -2.263699452486577], 
     Hue[0.5770162145177631, 1, -2.060287836163363], 
     Hue[0.5770622326119772, 1, -1.888986137540875], 
     Hue[0.5771436030847854, 1, -1.6853227538450055`], 
     Hue[0.5772451597724862, 1, -1.5137071553203294`], 
     Hue[0.5774250640085266, 1, -1.3094885943802075`], 
     Hue[0.5776501893875571, 1, -1.1371798603711116`], 
     Hue[0.5779946812375545, 1, -0.9556184636995015], 
     Hue[0.5785543427204775, 1, -0.7579614250967994], 
     Hue[0.5793026517581111, 1, -0.5797948902673855], 
     Hue[0.5804691233366941, 1, -0.3911727309745494], 
     Hue[0.5821805245300724, 1, -0.20471710396772314`], 
     Hue[0.5848248375291436, 1, -0.011679428682600301`], 
     Hue[0.5885851672540707, 1, 0.17273929637918173`], 
     Hue[0.5942022779557254, 1, 0.3588117121250244], 
     Hue[0.6026372897834331, 1, 0.5463921665657131], 
     Hue[0.6152985817968641, 1, 0.7339480387348957], 
     Hue[0.6346076049984368, 1, 0.92165487282635], 
     Hue[0.665148947400712, 1, 1.1093127241276675`], 
     Hue[0.7197236635313518, 1, 1.2970626426633034`], 
     Hue[0.9340035686637386, 1, 1.297284573949255], 
     Hue[0.988654431623437, 1, 1.1093951463223484`], 
     Hue[0.7023050418099317, 1, -17.264488266373966`], 
     Hue[0.7023050418099317, 1, -17.07736705803298], 
     Hue[0.7023050418099317, 1, -16.90742299186392], 
     Hue[0.7023050418099317, 1, -16.70312464135101], 
     Hue[0.7023050418099317, 1, -16.53318057518195], 
     Hue[0.7023050418099317, 1, -16.32888222466904], 
     Hue[0.7023050418099317, 1, -16.15893815849998], 
     Hue[0.7023050418099317, 1, -15.954639807987068`], 
     Hue[0.7023050418099317, 1, -15.784695741818005`], 
     Hue[0.7023050418099317, 1, -15.580397391305098`], 
     Hue[0.7023050418099318, 1, -15.407712291810729`], 
     Hue[0.7023050418099319, 1, -15.206154974623129`], 
     Hue[0.7023050418099319, 1, -15.033469875128759`], 
     Hue[0.7023050418099321, 1, -14.831912557941154`], 
     Hue[0.7023050418099324, 1, -14.657856941784134`], 
     Hue[0.7023050418099327, 1, -14.457670141259184`], 
     Hue[0.702305041809933, 1, -14.283614525102161`], 
     Hue[0.7023050418099339, 1, -14.083427724577211`], 
     Hue[0.7023050418099348, 1, -13.908172906340367`], 
     Hue[0.7023050418099366, 1, -13.709185307895236`], 
     Hue[0.702305041809939, 1, -13.511830908473101`], 
     Hue[0.7023050418099424, 1, -13.334942891213261`], 
     Hue[0.7023050418099479, 1, -13.137588491791123`], 
     Hue[0.7023050418099552, 1, -12.960700474531277`], 
     Hue[0.7023050418099673, 1, -12.763346075109132`], 
     Hue[0.7023050418099834, 1, -12.586458057849281`], 
     Hue[0.7023050418100101, 1, -12.389103658427121`], 
     Hue[0.7023050418100455, 1, -12.212215641167253`], 
     Hue[0.7023050418101042, 1, -12.014861241745066`], 
     Hue[0.7023050418101819, 1, -11.837973224485156`], 
     Hue[0.702305041810311, 1, -11.640618825062903`], 
     Hue[0.7023050418104821, 1, -11.463730807802907`], 
     Hue[0.7023050418107656, 1, -11.266376408380511`], 
     Hue[0.7023050418111418, 1, -11.08948839112033], 
     Hue[0.7023050418117651, 1, -10.89213399169762], 
     Hue[0.7023050418125925, 1, -10.71524597443702], 
     Hue[0.702305041813963, 1, -10.517891575013621`], 
     Hue[0.7023050418157819, 1, -10.341003557752106`], 
     Hue[0.7023050418187955, 1, -10.143649158327193`], 
     Hue[0.7023050418231155, 1, -9.955066065542063], 
     Hue[0.7023050418296317, 1, -9.764290146094657], 
     Hue[0.7023050418389194, 1, -9.580823648845518], 
     Hue[0.7023050418532469, 1, -9.390047729390908], 
     Hue[0.7023050418736676, 1, -9.206581232131503], 
     Hue[0.7023050419051701, 1, -9.015805312661056], 
     Hue[0.7023050419500698, 1, -8.832338815379076], 
     Hue[0.702305042019335, 1, -8.641562895873808], 
     Hue[0.7023050421180572, 1, -8.458096398542196], 
     Hue[0.7023050422703525, 1, -8.267320478960357], 
     Hue[0.7023050424874158, 1, -8.083853981519615], 
     Hue[0.7023050428222717, 1, -7.893078061769432], 
     Hue[0.7023050432995348, 1, -7.709611564088742], 
     Hue[0.7023050440357914, 1, -7.518835643968402], 
     Hue[0.7023050450851629, 1, -7.335369145760137], 
     Hue[0.7023050467039905, 1, -7.144593224825926], 
     Hue[0.7023050490112726, 1, -6.961126725457668], 
     Hue[0.7023050525706335, 1, -6.770350802733975], 
     Hue[0.7023050576437182, 1, -6.586884300815207], 
     Hue[0.7023050654697829, 1, -6.396108374156935], 
     Hue[0.702305077055347, 1, -6.206794328471972], 
     Hue[0.7023050941124378, 1, -6.019307633291602], 
     Hue[0.702305119305001, 1, -5.83255187282913], 
     Hue[0.7023051568089029, 1, -5.645065158793597], 
     Hue[0.7023052122005002, 1, -5.458309370482928], 
     Hue[0.702305294661397, 1, -5.270822614990157], 
     Hue[0.7023054164525044, 1, -5.084066765449171], 
     Hue[0.7023055977617223, 1, -4.896579918803858], 
     Hue[0.7023058655475674, 1, -4.709823934635445], 
     Hue[0.7023062912989583, 1, -4.511920935946621], 
     Hue[0.7023068641707448, 1, -4.332656828210426], 
     Hue[0.7023077367634194, 1, -4.1468139641254345`], 
     Hue[0.702309048701711, 1, -3.958412397173242], 
     Hue[0.7023110975231192, 1, -3.762243889730348], 
     Hue[0.702313879111906, 1, -3.582703642279651], 
     Hue[0.7023183735191078, 1, -3.3874008743145216`], 
     Hue[0.7023245029535314, 1, -3.2077204895888443`], 
     Hue[0.7023343738465526, 1, -3.012846764512715], 
     Hue[0.70234789115968, 1, -2.832816945775229], 
     Hue[0.7023695746591201, 1, -2.6383120938835845`], 
     Hue[0.7024040411226011, 1, -2.4350413128474235`], 
     Hue[0.7024469643338483, 1, -2.263961357492187], 
     Hue[0.7025227643721395, 1, -2.0606898004900502`], 
     Hue[0.702617193542955, 1, -1.8895627558948898`], 
     Hue[0.7027839959206661, 1, -1.686208354638785], 
     Hue[0.7029918739623937, 1, -1.5149786647453538`], 
     Hue[0.7033592942425222, 1, -1.3114444668998326`], 
     Hue[0.7038175800883953, 1, -1.1399934269983933`], 
     Hue[0.7045718738393398, 1, -0.9478201600095999], 
     Hue[0.705675815684835, 1, -0.7593790487326133], 
     Hue[0.7073143061760855, 1, -0.5712522736502104], 
     Hue[0.7096056406199112, 1, -0.3924234684949106], 
     Hue[0.6085585468968374, 1, 0.17090244610714445`], 
     Hue[0.7131504896286025, 1, -0.20462474875124315`], 
     Hue[0.718420706600674, 1, -0.01694704942738956], 
     Hue[0.7138699864397495, 1, 0.5465226465665212], 
     Hue[0.7262909865734115, 1, 0.17096168443604465`], 
     Hue[0.7382015310179748, 1, 0.3602335279846379], 
     Hue[0.7816298389286039, 1, 0.9217541561152284], 
     Hue[0.7118024905948535, 1, 1.1092838312755176`], 
     Hue[0.7560007884314117, 1, 0.5465017720380615], 
     Hue[0.7842130805679095, 1, 0.734966281838949], 
     Hue[0.8850037340747511, 1, 1.1094227597814366`], 
     Hue[0.8863716869749997, 1, 1.297026087046045], 
     Hue[0.8323641427654178, 1, 0.9216623956880626], 
     Hue[0.9518105478475207, 1, 1.1093056374645798`], 
     Hue[0.9872144963474178, 1, 1.1092828502643308`], 
     Hue[0.8276998429248634, 1, -17.264488266373966`], 
     Hue[0.8276998429248634, 1, -17.07736705803298], 
     Hue[0.8276998429248634, 1, -16.90742299186392], 
     Hue[0.8276998429248634, 1, -16.70312464135101], 
     Hue[0.8276998429248634, 1, -16.53318057518195], 
     Hue[0.8276998429248634, 1, -16.32888222466904], 
     Hue[0.8276998429248634, 1, -16.15893815849998], 
     Hue[0.8276998429248634, 1, -15.954639807987068`], 
     Hue[0.8276998429248634, 1, -15.784695741818005`], 
     Hue[0.8276998429248634, 1, -15.580397391305098`], 
     Hue[0.8276998429248635, 1, -15.407712291810729`], 
     Hue[0.8276998429248636, 1, -15.206154974623129`], 
     Hue[0.8276998429248636, 1, -15.033469875128759`], 
     Hue[0.8276998429248639, 1, -14.831912557941154`], 
     Hue[0.827699842924864, 1, -14.657856941784134`], 
     Hue[0.8276998429248643, 1, -14.457670141259184`], 
     Hue[0.8276998429248648, 1, -14.283614525102164`], 
     Hue[0.8276998429248654, 1, -14.083427724577216`], 
     Hue[0.8276998429248664, 1, -13.908172906340376`], 
     Hue[0.8276998429248679, 1, -13.709185307895249`], 
     Hue[0.8276998429248702, 1, -13.511830908473117`], 
     Hue[0.8276998429248733, 1, -13.334942891213286`], 
     Hue[0.8276998429248784, 1, -13.137588491791162`], 
     Hue[0.8276998429248852, 1, -12.960700474531334`], 
     Hue[0.8276998429248964, 1, -12.763346075109219`], 
     Hue[0.8276998429249113, 1, -12.586458057849404`], 
     Hue[0.8276998429249359, 1, -12.38910365842731], 
     Hue[0.8276998429249687, 1, -12.212215641167525`], 
     Hue[0.8276998429250229, 1, -12.014861241745477`], 
     Hue[0.8276998429250948, 1, -11.837973224485753`], 
     Hue[0.827699842925214, 1, -11.640618825063807`], 
     Hue[0.8276998429253721, 1, -11.463730807804222`], 
     Hue[0.8276998429256343, 1, -11.266376408382502`], 
     Hue[0.8276998429259821, 1, -11.089488391123218`], 
     Hue[0.8276998429265583, 1, -10.892133991701998`], 
     Hue[0.827699842927323, 1, -10.715245974443372`], 
     Hue[0.8276998429285899, 1, -10.517891575023246`], 
     Hue[0.8276998429302713, 1, -10.341003557766074`], 
     Hue[0.8276998429330569, 1, -10.143649158348355`], 
     Hue[0.8276998429370502, 1, -9.955066065573535], 
     Hue[0.8276998429430737, 1, -9.764290146141688], 
     Hue[0.8276998429516589, 1, -9.580823648914722], 
     Hue[0.827699842964903, 1, -9.390047729494315], 
     Hue[0.8276998429837794, 1, -9.20658123228366], 
     Hue[0.8276998430128994, 1, -9.01580531288842], 
     Hue[0.8276998430544036, 1, -8.83233881571363], 
     Hue[0.8276998431184306, 1, -8.641562896373719], 
     Hue[0.8276998432096869, 1, -8.458096399277787], 
     Hue[0.8276998433504648, 1, -8.267320480059526], 
     Hue[0.8276998435511127, 1, -8.083853983136983], 
     Hue[0.827699843860645, 1, -7.893078064186201], 
     Hue[0.827699844301815, 1, -7.709611567644891], 
     Hue[0.827699844982392, 1, -7.518835649282223], 
     Hue[0.8276998459524046, 1, -7.335369153579136], 
     Hue[0.827699847448808, 1, -7.144593236509569], 
     Hue[0.8276998495816014, 1, -6.961126742649513], 
     Hue[0.8276998528717845, 1, -6.770350828423123], 
     Hue[0.8276998575612156, 1, -6.586884338615389], 
     Hue[0.8276998647954313, 1, -6.39610843064037], 
     Hue[0.8276998755048317, 1, -6.206794412613754], 
     Hue[0.82769989127197, 1, -6.019307758153966], 
     Hue[0.8276999145593256, 1, -5.832552057833969], 
     Hue[0.8276999492269544, 1, -5.6450654333318875`], 
     Hue[0.8277000004294781, 1, -5.458309777258109], 
     Hue[0.827700076654092, 1, -5.270823218624945], 
     Hue[0.827700189234369, 1, -5.084067659836729], 
     Hue[0.8277003568312593, 1, -4.896581246031789], 
     Hue[0.827700604364033, 1, -4.709825901148934], 
     Hue[0.827700997913794, 1, -4.511923918854881], 
     Hue[0.8277015274538684, 1, -4.332661178729239], 
     Hue[0.8277023340382452, 1, -4.146820397765914], 
     Hue[0.8277035467201096, 1, -3.958421962754592], 
     Hue[0.8277054405032364, 1, -3.762258346335175], 
     Hue[0.8277080115414001, 1, -3.5827247390988353`], 
     Hue[0.8277121655953585, 1, -3.3874326999508044`], 
     Hue[0.8277178305564556, 1, -3.2077669466153003`], 
     Hue[0.8277269527241997, 1, -3.012916782890324], 
     Hue[0.8277394503972602, 1, -2.8328335810399308`], 
     Hue[0.8277594804924049, 1, -2.6384313318897172`], 
     Hue[0.8277913098870637, 1, -2.435277582864596], 
     Hue[0.8278309390265831, 1, -2.2643000223891754`], 
     Hue[0.8279008802094284, 1, -2.0612092227449814`], 
     Hue[0.8279879362035989, 1, -1.8903072409838682`], 
     Hue[0.8281415130559968, 1, -1.6873500749985684`], 
     Hue[0.8283325497690505, 1, -1.5166148640983452`], 
     Hue[0.8286692330474608, 1, -1.3139530781199198`], 
     Hue[0.8291153574830995, 1, -1.134130307198167], 
     Hue[0.8297716630215248, 1, -0.9531936279368212], 
     Hue[0.8307638662329052, 1, -0.7673414065042956], 
     Hue[0.8322718755189358, 1, -0.5772686147621795], 
     Hue[0.8344516067481837, 1, -0.39216896071833696`], 
     Hue[0.8377988856658904, 1, -0.20109276960975175`], 
     Hue[0.8425968378359989, 1, -0.01682629293678528], 
     Hue[0.8498604930605396, 1, 0.17098202529683348`], 
     Hue[0.8607736635913341, 1, 0.3592954905602178], 
     Hue[0.86572561771703, 1, 0.7338592417125224], 
     Hue[0.8772674912464752, 1, 0.5471985765695924], 
     Hue[0.9157837270810918, 1, 0.921577834093671], 
     Hue[0.9026924697280677, 1, 0.7338681598543865], 
     Hue[0.9454254519011835, 1, 0.9216519152496085], 
     Hue[0.9530946440397952, 1, -17.264488266373966`], 
     Hue[0.9530946440397952, 1, -17.07736705803298], 
     Hue[0.9530946440397952, 1, -16.90742299186392], 
     Hue[0.9530946440397952, 1, -16.70312464135101], 
     Hue[0.9530946440397952, 1, -16.53318057518195], 
     Hue[0.9530946440397952, 1, -16.32888222466904], 
     Hue[0.9530946440397952, 1, -16.15893815849998], 
     Hue[0.9530946440397952, 1, -15.954639807987068`], 
     Hue[0.9530946440397952, 1, -15.784695741818005`], 
     Hue[0.9530946440397952, 1, -15.580397391305098`], 
     Hue[0.9530946440397952, 1, -15.407712291810729`], 
     Hue[0.9530946440397953, 1, -15.206154974623129`], 
     Hue[0.9530946440397953, 1, -15.033469875128759`], 
     Hue[0.9530946440397953, 1, -14.831912557941154`], 
     Hue[0.9530946440397954, 1, -14.657856941784138`], 
     Hue[0.9530946440397955, 1, -14.457670141259188`], 
     Hue[0.9530946440397956, 1, -14.283614525102164`], 
     Hue[0.9530946440397958, 1, -14.08342772457722], 
     Hue[0.9530946440397962, 1, -13.908172906340381`], 
     Hue[0.9530946440397966, 1, -13.709185307895257`], 
     Hue[0.9530946440397974, 1, -13.51183090847313], 
     Hue[0.9530946440397984, 1, -13.334942891213304`], 
     Hue[0.9530946440398, 1, -13.137588491791186`], 
     Hue[0.9530946440398023, 1, -12.960700474531372`], 
     Hue[0.953094644039806, 1, -12.763346075109272`], 
     Hue[0.9530946440398109, 1, -12.586458057849484`], 
     Hue[0.953094644039819, 1, -12.389103658427429`], 
     Hue[0.9530946440398298, 1, -12.212215641167699`], 
     Hue[0.9530946440398476, 1, -12.014861241745741`], 
     Hue[0.9530946440398712, 1, -11.837973224486134`], 
     Hue[0.9530946440399104, 1, -11.640618825064386`], 
     Hue[0.9530946440399625, 1, -11.46373080780506], 
     Hue[0.9530946440400486, 1, -11.266376408383774`], 
     Hue[0.9530946440401631, 1, -11.089488391125062`], 
     Hue[0.9530946440403526, 1, -10.892133991704792`], 
     Hue[0.9530946440406041, 1, -10.715245974447427`], 
     Hue[0.9530946440410207, 1, -10.517891575029388`], 
     Hue[0.9530946440415737, 1, -10.34100355777499], 
     Hue[0.9530946440424899, 1, -10.143649158361862`], 
     Hue[0.9530946440438033, 1, -9.955066065593627], 
     Hue[0.9530946440457844, 1, -9.764290146171708], 
     Hue[0.9530946440486079, 1, -9.580823648958894], 
     Hue[0.9530946440529637, 1, -9.390047729560322], 
     Hue[0.953094644059172, 1, -9.206581232380788], 
     Hue[0.9530946440687492, 1, -9.015805313033553], 
     Hue[0.9530946440823994, 1, -8.832338815927187], 
     Hue[0.9530946441034572, 1, -8.641562896692827], 
     Hue[0.9530946441334704, 1, -8.458096399747339], 
     Hue[0.9530946441797707, 1, -8.26732048076116], 
     Hue[0.9530946442457615, 1, -8.0838539841694], 
     Hue[0.9530946443475633, 1, -7.893078065728907], 
     Hue[0.9530946444926591, 1, -7.7096115699148955`], 
     Hue[0.9530946447164934, 1, -7.518835652674208], 
     Hue[0.9530946450355197, 1, -7.3353691585702565`], 
     Hue[0.9530946455276701, 1, -7.144593243967621], 
     Hue[0.953094646229122, 1, -6.96112675362363], 
     Hue[0.9530946473112265, 1, -6.770350844821344], 
     Hue[0.9530946488535279, 1, -6.5868843627444775`], 
     Hue[0.9530946512327805, 1, -6.396108466695587], 
     Hue[0.9530946547549822, 1, -6.20679446632419], 
     Hue[0.9530946599406167, 1, -6.019307837857663], 
     Hue[0.9530946675995651, 1, -5.832552175928535], 
     Hue[0.9530946790013546, 1, -5.645065608578491], 
     Hue[0.9530946958412784, 1, -5.458310036915647], 
     Hue[0.9530947209106698, 1, -5.27082360394397], 
     Hue[0.9530947579369929, 1, -5.084068230751799], 
     Hue[0.9530948130575768, 1, -4.896582093240907], 
     Hue[0.9530948944679856, 1, -4.709827156430295], 
     Hue[0.9530950239012526, 1, -4.511925822923192], 
     Hue[0.9530951980593618, 1, -4.332663955766013], 
     Hue[0.9530954633321249, 1, -4.146824504477917], 
     Hue[0.9530958621610927, 1, -3.9584280685765645`], 
     Hue[0.9530964849851401, 1, -3.7622675739987272`], 
     Hue[0.9530973305305253, 1, -3.5827382049086482`], 
     Hue[0.9530986966553973, 1, -3.3874530130655156`], 
     Hue[0.9531005596019662, 1, -3.207796596903586], 
     Hue[0.9531035593117431, 1, -3.0129614671192115`], 
     Hue[0.9531083261036108, 1, -2.809509463109749], 
     Hue[0.9531142542083543, 1, -2.6385272899045438`], 
     Hue[0.9531247169599556, 1, -2.435428278930652], 
     Hue[0.9531377404859461, 1, -2.2645159510219415`], 
     Hue[0.9531607168908851, 1, -2.061540193928371], 
     Hue[0.9531893001541911, 1, -1.8907812527577625`], 
     Hue[0.9532396824243469, 1, -1.6880760129196954`], 
     Hue[0.9533022792904252, 1, -1.5176534400626605`], 
     Hue[0.9534124000755138, 1, -1.31554066133777], 
     Hue[0.9535579258846666, 1, -1.1364414590549796`], 
     Hue[0.953779473277326, 1, -0.9507961449724254], 
     Hue[0.9541068215856712, 1, -0.7652202469935065], 
     Hue[0.9545907418790222, 1, -0.579614806703785], 
     Hue[0.9553377161051834, 1, -0.38725513577247295`], 
     Hue[0.9564008752677866, 1, -0.2029913616765504], 
     Hue[0.9579871504585818, 1, -0.016881508604998263`], 
     Hue[0.9603585865581379, 1, 0.17075693124222224`], 
     Hue[0.9638904189404931, 1, 0.3587677936441922], 
     Hue[0.9691735429919839, 1, 0.5475414749714587], 
     Hue[0.9769471670082318, 1, 0.7339018123932748], 
     Hue[0.9886875148837317, 1, 0.9218365927014317], 
     Hue[1.0784894451547262`, 1, -17.264488266373966`], 
     Hue[1.0784894451547262`, 1, -17.07736705803298], 
     Hue[1.0784894451547262`, 1, -16.90742299186392], 
     Hue[1.0784894451547262`, 1, -16.70312464135101], 
     Hue[1.0784894451547262`, 1, -16.53318057518195], 
     Hue[1.0784894451547262`, 1, -16.32888222466904], 
     Hue[1.0784894451547262`, 1, -16.15893815849998], 
     Hue[1.0784894451547262`, 1, -15.954639807987068`], 
     Hue[1.0784894451547262`, 1, -15.784695741818005`], 
     Hue[1.0784894451547262`, 1, -15.580397391305098`], 
     Hue[1.0784894451547262`, 1, -15.407712291810729`], 
     Hue[1.0784894451547262`, 1, -15.206154974623129`], 
     Hue[1.0784894451547262`, 1, -15.033469875128759`], 
     Hue[1.078489445154726, 1, -14.831912557941154`], 
     Hue[1.078489445154726, 1, -14.657856941784138`], 
     Hue[1.0784894451547258`, 1, -14.457670141259188`], 
     Hue[1.0784894451547256`, 1, -14.283614525102164`], 
     Hue[1.0784894451547253`, 1, -14.08342772457722], 
     Hue[1.0784894451547247`, 1, -13.90817290634038], 
     Hue[1.078489445154724, 1, -13.709185307895256`], 
     Hue[1.0784894451547227`, 1, -13.511830908473128`], 
     Hue[1.078489445154721, 1, -13.334942891213302`], 
     Hue[1.0784894451547182`, 1, -13.137588491791181`], 
     Hue[1.0784894451547147`, 1, -12.960700474531365`], 
     Hue[1.0784894451547087`, 1, -12.763346075109263`], 
     Hue[1.0784894451547007`, 1, -12.58645805784947], 
     Hue[1.0784894451546874`, 1, -12.38910365842741], 
     Hue[1.0784894451546698`, 1, -12.212215641167672`], 
     Hue[1.078489445154641, 1, -12.014861241745699`], 
     Hue[1.0784894451546023`, 1, -11.837973224486076`], 
     Hue[1.0784894451545384`, 1, -11.640618825064296`], 
     Hue[1.0784894451544536`, 1, -11.463730807804929`], 
     Hue[1.0784894451543132`, 1, -11.266376408383577`], 
     Hue[1.0784894451541267`, 1, -11.089488391124775`], 
     Hue[1.0784894451538178`, 1, -10.892133991704355`], 
     Hue[1.078489445153408, 1, -10.715245974446795`], 
     Hue[1.0784894451527287`, 1, -10.517891575028433`], 
     Hue[1.0784894451518274`, 1, -10.3410035577736], 
     Hue[1.0784894451503344`, 1, -10.143649158359757`], 
     Hue[1.0784894451481937`, 1, -9.955066065590495], 
     Hue[1.078489445144965, 1, -9.76429014616703], 
     Hue[1.078489445140363, 1, -9.580823648952009], 
     Hue[1.0784894451332636`, 1, -9.390047729550034], 
     Hue[1.0784894451231453`, 1, -9.206581232365648], 
     Hue[1.0784894451075357`, 1, -9.01580531301093], 
     Hue[1.0784894450852882`, 1, -8.832338815893896], 
     Hue[1.0784894450509674`, 1, -8.641562896643086], 
     Hue[1.0784894450020506`, 1, -8.458096399674146], 
     Hue[1.0784894449265885`, 1, -8.26732048065179], 
     Hue[1.078489444819034, 1, -8.083853984008465], 
     Hue[1.0784894446531137`, 1, -7.893078065488429], 
     Hue[1.0784894444166304`, 1, -7.709611569561045], 
     Hue[1.0784894440518167`, 1, -7.518835652145465], 
     Hue[1.0784894435318548`, 1, -7.335369157792241], 
     Hue[1.0784894427297285`, 1, -7.144593242805059], 
     Hue[1.0784894415864743`, 1, -6.9611267519129845`], 
     Hue[1.0784894398228173`, 1, -6.770350842265188], 
     Hue[1.078489437309113, 1, -6.586884358983233], 
     Hue[1.0784894334313122`, 1, -6.396108461075298], 
     Hue[1.0784894276906876`, 1, -6.206794457951805], 
     Hue[1.0784894192389338`, 1, -6.019307825433446], 
     Hue[1.078489406756074, 1, -5.832552157519949], 
     Hue[1.0784893881729818`, 1, -5.645065581261046], 
     Hue[1.0784893607266, 1, -5.458309996440231], 
     Hue[1.0784893198674992`, 1, -5.2708235438804545`], 
     Hue[1.078489259520505, 1, -5.084068141757608], 
     Hue[1.0784891696827417`, 1, -4.8965819611780885`], 
     Hue[1.0784890369967255`, 1, -4.7098269607573835`], 
     Hue[1.0784888260410164`, 1, -4.511925526117893], 
     Hue[1.0784885421907617`, 1, -4.332663522883461], 
     Hue[1.0784881098376768`, 1, -4.146823864328031], 
     Hue[1.078487459808172, 1, -3.9584271168109293`], 
     Hue[1.078486444699641, 1, -3.762266135613465], 
     Hue[1.0784850665858536`, 1, -3.5827361059074887`], 
     Hue[1.0784828399964792`, 1, -3.3874498467700516`], 
     Hue[1.0784798036422267`, 1, -3.2077919752580693`], 
     Hue[1.0784749144765748`, 1, -3.0129545022915254`], 
     Hue[1.0784671450807197`, 1, -2.8094987753191782`], 
     Hue[1.0784574826906779`, 1, -2.6385119730858326`], 
     Hue[1.07844042868862, 1, -2.4354047947070505`], 
     Hue[1.0784191998744121`, 1, -2.2644823049644556`], 
     Hue[1.078381745296725, 1, -2.061488632451719], 
     Hue[1.0783351468568465`, 1, -1.8907074259817167`], 
     Hue[1.0782529995191688`, 1, -1.6879629995449525`], 
     Hue[1.0781509176521282`, 1, -1.5174918452659638`], 
     Hue[1.0779712840201168`, 1, -1.3152938858737724`], 
     Hue[1.0777337976384047`, 1, -1.1360826728856728`], 
     Hue[1.0773720358661547`, 1, -0.9502680536795556], 
     Hue[1.0768370436615438`, 1, -0.7644447004509685], 
     Hue[1.0760488002267985`, 1, -0.5791892805288184], 
     Hue[1.074822320458993, 1, -0.38581854571828456`], 
     Hue[1.073103781732849, 1, -0.2033091829596645], 
     Hue[1.070493296556067, 1, -0.015689112860906684`], 
     Hue[1.0666450882505778`, 1, 0.17069568227778664`], 
     Hue[1.060882535590518, 1, 0.35847388477606923`], 
     Hue[1.0522854499853125`, 1, 0.5461649021542622], 
     Hue[1.039369939120333, 1, 0.7338572719889151], 
     Hue[1.0196382548478904`, 1, 0.9217610764718794], 
     Hue[1.203884246269658, 1, -17.264488266373966`], 
     Hue[1.203884246269658, 1, -17.07736705803298], 
     Hue[1.203884246269658, 1, -16.90742299186392], 
     Hue[1.203884246269658, 1, -16.70312464135101], 
     Hue[1.203884246269658, 1, -16.53318057518195], 
     Hue[1.203884246269658, 1, -16.32888222466904], 
     Hue[1.203884246269658, 1, -16.15893815849998], 
     Hue[1.203884246269658, 1, -15.954639807987068`], 
     Hue[1.203884246269658, 1, -15.784695741818005`], 
     Hue[1.203884246269658, 1, -15.580397391305098`], 
     Hue[1.203884246269658, 1, -15.407712291810729`], 
     Hue[1.2038842462696577`, 1, -15.206154974623129`], 
     Hue[1.2038842462696577`, 1, -15.033469875128759`], 
     Hue[1.2038842462696575`, 1, -14.831912557941154`], 
     Hue[1.2038842462696575`, 1, -14.657856941784134`], 
     Hue[1.203884246269657, 1, -14.457670141259184`], 
     Hue[1.2038842462696566`, 1, -14.283614525102161`], 
     Hue[1.2038842462696557`, 1, -14.083427724577215`], 
     Hue[1.2038842462696548`, 1, -13.908172906340374`], 
     Hue[1.203884246269653, 1, -13.709185307895247`], 
     Hue[1.2038842462696506`, 1, -13.511830908473113`], 
     Hue[1.2038842462696473`, 1, -13.334942891213283`], 
     Hue[1.2038842462696417`, 1, -13.137588491791153`], 
     Hue[1.2038842462696344`, 1, -12.96070047453132], 
     Hue[1.2038842462696222`, 1, -12.763346075109197`], 
     Hue[1.2038842462696062`, 1, -12.586458057849374`], 
     Hue[1.2038842462695794`, 1, -12.389103658427263`], 
     Hue[1.2038842462695438`, 1, -12.21221564116746], 
     Hue[1.203884246269485, 1, -12.014861241745377`], 
     Hue[1.203884246269407, 1, -11.83797322448561], 
     Hue[1.2038842462692776`, 1, -11.640618825063592`], 
     Hue[1.203884246269106, 1, -11.463730807803907`], 
     Hue[1.2038842462688217`, 1, -11.266376408382026`], 
     Hue[1.2038842462684443`, 1, -11.089488391122526`], 
     Hue[1.203884246267819, 1, -10.892133991700948`], 
     Hue[1.2038842462669892`, 1, -10.715245974441848`], 
     Hue[1.2038842462656145`, 1, -10.517891575020938`], 
     Hue[1.2038842462637902`, 1, -10.341003557762724`], 
     Hue[1.2038842462607675`, 1, -10.14364915834328], 
     Hue[1.2038842462564343`, 1, -9.955066065565987], 
     Hue[1.2038842462498984`, 1, -9.764290146130406], 
     Hue[1.203884246240583, 1, -9.580823648898122], 
     Hue[1.2038842462262123`, 1, -9.39004772946951], 
     Hue[1.2038842462057298`, 1, -9.206581232247164], 
     Hue[1.2038842461741324`, 1, -9.01580531283388], 
     Hue[1.203884246129097, 1, -8.83233881563338], 
     Hue[1.203884246059623, 1, -8.641562896253804], 
     Hue[1.203884245960603, 1, -8.45809639910134], 
     Hue[1.2038842458078483`, 1, -8.267320479795865], 
     Hue[1.2038842455901302`, 1, -8.08385398274902], 
     Hue[1.2038842452542644`, 1, -7.8930780636064855`], 
     Hue[1.2038842447755616`, 1, -7.7096115667918665`], 
     Hue[1.2038842440370838`, 1, -7.518835648007582], 
     Hue[1.2038842429845469`, 1, -7.33536915170357], 
     Hue[1.203884241360836, 1, -7.14459323370698], 
     Hue[1.203884239046594, 1, -6.961126738525658], 
     Hue[1.2038842354764963`, 1, -6.770350822260995], 
     Hue[1.2038842303881088`, 1, -6.586884329548152], 
     Hue[1.2038842225384374`, 1, -6.39610841709153], 
     Hue[1.2038842109179273`, 1, -6.20679439243043], 
     Hue[1.203884193809388, 1, -6.019307728202882], 
     Hue[1.2038841685408423`, 1, -5.832552013456348], 
     Hue[1.2038841309238348`, 1, -5.64506536747764], 
     Hue[1.2038840753652054`, 1, -5.458309679683858], 
     Hue[1.203883992655693, 1, -5.270823073829501], 
     Hue[1.2038838704974868`, 1, -5.084067445297762], 
     Hue[1.2038836886419833`, 1, -4.896580927666546], 
     Hue[1.2038834200497583`, 1, -4.709825429437263], 
     Hue[1.2038829930174402`, 1, -4.511923203339652], 
     Hue[1.2038824184242878`, 1, -4.332660135165247], 
     Hue[1.2038815432144787`, 1, -4.1468188545262565`], 
     Hue[1.2038802273523215`, 1, -3.958419668266651], 
     Hue[1.2038781724294931`, 1, -3.762254878668693], 
     Hue[1.203875382608576, 1, -3.582719678715968], 
     Hue[1.2038708750254403`, 1, -3.3874250662341705`], 
     Hue[1.2038647278712742`, 1, -3.2077558036653544`], 
     Hue[1.2038548290472812`, 1, -3.012899989265777], 
     Hue[1.203841268496931, 1, -2.8328261762217943`], 
     Hue[1.2038195309140736`, 1, -2.638401349644237], 
     Hue[1.2037849858598642`, 1, -2.435220929531803], 
     Hue[1.203741972765986, 1, -2.264218829897673], 
     Hue[1.2036660484236061`, 1, -2.0610847309851126`], 
     Hue[1.2035715258373474`, 1, -1.8901288718812614`], 
     Hue[1.2034047247778041`, 1, -1.6870767072603206`], 
     Hue[1.203197145158889, 1, -1.5162234107538735`], 
     Hue[1.2028310554713264`, 1, -1.3133537417070367`], 
     Hue[1.202375861384565, 1, -1.1427302352438542`], 
     Hue[1.2016300968611384`, 1, -0.9519157191053618], 
     Hue[1.200546285418844, 1, -0.7654556479614552], 
     Hue[1.1988937404229159`, 1, -0.5744645046084751], 
     Hue[1.1964938263041884`, 1, -0.3880499184644155], 
     Hue[1.1929810100401192`, 1, -0.20353514271076323`], 
     Hue[1.1875914003199357`, 1, -0.013201909132085188`], 
     Hue[1.1797922362474813`, 1, 0.17161081567001235`], 
     Hue[1.1679660511700871`, 1, 0.3590850608880475], 
     Hue[1.1499624471032537`, 1, 0.5469899343349551], 
     Hue[1.121904596150179, 1, 0.7339133280464156], 
     Hue[1.0732813004021924`, 1, 0.9217495469259995], 
     Hue[1.3292790473845892`, 1, -17.264488266373966`], 
     Hue[1.3292790473845892`, 1, -17.07736705803298], 
     Hue[1.3292790473845892`, 1, -16.90742299186392], 
     Hue[1.3292790473845892`, 1, -16.70312464135101], 
     Hue[1.3292790473845892`, 1, -16.53318057518195], 
     Hue[1.3292790473845892`, 1, -16.32888222466904], 
     Hue[1.3292790473845892`, 1, -16.15893815849998], 
     Hue[1.3292790473845892`, 1, -15.954639807987068`], 
     Hue[1.3292790473845892`, 1, -15.784695741818005`], 
     Hue[1.3292790473845892`, 1, -15.580397391305098`], 
     Hue[1.329279047384589, 1, -15.407712291810729`], 
     Hue[1.329279047384589, 1, -15.206154974623129`], 
     Hue[1.3292790473845888`, 1, -15.033469875128759`], 
     Hue[1.3292790473845888`, 1, -14.831912557941154`], 
     Hue[1.3292790473845886`, 1, -14.657856941784134`], 
     Hue[1.3292790473845884`, 1, -14.457670141259184`], 
     Hue[1.329279047384588, 1, -14.283614525102157`], 
     Hue[1.3292790473845872`, 1, -14.08342772457721], 
     Hue[1.3292790473845861`, 1, -13.908172906340365`], 
     Hue[1.3292790473845848`, 1, -13.709185307895234`], 
     Hue[1.3292790473845824`, 1, -13.511830908473096`], 
     Hue[1.3292790473845795`, 1, -13.334942891213256`], 
     Hue[1.3292790473845744`, 1, -13.137588491791114`], 
     Hue[1.3292790473845675`, 1, -12.960700474531265`], 
     Hue[1.3292790473845564`, 1, -12.763346075109112`], 
     Hue[1.3292790473845417`, 1, -12.586458057849251`], 
     Hue[1.329279047384517, 1, -12.389103658427077`], 
     Hue[1.3292790473844844`, 1, -12.212215641167187`], 
     Hue[1.3292790473844307`, 1, -12.014861241744967`], 
     Hue[1.3292790473843592`, 1, -11.837973224485014`], 
     Hue[1.3292790473842406`, 1, -11.640618825062687`], 
     Hue[1.3292790473840832`, 1, -11.463730807802593`], 
     Hue[1.3292790473838225`, 1, -11.266376408380037`], 
     Hue[1.3292790473834766`, 1, -11.08948839111964], 
     Hue[1.3292790473829035`, 1, -10.892133991696573`], 
     Hue[1.3292790473821428`, 1, -10.715245974435502`], 
     Hue[1.3292790473808827`, 1, -10.517891575011323`], 
     Hue[1.32927904737921, 1, -10.34100355774877], 
     Hue[1.3292790473764393`, 1, -10.14364915832214], 
     Hue[1.3292790473724672`, 1, -9.955066065534544], 
     Hue[1.3292790473664757`, 1, -9.764290146083422], 
     Hue[1.3292790473579363`, 1, -9.580823648828986], 
     Hue[1.3292790473447627`, 1, -9.390047729366206], 
     Hue[1.3292790473259866`, 1, -9.206581232095155], 
     Hue[1.3292790472970215`, 1, -9.01580531260674], 
     Hue[1.329279047255738, 1, -8.832338815299156], 
     Hue[1.3292790471920517`, 1, -8.641562895754385], 
     Hue[1.3292790471012805`, 1, -8.458096398366473], 
     Hue[1.3292790469612514`, 1, -8.267320478697782], 
     Hue[1.3292790467616709`, 1, -8.08385398113325], 
     Hue[1.329279046453785, 1, -7.8930780611920985`], 
     Hue[1.3292790460149613`, 1, -7.709611563239231], 
     Hue[1.3292790453380041`, 1, -7.518835642699007], 
     Hue[1.3292790443731506`, 1, -7.335369143892293], 
     Hue[1.329279042884706, 1, -7.144593222034872], 
     Hue[1.3292790407632564`, 1, -6.961126721350785], 
     Hue[1.3292790374905727`, 1, -6.770350796597209], 
     Hue[1.3292790328260828`, 1, -6.586884291785291], 
     Hue[1.3292790256303424`, 1, -6.396108360663858], 
     Hue[1.3292790149778988`, 1, -6.206794308371714], 
     Hue[1.3292789992946137`, 1, -6.019307603463781], 
     Hue[1.3292789761310995`, 1, -5.832551828634132], 
     Hue[1.329278941647818, 1, -5.645065093210327], 
     Hue[1.3292788907175377`, 1, -5.458309273310124], 
     Hue[1.3292788148981447`, 1, -5.270822470790321], 
     Hue[1.3292787029162176`, 1, -5.084066551792437], 
     Hue[1.3292785362097694`, 1, -4.896579601747227], 
     Hue[1.3292782899914484`, 1, -4.709823464861441], 
     Hue[1.3292778985298312`, 1, -4.5119202233674915`], 
     Hue[1.3292773717961797`, 1, -4.3326557889226915`], 
     Hue[1.329276569479266, 1, -4.146812427196106], 
     Hue[1.3292753631970315`, 1, -3.958410112037373], 
     Hue[1.3292734793684586`, 1, -3.7622404361265946`], 
     Hue[1.3292709217678769`, 1, -3.582698602277749], 
     Hue[1.329266789237954, 1, -3.387393270999791], 
     Hue[1.3292611532568, 1, -3.2077093903331626`], 
     Hue[1.3292520768507146`, 1, -3.012830035081276], 
     Hue[1.329239647167938, 1, -2.8327925057509304`], 
     Hue[1.3292197075237846`, 1, -2.6382752837154566`], 
     Hue[1.3291880108241192`, 1, -2.4349848365636877`], 
     Hue[1.3291485333002053`, 1, -2.2638803838417756`], 
     Hue[1.3290788082092704`, 1, -2.0605655497539486`], 
     Hue[1.3289919292266086`, 1, -1.889384563320576], 
     Hue[1.3288384154738324`, 1, -1.6859348000815844`], 
     Hue[1.3286470120779574`, 1, -1.5145861267216703`], 
     Hue[1.3283084755671468`, 1, -1.310841254530687], 
     Hue[1.327885794994485, 1, -1.1391267749729284`], 
     Hue[1.327189080319055, 1, -0.9465183234561918], 
     Hue[1.3262317285981133`, 1, -0.767404635233923], 
     Hue[1.3246451397432126`, 1, -0.5683519962107624], 
     Hue[1.3225332929635787`, 1, -0.39005851450314766`], 
     Hue[1.3192928869547988`, 1, -0.20389174766397677`], 
     Hue[1.3144074257618144`, 1, -0.015100509502171011`], 
     Hue[1.3072481757318035`, 1, 0.17074322736767344`], 
     Hue[1.2963471679882996`, 1, 0.359815089845257], 
     Hue[1.1342882676240542`, 1, 0.7338834143998157], 
     Hue[1.2800275867587403`, 1, 0.5467903289361822], 
     Hue[1.2547189494970632`, 1, 0.7338589707459431], 
     Hue[1.0842130231275489`, 1, 0.9215668863308644], 
     Hue[1.212250160475798, 1, 0.9218963132620691], 
     Hue[1.4546738484995214`, 1, -17.264488266373966`], 
     Hue[1.4546738484995214`, 1, -17.07736705803298], 
     Hue[1.4546738484995214`, 1, -16.90742299186392], 
     Hue[1.4546738484995214`, 1, -16.70312464135101], 
     Hue[1.4546738484995214`, 1, -16.53318057518195], 
     Hue[1.4546738484995214`, 1, -16.32888222466904], 
     Hue[1.4546738484995214`, 1, -16.15893815849998], 
     Hue[1.4546738484995214`, 1, -15.954639807987068`], 
     Hue[1.4546738484995214`, 1, -15.784695741818005`], 
     Hue[1.4546738484995214`, 1, -15.580397391305098`], 
     Hue[1.4546738484995214`, 1, -15.407712291810729`], 
     Hue[1.4546738484995214`, 1, -15.206154974623129`], 
     Hue[1.4546738484995214`, 1, -15.033469875128759`], 
     Hue[1.4546738484995214`, 1, -14.831912557941154`], 
     Hue[1.4546738484995214`, 1, -14.65785694178413], 
     Hue[1.4546738484995212`, 1, -14.45767014125918], 
     Hue[1.454673848499521, 1, -14.283614525102157`], 
     Hue[1.454673848499521, 1, -14.083427724577206`], 
     Hue[1.4546738484995205`, 1, -13.90817290634036], 
     Hue[1.45467384849952, 1, -13.709185307895225`], 
     Hue[1.4546738484995194`, 1, -13.511830908473085`], 
     Hue[1.4546738484995183`, 1, -13.33494289121324], 
     Hue[1.4546738484995168`, 1, -13.137588491791089`], 
     Hue[1.4546738484995145`, 1, -12.96070047453123], 
     Hue[1.454673848499511, 1, -12.763346075109059`], 
     Hue[1.4546738484995063`, 1, -12.586458057849173`], 
     Hue[1.4546738484994985`, 1, -12.38910365842696], 
     Hue[1.454673848499488, 1, -12.212215641167017`], 
     Hue[1.4546738484994708`, 1, -12.014861241744708`], 
     Hue[1.454673848499448, 1, -11.837973224484635`], 
     Hue[1.45467384849941, 1, -11.640618825062115`], 
     Hue[1.4546738484993598`, 1, -11.463730807801765`], 
     Hue[1.4546738484992763`, 1, -11.266376408378783`], 
     Hue[1.4546738484991657`, 1, -11.089488391117817`], 
     Hue[1.4546738484989823`, 1, -10.892133991693814`], 
     Hue[1.4546738484987392`, 1, -10.715245974431497`], 
     Hue[1.4546738484983361`, 1, -10.517891575005253`], 
     Hue[1.4546738484978012`, 1, -10.341003557739963`], 
     Hue[1.454673848496915, 1, -10.143649158308794`], 
     Hue[1.4546738484956445`, 1, -9.955066065514696], 
     Hue[1.4546738484937285`, 1, -9.764290146053765], 
     Hue[1.4546738484909973`, 1, -9.580823648785346], 
     Hue[1.454673848486784, 1, -9.390047729300997], 
     Hue[1.454673848480779, 1, -9.206581231999204], 
     Hue[1.4546738484715154`, 1, -9.015805312463364], 
     Hue[1.454673848458312, 1, -8.832338815088185], 
     Hue[1.4546738484379436`, 1, -8.641562895439138], 
     Hue[1.4546738484089128`, 1, -8.458096397902604], 
     Hue[1.4546738483641284`, 1, -8.26732047800464], 
     Hue[1.4546738483002977`, 1, -8.08385398011333], 
     Hue[1.4546738482018284`, 1, -7.89307805966807], 
     Hue[1.4546738480614825`, 1, -7.709611560996701], 
     Hue[1.4546738478449757`, 1, -7.518835639348079], 
     Hue[1.4546738475363932`, 1, -7.335369138961583], 
     Hue[1.4546738470603537`, 1, -7.144593214667094], 
     Hue[1.4546738463818647`, 1, -6.961126710509501], 
     Hue[1.4546738453351837`, 1, -6.7703507803974725`], 
     Hue[1.4546738438433708`, 1, -6.58688426794826], 
     Hue[1.4546738415420046`, 1, -6.3961083250450494`], 
     Hue[1.4546738381351036`, 1, -6.2067942553113715`], 
     Hue[1.4546738331192213`, 1, -6.019307524724767], 
     Hue[1.454673825710985, 1, -5.8325517119688515`], 
     Hue[1.4546738146824192`, 1, -5.645064920084591], 
     Hue[1.4546737983937108`, 1, -5.458309016794743], 
     Hue[1.4546737741448648`, 1, -5.270822090133513], 
     Hue[1.4546737383303567`, 1, -5.084065987783933], 
     Hue[1.454673685013582, 1, -4.8965787647842465`], 
     Hue[1.4546736062668655`, 1, -4.709822224755183], 
     Hue[1.4546734810674709`, 1, -4.511918342302393], 
     Hue[1.4546733126041012`, 1, -4.332653045405941], 
     Hue[1.4546730560007313`, 1, -4.146808369987212], 
     Hue[1.454672670195292, 1, -3.9584040796671465`], 
     Hue[1.4546720676836808`, 1, -3.762231319118155], 
     Hue[1.454671249664641, 1, -3.5826852972486405`], 
     Hue[1.4546699278921358`, 1, -3.387373198723437], 
     Hue[1.4546681251862983`, 1, -3.207680088205871], 
     Hue[1.4546652218905263`, 1, -3.0127858673374446`], 
     Hue[1.4546612481023726`, 1, -2.832819369774791], 
     Hue[1.4546548678258904`, 1, -2.6382152186939773`], 
     Hue[1.4546447237380251`, 1, -2.4348356868356227`], 
     Hue[1.4546320882501371`, 1, -2.263666498189413], 
     Hue[1.4546097630687436`, 1, -2.0602372420509525`], 
     Hue[1.4545819303431522`, 1, -1.8889135301553448`], 
     Hue[1.4545327094245586`, 1, -1.685211157845078], 
     Hue[1.4544712665338924`, 1, -1.5135467835545409`], 
     Hue[1.4543623914898793`, 1, -1.3092415047201096`], 
     Hue[1.4542260932032214`, 1, -1.1368236910999012`], 
     Hue[1.4540176608876483`, 1, -0.9552794709486101], 
     Hue[1.4537002337173197`, 1, -0.7678608210011852], 
     Hue[1.4532236910096654`, 1, -0.578618864576578], 
     Hue[1.4525139753225607`, 1, -0.38939763500342606`], 
     Hue[1.3917055730901398`, 1, 0.17097196681521198`], 
     Hue[1.4514694031518252`, 1, -0.20203263023550222`], 
     Hue[1.4499377702781353`, 1, -0.016502204080992122`], 
     Hue[1.4475724476036727`, 1, 0.1758245422646858], 
     Hue[1.2858558177118642`, 1, 0.5462663167587021], 
     Hue[1.4442398105811116`, 1, 0.35841296020804114`], 
     Hue[1.4391093890865303`, 1, 0.547956343298089], 
     Hue[1.2183620736515959`, 1, 0.9217328875984977], 
     Hue[1.2882739352852561`, 1, 1.1094815635371198`], 
     Hue[1.376000741007534, 1, 1.297237519220332], 
     Hue[1.4316094943341517`, 1, 0.733866626430557], 
     Hue[1.420283595264774, 1, 0.9215835763973605], 
     Hue[1.4031074219306652`, 1, 1.1093671172023742`], 
     Hue[1.376297618826006, 1, 1.2972094717288387`], 
     Hue[1.1149948382144188`, 1, 1.1094014611516998`], 
     Hue[1.1136183330313574`, 1, 1.2971469330972814`], 
     Hue[1.0481852377847245`, 1, 1.1093577703184405`], 
     Hue[1.0330361487290045`, 1, 1.2971319811570963`], 
     Hue[1.012784755891417, 1, 1.1092844196734588`], 
     Hue[1.0062308410791776`, 1, 1.109283270876556], 
     Hue[0.5800686496144527, 1, -17.264488266373966`], 
     Hue[0.5800686496144527, 1, -17.07736705803298], 
     Hue[0.5800686496144527, 1, -16.90742299186392], 
     Hue[0.5800686496144527, 1, -16.70312464135101], 
     Hue[0.5800686496144527, 1, -16.53318057518195], 
     Hue[0.5800686496144527, 1, -16.32888222466904], 
     Hue[0.5800686496144527, 1, -16.15893815849998], 
     Hue[0.5800686496144527, 1, -15.954639807987068`], 
     Hue[0.5800686496144527, 1, -15.784695741818005`], 
     Hue[0.5800686496144527, 1, -15.580397391305098`], 
     Hue[0.5800686496144527, 1, -15.407712291810729`], 
     Hue[0.5800686496144527, 1, -15.206154974623129`], 
     Hue[0.5800686496144528, 1, -15.033469875128759`], 
     Hue[0.5800686496144529, 1, -14.831912557941154`], 
     Hue[0.5800686496144529, 1, -14.65785694178413], 
     Hue[0.5800686496144531, 1, -14.45767014125918], 
     Hue[0.5800686496144534, 1, -14.283614525102157`], 
     Hue[0.5800686496144537, 1, -14.083427724577206`], 
     Hue[0.5800686496144543, 1, -13.908172906340361`], 
     Hue[0.5800686496144551, 1, -13.709185307895227`], 
     Hue[0.5800686496144564, 1, -13.511830908473087`], 
     Hue[0.580068649614458, 1, -13.334942891213243`], 
     Hue[0.5800686496144608, 1, -13.137588491791094`], 
     Hue[0.5800686496144645, 1, -12.960700474531237`], 
     Hue[0.5800686496144707, 1, -12.763346075109068`], 
     Hue[0.5800686496144787, 1, -12.586458057849187`], 
     Hue[0.5800686496144922, 1, -12.38910365842698], 
     Hue[0.5800686496145101, 1, -12.212215641167047`], 
     Hue[0.5800686496145397, 1, -12.014861241744752`], 
     Hue[0.580068649614579, 1, -11.837973224484703`], 
     Hue[0.580068649614644, 1, -11.640618825062214`], 
     Hue[0.5800686496147304, 1, -11.463730807801909`], 
     Hue[0.5800686496148735, 1, -11.266376408379], 
     Hue[0.5800686496150633, 1, -11.089488391118135`], 
     Hue[0.5800686496153779, 1, -10.892133991694294`], 
     Hue[0.5800686496157954, 1, -10.715245974432191`], 
     Hue[0.580068649616487, 1, -10.517891575006306`], 
     Hue[0.5800686496174048, 1, -10.341003557741491`], 
     Hue[0.5800686496189256, 1, -10.143649158311112`], 
     Hue[0.5800686496211055, 1, -9.95506606551814], 
     Hue[0.5800686496243938, 1, -9.76429014605891], 
     Hue[0.5800686496290804, 1, -9.580823648792919], 
     Hue[0.5800686496363104, 1, -9.390047729312311], 
     Hue[0.5800686496466152, 1, -9.206581232015852], 
     Hue[0.580068649662512, 1, -9.015805312488242], 
     Hue[0.5800686496851695, 1, -8.83233881512479], 
     Hue[0.5800686497201221, 1, -8.641562895493838], 
     Hue[0.5800686497699394, 1, -8.45809639798309], 
     Hue[0.5800686498467909, 1, -8.267320478124907], 
     Hue[0.5800686499563257, 1, -8.083853980290296], 
     Hue[0.5800686501253012, 1, -7.893078059932502], 
     Hue[0.5800686503661385, 1, -7.709611561385802], 
     Hue[0.5800686507376693, 1, -7.518835639929496], 
     Hue[0.5800686512672049, 1, -7.335369139817106], 
     Hue[0.5800686520841001, 1, -7.144593215945473], 
     Hue[0.5800686532484045, 1, -6.961126712390564], 
     Hue[0.5800686550445346, 1, -6.770350783208276], 
     Hue[0.5800686576045226, 1, -6.586884272084204], 
     Hue[0.580068661553724, 1, -6.39610833122524], 
     Hue[0.5800686674000504, 1, -6.2067942645178285`], 
     Hue[0.5800686760074286, 1, -6.01930753838671], 
     Hue[0.5800686887201447, 1, -5.832551732211352], 
     Hue[0.5800687076454349, 1, -5.645064950123503], 
     Hue[0.580068735597258, 1, -5.4583090613025345`], 
     Hue[0.5800687772088693, 1, -5.270822156181004], 
     Hue[0.5800688386674316, 1, -5.084066085644677], 
     Hue[0.5800689301602919, 1, -4.896578910005211], 
     Hue[0.580069065291507, 1, -4.709822439925456], 
     Hue[0.580069280136527, 1, -4.5119186686855075`], 
     Hue[0.5800695692233571, 1, -4.3326535214335316`], 
     Hue[0.5800700095600066, 1, -4.146809073955134], 
     Hue[0.5800706716092647, 1, -3.9584051263496907`], 
     Hue[0.5800717055284035, 1, -3.7622329010278275`], 
     Hue[0.580073109257857, 1, -3.582687605846658], 
     Hue[0.580075377424587, 1, -3.3873766815691084`], 
     Hue[0.5800784708566976, 1, -3.2076851726529165`], 
     Hue[0.5800834528505002, 1, -3.012793531435041], 
     Hue[0.5800902716987395, 1, -2.832830565157602], 
     Hue[0.5801012197645512, 1, -2.6382320850242316`], 
     Hue[0.580118625704143, 1, -2.434861572398253], 
     Hue[0.5801403056385162, 1, -2.2637036231255445`], 
     Hue[0.5801786086129237, 1, -2.0602942389990346`], 
     Hue[0.5802263563068032, 1, -1.8889953257421592`], 
     Hue[0.5803107837341774, 1, -1.6853368746083548`], 
     Hue[0.5804161532766658, 1, -1.51372744556226], 
     Hue[0.5806028051248358, 1, -1.3095198497459613`], 
     Hue[0.5808363620429129, 1, -1.1372249020059237`], 
     Hue[0.5811939488905422, 1, -0.9555922038990088], 
     Hue[0.5817743765471144, 1, -0.7580247233728645], 
     Hue[0.5825502929151951, 1, -0.5799433233728961], 
     Hue[0.5837596991725689, 1, -0.39139645868923956`], 
     Hue[0.585551272382687, 1, -0.20350327515696232`], 
     Hue[0.5882855925692061, 1, -0.01142840828419267], 
     Hue[0.5921635331641018, 1, 0.17195287547344085`], 
     Hue[0.5980491703254371, 1, 0.35973987633669524`], 
     Hue[0.6068351224432915, 1, 0.5474934895387742], 
     Hue[0.6239651698174713, 1, 1.2972922588796376`], 
     Hue[0.6199650480790082, 1, 0.7343391525371905], 
     Hue[0.6400716457789131, 1, 0.9218695817586514], 
     Hue[0.6720512235363916, 1, 1.1093540885804096`], 
     Hue[0.7307288001792228, 1, 1.2972865486125098`], 
     Hue[0.929500852733049, 1, 1.2970879111781852`], 
     Hue[0.9879978485995468, 1, 1.1097575569749698`], 
     Hue[0.7054634507293838, 1, -17.264488266373966`], 
     Hue[0.7054634507293838, 1, -17.07736705803298], 
     Hue[0.7054634507293838, 1, -16.90742299186392], 
     Hue[0.7054634507293838, 1, -16.70312464135101], 
     Hue[0.7054634507293838, 1, -16.53318057518195], 
     Hue[0.7054634507293838, 1, -16.32888222466904], 
     Hue[0.7054634507293838, 1, -16.15893815849998], 
     Hue[0.7054634507293839, 1, -15.954639807987068`], 
     Hue[0.7054634507293839, 1, -15.784695741818005`], 
     Hue[0.705463450729384, 1, -15.580397391305098`], 
     Hue[0.705463450729384, 1, -15.407712291810729`], 
     Hue[0.705463450729384, 1, -15.206154974623129`], 
     Hue[0.7054634507293841, 1, -15.033469875128759`], 
     Hue[0.7054634507293843, 1, -14.831912557941154`], 
     Hue[0.7054634507293844, 1, -14.657856941784134`], 
     Hue[0.7054634507293849, 1, -14.457670141259184`], 
     Hue[0.7054634507293853, 1, -14.283614525102161`], 
     Hue[0.705463450729386, 1, -14.083427724577211`], 
     Hue[0.7054634507293871, 1, -13.908172906340367`], 
     Hue[0.7054634507293887, 1, -13.709185307895238`], 
     Hue[0.7054634507293913, 1, -13.511830908473101`], 
     Hue[0.7054634507293946, 1, -13.334942891213263`], 
     Hue[0.7054634507294002, 1, -13.137588491791124`], 
     Hue[0.7054634507294075, 1, -12.96070047453128], 
     Hue[0.7054634507294197, 1, -12.763346075109135`], 
     Hue[0.705463450729436, 1, -12.586458057849285`], 
     Hue[0.7054634507294627, 1, -12.389103658427127`], 
     Hue[0.7054634507294983, 1, -12.21221564116726], 
     Hue[0.7054634507295573, 1, -12.014861241745075`], 
     Hue[0.7054634507296356, 1, -11.837973224485172`], 
     Hue[0.7054634507297654, 1, -11.640618825062925`], 
     Hue[0.7054634507299375, 1, -11.463730807802941`], 
     Hue[0.7054634507302227, 1, -11.266376408380562`], 
     Hue[0.7054634507306011, 1, -11.089488391120401`], 
     Hue[0.7054634507312282, 1, -10.89213399169773], 
     Hue[0.7054634507320604, 1, -10.71524597443718], 
     Hue[0.7054634507334391, 1, -10.517891575013861`], 
     Hue[0.7054634507352688, 1, -10.341003557752455`], 
     Hue[0.7054634507383002, 1, -10.14364915832772], 
     Hue[0.7054634507426458, 1, -9.955066065542846], 
     Hue[0.7054634507492008, 1, -9.764290146095826], 
     Hue[0.7054634507585436, 1, -9.58082364884724], 
     Hue[0.705463450772956, 1, -9.390047729393482], 
     Hue[0.705463450793498, 1, -9.206581232135289], 
     Hue[0.7054634508251874, 1, -9.015805312666712], 
     Hue[0.7054634508703536, 1, -8.8323388153874], 
     Hue[0.7054634509400298, 1, -8.641562895886247], 
     Hue[0.7054634510393379, 1, -8.4580963985605], 
     Hue[0.7054634511925371, 1, -8.26732047898771], 
     Hue[0.7054634514108884, 1, -8.083853981559862], 
     Hue[0.7054634517477314, 1, -7.893078061829569], 
     Hue[0.7054634522278268, 1, -7.709611564177233], 
     Hue[0.7054634529684527, 1, -7.518835644100629], 
     Hue[0.7054634540240515, 1, -7.3353691459547035`], 
     Hue[0.7054634556524859, 1, -7.144593225116657], 
     Hue[0.7054634579734603, 1, -6.961126725885465], 
     Hue[0.7054634615539439, 1, -6.770350803373213], 
     Hue[0.7054634666571342, 1, -6.586884301755813], 
     Hue[0.7054634745296419, 1, -6.396108375562447], 
     Hue[0.705463486183959, 1, -6.2067943305657245`], 
     Hue[0.7054635033422734, 1, -6.01930763639863], 
     Hue[0.7054635286843385, 1, -5.832551877432721], 
     Hue[0.7054635664108025, 1, -5.645065165625107], 
     Hue[0.7054636221311132, 1, -5.458309380604975], 
     Hue[0.705463705081361, 1, -5.270822630010795], 
     Hue[0.7054638275952152, 1, -5.0840667877048125`], 
     Hue[0.7054640099803722, 1, -4.896579951830183], 
     Hue[0.7054642793553172, 1, -4.709823983569616], 
     Hue[0.7054647076331731, 1, -4.511921010172631], 
     Hue[0.7054652839043847, 1, -4.33265693646805], 
     Hue[0.7054661616748715, 1, -4.146814124219815], 
     Hue[0.7054674813976145, 1, -3.9584126352042075`], 
     Hue[0.7054695423749409, 1, -3.762244249473686], 
     Hue[0.7054723404655576, 1, -3.5827041672676216`], 
     Hue[0.7054768615318037, 1, -3.3874016663033064`], 
     Hue[0.7054830273154133, 1, -3.207721645718097], 
     Hue[0.7054929567256005, 1, -3.0128485070738824`], 
     Hue[0.7055065541330232, 1, -2.832819491436992], 
     Hue[0.7055283660179199, 1, -2.6383159279036317`], 
     Hue[0.7055630363097618, 1, -2.4350471949532935`], 
     Hue[0.7056062129429845, 1, -2.263969790562367], 
     Hue[0.7056824593778601, 1, -2.0607027393878115`], 
     Hue[0.7057774426309258, 1, -1.8895813097202796`], 
     Hue[0.7059452182672831, 1, -1.6862368314639211`], 
     Hue[0.7061542994211473, 1, -1.5150195163640496`], 
     Hue[0.7065238195203236, 1, -1.3115072127783745`], 
     Hue[0.7069846767091139, 1, -1.1400835206059134`], 
     Hue[0.7077430869706569, 1, -0.9479553569467307], 
     Hue[0.7088527934767632, 1, -0.7595804542882785], 
     Hue[0.7104992684937008, 1, -0.5715523555848718], 
     Hue[0.7128078515009555, 1, -0.39239460076044463`], 
     Hue[0.6055045442542785, 1, 0.17169751020203183`], 
     Hue[0.7165041440837658, 1, -0.19897347072798865`], 
     Hue[0.7216981723089577, 1, -0.01627336874832186], 
     Hue[0.713578459483476, 1, 0.5467950553734219], 
     Hue[0.7297089850797358, 1, 0.17322509017788235`], 
     Hue[0.7415342461877341, 1, 0.35968460640013866`], 
     Hue[0.7815041944142965, 1, 0.9220846290902498], 
     Hue[0.711711880451886, 1, 1.1095182571764388`], 
     Hue[0.7595296887183949, 1, 0.5468316849920047], 
     Hue[0.7876978169782463, 1, 0.7338739972700214], 
     Hue[0.8849999209204252, 1, 1.1094796721519318`], 
     Hue[0.8864154406049455, 1, 1.2975547645063616`], 
     Hue[0.8365194066415187, 1, 0.9216261884691406], 
     Hue[0.951837689042759, 1, 1.109639985939428], 
     Hue[0.987251454612794, 1, 1.109360255080821], 
     Hue[0.8308582518443162, 1, -17.264488266373966`], 
     Hue[0.8308582518443162, 1, -17.07736705803298], 
     Hue[0.8308582518443162, 1, -16.90742299186392], 
     Hue[0.8308582518443162, 1, -16.70312464135101], 
     Hue[0.8308582518443162, 1, -16.53318057518195], 
     Hue[0.8308582518443162, 1, -16.32888222466904], 
     Hue[0.8308582518443162, 1, -16.15893815849998], 
     Hue[0.8308582518443162, 1, -15.954639807987068`], 
     Hue[0.8308582518443162, 1, -15.784695741818005`], 
     Hue[0.8308582518443162, 1, -15.580397391305098`], 
     Hue[0.8308582518443163, 1, -15.407712291810729`], 
     Hue[0.8308582518443163, 1, -15.206154974623129`], 
     Hue[0.8308582518443164, 1, -15.033469875128759`], 
     Hue[0.8308582518443166, 1, -14.831912557941154`], 
     Hue[0.8308582518443167, 1, -14.657856941784134`], 
     Hue[0.830858251844317, 1, -14.457670141259184`], 
     Hue[0.8308582518443175, 1, -14.283614525102164`], 
     Hue[0.8308582518443182, 1, -14.083427724577216`], 
     Hue[0.830858251844319, 1, -13.908172906340376`], 
     Hue[0.8308582518443206, 1, -13.709185307895249`], 
     Hue[0.8308582518443228, 1, -13.511830908473119`], 
     Hue[0.8308582518443259, 1, -13.334942891213288`], 
     Hue[0.8308582518443309, 1, -13.137588491791163`], 
     Hue[0.8308582518443377, 1, -12.960700474531336`], 
     Hue[0.8308582518443488, 1, -12.76334607510922], 
     Hue[0.8308582518443635, 1, -12.586458057849407`], 
     Hue[0.8308582518443879, 1, -12.389103658427313`], 
     Hue[0.8308582518444203, 1, -12.21221564116753], 
     Hue[0.8308582518444738, 1, -12.014861241745486`], 
     Hue[0.830858251844545, 1, -11.837973224485767`], 
     Hue[0.8308582518446629, 1, -11.64061882506383], 
     Hue[0.8308582518448194, 1, -11.463730807804252`], 
     Hue[0.8308582518450787, 1, -11.266376408382548`], 
     Hue[0.8308582518454227, 1, -11.089488391123284`], 
     Hue[0.8308582518459927, 1, -10.892133991702098`], 
     Hue[0.8308582518467493, 1, -10.715245974443517`], 
     Hue[0.8308582518480025, 1, -10.517891575023466`], 
     Hue[0.8308582518496659, 1, -10.341003557766392`], 
     Hue[0.8308582518524217, 1, -10.143649158348838`], 
     Hue[0.8308582518563721, 1, -9.955066065574254], 
     Hue[0.830858251862331, 1, -9.764290146142761], 
     Hue[0.830858251870824, 1, -9.580823648916299], 
     Hue[0.8308582518839258, 1, -9.390047729496674], 
     Hue[0.8308582519025997, 1, -9.206581232287132], 
     Hue[0.8308582519314069, 1, -9.015805312893605], 
     Hue[0.8308582519724657, 1, -8.832338815721261], 
     Hue[0.8308582520358052, 1, -8.641562896385121], 
     Hue[0.8308582521260819, 1, -8.458096399294567], 
     Hue[0.8308582522653485, 1, -8.267320480084598], 
     Hue[0.8308582524638424, 1, -8.083853983173874], 
     Hue[0.8308582527700517, 1, -7.8930780642413305`], 
     Hue[0.8308582532064854, 1, -7.709611567726006], 
     Hue[0.8308582538797562, 1, -7.518835649403434], 
     Hue[0.8308582548393553, 1, -7.335369153757491], 
     Hue[0.8308582563196941, 1, -7.144593236776081], 
     Hue[0.8308582584295909, 1, -6.96112674304167], 
     Hue[0.8308582616844525, 1, -6.770350829009109], 
     Hue[0.8308582663235404, 1, -6.586884339477635], 
     Hue[0.8308582734800936, 1, -6.396108431928794], 
     Hue[0.8308582840745236, 1, -6.206794414533082], 
     Hue[0.8308582996723943, 1, -6.019307761002156], 
     Hue[0.8308583227097492, 1, -5.832552062054047], 
     Hue[0.8308583570052046, 1, -5.645065439594278], 
     Hue[0.8308584076580444, 1, -5.458309786536903], 
     Hue[0.8308584830643488, 1, -5.270823232394224], 
     Hue[0.8308585944360175, 1, -5.0840676802382445`], 
     Hue[0.8308587602336615, 1, -4.896581276306621], 
     Hue[0.83085900510902, 1, -4.709825946006176], 
     Hue[0.8308593944337533, 1, -4.511923986896494], 
     Hue[0.8308599182887905, 1, -4.332661277966432], 
     Hue[0.8308607162137054, 1, -4.146820544519342], 
     Hue[0.8308619158759584, 1, -3.958422180947136], 
     Hue[0.8308637893263038, 1, -3.762258676089327], 
     Hue[0.830866332758865, 1, -3.5827252203089355`], 
     Hue[0.8308704422067279, 1, -3.3874334258642085`], 
     Hue[0.830876046330834, 1, -3.2077680062238345`], 
     Hue[0.8308850705175028, 1, -3.012918379813594], 
     Hue[0.8308974339200884, 1, -2.832835914047128], 
     Hue[0.8309172487392282, 1, -2.6384348444900514`], 
     Hue[0.8309487358409738, 1, -2.435282969594068], 
     Hue[0.8309879384620104, 1, -2.2643077419217166`], 
     Hue[0.8310571259461617, 1, -2.0612210578575034`], 
     Hue[0.8311432421349592, 1, -1.8903241959714532`], 
     Hue[0.8312951565378228, 1, -1.6873760544521963`], 
     Hue[0.831484117252324, 1, -1.5166520556732312`], 
     Hue[0.8318171200969291, 1, -1.3140099931787643`], 
     Hue[0.8322583252135707, 1, -1.1342132842134725`], 
     Hue[0.8329073059993999, 1, -0.9533147930621311], 
     Hue[0.833888238175896, 1, -0.7675199550158613], 
     Hue[0.8353786655781337, 1, -0.577533555016384], 
     Hue[0.8375652981412882, 1, -0.39019660091135755`], 
     Hue[0.8408366807591816, 1, -0.2016654081399527], 
     Hue[0.8456031931633029, 1, -0.01655852552840109], 
     Hue[0.8527703299783379, 1, 0.17078512212456554`], 
     Hue[0.8635332661700346, 1, 0.3587421912244262], 
     Hue[0.8655274428105276, 1, 0.7342044782300253], 
     Hue[0.8798687753603885, 1, 0.5471291594329043], 
     Hue[0.9157750444864149, 1, 0.921607087924359], 
     Hue[0.9049797598149079, 1, 0.7338571848830918], 
     Hue[0.947022200902461, 1, 0.9216205513025462], 
     Hue[0.9562530529592472, 1, -17.264488266373966`], 
     Hue[0.9562530529592473, 1, -17.07736705803298], 
     Hue[0.9562530529592473, 1, -16.90742299186392], 
     Hue[0.9562530529592473, 1, -16.70312464135101], 
     Hue[0.9562530529592473, 1, -16.53318057518195], 
     Hue[0.9562530529592473, 1, -16.32888222466904], 
     Hue[0.9562530529592473, 1, -16.15893815849998], 
     Hue[0.9562530529592473, 1, -15.954639807987068`], 
     Hue[0.9562530529592473, 1, -15.784695741818005`], 
     Hue[0.9562530529592473, 1, -15.580397391305098`], 
     Hue[0.9562530529592473, 1, -15.407712291810729`], 
     Hue[0.9562530529592473, 1, -15.206154974623129`], 
     Hue[0.9562530529592473, 1, -15.033469875128759`], 
     Hue[0.9562530529592475, 1, -14.831912557941154`], 
     Hue[0.9562530529592475, 1, -14.657856941784138`], 
     Hue[0.9562530529592476, 1, -14.457670141259188`], 
     Hue[0.9562530529592477, 1, -14.283614525102164`], 
     Hue[0.9562530529592479, 1, -14.08342772457722], 
     Hue[0.9562530529592482, 1, -13.908172906340381`], 
     Hue[0.9562530529592487, 1, -13.709185307895257`], 
     Hue[0.9562530529592493, 1, -13.51183090847313], 
     Hue[0.9562530529592503, 1, -13.334942891213304`], 
     Hue[0.9562530529592519, 1, -13.137588491791186`], 
     Hue[0.956253052959254, 1, -12.960700474531372`], 
     Hue[0.9562530529592574, 1, -12.763346075109274`], 
     Hue[0.956253052959262, 1, -12.586458057849484`], 
     Hue[0.9562530529592695, 1, -12.38910365842743], 
     Hue[0.9562530529592796, 1, -12.2122156411677], 
     Hue[0.9562530529592963, 1, -12.014861241745743`], 
     Hue[0.9562530529593184, 1, -11.83797322448614], 
     Hue[0.956253052959355, 1, -11.640618825064394`], 
     Hue[0.9562530529594037, 1, -11.46373080780507], 
     Hue[0.9562530529594842, 1, -11.266376408383788`], 
     Hue[0.9562530529595911, 1, -11.089488391125084`], 
     Hue[0.9562530529597681, 1, -10.892133991704823`], 
     Hue[0.9562530529600032, 1, -10.715245974447473`], 
     Hue[0.9562530529603925, 1, -10.51789157502946], 
     Hue[0.9562530529609092, 1, -10.34100355777509], 
     Hue[0.9562530529617653, 1, -10.143649158362017`], 
     Hue[0.9562530529629926, 1, -9.955066065593856], 
     Hue[0.9562530529648438, 1, -9.764290146172051], 
     Hue[0.9562530529674822, 1, -9.5808236489594], 
     Hue[0.9562530529715524, 1, -9.390047729561077], 
     Hue[0.9562530529773536, 1, -9.206581232381899], 
     Hue[0.9562530529863029, 1, -9.015805313035212], 
     Hue[0.9562530529990582, 1, -8.832338815929628], 
     Hue[0.9562530530187352, 1, -8.641562896696476], 
     Hue[0.9562530530467805, 1, -8.458096399752705], 
     Hue[0.956253053090045, 1, -8.26732048076918], 
     Hue[0.956253053151709, 1, -8.083853984181198], 
     Hue[0.9562530532468358, 1, -7.893078065746537], 
     Hue[0.9562530533824182, 1, -7.709611569940837], 
     Hue[0.9562530535915761, 1, -7.518835652712975], 
     Hue[0.9562530538896847, 1, -7.335369158627299], 
     Hue[0.956253054349566, 1, -7.1445932440528575`], 
     Hue[0.9562530550050254, 1, -6.96112675374905], 
     Hue[0.956253056016179, 1, -6.770350845008757], 
     Hue[0.9562530574573558, 1, -6.586884363020244], 
     Hue[0.9562530596806067, 1, -6.396108467107656], 
     Hue[0.9562530629718665, 1, -6.206794466938036], 
     Hue[0.956253067817492, 1, -6.01930783876858], 
     Hue[0.9562530749742623, 1, -5.832552177278213], 
     Hue[0.9562530856284651, 1, -5.645065610581349], 
     Hue[0.9562531013642371, 1, -5.458310039883219], 
     Hue[0.9562531247898912, 1, -5.2708236083477], 
     Hue[0.9562531593884908, 1, -5.084068237276664], 
     Hue[0.9562532108949546, 1, -4.896582102923472], 
     Hue[0.9562532869674837, 1, -4.709827170776615], 
     Hue[0.9562534079141276, 1, -4.511925844684317], 
     Hue[0.9562535706531091, 1, -4.33266398750402], 
     Hue[0.956253818532563, 1, -4.146824551412291], 
     Hue[0.9562541912112263, 1, -3.958428138357866], 
     Hue[0.9562547731980519, 1, -3.7622676794577625`], 
     Hue[0.9562555633027203, 1, -3.5827383588022625`], 
     Hue[0.9562568398531813, 1, -3.3874532452099686`], 
     Hue[0.9562585806489342, 1, -3.2077969357493625`], 
     Hue[0.9562613836702691, 1, -3.012961977757673], 
     Hue[0.9562658379034407, 1, -2.80951024669712], 
     Hue[0.9562713772950244, 1, -2.6385284128625663`], 
     Hue[0.9562811539717535, 1, -2.4354300006531], 
     Hue[0.9562933234705755, 1, -2.264518417692475], 
     Hue[0.9563147930880492, 1, -2.061543973866831], 
     Hue[0.9563415017017657, 1, -1.8907866646786313`], 
     Hue[0.9563885791756142, 1, -1.688084296706749], 
     Hue[0.9564470692438909, 1, -1.5176652835278086`], 
     Hue[0.9565499632020529, 1, -1.315558744310039], 
     Hue[0.9566859345464065, 1, -1.1364677431872374`], 
     Hue[0.9568929273166633, 1, -0.9508348173508117], 
     Hue[0.9571987507414359, 1, -0.7652770089106955], 
     Hue[0.9576508084454943, 1, -0.5796978407278379], 
     Hue[0.9583485031835443, 1, -0.3873776213843505], 
     Hue[0.9593413279683027, 1, -0.2031676872683481], 
     Hue[0.9608246492978688, 1, -0.0168845602163179], 
     Hue[0.9630730654926551, 1, 0.17303483950498078`], 
     Hue[0.9663392127157785, 1, 0.3587310840870951], 
     Hue[0.9712551557144496, 1, 0.5469329087332705], 
     Hue[0.9785287227531333, 1, 0.7338543986708577], 
     Hue[0.989466124393201, 1, 0.9216916210248185], 
     Hue[1.0816478540741785`, 1, -17.264488266373966`], 
     Hue[1.0816478540741785`, 1, -17.07736705803298], 
     Hue[1.0816478540741785`, 1, -16.90742299186392], 
     Hue[1.0816478540741785`, 1, -16.70312464135101], 
     Hue[1.0816478540741785`, 1, -16.53318057518195], 
     Hue[1.0816478540741785`, 1, -16.32888222466904], 
     Hue[1.0816478540741785`, 1, -16.15893815849998], 
     Hue[1.0816478540741785`, 1, -15.954639807987068`], 
     Hue[1.0816478540741785`, 1, -15.784695741818005`], 
     Hue[1.0816478540741785`, 1, -15.580397391305098`], 
     Hue[1.0816478540741783`, 1, -15.407712291810729`], 
     Hue[1.0816478540741783`, 1, -15.206154974623129`], 
     Hue[1.0816478540741783`, 1, -15.033469875128759`], 
     Hue[1.0816478540741783`, 1, -14.831912557941154`], 
     Hue[1.081647854074178, 1, -14.657856941784138`], 
     Hue[1.0816478540741779`, 1, -14.457670141259188`], 
     Hue[1.0816478540741776`, 1, -14.283614525102164`], 
     Hue[1.0816478540741774`, 1, -14.08342772457722], 
     Hue[1.0816478540741767`, 1, -13.90817290634038], 
     Hue[1.081647854074176, 1, -13.709185307895256`], 
     Hue[1.0816478540741747`, 1, -13.511830908473128`], 
     Hue[1.081647854074173, 1, -13.3349428912133], 
     Hue[1.08164785407417, 1, -13.137588491791181`], 
     Hue[1.0816478540741663`, 1, -12.960700474531365`], 
     Hue[1.08164785407416, 1, -12.763346075109263`], 
     Hue[1.0816478540741519`, 1, -12.586458057849468`], 
     Hue[1.081647854074138, 1, -12.389103658427407`], 
     Hue[1.08164785407412, 1, -12.212215641167669`], 
     Hue[1.08164785407409, 1, -12.014861241745693`], 
     Hue[1.08164785407405, 1, -11.837973224486069`], 
     Hue[1.0816478540739836`, 1, -11.640618825064285`], 
     Hue[1.0816478540738956`, 1, -11.463730807804914`], 
     Hue[1.0816478540737502`, 1, -11.26637640838355], 
     Hue[1.0816478540735568`, 1, -11.089488391124739`], 
     Hue[1.0816478540732366`, 1, -10.892133991704302`], 
     Hue[1.0816478540728116`, 1, -10.715245974446715`], 
     Hue[1.0816478540721075`, 1, -10.517891575028312`], 
     Hue[1.0816478540711731`, 1, -10.341003557773425`], 
     Hue[1.0816478540696253`, 1, -10.14364915835949], 
     Hue[1.081647854067406, 1, -9.9550660655901], 
     Hue[1.0816478540640586`, 1, -9.76429014616644], 
     Hue[1.0816478540592875`, 1, -9.580823648951144], 
     Hue[1.0816478540519276`, 1, -9.39004772954874], 
     Hue[1.0816478540414376`, 1, -9.206581232363744], 
     Hue[1.081647854025255, 1, -9.015805313008084], 
     Hue[1.08164785400219, 1, -8.832338815889708], 
     Hue[1.081647853966609, 1, -8.641562896636826], 
     Hue[1.0816478539158958`, 1, -8.458096399664937], 
     Hue[1.0816478538376626`, 1, -8.267320480638029], 
     Hue[1.0816478537261582`, 1, -8.083853983988218], 
     Hue[1.0816478535541445`, 1, -7.893078065458172], 
     Hue[1.0816478533089766`, 1, -7.709611569516526], 
     Hue[1.0816478529307654`, 1, -7.51883565207894], 
     Hue[1.0816478523917084`, 1, -7.3353691576943545`], 
     Hue[1.0816478515601247`, 1, -7.14459324265879], 
     Hue[1.0816478503748852`, 1, -6.9611267516977575`], 
     Hue[1.0816478485464593`, 1, -6.770350841943586], 
     Hue[1.0816478459404413`, 1, -6.586884358510011], 
     Hue[1.0816478419202316`, 1, -6.396108460368179], 
     Hue[1.081647835968787, 1, -6.206794456898431], 
     Hue[1.0816478272066494`, 1, -6.01930782387029], 
     Hue[1.0816478142653667`, 1, -5.832552155203867], 
     Hue[1.0816477949998253`, 1, -5.645065577824093], 
     Hue[1.0816477665454969`, 1, -5.458309991347803], 
     Hue[1.081647724185878, 1, -5.270823536323543], 
     Hue[1.0816476616226869`, 1, -5.084068130560772], 
     Hue[1.0816475684856994`, 1, -4.896581944562557], 
     Hue[1.0816474309268855`, 1, -4.709826936138722], 
     Hue[1.0816472122239709`, 1, -4.511925488775212], 
     Hue[1.0816469179494896`, 1, -4.332663468420146], 
     Hue[1.0816464697184625`, 1, -4.1468237837872435`], 
     Hue[1.0816457958168688`, 1, -3.958426997063958], 
     Hue[1.0816447434286371`, 1, -3.7622659546419417`], 
     Hue[1.0816433147034037`, 1, -3.582735841819665], 
     Hue[1.0816410063411275`, 1, -3.3874494483985744`], 
     Hue[1.0816378584727426`, 1, -3.2077913937778755`], 
     Hue[1.0816327897409055`, 1, -3.012953625995012], 
     Hue[1.0816247349826482`, 1, -2.809497430597288], 
     Hue[1.0816147176801947`, 1, -2.638510045925372], 
     Hue[1.0815970372020716`, 1, -2.4354018398673976`], 
     Hue[1.0815750284438699`, 1, -2.264478071437253], 
     Hue[1.0815361975008047`, 1, -2.0614821444349998`], 
     Hue[1.0814878861663537`, 1, -1.8906981358164991`], 
     Hue[1.0814027178184942`, 1, -1.6879487769212946`], 
     Hue[1.0812968793767856`, 1, -1.5174715063753001`], 
     Hue[1.0811106286876417`, 1, -1.3152628195712939`], 
     Hue[1.0808643812812921`, 1, -1.136037493677055], 
     Hue[1.0804892458688924`, 1, -0.9502015284635263], 
     Hue[1.0799344145748642`, 1, -0.7643469452084228], 
     Hue[1.0791168089322067`, 1, -0.5790462486788925], 
     Hue[1.077844336733851, 1, -0.3856068213316943], 
     Hue[1.076060746639508, 1, -0.20300483498711674`], 
     Hue[1.0733501577125761`, 1, -0.015252267918329787`], 
     Hue[1.069365979192431, 1, 0.17076106323803675`], 
     Hue[1.0633605651130098`, 1, 0.3592757164850401], 
     Hue[1.054463477197556, 1, 0.5463167043336296], 
     Hue[1.0410166333236504`, 1, 0.7343574564123166], 
     Hue[1.0205463615951313`, 1, 0.9216020435240956], 
     Hue[1.207042655189114, 1, -17.264488266373966`], 
     Hue[1.207042655189114, 1, -17.07736705803298], 
     Hue[1.207042655189114, 1, -16.90742299186392], 
     Hue[1.207042655189114, 1, -16.70312464135101], 
     Hue[1.207042655189114, 1, -16.53318057518195], 
     Hue[1.207042655189114, 1, -16.32888222466904], 
     Hue[1.207042655189114, 1, -16.15893815849998], 
     Hue[1.207042655189114, 1, -15.954639807987068`], 
     Hue[1.207042655189114, 1, -15.784695741818005`], 
     Hue[1.207042655189114, 1, -15.580397391305098`], 
     Hue[1.207042655189114, 1, -15.407712291810729`], 
     Hue[1.207042655189114, 1, -15.206154974623129`], 
     Hue[1.2070426551891138`, 1, -15.033469875128759`], 
     Hue[1.2070426551891136`, 1, -14.831912557941154`], 
     Hue[1.2070426551891136`, 1, -14.657856941784134`], 
     Hue[1.2070426551891131`, 1, -14.457670141259184`], 
     Hue[1.2070426551891127`, 1, -14.283614525102161`], 
     Hue[1.2070426551891118`, 1, -14.083427724577215`], 
     Hue[1.207042655189111, 1, -13.908172906340374`], 
     Hue[1.2070426551891091`, 1, -13.709185307895245`], 
     Hue[1.2070426551891067`, 1, -13.511830908473113`], 
     Hue[1.2070426551891034`, 1, -13.33494289121328], 
     Hue[1.2070426551890978`, 1, -13.137588491791151`], 
     Hue[1.2070426551890905`, 1, -12.96070047453132], 
     Hue[1.207042655189078, 1, -12.763346075109196`], 
     Hue[1.2070426551890618`, 1, -12.586458057849372`], 
     Hue[1.207042655189035, 1, -12.38910365842726], 
     Hue[1.2070426551889994`, 1, -12.212215641167454`], 
     Hue[1.2070426551889402`, 1, -12.014861241745368`], 
     Hue[1.2070426551888616`, 1, -11.837973224485596`], 
     Hue[1.2070426551887317`, 1, -11.640618825063568`], 
     Hue[1.207042655188559, 1, -11.463730807803874`], 
     Hue[1.207042655188273, 1, -11.266376408381976`], 
     Hue[1.2070426551878934`, 1, -11.089488391122453`], 
     Hue[1.2070426551872646`, 1, -10.892133991700838`], 
     Hue[1.2070426551864302`, 1, -10.71524597444169], 
     Hue[1.2070426551850475`, 1, -10.517891575020698`], 
     Hue[1.2070426551832127`, 1, -10.341003557762374`], 
     Hue[1.2070426551801727`, 1, -10.14364915834275], 
     Hue[1.2070426551758149`, 1, -9.9550660655652], 
     Hue[1.2070426551692415`, 1, -9.764290146129232], 
     Hue[1.2070426551598727`, 1, -9.580823648896395], 
     Hue[1.2070426551454196`, 1, -9.39004772946693], 
     Hue[1.2070426551248203`, 1, -9.206581232243364], 
     Hue[1.207042655093042, 1, -9.015805312828206], 
     Hue[1.2070426550477493`, 1, -8.83233881562503], 
     Hue[1.2070426549778779`, 1, -8.641562896241327], 
     Hue[1.2070426548782915`, 1, -8.458096399082981], 
     Hue[1.207042654724663, 1, -8.267320479768435], 
     Hue[1.2070426545056998`, 1, -8.083853982708657], 
     Hue[1.2070426541679131`, 1, -7.893078063546171], 
     Hue[1.2070426536864722`, 1, -7.709611566703118], 
     Hue[1.2070426529437712`, 1, -7.518835647874972], 
     Hue[1.2070426518852142`, 1, -7.335369151508439], 
     Hue[1.207042650252217, 1, -7.144593233415404], 
     Hue[1.2070426479247387`, 1, -6.961126738096618], 
     Hue[1.2070426443342224`, 1, -6.770350821619895], 
     Hue[1.2070426392167328`, 1, -6.586884328604811], 
     Hue[1.207042631322166, 1, -6.39610841568193], 
     Hue[1.2070426196351942`, 1, -6.206794390330587], 
     Hue[1.207042602428805, 1, -6.019307725086818], 
     Hue[1.2070425770157394`, 1, -5.832552008839367], 
     Hue[1.207042539183586, 1, -5.645065360626262], 
     Hue[1.207042483307195, 1, -5.458309669532378], 
     Hue[1.2070424001246338`, 1, -5.270823058765196], 
     Hue[1.207042277267752, 1, -5.084067422977441], 
     Hue[1.2070420943721316`, 1, -4.8965808945442815`], 
     Hue[1.207041824243687, 1, -4.709825380361038], 
     Hue[1.2070413947689091`, 1, -4.5119231288984025`], 
     Hue[1.207040816889234, 1, -4.332660026594159], 
     Hue[1.2070399366732936`, 1, -4.146818693969353], 
     Hue[1.2070386132841462`, 1, -3.95841942955031], 
     Hue[1.2070365466058839`, 1, -3.7622545178949913`], 
     Hue[1.2070337408237601`, 1, -3.5827191522351685`], 
     Hue[1.2070292074475684`, 1, -3.3874242720197056`], 
     Hue[1.2070230251102416`, 1, -3.2077546443396106`], 
     Hue[1.2070130696104782`, 1, -3.01289824201419], 
     Hue[1.2069994313791186`, 1, -2.8328236235946864`], 
     Hue[1.2069775691770004`, 1, -2.638397506078788], 
     Hue[1.206942825835185, 1, -2.435215034628241], 
     Hue[1.2068995654279855`, 1, -2.2642103811589074`], 
     Hue[1.2068232034066422`, 1, -2.0610717753015493`], 
     Hue[1.2067281339039124`, 1, -1.8901103069328367`], 
     Hue[1.206560362242007, 1, -1.6870482484135982`], 
     Hue[1.2063515649756507`, 1, -1.5161826474584863`], 
     Hue[1.205983301483957, 1, -1.313291300700379], 
     Hue[1.2055253576535196`, 1, -1.142640881028549], 
     Hue[1.2047749760760347`, 1, -0.9517823716418234], 
     Hue[1.2036842073712095`, 1, -0.7652585938101457], 
     Hue[1.2020813697287602`, 1, -0.5799619401899554], 
     Hue[1.1996383365519758`, 1, -0.3898670517275895], 
     Hue[1.1960623089832096`, 1, -0.20290189414236837`], 
     Hue[1.1907880713313828`, 1, -0.017023767852071714`], 
     Hue[1.1827423297035475`, 1, 0.17295981744174693`], 
     Hue[1.1709605254946465`, 1, 0.35850211194666914`], 
     Hue[1.152902336317878, 1, 0.5461276685703053], 
     Hue[1.1245181481286932`, 1, 0.734065648189032], 
     Hue[1.075466204457783, 1, 0.9217318012278398], 
     Hue[0.8595733329031924, 1, -17.27618334189528], 
     Hue[0.7968759323457268, 1, -17.089062133554293`], 
     Hue[0.8566650062171772, 1, -16.91062086407678], 
     Hue[0.7968759323457268, 1, -16.714819716872324`], 
     Hue[0.8566650062171772, 1, -16.53637844739481], 
     Hue[0.7968759323457268, 1, -16.34057730019035], 
     Hue[0.8571395226764746, 1, -16.16071983016143], 
     Hue[0.7968759323457268, 1, -15.966334883508381`], 
     Hue[0.8574954100209482, 1, -15.7854152630659], 
     Hue[0.7968759323457268, 1, -15.592092466826411`], 
     Hue[0.8614101708101495, 1, -15.399489191834807`], 
     Hue[0.7968759323457271, 1, -15.217850050144438`], 
     Hue[0.8614101708101496, 1, -15.025246775152837`], 
     Hue[0.7968759323457273, 1, -14.843607633462467`], 
     Hue[0.8614101708101499, 1, -14.651004358470864`], 
     Hue[0.7968759323457278, 1, -14.469365216780497`], 
     Hue[0.8614101708101505, 1, -14.276761941788898`], 
     Hue[0.796875932345729, 1, -14.095122800098528`], 
     Hue[0.8614101708101519, 1, -13.90251952510693], 
     Hue[0.798835226113152, 1, -13.715032845655903`], 
     Hue[0.862328589763633, 1, -13.525536075099662`], 
     Hue[0.7988352261131578, 1, -13.340790428973937`], 
     Hue[0.8623285897636399, 1, -13.151293658417709`], 
     Hue[0.7988352261131705, 1, -12.966548012291979`], 
     Hue[0.8623285897636549, 1, -12.777051241735776`], 
     Hue[0.7988352261131983, 1, -12.592305595610034`], 
     Hue[0.8623285897636881, 1, -12.40280882505389], 
     Hue[0.7988352261132594, 1, -12.21806317892812], 
     Hue[0.8623285897637608, 1, -12.028566408372102`], 
     Hue[0.7998148729971053, 1, -11.840896993365954`], 
     Hue[0.8627877992406616, 1, -11.652953475027886`], 
     Hue[0.7998148729974022, 1, -11.46665457668427], 
     Hue[0.8627877992410136, 1, -11.278711058346817`], 
     Hue[0.7998148729980552, 1, -11.092412160002931`], 
     Hue[0.8627877992417876, 1, -10.904468641666826`], 
     Hue[0.8003046964413525, 1, -10.716707858882213`], 
     Hue[0.8648618953800992, 1, -10.52403605806312], 
     Hue[0.8006720640259153, 1, -10.34136902887326], 
     Hue[0.8650283588191668, 1, -10.14929682910082], 
     Hue[0.8047131074284013, 1, -9.955066065568099], 
     Hue[0.8650838466391828, 1, -9.774888808343832], 
     Hue[0.8047131074439745, 1, -9.580823648902768], 
     Hue[0.8650838466573054, 1, -9.400646391709596], 
     Hue[0.8047131074782158, 1, -9.206581232257381], 
     Hue[0.8650838466971524, 1, -9.026403975132583], 
     Hue[0.804713107553503, 1, -8.832338815655849], 
     Hue[0.8668594567616823, 1, -8.646862227595921], 
     Hue[0.804713107719039, 1, -8.458096399150739], 
     Hue[0.8668594569545495, 1, -8.272619811433499], 
     Hue[0.8047131080830078, 1, -8.083853982857638], 
     Hue[0.8668594573786117, 1, -7.8983773958938785`], 
     Hue[0.8047131088832757, 1, -7.709611567030689], 
     Hue[0.866859458311009, 1, -7.524134981723619], 
     Hue[0.8047131106428469, 1, -7.3353691522286715`], 
     Hue[0.8668594603610964, 1, -7.1498925705642185`], 
     Hue[0.8047131145116642, 1, -6.961126739680217], 
     Hue[0.8677472698613014, 1, -6.773000500739726], 
     Hue[0.8047131230181388, 1, -6.586884332086713], 
     Hue[0.8677472797773536, 1, -6.3987581110709275`], 
     Hue[0.8066724357582282, 1, -6.206794399354386], 
     Hue[0.868619799603872, 1, -6.021911773379639], 
     Hue[0.8066724772047001, 1, -5.832552028680238], 
     Hue[0.8686198475636343, 1, -5.64766948879477], 
     Hue[0.8066725683341684, 1, -5.45830971315703], 
     Hue[0.8690562020564345, 1, -5.272125374775715], 
     Hue[0.8066727687028975, 1, -5.084067518896082], 
     Hue[0.8692745585026711, 1, -4.897232608298866], 
     Hue[0.8066732092584672, 1, -4.709825591259605], 
     Hue[0.8729831860010944, 1, -4.511924812827844], 
     Hue[0.8076538316439277, 1, -4.332660525967042], 
     Hue[0.8699093970062508, 1, -4.146862538177596], 
     Hue[0.807655969647177, 1, -3.9584205275253908`], 
     Hue[0.8733847581499502, 1, -3.762262712646601], 
     Hue[0.808150510346247, 1, -3.5827216531719017`], 
     Hue[0.8735891754392775, 1, -3.387442348915072], 
     Hue[0.8084057952336121, 1, -3.2077602387833304`], 
     Hue[0.8737006009727928, 1, -3.0129380498239398`], 
     Hue[0.8086658796850491, 1, -2.8328361275951073`], 
     Hue[0.8738232122969407, 1, -2.6384851529572586`], 
     Hue[0.812643631320296, 1, -2.4469431800049746`], 
     Hue[0.8721178809895532, 1, -2.2696668748145825`], 
     Hue[0.812755471233331, 1, -2.072839513281032], 
     Hue[0.8756024566050211, 1, -1.8857960902865536`], 
     Hue[0.8130011467897215, 1, -1.6989028510255662`], 
     Hue[0.875880044450941, 1, -1.5123898917443241`], 
     Hue[0.8135402064118067, 1, -1.3253359799901039`], 
     Hue[0.8764869584942695, 1, -1.1399859636441232`], 
     Hue[0.8147200415899065, 1, -0.9525945492889363], 
     Hue[0.8794569837718245, 1, -0.7650029938423939], 
     Hue[0.8192783994436198, 1, -0.5761296728408656], 
     Hue[0.8878827696723728, 1, -0.38414058085283154`], 
     Hue[0.8268118102604455, 1, -0.20473256977437715`], 
     Hue[0.8997677235214272, 1, -0.015052173362605226`], 
     Hue[0.8481124883727293, 1, 0.171716115118963], 
     Hue[0.9314557504607183, 1, 0.3594465179787074], 
     Hue[0.9024624856727858, 1, 0.5462080663228938], 
     Hue[0.8878987756972126, 1, 0.7342016978264134], 
     Hue[0.968216451049421, 1, 0.9216355081643067], 
     Hue[0.9849681340181247, 1, -17.27618334189528], 
     Hue[0.922270733460658, 1, -17.089062133554293`], 
     Hue[0.9820598073321095, 1, -16.91062086407678], 
     Hue[0.922270733460658, 1, -16.714819716872324`], 
     Hue[0.9820598073321095, 1, -16.53637844739481], 
     Hue[0.922270733460658, 1, -16.34057730019035], 
     Hue[0.9825343237914069, 1, -16.16071983016143], 
     Hue[0.922270733460658, 1, -15.966334883508381`], 
     Hue[0.9828902111358793, 1, -15.7854152630659], 
     Hue[0.922270733460658, 1, -15.592092466826411`], 
     Hue[0.9868049719250817, 1, -15.399489191834807`], 
     Hue[0.9222707334606581, 1, -15.217850050144438`], 
     Hue[0.9868049719250817, 1, -15.025246775152837`], 
     Hue[0.9222707334606581, 1, -14.843607633462467`], 
     Hue[0.9868049719250818, 1, -14.651004358470868`], 
     Hue[0.9222707334606585, 1, -14.469365216780501`], 
     Hue[0.9868049719250818, 1, -14.276761941788898`], 
     Hue[0.922270733460659, 1, -14.095122800098533`], 
     Hue[0.986804971925082, 1, -13.902519525106934`], 
     Hue[0.9242300272280808, 1, -13.715032845655912`], 
     Hue[0.9877233908785591, 1, -13.52553607509967], 
     Hue[0.9242300272280836, 1, -13.340790428973955`], 
     Hue[0.9877233908785598, 1, -13.151293658417725`], 
     Hue[0.9242300272280897, 1, -12.966548012292021`], 
     Hue[0.9877233908785613, 1, -12.777051241735814`], 
     Hue[0.924230027228103, 1, -12.592305595610126`], 
     Hue[0.9877233908785646, 1, -12.402808825053972`], 
     Hue[0.9242300272281324, 1, -12.218063178928325`], 
     Hue[0.987723390878572, 1, -12.028566408372285`], 
     Hue[0.9252096741119066, 1, -11.840896993366409`], 
     Hue[0.9881826003553278, 1, -11.652953475028285`], 
     Hue[0.9252096741120479, 1, -11.466654576685269`], 
     Hue[0.9881826003553622, 1, -11.278711058347696`], 
     Hue[0.9252096741123588, 1, -11.092412160005123`], 
     Hue[0.9881826003554378, 1, -10.904468641668759`], 
     Hue[0.9256994975548944, 1, -10.716707858887037`], 
     Hue[0.9902566964921585, 1, -10.524036058067315`], 
     Hue[0.9260668651377766, 1, -10.34136902888387], 
     Hue[0.9904231599277736, 1, -10.149296829110034`], 
     Hue[0.9301079085362078, 1, -9.955066065591494], 
     Hue[0.9904786477402012, 1, -9.774888808364084], 
     Hue[0.9301079085432405, 1, -9.580823648954208], 
     Hue[0.9904786477416464, 1, -9.400646391754123], 
     Hue[0.9301079085587034, 1, -9.206581232370482], 
     Hue[0.990478647744824, 1, -9.026403975230483], 
     Hue[0.9301079085927023, 1, -8.832338815904524], 
     Hue[0.9922542577262655, 1, -8.6468622278086], 
     Hue[0.9301079086674564, 1, -8.458096399697512], 
     Hue[0.9922542577389051, 1, -8.272619811901123], 
     Hue[0.9301079088318204, 1, -8.083853984059841], 
     Hue[0.992254257766696, 1, -7.898377396922055], 
     Hue[0.930107909193212, 1, -7.7096115696740055`], 
     Hue[0.9922542578278004, 1, -7.5241349839842995`], 
     Hue[0.9301079099878135, 1, -7.335369158040607], 
     Hue[0.9922542579621526, 1, -7.149892575534836], 
     Hue[0.9301079117349257, 1, -6.961126752459074], 
     Hue[0.9931420631865391, 1, -6.773000511600381], 
     Hue[0.930107915576349, 1, -6.586884360183937], 
     Hue[0.9931420637648715, 1, -6.398758134950544], 
     Hue[0.9320672175696899, 1, -6.206794461193213], 
     Hue[0.9940145627568746, 1, -6.021911825552696], 
     Hue[0.9320672358765602, 1, -5.832552164646919], 
     Hue[0.9940145652106527, 1, -5.647669603509024], 
     Hue[0.9320672761283463, 1, -5.458310012110476], 
     Hue[0.994450818912958, 1, -5.272125626186613], 
     Hue[0.9320673646308968, 1, -5.084068176212126], 
     Hue[0.9946689536746841, 1, -4.897233160179266], 
     Hue[0.9320675592231249, 1, -4.709827036513078], 
     Hue[0.9983770640742862, 1, -4.511925990998109], 
     Hue[0.9330476281019705, 1, -4.332663704883453], 
     Hue[0.9953022242697271, 1, -4.146865193345959], 
     Hue[0.9330485617929127, 1, -3.958427516969003], 
     Hue[0.9987750810655858, 1, -3.762268388947694], 
     Hue[0.9335404236854203, 1, -3.582737022979968], 
     Hue[0.9989741129983123, 1, -3.3874548073581057`], 
     Hue[0.9337898154247812, 1, -3.2077940323664036`], 
     Hue[0.9990736971138402, 1, -3.0129654142853077`], 
     Hue[0.9379625524598512, 1, -2.821196887255139], 
     Hue[0.9970465798723278, 1, -2.644883324158606], 
     Hue[0.9379834805677749, 1, -2.4471065396212923`], 
     Hue[0.9974545236045391, 1, -2.2696660755088898`], 
     Hue[0.9380294486898043, 1, -2.073198339063185], 
     Hue[1.000763358209385, 1, -1.8860817399079235`], 
     Hue[0.9381302929917468, 1, -1.6996900854645387`], 
     Hue[1.0007614706519015`, 1, -1.5130153022844797`], 
     Hue[0.9383509302066605, 1, -1.327058579100257], 
     Hue[1.0007573530758553`, 1, -1.1413483504633024`], 
     Hue[0.940773963634697, 1, -0.9506064905103646], 
     Hue[1.0031138117893, 1, -0.7656567988460299], 
     Hue[0.9432271655978869, 1, -0.5799663423190977], 
     Hue[1.008142261837329, 1, -0.38840816168559456`], 
     Hue[0.9523274930771409, 1, -0.20272729887756236`], 
     Hue[1.0165402650820692`, 1, -0.014057671495586455`], 
     Hue[0.9699599670386125, 1, 0.17223461777271754`], 
     Hue[1.0316839074347954`, 1, 0.358546605172017], 
     Hue[1.0036203557776235`, 1, 0.5467696408009326], 
     Hue[0.9950427953181264, 1, 0.7338844941950462], 
     Hue[1.0092985924238218`, 1, 0.922040153619089], 
     Hue[1.110362935133056, 1, -17.27618334189528], 
     Hue[1.0476655345755892`, 1, -17.089062133554293`], 
     Hue[1.1074546084470407`, 1, -16.91062086407678], 
     Hue[1.0476655345755892`, 1, -16.714819716872324`], 
     Hue[1.1074546084470407`, 1, -16.53637844739481], 
     Hue[1.0476655345755892`, 1, -16.34057730019035], 
     Hue[1.107929124906338, 1, -16.16071983016143], 
     Hue[1.0476655345755892`, 1, -15.966334883508381`], 
     Hue[1.1082850122508117`, 1, -15.7854152630659], 
     Hue[1.0476655345755892`, 1, -15.592092466826411`], 
     Hue[1.1121997730400128`, 1, -15.399489191834807`], 
     Hue[1.047665534575589, 1, -15.217850050144438`], 
     Hue[1.1121997730400126`, 1, -15.025246775152837`], 
     Hue[1.047665534575589, 1, -14.843607633462467`], 
     Hue[1.1121997730400124`, 1, -14.651004358470864`], 
     Hue[1.0476655345755888`, 1, -14.469365216780501`], 
     Hue[1.112199773040012, 1, -14.276761941788898`], 
     Hue[1.0476655345755885`, 1, -14.095122800098533`], 
     Hue[1.1121997730400106`, 1, -13.902519525106932`], 
     Hue[1.0496248283430092`, 1, -13.715032845655914`], 
     Hue[1.1131181919934858`, 1, -13.525536075099664`], 
     Hue[1.0496248283430074`, 1, -13.340790428973959`], 
     Hue[1.11311819199348, 1, -13.151293658417712`], 
     Hue[1.0496248283430032`, 1, -12.966548012292026`], 
     Hue[1.1131181919934672`, 1, -12.777051241735789`], 
     Hue[1.0496248283429943`, 1, -12.592305595610137`], 
     Hue[1.1131181919934388`, 1, -12.402808825053915`], 
     Hue[1.0496248283429745`, 1, -12.218063178928347`], 
     Hue[1.1131181919933764`, 1, -12.028566408372159`], 
     Hue[1.0506044752266397`, 1, -11.840896993366451`], 
     Hue[1.113577401469977, 1, -11.652953475028008`], 
     Hue[1.050604475226542, 1, -11.466654576685368`], 
     Hue[1.1135774014696735`, 1, -11.278711058347083`], 
     Hue[1.0506044752263275`, 1, -11.092412160005342`], 
     Hue[1.1135774014690063`, 1, -10.904468641667412`], 
     Hue[1.0510942986677, 1, -10.7167078588875], 
     Hue[1.1156514976040677`, 1, -10.524036058064198`], 
     Hue[1.0514616662480236`, 1, -10.341369028884857`], 
     Hue[1.1158179610360557`, 1, -10.149296829103154`], 
     Hue[1.0555027096405583`, 1, -9.955066065592924], 
     Hue[1.1158734488405093`, 1, -9.774888808348933], 
     Hue[1.055502709634906, 1, -9.580823648957349], 
     Hue[1.1158734488244253`, 1, -9.400646391720812], 
     Hue[1.0555027096224783`, 1, -9.206581232377387], 
     Hue[1.115873448789061, 1, -9.026403975157244], 
     Hue[1.0555027095951532`, 1, -8.83233881591971], 
     Hue[1.117649058684634, 1, -8.646862227640536], 
     Hue[1.0555027095350729`, 1, -8.458096399730902], 
     Hue[1.1176490585095975`, 1, -8.272619811531593], 
     Hue[1.0555027094029727`, 1, -8.083853984133256], 
     Hue[1.1176490581247398`, 1, -7.898377396109564], 
     Hue[1.0555027091125202`, 1, -7.709611569835423], 
     Hue[1.1176490572785427`, 1, -7.524134982197848], 
     Hue[1.0555027084738944`, 1, -7.335369158395523], 
     Hue[1.1176490554179859`, 1, -7.149892571606915], 
     Hue[1.0555027070697305`, 1, -6.96112675323944], 
     Hue[1.1185368562274653`, 1, -6.773000502781089], 
     Hue[1.0555027039823566`, 1, -6.5868843618997515`], 
     Hue[1.1185368471272674`, 1, -6.398758115559327], 
     Hue[1.0574619903814253`, 1, -6.206794463972894], 
     Hue[1.1194093247035908`, 1, -6.021911782040842], 
     Hue[1.057461974760493, 1, -5.832552170758678], 
     Hue[1.1194092802053799`, 1, -5.647669507838384], 
     Hue[1.0574619404143486`, 1, -5.458310025548554], 
     Hue[1.119845430347854, 1, -5.272125413703403], 
     Hue[1.0574618648966754`, 1, -5.084068205758723], 
     Hue[1.12006333737878, 1, -4.897232690639689], 
     Hue[1.05746169885456, 1, -4.709827101477639], 
     Hue[1.1237709342891122`, 1, -4.511924869252241], 
     Hue[1.0584409655551295`, 1, -4.332663821717368], 
     Hue[1.1206950024832647`, 1, -4.1468628903711], 
     Hue[1.0584401447571374`, 1, -3.958427773848128], 
     Hue[1.1241653752378808`, 1, -3.7622629190416657`], 
     Hue[1.0589281268109099`, 1, -3.5827375243037674`], 
     Hue[1.1243589975672157`, 1, -3.387442729453597], 
     Hue[1.0591689864179505`, 1, -3.207795064422072], 
     Hue[1.1244466880146622`, 1, -3.012938805745626], 
     Hue[1.0633220732042847`, 1, -2.821196462307479], 
     Hue[1.1223937985848855`, 1, -2.644827386908978], 
     Hue[1.0633007345505825`, 1, -2.447105605874259], 
     Hue[1.122699435795814, 1, -2.2696769854580925`], 
     Hue[1.063253864513525, 1, -2.073196288890191], 
     Hue[1.1259251873249414`, 1, -1.8857894030527456`], 
     Hue[1.063151040830584, 1, -1.6996855915826983`], 
     Hue[1.1256449189926434`, 1, -1.5123752397724075`], 
     Hue[1.0629260692492015`, 1, -1.3270487649615321`], 
     Hue[1.125032111734858, 1, -1.1399539952046156`], 
     Hue[1.0643582135748997`, 1, -0.9505193584228644], 
     Hue[1.1244726152851925`, 1, -0.7673405681841503], 
     Hue[1.0646709020397251`, 1, -0.5796736779878442], 
     Hue[1.124763379382873, 1, -0.3917718526456109], 
     Hue[1.0680960294414794`, 1, -0.20379893314504338`], 
     Hue[1.1247649679122778`, 1, -0.015201080994227567`], 
     Hue[1.0734290413553393`, 1, 0.17109229350327282`], 
     Hue[1.1215101260869071`, 1, 0.35859947497796263`], 
     Hue[1.0794319441649027`, 1, 0.5470887261262953], 
     Hue[1.0508809239148726`, 1, 0.733913520010969], 
     Hue[1.0350753017139827`, 1, 0.9221287879045361], 
     Hue[1.235757736247987, 1, -17.27618334189528], 
     Hue[1.1730603356905214`, 1, -17.089062133554293`], 
     Hue[1.232849409561972, 1, -16.91062086407678], 
     Hue[1.1730603356905214`, 1, -16.714819716872324`], 
     Hue[1.232849409561972, 1, -16.53637844739481], 
     Hue[1.1730603356905214`, 1, -16.34057730019035], 
     Hue[1.2333239260212692`, 1, -16.16071983016143], 
     Hue[1.1730603356905214`, 1, -15.966334883508381`], 
     Hue[1.2336798133657427`, 1, -15.7854152630659], 
     Hue[1.1730603356905214`, 1, -15.592092466826411`], 
     Hue[1.237594574154944, 1, -15.399489191834807`], 
     Hue[1.1730603356905211`, 1, -15.217850050144438`], 
     Hue[1.2375945741549437`, 1, -15.025246775152837`], 
     Hue[1.1730603356905211`, 1, -14.843607633462467`], 
     Hue[1.2375945741549432`, 1, -14.651004358470864`], 
     Hue[1.1730603356905205`, 1, -14.469365216780497`], 
     Hue[1.2375945741549426`, 1, -14.276761941788894`], 
     Hue[1.1730603356905194`, 1, -14.09512280009853], 
     Hue[1.2375945741549406`, 1, -13.902519525106923`], 
     Hue[1.1750196294579374`, 1, -13.715032845655905`], 
     Hue[1.2385129931084145`, 1, -13.52553607509965], 
     Hue[1.175019629457932, 1, -13.340790428973941`], 
     Hue[1.2385129931084056`, 1, -13.151293658417679`], 
     Hue[1.1750196294579203`, 1, -12.966548012291991`], 
     Hue[1.2385129931083858`, 1, -12.777051241735714`], 
     Hue[1.1750196294578943`, 1, -12.592305595610057`], 
     Hue[1.2385129931083423`, 1, -12.402808825053752`], 
     Hue[1.175019629457837, 1, -12.218063178928173`], 
     Hue[1.238512993108247, 1, -12.0285664083718], 
     Hue[1.1759992763414193`, 1, -11.840896993366064`], 
     Hue[1.2389722025847767`, 1, -11.652953475027214`], 
     Hue[1.1759992763411404`, 1, -11.46665457668451], 
     Hue[1.2389722025843142`, 1, -11.27871105834534], 
     Hue[1.175999276340527, 1, -11.092412160003457`], 
     Hue[1.2389722025832972`, 1, -10.90446864166358], 
     Hue[1.1764890997810231`, 1, -10.71670785888333], 
     Hue[1.2410462987176085`, 1, -10.524036058055605`], 
     Hue[1.1768564673594153`, 1, -10.341369028875643`], 
     Hue[1.2412127621479323`, 1, -10.149296829084232`], 
     Hue[1.180897510747686, 1, -9.955066065571543], 
     Hue[1.2412682499487253`, 1, -9.774888808307312], 
     Hue[1.1808975107326798`, 1, -9.580823648910341], 
     Hue[1.2412682499245904`, 1, -9.400646391629296], 
     Hue[1.180897510699685, 1, -9.206581232274031], 
     Hue[1.2412682498715244`, 1, -9.026403974956024], 
     Hue[1.1808975106271389`, 1, -8.832338815692456], 
     Hue[1.243043859729051, 1, -8.646862227190766], 
     Hue[1.1808975104676294`, 1, -8.458096399231232], 
     Hue[1.2430438594694873`, 1, -8.272619810542675], 
     Hue[1.1808975101169112`, 1, -8.083853983034619], 
     Hue[1.2430438588987773`, 1, -7.898377393935202], 
     Hue[1.180897509345778, 1, -7.709611567419821], 
     Hue[1.2430438576439415`, 1, -7.524134977417019], 
     Hue[1.1808975076502666`, 1, -7.335369153084273], 
     Hue[1.2430438548848999`, 1, -7.149892561095176], 
     Hue[1.1808975039222984`, 1, -6.961126741561448], 
     Hue[1.243931653742083, 1, -6.77300047947905], 
     Hue[1.1808974957255127`, 1, -6.5868843362230285`], 
     Hue[1.2439316403260892`, 1, -6.398758064324495], 
     Hue[1.1828567708724687`, 1, -6.206794406055369], 
     Hue[1.2448041085257933`, 1, -6.02191166848553], 
     Hue[1.1828567305291167`, 1, -5.832552043413871], 
     Hue[1.2448040432982892`, 1, -5.647669258161276], 
     Hue[1.1828566418251123`, 1, -5.458309745552258], 
     Hue[1.245240148139027, 1, -5.2721248625413395`], 
     Hue[1.1828564467893372`, 1, -5.084067590124286], 
     Hue[1.2454579555930994`, 1, -4.897231476375082], 
     Hue[1.1828560179595744`, 1, -4.709825747870666], 
     Hue[1.249165345216187, 1, -4.511922108611418], 
     Hue[1.1838347065146857`, 1, -4.332660807622361], 
     Hue[1.2460889237028774`, 1, -4.1468569862935185`], 
     Hue[1.1838326148813902`, 1, -3.9584211468019337`], 
     Hue[1.2495582964211236`, 1, -3.762249525808701], 
     Hue[1.1843178020194052`, 1, -3.5827228617901534`], 
     Hue[1.2497496720755916`, 1, -3.3874132301253352`], 
     Hue[1.1845525164048016`, 1, -3.207762727107477], 
     Hue[1.2498324221563066`, 1, -3.012873892125417], 
     Hue[1.1847711341168872`, 1, -2.8328298145055415`], 
     Hue[1.249893522196128, 1, -2.6383391743894506`], 
     Hue[1.1886410271370227`, 1, -2.4469409274648877`], 
     Hue[1.2479981079791678`, 1, -2.2695222968481783`], 
     Hue[1.1885288148185764`, 1, -2.0728345634237355`], 
     Hue[1.2512247542909822`, 1, -1.8850898905636109`], 
     Hue[1.1882823167376046`, 1, -1.6988919815049954`], 
     Hue[1.2508294147929218`, 1, -1.5108398594761938`], 
     Hue[1.1877414308314729`, 1, -1.3253121481083794`], 
     Hue[1.2499601418380675`, 1, -1.136591007553841], 
     Hue[1.18655749572651, 1, -0.9525424764995092], 
     Hue[1.2480489287407055`, 1, -0.7623842687658549], 
     Hue[1.1858560845595572`, 1, -0.5756670098087049], 
     Hue[1.244605408688714, 1, -0.3859743646189495], 
     Hue[1.1815491238628386`, 1, -0.20441774107912924`], 
     Hue[1.2344713284726703`, 1, -0.016750650458211114`], 
     Hue[1.1744797674627272`, 1, 0.17129383931291198`], 
     Hue[1.2171402983705744`, 1, 0.359701586438427], 
     Hue[1.1577830086919856`, 1, 0.5466876403278608], 
     Hue[1.1806918096809969`, 1, 0.7341454040038746], 
     Hue[1.1082943254582842`, 1, 0.7343172469043955], 
     Hue[1.115691015321758, 1, 0.9215640660446597], 
     Hue[1.067518487761356, 1, 0.921801418281629], 
     Hue[1.3611525373629192`, 1, -17.27618334189528], 
     Hue[1.2984551368054527`, 1, -17.089062133554293`], 
     Hue[1.3582442106769042`, 1, -16.91062086407678], 
     Hue[1.2984551368054527`, 1, -16.714819716872324`], 
     Hue[1.3582442106769042`, 1, -16.53637844739481], 
     Hue[1.2984551368054527`, 1, -16.34057730019035], 
     Hue[1.3587187271362016`, 1, -16.16071983016143], 
     Hue[1.2984551368054524`, 1, -15.966334883508381`], 
     Hue[1.3590746144806738`, 1, -15.7854152630659], 
     Hue[1.2984551368054524`, 1, -15.592092466826411`], 
     Hue[1.3629893752698763`, 1, -15.399489191834807`], 
     Hue[1.2984551368054524`, 1, -15.217850050144438`], 
     Hue[1.362989375269876, 1, -15.025246775152837`], 
     Hue[1.2984551368054522`, 1, -14.843607633462467`], 
     Hue[1.3629893752698758`, 1, -14.651004358470864`], 
     Hue[1.2984551368054515`, 1, -14.469365216780497`], 
     Hue[1.3629893752698752`, 1, -14.276761941788891`], 
     Hue[1.2984551368054504`, 1, -14.095122800098524`], 
     Hue[1.3629893752698736`, 1, -13.902519525106916`], 
     Hue[1.3004144305728684`, 1, -13.715032845655893`], 
     Hue[1.3639077942233475`, 1, -13.525536075099632`], 
     Hue[1.3004144305728627`, 1, -13.340790428973916`], 
     Hue[1.3639077942233406`, 1, -13.151293658417643`], 
     Hue[1.30041443057285, 1, -12.966548012291934`], 
     Hue[1.3639077942233258`, 1, -12.777051241735634`], 
     Hue[1.3004144305728222`, 1, -12.592305595609936`], 
     Hue[1.363907794223293, 1, -12.402808825053578`], 
     Hue[1.3004144305727614`, 1, -12.218063178927904`], 
     Hue[1.3639077942232207`, 1, -12.028566408371418`], 
     Hue[1.3013940774563375`, 1, -11.840896993365469`], 
     Hue[1.3643670036998026`, 1, -11.652953475026376`], 
     Hue[1.3013940774560415`, 1, -11.466654576683203`], 
     Hue[1.3643670036994537`, 1, -11.278711058343495`], 
     Hue[1.3013940774553907`, 1, -11.092412160000581`], 
     Hue[1.3643670036986864`, 1, -10.90446864165952], 
     Hue[1.3018839008958096`, 1, -10.716707858876985`], 
     Hue[1.366441099833599, 1, -10.524036058046601`], 
     Hue[1.3022512684740384`, 1, -10.341369028861656`], 
     Hue[1.3666075632652017`, 1, -10.149296829064422`], 
     Hue[1.306292311862191, 1, -9.955066065539954], 
     Hue[1.3666630510688051`, 1, -9.774888808263743], 
     Hue[1.3062923118466738`, 1, -9.580823648840887], 
     Hue[1.366663051050842, 1, -9.400646391533503], 
     Hue[1.3062923118125558`, 1, -9.206581232121318], 
     Hue[1.366663051011346, 1, -9.026403974745403], 
     Hue[1.3062923117375398`, 1, -8.832338815356682], 
     Hue[1.3684386609010717`, 1, -8.646862226724343], 
     Hue[1.3062923115726, 1, -8.458096398492957], 
     Hue[1.3684386607099415`, 1, -8.272619809517137], 
     Hue[1.306292311209942, 1, -8.083853981411357], 
     Hue[1.3684386602896979`, 1, -7.898377391680319], 
     Hue[1.3062923104125561`, 1, -7.70961156385071], 
     Hue[1.368438659365697, 1, -7.524134972459149], 
     Hue[1.3062923086593214`, 1, -7.3353691452367675`], 
     Hue[1.3684386573340706`, 1, -7.1498925501941715`], 
     Hue[1.3062923048044368`, 1, -6.961126724306921], 
     Hue[1.369326457852054, 1, -6.773000455426124], 
     Hue[1.3062922963285952`, 1, -6.586884298285027], 
     Hue[1.3693264480262948`, 1, -6.398758011438668], 
     Hue[1.3082515711964553`, 1, -6.206794321571344], 
     Hue[1.3701989244140789`, 1, -6.0219115518047355`], 
     Hue[1.3082515299049589`, 1, -5.832551857656528], 
     Hue[1.3701988768957745`, 1, -5.647669001611941], 
     Hue[1.3082514391161821`, 1, -5.458309337122497], 
     Hue[1.3706350213893657`, 1, -5.272124297498632], 
     Hue[1.3082512394962653`, 1, -5.08406669209861], 
     Hue[1.3708529161021872`, 1, -4.897230232945467], 
     Hue[1.3082508005857947`, 1, -4.709823773357242], 
     Hue[1.3745605268003365`, 1, -4.511919335895095], 
     Hue[1.3092294757279124`, 1, -4.3326564387326725`], 
     Hue[1.3714845064836112`, 1, -4.146850960268055], 
     Hue[1.3092273458105013`, 1, -3.958411540809699], 
     Hue[1.374954952635263, 1, -3.7622361013255174`], 
     Hue[1.309712469978948, 1, -3.582701674428236], 
     Hue[1.375148569194261, 1, -3.387383690680819], 
     Hue[1.3099470473451804`, 1, -3.207716068939508], 
     Hue[1.3752362468928896`, 1, -3.0128089143105576`], 
     Hue[1.3101386045616565`, 1, -2.8328070443242215`], 
     Hue[1.375297315339215, 1, -2.6382287288731465`], 
     Hue[1.3140364809339835`, 1, -2.446709356429878], 
     Hue[1.3733315621295359`, 1, -2.2695187809669433`], 
     Hue[1.3139249310830485`, 1, -2.0723253960182513`], 
     Hue[1.3767186730799466`, 1, -1.884393994017567], 
     Hue[1.3136794297365497`, 1, -1.6977724367265454`], 
     Hue[1.376441259019241, 1, -1.509307027247316], 
     Hue[1.3131385120671162`, 1, -1.3228504951886386`], 
     Hue[1.3724959280071511`, 1, -1.1432927170430978`], 
     Hue[1.3119437580056788`, 1, -0.9471300047725009], 
     Hue[1.370331267024672, 1, -0.7676011766059838], 
     Hue[1.3073685964130182`, 1, -0.5758127272067435], 
     Hue[1.365544616371897, 1, -0.39032722952929455`], 
     Hue[1.2991298487555425`, 1, -0.2032739158084329], 
     Hue[1.3539256664811063`, 1, -0.013641105460261871`], 
     Hue[1.4068887938539676`, 1, 0.17188761828488852`], 
     Hue[1.2832397576477637`, 1, 0.17139993719060098`], 
     Hue[1.327868015374704, 1, 0.35841967182170276`], 
     Hue[1.3701123753723223`, 1, 0.546287769497861], 
     Hue[1.2515327314361953`, 1, 0.5465815129363186], 
     Hue[1.2782814572771355`, 1, 0.7341011613224968], 
     Hue[1.297771570805414, 1, 0.9222506846371008], 
     Hue[1.3103429893962648`, 1, 1.10933465254528], 
     Hue[1.1890421379663936`, 1, 0.9216375402395409], 
     Hue[1.1795487241345475`, 1, 1.1094900006637494`], 
     Hue[1.1394495187272093`, 1, 1.2970941377336163`], 
     Hue[1.091193911041288, 1, 1.1093136704691986`], 
     Hue[1.0270654897035654`, 1, 1.10934248824572], 
     Hue[1.4865473384778505`, 1, -17.27618334189528], 
     Hue[1.4238499379203837`, 1, -17.089062133554293`], 
     Hue[1.4836390117918354`, 1, -16.91062086407678], 
     Hue[1.4238499379203837`, 1, -16.714819716872324`], 
     Hue[1.4836390117918354`, 1, -16.53637844739481], 
     Hue[1.4238499379203837`, 1, -16.34057730019035], 
     Hue[1.4841135282511326`, 1, -16.16071983016143], 
     Hue[1.4238499379203837`, 1, -15.966334883508381`], 
     Hue[1.4844694155956062`, 1, -15.7854152630659], 
     Hue[1.4238499379203837`, 1, -15.592092466826411`], 
     Hue[1.4883841763848076`, 1, -15.399489191834807`], 
     Hue[1.4238499379203837`, 1, -15.217850050144438`], 
     Hue[1.4883841763848076`, 1, -15.025246775152837`], 
     Hue[1.4238499379203835`, 1, -14.843607633462467`], 
     Hue[1.4883841763848076`, 1, -14.65100435847086], 
     Hue[1.4238499379203833`, 1, -14.469365216780494`], 
     Hue[1.4883841763848074`, 1, -14.276761941788891`], 
     Hue[1.4238499379203828`, 1, -14.095122800098519`], 
     Hue[1.4883841763848071`, 1, -13.902519525106912`], 
     Hue[1.425809231687803, 1, -13.715032845655884`], 
     Hue[1.4893025953382848`, 1, -13.525536075099625`], 
     Hue[1.4258092316878004`, 1, -13.340790428973898`], 
     Hue[1.4893025953382844`, 1, -13.151293658417627`], 
     Hue[1.4258092316877944`, 1, -12.966548012291893`], 
     Hue[1.489302595338283, 1, -12.777051241735599`], 
     Hue[1.4258092316877813`, 1, -12.592305595609842`], 
     Hue[1.4893025953382801`, 1, -12.402808825053496`], 
     Hue[1.4258092316877526`, 1, -12.2180631789277], 
     Hue[1.4893025953382737`, 1, -12.028566408371242`], 
     Hue[1.4267888785714, 1, -11.840896993365018`], 
     Hue[1.489761804815, 1, -11.652953475025983`], 
     Hue[1.4267888785712615`, 1, -11.466654576682213`], 
     Hue[1.4897618048149703`, 1, -11.278711058342632`], 
     Hue[1.4267888785709568`, 1, -11.092412159998407`], 
     Hue[1.4897618048149048`, 1, -10.904468641657624`], 
     Hue[1.427278702012146, 1, -10.716707858872203`], 
     Hue[1.491835900951416, 1, -10.52403605804249], 
     Hue[1.4276460695920756`, 1, -10.341369028851139`], 
     Hue[1.4920023643864877`, 1, -10.149296829055396`], 
     Hue[1.4316871129843254`, 1, -9.955066065516773], 
     Hue[1.4920578521977157`, 1, -9.774888808243906], 
     Hue[1.4316871129774418`, 1, -9.580823648789913], 
     Hue[1.49205785219651, 1, -9.400646391489886], 
     Hue[1.431687112962306, 1, -9.206581232009244], 
     Hue[1.492057852193859, 1, -9.026403974649497], 
     Hue[1.4316871129290272`, 1, -8.832338815110262], 
     Hue[1.4938334621670517`, 1, -8.646862226516127], 
     Hue[1.4316871128558557`, 1, -8.458096397951143], 
     Hue[1.4938334621569878`, 1, -8.272619809059325], 
     Hue[1.4316871126949717`, 1, -8.083853980220056], 
     Hue[1.4938334621348597`, 1, -7.898377390673718], 
     Hue[1.4316871123412316`, 1, -7.709611561231362], 
     Hue[1.4938334620862062`, 1, -7.524134970245906], 
     Hue[1.4316871115634535`, 1, -7.335369139477533], 
     Hue[1.4938334619792302`, 1, -7.149892545327854], 
     Hue[1.4316871098533315`, 1, -6.961126711643936], 
     Hue[1.4947212667924044`, 1, -6.773000444796681], 
     Hue[1.4316871060932388`, 1, -6.586884270442571], 
     Hue[1.4947212663471905`, 1, -6.398757988067412], 
     Hue[1.4336463918194946`, 1, -6.206794260307162], 
     Hue[1.4955937636625412`, 1, -6.021911500758361], 
     Hue[1.4336463739129026`, 1, -5.832551722953238], 
     Hue[1.4955937618559714`, 1, -5.6476688893747955`], 
     Hue[1.4336463345411548`, 1, -5.458309040946444], 
     Hue[1.4960300075898854`, 1, -5.272124051555199], 
     Hue[1.4336462479732563`, 1, -5.084066040887074], 
     Hue[1.4962481249768347`, 1, -4.897229693106797], 
     Hue[1.433646057633292, 1, -4.7098223415151645`], 
     Hue[1.4999562548391845`, 1, -4.511918185084593], 
     Hue[1.434625292017447, 1, -4.332653289627176], 
     Hue[1.4968812902278825`, 1, -4.146848363526009], 
     Hue[1.4346243790160746`, 1, -3.9584046166575613`], 
     Hue[0.5003542508526672, 1, -3.7622305571600085`], 
     Hue[1.4351122096987874`, 1, -3.58268644784642], 
     Hue[0.5005532760244134, 1, -3.387371521280304], 
     Hue[1.4353527410760347`, 1, -3.2076825852544246`], 
     Hue[0.5006528488291495, 1, -3.0127821762466773`], 
     Hue[1.4355268024562808`, 1, -2.832824807069769], 
     Hue[0.5007276531868274, 1, -2.6382070959111594`], 
     Hue[1.4394867759524428`, 1, -2.4465473605834696`], 
     Hue[1.4988301135067161`, 1, -2.2693872753617477`], 
     Hue[1.4394417507764738`, 1, -2.0719688529862266`], 
     Hue[1.498984114045402, 1, -1.8941556932093715`], 
     Hue[1.4393425282178414`, 1, -1.6969867608514007`], 
     Hue[1.4989816322366936`, 1, -1.518754282777522], 
     Hue[1.4391232738208795`, 1, -1.3211145922684964`], 
     Hue[1.4986109542188932`, 1, -1.1430436079938022`], 
     Hue[1.434562760853701, 1, -0.9555674350612942], 
     Hue[1.4971008016558254`, 1, -0.7676003953452333], 
     Hue[1.4315594616843623`, 1, -0.579338485049969], 
     Hue[1.4944658343463335`, 1, -0.3884420264630195], 
     Hue[1.4238323988339783`, 1, -0.20414257076819986`], 
     Hue[1.484652749248618, 1, -0.014472675999188], 
     Hue[0.5491895351405685, 1, 0.17306042073311156`], 
     Hue[1.462289711845897, 1, 0.35981862798410114`], 
     Hue[0.5238832013620123, 1, 0.5466323085938835], 
     Hue[1.4120852839743656`, 1, 0.7339719816204175], 
     Hue[1.4579632779964897`, 1, 0.9217767157922541], 
     Hue[0.5162820846708391, 1, 1.1098743522516197`], 
     Hue[0.6231505793588792, 1, 1.2970388911730026`], 
     Hue[1.3164273596330347`, 1, 1.2971624812201468`], 
     Hue[0.9994032956082466, 1, 1.2970448375519756`], 
     Hue[1.0104564640130629`, 1, 1.1092950798903918`], 
     Hue[0.6119421395927817, 1, -17.27618334189528], 
     Hue[0.5492447390353161, 1, -17.089062133554293`], 
     Hue[0.6090338129067665, 1, -16.91062086407678], 
     Hue[0.5492447390353161, 1, -16.714819716872324`], 
     Hue[0.6090338129067665, 1, -16.53637844739481], 
     Hue[0.5492447390353161, 1, -16.34057730019035], 
     Hue[0.609508329366065, 1, -16.16071983016143], 
     Hue[0.5492447390353161, 1, -15.966334883508381`], 
     Hue[0.6098642167105375, 1, -15.7854152630659], 
     Hue[0.5492447390353161, 1, -15.592092466826411`], 
     Hue[0.6137789774997386, 1, -15.399489191834807`], 
     Hue[0.5492447390353161, 1, -15.217850050144438`], 
     Hue[0.6137789774997389, 1, -15.025246775152837`], 
     Hue[0.5492447390353161, 1, -14.843607633462467`], 
     Hue[0.6137789774997391, 1, -14.651004358470864`], 
     Hue[0.5492447390353163, 1, -14.469365216780494`], 
     Hue[0.6137789774997396, 1, -14.276761941788891`], 
     Hue[0.5492447390353167, 1, -14.095122800098519`], 
     Hue[0.6137789774997409, 1, -13.902519525106914`], 
     Hue[0.5512040328027381, 1, -13.715032845655884`], 
     Hue[0.6146973964532215, 1, -13.52553607509963], 
     Hue[0.55120403280274, 1, -13.340790428973895`], 
     Hue[0.6146973964532274, 1, -13.15129365841764], 
     Hue[0.5512040328027442, 1, -12.966548012291888`], 
     Hue[0.6146973964532405, 1, -12.777051241735625`], 
     Hue[0.5512040328027534, 1, -12.592305595609833`], 
     Hue[0.6146973964532692, 1, -12.402808825053555`], 
     Hue[0.5512040328027736, 1, -12.218063178927679`], 
     Hue[0.6146973964533322, 1, -12.02856640837137], 
     Hue[0.5521836796865306, 1, -11.840896993364979`], 
     Hue[0.6151566059302133, 1, -11.652953475026269`], 
     Hue[0.5521836796866311, 1, -11.466654576682126`], 
     Hue[0.6151566059305202, 1, -11.278711058343264`], 
     Hue[0.5521836796868521, 1, -11.092412159998215`], 
     Hue[0.615156605931195, 1, -10.904468641659012`], 
     Hue[0.5526735031292052, 1, -10.7167078588718], 
     Hue[0.6172307020693597, 1, -10.524036058045697`], 
     Hue[0.553040870711695, 1, -10.341369028850288`], 
     Hue[0.6173971655080459, 1, -10.149296829062473`], 
     Hue[0.5570819141098426, 1, -9.955066065515657], 
     Hue[0.61745265332722, 1, -9.774888808259488], 
     Hue[0.5570819141156489, 1, -9.580823648787462], 
     Hue[0.6174526533434823, 1, -9.400646391524145], 
     Hue[0.5570819141284151, 1, -9.206581232003852], 
     Hue[0.6174526533792384, 1, -9.026403974724827], 
     Hue[0.5570819141564844, 1, -8.832338815098407], 
     Hue[0.6192282634379791, 1, -8.64686222668882], 
     Hue[0.5570819142182013, 1, -8.458096397925079], 
     Hue[0.619228263614912, 1, -8.27261980943903], 
     Hue[0.5570819143539001, 1, -8.083853980162747], 
     Hue[0.6192282640039395, 1, -7.898377391508585], 
     Hue[0.5570819146522645, 1, -7.709611561105356], 
     Hue[0.6192282648593049, 1, -7.524134972081552], 
     Hue[0.5570819153082867, 1, -7.335369139200483], 
     Hue[0.6192282667400204, 1, -7.14989254936394], 
     Hue[0.5570819167507006, 1, -6.961126711034775], 
     Hue[0.6201160759516231, 1, -6.773000453854636], 
     Hue[0.5570819199221759, 1, -6.586884269103192], 
     Hue[0.620116085149319, 1, -6.398758007983392], 
     Hue[0.5590412212454816, 1, -6.206794258365762], 
     Hue[0.620988603799121, 1, -6.0219115454280185`], 
     Hue[0.5590412372761462, 1, -5.832551718684627], 
     Hue[0.6209886487688983, 1, -5.64766898759127], 
     Hue[0.559041272523238, 1, -5.45830903156092], 
     Hue[0.6214249976695565, 1, -5.272124269646212], 
     Hue[0.5590413500221281, 1, -5.0840660202508134`], 
     Hue[0.6216433419232591, 1, -4.897230174990134], 
     Hue[0.5590415204217494, 1, -4.709822296141406], 
     Hue[0.6253519830898603, 1, -4.511919334374175], 
     Hue[0.5600215571429066, 1, -4.332653216138914], 
     Hue[0.6222781065403349, 1, -4.146850726435156], 
     Hue[0.5600223991338591, 1, -3.958404455072614], 
     Hue[0.6257535407557255, 1, -3.762236161018186], 
     Hue[0.5605141108821021, 1, -3.5826861566673456`], 
     Hue[0.6259579542639824, 1, -3.387383895926658], 
     Hue[0.5607631786683294, 1, -3.207682015782889], 
     Hue[0.6260693765239492, 1, -3.0128094471623843`], 
     Hue[0.5609560289740285, 1, -2.832823671762962], 
     Hue[0.6261702458440255, 1, -2.638267175887737], 
     Hue[0.5649592082611172, 1, -2.44655059693571], 
     Hue[0.6243293018410414, 1, -2.269514216006651], 
     Hue[0.5650073618296177, 1, -2.071975978861377], 
     Hue[0.6279764679592961, 1, -1.884414606409689], 
     Hue[0.5651134756797812, 1, -1.6970024772970256`], 
     Hue[0.6282620952857174, 1, -1.509352507347528], 
     Hue[0.5653479442752267, 1, -1.3211493849958231`], 
     Hue[0.6254882213281945, 1, -1.1433282235374749`], 
     Hue[0.5617493669545275, 1, -0.9555054746954659], 
     Hue[0.628605715070909, 1, -0.7600020758385211], 
     Hue[0.5609106093805712, 1, -0.579059094342971], 
     Hue[0.6262544758267445, 1, -0.3922816389134385], 
     Hue[0.5590142784018229, 1, -0.19960691836417088`], 
     Hue[0.6268764465310521, 1, -0.014811423598483087`], 
     Hue[0.6231312992072354, 1, 0.35857223953994244`], 
     Hue[0.6041563461050006, 1, 0.7343324039340831], 
     Hue[0.8807449197829291, 1, 1.1093017210716862`], 
     Hue[0.7571686982255239, 1, 1.2972298615942321`], 
     Hue[0.9498782480683167, 1, 1.1092995213791166`], 
     Hue[0.9268760639890213, 1, 1.2971424715265008`], 
     Hue[0.9762128213475675, 1, 1.1092838760464403`], 
     Hue[0.9915883171310725, 1, 1.1093916274202165`], 
     Hue[0.7373369407077139, 1, -17.27618334189528], 
     Hue[0.6746395401502472, 1, -17.089062133554293`], 
     Hue[0.7344286140216988, 1, -16.91062086407678], 
     Hue[0.6746395401502472, 1, -16.714819716872324`], 
     Hue[0.7344286140216988, 1, -16.53637844739481], 
     Hue[0.6746395401502472, 1, -16.34057730019035], 
     Hue[0.7349031304809961, 1, -16.16071983016143], 
     Hue[0.6746395401502472, 1, -15.966334883508381`], 
     Hue[0.7352590178254685, 1, -15.7854152630659], 
     Hue[0.6746395401502473, 1, -15.592092466826411`], 
     Hue[0.739173778614671, 1, -15.399489191834807`], 
     Hue[0.6746395401502474, 1, -15.217850050144438`], 
     Hue[0.7391737786146713, 1, -15.025246775152837`], 
     Hue[0.6746395401502476, 1, -14.843607633462467`], 
     Hue[0.7391737786146716, 1, -14.651004358470864`], 
     Hue[0.6746395401502481, 1, -14.469365216780497`], 
     Hue[0.7391737786146724, 1, -14.276761941788894`], 
     Hue[0.6746395401502492, 1, -14.095122800098522`], 
     Hue[0.7391737786146744, 1, -13.902519525106923`], 
     Hue[0.6765988339176723, 1, -13.715032845655891`], 
     Hue[0.7400921975681551, 1, -13.525536075099646`], 
     Hue[0.6765988339176776, 1, -13.34079042897391], 
     Hue[0.7400921975681642, 1, -13.151293658417673`], 
     Hue[0.6765988339176895, 1, -12.966548012291925`], 
     Hue[0.7400921975681839, 1, -12.7770512417357], 
     Hue[0.6765988339177156, 1, -12.592305595609915`], 
     Hue[0.7400921975682273, 1, -12.40280882505372], 
     Hue[0.6765988339177731, 1, -12.218063178927856`], 
     Hue[0.7400921975683228, 1, -12.02856640837173], 
     Hue[0.677578480801613, 1, -11.840896993365373`], 
     Hue[0.7405514070452744, 1, -11.652953475027067`], 
     Hue[0.6775784808018934, 1, -11.466654576682993`], 
     Hue[0.7405514070457373, 1, -11.278711058345015`], 
     Hue[0.6775784808025098, 1, -11.092412160000121`], 
     Hue[0.7405514070467549, 1, -10.904468641662863`], 
     Hue[0.6780683042457317, 1, -10.716707858876019`], 
     Hue[0.7426255031856536, 1, -10.52403605805433], 
     Hue[0.678435671830135, 1, -10.341369028859608`], 
     Hue[0.7427919666259698, 1, -10.149296829081484`], 
     Hue[0.6824767152325057, 1, -9.955066065537267], 
     Hue[0.7428474544487287, 1, -9.774888808301307], 
     Hue[0.6824767152475804, 1, -9.580823648834976], 
     Hue[0.7428474544728755, 1, -9.400646391616094], 
     Hue[0.6824767152807252, 1, -9.20658123210832], 
     Hue[0.7428474545259679, 1, -9.026403974927], 
     Hue[0.6824767153536017, 1, -8.832338815328105], 
     Hue[0.7446230646219267, 1, -8.646862227140653], 
     Hue[0.6824767155138372, 1, -8.458096398430124], 
     Hue[0.7446230648815904, 1, -8.272619810432492], 
     Hue[0.6824767158661516, 1, -8.083853981273203], 
     Hue[0.7446230654525199, 1, -7.898377393692935], 
     Hue[0.6824767166407946, 1, -7.7096115635469475`], 
     Hue[0.7446230667078383, 1, -7.5241349768843415`], 
     Hue[0.6824767183440238, 1, -7.335369144568879], 
     Hue[0.7446230694679414, 1, -7.149892559923965], 
     Hue[0.6824767220889606, 1, -6.961126722838416], 
     Hue[0.7455108805892214, 1, -6.773000477262149], 
     Hue[0.6824767303230563, 1, -6.586884295056186], 
     Hue[0.745510894009633, 1, -6.3987580594501345`], 
     Hue[0.6844360427907351, 1, -6.2067943168912105`], 
     Hue[0.7463834218283886, 1, -6.021911659489892], 
     Hue[0.6844360833117876, 1, -5.8325518473661875`], 
     Hue[0.7463834870738221, 1, -5.647669238382321], 
     Hue[0.6844361724065706, 1, -5.458309314496832], 
     Hue[0.7468198802713419, 1, -5.2721248232499915`], 
     Hue[0.684436368301871, 1, -5.08406664235089], 
     Hue[0.7470383218908423, 1, -4.897231394617854], 
     Hue[0.6844367990229913, 1, -4.709823663975317], 
     Hue[0.7507471651846579, 1, -4.511922106465881], 
     Hue[0.685417408341496, 1, -4.332656261576748], 
     Hue[0.7476737678304235, 1, -4.146856656433493], 
     Hue[0.6854195090978028, 1, -3.9584111512878577`], 
     Hue[0.7511501769280661, 1, -3.762249610012451], 
     Hue[0.6859139889252805, 1, -3.582700972526914], 
     Hue[0.7513567824714461, 1, -3.3874135196298054`], 
     Hue[0.6861691429384644, 1, -3.2077146963050582`], 
     Hue[0.7514730223559491, 1, -3.0128746436141016`], 
     Hue[0.6864060006794259, 1, -2.8328043554012208`], 
     Hue[0.7515969148461583, 1, -2.6383735402708712`], 
     Hue[0.6904079651928217, 1, -2.4467171529131972`], 
     Hue[0.7498709318122216, 1, -2.269516430200471], 
     Hue[0.6905207929811408, 1, -2.0723425482419104`], 
     Hue[0.7534634663416828, 1, -1.8851188829001948`], 
     Hue[0.6907690911780962, 1, -1.6978101974974582`], 
     Hue[0.7538586708975993, 1, -1.510903603103101], 
     Hue[0.691316095089819, 1, -1.3229337507478431`], 
     Hue[0.7547274438318675, 1, -1.136731143674248], 
     Hue[0.6925239200405588, 1, -0.9473141647262713], 
     Hue[0.7566365756409017, 1, -0.7626922347717735], 
     Hue[0.6952039707632759, 1, -0.5701273168634413], 
     Hue[0.7608267591316205, 1, -0.3891366409948114], 
     Hue[0.6958629920840006, 1, -0.20378640748927324`], 
     Hue[0.7706392296977611, 1, -0.015956106075965204`], 
     Hue[0.7043629155868227, 1, 0.17218226851727636`], 
     Hue[0.7968394587382892, 1, 0.3590182721201829], 
     Hue[0.7235096818859063, 1, 0.5476733311046049], 
     Hue[0.8627317418226451, 1, -17.27618334189528], 
     Hue[0.8000343412651784, 1, -17.089062133554293`], 
     Hue[0.85982341513663, 1, -16.91062086407678], 
     Hue[0.8000343412651784, 1, -16.714819716872324`], 
     Hue[0.85982341513663, 1, -16.53637844739481], 
     Hue[0.8000343412651784, 1, -16.34057730019035], 
     Hue[0.8602979315959273, 1, -16.16071983016143], 
     Hue[0.8000343412651785, 1, -15.966334883508381`], 
     Hue[0.8606538189404009, 1, -15.7854152630659], 
     Hue[0.8000343412651785, 1, -15.592092466826411`], 
     Hue[0.8645685797296022, 1, -15.399489191834807`], 
     Hue[0.8000343412651786, 1, -15.217850050144438`], 
     Hue[0.8645685797296023, 1, -15.025246775152837`], 
     Hue[0.8000343412651788, 1, -14.843607633462467`], 
     Hue[0.8645685797296025, 1, -14.651004358470864`], 
     Hue[0.8000343412651794, 1, -14.469365216780497`], 
     Hue[0.8645685797296032, 1, -14.276761941788898`], 
     Hue[0.8000343412651805, 1, -14.095122800098528`], 
     Hue[0.8645685797296047, 1, -13.90251952510693], 
     Hue[0.8019936350326048, 1, -13.715032845655903`], 
     Hue[0.8654869986830857, 1, -13.525536075099662`], 
     Hue[0.8019936350326105, 1, -13.340790428973937`], 
     Hue[0.8654869986830924, 1, -13.151293658417709`], 
     Hue[0.8019936350326231, 1, -12.96654801229198], 
     Hue[0.8654869986831072, 1, -12.777051241735778`], 
     Hue[0.8019936350326506, 1, -12.592305595610036`], 
     Hue[0.8654869986831397, 1, -12.402808825053892`], 
     Hue[0.8019936350327115, 1, -12.218063178928126`], 
     Hue[0.8654869986832112, 1, -12.02856640837211], 
     Hue[0.8029732819165563, 1, -11.84089699336597], 
     Hue[0.8659462081601081, 1, -11.652953475027903`], 
     Hue[0.8029732819168514, 1, -11.466654576684302`], 
     Hue[0.8659462081604541, 1, -11.278711058346854`], 
     Hue[0.8029732819175, 1, -11.092412160003], 
     Hue[0.8659462081612147, 1, -10.90446864166691], 
     Hue[0.8034631053607865, 1, -10.71670785888237], 
     Hue[0.8680203042994955, 1, -10.524036058063302`], 
     Hue[0.8038304729453288, 1, -10.341369028873604`], 
     Hue[0.8681867677384967, 1, -10.149296829101225`], 
     Hue[0.8078715163477592, 1, -9.955066065568866], 
     Hue[0.8682422555583666, 1, -9.77488880834472], 
     Hue[0.8078715163632187, 1, -9.580823648904454], 
     Hue[0.8682422555761684, 1, -9.400646391711549], 
     Hue[0.80787151639721, 1, -9.206581232261087], 
     Hue[0.8682422556153095, 1, -9.026403975136875], 
     Hue[0.8078715164719475, 1, -8.832338815663997], 
     Hue[0.8700178656782217, 1, -8.646862227605364], 
     Hue[0.8078715166362751, 1, -8.458096399168657], 
     Hue[0.8700178658675963, 1, -8.272619811454263], 
     Hue[0.8078715169975866, 1, -8.083853982897036], 
     Hue[0.8700178662839798, 1, -7.898377395939531], 
     Hue[0.807871517792012, 1, -7.709611567117311], 
     Hue[0.8700178671994936, 1, -7.524134981823997], 
     Hue[0.8078715195387371, 1, -7.3353691524191325`], 
     Hue[0.8700178692124587, 1, -7.14989257078492], 
     Hue[0.8078715233793096, 1, -6.961126740098988], 
     Hue[0.8709056786292944, 1, -6.7730005012251935`], 
     Hue[0.8078715318236815, 1, -6.586884333007477], 
     Hue[0.8709056883637876, 1, -6.398758112138339], 
     Hue[0.8098308444156866, 1, -6.2067944013945], 
     Hue[0.8717782077827577, 1, -6.021911775727403], 
     Hue[0.8098308855480985, 1, -5.832552033165893], 
     Hue[0.8717782548547833, 1, -5.647669493956861], 
     Hue[0.8098309759870329, 1, -5.458309723019759], 
     Hue[0.8722146073754274, 1, -5.272125386127475], 
     Hue[0.8098311748374603, 1, -5.084067540581513], 
     Hue[0.8724329594833646, 1, -4.897232633260006], 
     Hue[0.8098316120546681, 1, -4.709825638939859], 
     Hue[0.8761415766202685, 1, -4.5119248677464485`], 
     Hue[0.8108122267994169, 1, -4.332660631198852], 
     Hue[0.8730677672323204, 1, -4.146862658870014], 
     Hue[0.810814348302547, 1, -3.958420758899046], 
     Hue[0.8765430781542553, 1, -3.7622629781353663`], 
     Hue[0.8113088519879649, 1, -3.582722162840202], 
     Hue[0.8767473883693108, 1, -3.387442932612399], 
     Hue[0.8115640554007812, 1, -3.207761360391303], 
     Hue[0.8768585784267926, 1, -3.0129393330218397`], 
     Hue[0.8118277870533418, 1, -2.832827178868631], 
     Hue[0.8769822259995349, 1, -2.638483336440718], 
     Hue[0.8158012528223278, 1, -2.4469486842918258`], 
     Hue[0.875274247368417, 1, -2.269673071518258], 
     Hue[0.8159121465179084, 1, -2.072851608471626], 
     Hue[0.8787561817548364, 1, -1.885809691381479], 
     Hue[0.816155732746651, 1, -1.6989294100298966`], 
     Hue[0.8790281560728984, 1, -1.5124196907209317`], 
     Hue[0.8166901560617514, 1, -1.3253942062547603`], 
     Hue[0.8796227323805783, 1, -1.1400509734220245`], 
     Hue[0.8178595958458809, 1, -0.9527217479535064], 
     Hue[0.882564668529231, 1, -0.7651433569619199], 
     Hue[0.8223924930574644, 1, -0.5764069514087227], 
     Hue[0.8909227347470892, 1, -0.38443526055469923`], 
     Hue[0.8319089531267291, 1, -0.19996332257282368`], 
     Hue[0.9024532490233156, 1, -0.0161567635135611], 
     Hue[0.8512332746645423, 1, 0.17108528363573772`], 
     Hue[0.9339569236851429, 1, 0.358579024010261], 
     Hue[0.9058350366603488, 1, 0.5462541738117113], 
     Hue[0.8929899761048662, 1, 0.7339498397087789], 
     Hue[0.9707552524132671, 1, 0.9216518650604378], 
     Hue[0.9881265429375768, 1, -17.27618334189528], 
     Hue[0.9254291423801101, 1, -17.089062133554293`], 
     Hue[0.9852182162515617, 1, -16.91062086407678], 
     Hue[0.9254291423801101, 1, -16.714819716872324`], 
     Hue[0.9852182162515617, 1, -16.53637844739481], 
     Hue[0.9254291423801101, 1, -16.34057730019035], 
     Hue[0.985692732710859, 1, -16.16071983016143], 
     Hue[0.9254291423801102, 1, -15.966334883508381`], 
     Hue[0.986048620055332, 1, -15.7854152630659], 
     Hue[0.9254291423801102, 1, -15.592092466826411`], 
     Hue[0.9899633808445338, 1, -15.399489191834807`], 
     Hue[0.9254291423801102, 1, -15.217850050144438`], 
     Hue[0.9899633808445338, 1, -15.025246775152837`], 
     Hue[0.9254291423801103, 1, -14.843607633462467`], 
     Hue[0.9899633808445338, 1, -14.651004358470868`], 
     Hue[0.9254291423801106, 1, -14.469365216780501`], 
     Hue[0.989963380844534, 1, -14.276761941788898`], 
     Hue[0.9254291423801112, 1, -14.095122800098533`], 
     Hue[0.9899633808445341, 1, -13.902519525106934`], 
     Hue[0.9273884361475334, 1, -13.715032845655912`], 
     Hue[0.9908817997980116, 1, -13.52553607509967], 
     Hue[0.927388436147536, 1, -13.340790428973957`], 
     Hue[0.9908817997980122, 1, -13.151293658417725`], 
     Hue[0.927388436147542, 1, -12.966548012292023`], 
     Hue[0.9908817997980133, 1, -12.777051241735814`], 
     Hue[0.9273884361475547, 1, -12.592305595610128`], 
     Hue[0.9908817997980157, 1, -12.402808825053972`], 
     Hue[0.927388436147583, 1, -12.218063178928329`], 
     Hue[0.9908817997980213, 1, -12.028566408372287`], 
     Hue[0.9283680830313547, 1, -11.840896993366414`], 
     Hue[0.9913410092747729, 1, -11.652953475028287`], 
     Hue[0.9283680830314904, 1, -11.466654576685283`], 
     Hue[0.9913410092747981, 1, -11.2787110583477], 
     Hue[0.9283680830317891, 1, -11.092412160005157`], 
     Hue[0.9913410092748536, 1, -10.904468641668766`], 
     Hue[0.9288579064742972, 1, -10.71670785888711], 
     Hue[0.9934151054115287, 1, -10.524036058067326`], 
     Hue[0.9292252740571202, 1, -10.34136902888403], 
     Hue[0.9935815688470447, 1, -10.14929682911006], 
     Hue[0.9332663174554116, 1, -9.955066065591835], 
     Hue[0.9936370566592537, 1, -9.774888808364143], 
     Hue[0.9332663174621457, 1, -9.580823648954956], 
     Hue[0.9936370566602198, 1, -9.400646391754254], 
     Hue[0.9332663174769524, 1, -9.206581232372125], 
     Hue[0.993637056662344, 1, -9.026403975230773], 
     Hue[0.9332663175095083, 1, -8.83233881590814], 
     Hue[0.9954126666414198, 1, -8.646862227809098], 
     Hue[0.9332663175810898, 1, -8.45809639970546], 
     Hue[0.9954126666489074, 1, -8.272619811902215], 
     Hue[0.933266317738478, 1, -8.083853984077319], 
     Hue[0.9954126666653704, 1, -7.898377396924459], 
     Hue[0.9332663180845318, 1, -7.709611569712432], 
     Hue[0.9954126667015682, 1, -7.524134983989584], 
     Hue[0.9332663188454097, 1, -7.3353691581251], 
     Hue[0.9954126667811573, 1, -7.149892575546457], 
     Hue[0.9332663205183728, 1, -6.961126752644851], 
     Hue[0.9963004718838545, 1, -6.773000511622378], 
     Hue[0.9332663241967625, 1, -6.5868843605924114`], 
     Hue[0.9963004721959056, 1, -6.398758134998909], 
     Hue[0.935225625819792, 1, -6.2067944620779345`], 
     Hue[0.9971729705963452, 1, -6.021911825641953], 
     Hue[0.9352256433242943, 1, -5.832552166592179], 
     Hue[0.997172971755521, 1, -5.647669603705278], 
     Hue[0.9352256818118929, 1, -5.4583100163875695`], 
     Hue[0.9976092225966442, 1, -5.272125626576476], 
     Hue[0.9352257664354815, 1, -5.084068185616265], 
     Hue[0.9978273510659641, 1, -4.8972331609904876`], 
     Hue[0.9352259524989567, 1, -4.709827057190104], 
     Hue[1.001535447041844, 1, -4.511925991019397], 
     Hue[0.9362060023194774, 1, -4.332663749990121], 
     Hue[0.9984605772311618, 1, -4.146865196618845], 
     Hue[0.9362068944130589, 1, -3.95842761614366], 
     Hue[1.0019333642132922`, 1, -3.7622683881122576`], 
     Hue[0.9366986641056354, 1, -3.582737240150795], 
     Hue[1.0021322450482337`, 1, -3.387454804486029], 
     Hue[0.9369478530630877, 1, -3.2077945088354554`], 
     Hue[1.002231496957481, 1, -3.0129654068316025`], 
     Hue[0.9411201143659921, 1, -2.82119789656722], 
     Hue[1.0002036668943128`, 1, -2.6448833582406506`], 
     Hue[0.9411400276389253, 1, -2.4471087573973715`], 
     Hue[1.0006100200058798`, 1, -2.2696661283632382`], 
     Hue[0.9411837663430552, 1, -2.0732032084639895`], 
     Hue[1.003915236685541, 1, -1.8860814534157695`], 
     Hue[0.9412797180668261, 1, -1.699700758774526], 
     Hue[1.0039055563979167`, 1, -1.5130146754771856`], 
     Hue[0.9414896426573047, 1, -1.327081887542491], 
     Hue[1.003884439472345, 1, -1.141346987147083], 
     Hue[0.9438886083231808, 1, -0.9506560040683303], 
     Hue[1.0062031624950107`, 1, -0.765650764396689], 
     Hue[0.946289540424239, 1, -0.5800700219181301], 
     Hue[1.0111480782169489`, 1, -0.3883805286436708], 
     Hue[0.9552694122678155, 1, -0.2029203144159759], 
     Hue[1.0193645775763565`, 1, -0.013944719016138363`], 
     Hue[0.9726289437812898, 1, 0.17196826491380068`], 
     Hue[1.033953049075245, 1, 0.3584281153537824], 
     Hue[1.0056842677387139`, 1, 0.546865153727023], 
     Hue[0.9966080311599782, 1, 0.733841109968201], 
     Hue[1.009850125345798, 1, 0.9215911979969826], 
     Hue[1.1135213440525087`, 1, -17.27618334189528], 
     Hue[1.050823943495042, 1, -17.089062133554293`], 
     Hue[1.110613017366493, 1, -16.91062086407678], 
     Hue[1.050823943495042, 1, -16.714819716872324`], 
     Hue[1.110613017366493, 1, -16.53637844739481], 
     Hue[1.050823943495042, 1, -16.34057730019035], 
     Hue[1.1110875338257908`, 1, -16.16071983016143], 
     Hue[1.050823943495042, 1, -15.966334883508381`], 
     Hue[1.1114434211702637`, 1, -15.7854152630659], 
     Hue[1.050823943495042, 1, -15.592092466826411`], 
     Hue[1.115358181959465, 1, -15.399489191834807`], 
     Hue[1.0508239434950417`, 1, -15.217850050144438`], 
     Hue[1.115358181959465, 1, -15.025246775152837`], 
     Hue[1.0508239434950417`, 1, -14.843607633462467`], 
     Hue[1.1153581819594645`, 1, -14.651004358470864`], 
     Hue[1.0508239434950415`, 1, -14.469365216780501`], 
     Hue[1.115358181959464, 1, -14.276761941788898`], 
     Hue[1.050823943495041, 1, -14.095122800098533`], 
     Hue[1.1153581819594627`, 1, -13.90251952510693], 
     Hue[1.0527832372624613`, 1, -13.715032845655912`], 
     Hue[1.116276600912938, 1, -13.525536075099664`], 
     Hue[1.0527832372624593`, 1, -13.340790428973957`], 
     Hue[1.116276600912932, 1, -13.151293658417712`], 
     Hue[1.052783237262455, 1, -12.966548012292026`], 
     Hue[1.1162766009129188`, 1, -12.777051241735787`], 
     Hue[1.0527832372624455`, 1, -12.592305595610137`], 
     Hue[1.1162766009128897`, 1, -12.402808825053912`], 
     Hue[1.0527832372624246`, 1, -12.218063178928347`], 
     Hue[1.1162766009128258`, 1, -12.028566408372154`], 
     Hue[1.0537628841460869`, 1, -11.840896993366448`], 
     Hue[1.116735810389424, 1, -11.652953475027992`], 
     Hue[1.0537628841459834`, 1, -11.466654576685356`], 
     Hue[1.1167358103891136`, 1, -11.27871105834705], 
     Hue[1.053762884145756, 1, -11.092412160005317`], 
     Hue[1.1167358103884313`, 1, -10.90446864166734], 
     Hue[1.0542527075871007`, 1, -10.716707858887448`], 
     Hue[1.1188099065234591`, 1, -10.52403605806403], 
     Hue[1.0546200751673604`, 1, -10.34136902888474], 
     Hue[1.1189763699553736`, 1, -10.149296829102786`], 
     Hue[1.0586611185597539`, 1, -9.955066065592636], 
     Hue[1.1190318577596658`, 1, -9.77488880834813], 
     Hue[1.0586611185537944`, 1, -9.580823648956718], 
     Hue[1.119031857743227, 1, -9.400646391719047], 
     Hue[1.058661118540691, 1, -9.206581232376001], 
     Hue[1.1190318577070824`, 1, -9.02640397515336], 
     Hue[1.05866111851188, 1, -8.83233881591666], 
     Hue[1.1208074676009365`, 1, -8.646862227631793], 
     Hue[1.0586611184485324`, 1, -8.458096399724196], 
     Hue[1.1208074674221244`, 1, -8.272619811512373], 
     Hue[1.0586611183092487`, 1, -8.083853984118516], 
     Hue[1.1208074670289654`, 1, -7.898377396067301], 
     Hue[1.0586611180030017`, 1, -7.709611569803012], 
     Hue[1.120807466164516, 1, -7.524134982104926], 
     Hue[1.0586611173296478`, 1, -7.335369158324258], 
     Hue[1.1208074642638273`, 1, -7.149892571402607], 
     Hue[1.0586611158491266`, 1, -6.961126753082746], 
     Hue[1.1216952649850087`, 1, -6.773000502326654], 
     Hue[1.0586611125938636`, 1, -6.586884361555222], 
     Hue[1.1216952556907263`, 1, -6.398758114560146], 
     Hue[1.0606203986186191`, 1, -6.2067944631808585`], 
     Hue[1.1225677328400778`, 1, -6.0219117798189945`], 
     Hue[1.060620382179845, 1, -5.832552169017206], 
     Hue[1.1225676874033044`, 1, -5.647669502953149], 
     Hue[1.0606203460354902`, 1, -5.458310021719538], 
     Hue[1.1230038354816525`, 1, -5.272125402901625], 
     Hue[1.0606202665640487`, 1, -5.08406819733978], 
     Hue[1.1232217379741258`, 1, -4.897232666822949], 
     Hue[1.0606200918287036`, 1, -4.70982708296678], 
     Hue[1.1269293248981733`, 1, -4.5119248143636685`], 
     Hue[1.061599339284033, 1, -4.332663780118991], 
     Hue[1.123853371154655, 1, -4.1468627742959105`], 
     Hue[1.0615984763030346`, 1, -3.958427682387077], 
     Hue[1.127323695639026, 1, -3.762262652374253], 
     Hue[1.0620863652956474`, 1, -3.5827373210315105`], 
     Hue[1.1275172118614574`, 1, -3.3874421417039136`], 
     Hue[1.062327020272426, 1, -3.20779461512865], 
     Hue[1.1276046690087944`, 1, -3.0129375120286905`], 
     Hue[1.0664796448755847`, 1, -2.8211953828371996`], 
     Hue[1.125551266618166, 1, -2.6448246148465966`], 
     Hue[1.0664573030652207`, 1, -2.4471032339209815`], 
     Hue[1.1258557759232763`, 1, -2.2696708669184265`], 
     Hue[1.066408229182817, 1, -2.073191080889691], 
     Hue[1.1290790483330233`, 1, -1.8857753961200177`], 
     Hue[1.0663005686443607`, 1, -1.6996741756850058`], 
     Hue[1.1287933272391546`, 1, -1.512344548481961], 
     Hue[1.066065004547899, 1, -1.3270238329204729`], 
     Hue[1.1281685277953195`, 1, -1.1398870237839624`], 
     Hue[1.0674737636816778`, 1, -0.950463129430904], 
     Hue[1.1275826528024915`, 1, -0.7671943266832775], 
     Hue[1.0677358154003673`, 1, -0.5795504140030467], 
     Hue[1.1278152933727046`, 1, -0.3914488252842139], 
     Hue[1.0710501000490755`, 1, -0.20351395496755753`], 
     Hue[1.127687881598822, 1, -0.014487325862295508`], 
     Hue[1.0761444988989024`, 1, 0.17176365425194773`], 
     Hue[1.1239232077679968`, 1, 0.3591722152258735], 
     Hue[1.0811137532264739`, 1, 0.5461409347262297], 
     Hue[1.0523499559989662`, 1, 0.7345935375572732], 
     Hue[1.0357432650319895`, 1, 0.9217041723531835], 
     Hue[1.2389161451674398`, 1, -17.27618334189528], 
     Hue[1.1762187446099737`, 1, -17.089062133554293`], 
     Hue[1.2360078184814247`, 1, -16.91062086407678], 
     Hue[1.1762187446099737`, 1, -16.714819716872324`], 
     Hue[1.2360078184814247`, 1, -16.53637844739481], 
     Hue[1.1762187446099737`, 1, -16.34057730019035], 
     Hue[1.236482334940722, 1, -16.16071983016143], 
     Hue[1.1762187446099737`, 1, -15.966334883508381`], 
     Hue[1.2368382222851955`, 1, -15.7854152630659], 
     Hue[1.1762187446099734`, 1, -15.592092466826411`], 
     Hue[1.2407529830743966`, 1, -15.399489191834807`], 
     Hue[1.1762187446099734`, 1, -15.217850050144438`], 
     Hue[1.2407529830743964`, 1, -15.025246775152837`], 
     Hue[1.1762187446099732`, 1, -14.843607633462467`], 
     Hue[1.240752983074396, 1, -14.651004358470864`], 
     Hue[1.1762187446099728`, 1, -14.469365216780497`], 
     Hue[1.2407529830743953`, 1, -14.276761941788894`], 
     Hue[1.1762187446099714`, 1, -14.09512280009853], 
     Hue[1.2407529830743933`, 1, -13.902519525106923`], 
     Hue[1.17817803837739, 1, -13.715032845655905`], 
     Hue[1.2416714020278672`, 1, -13.52553607509965], 
     Hue[1.1781780383773848`, 1, -13.340790428973941`], 
     Hue[1.241671402027858, 1, -13.151293658417677`], 
     Hue[1.1781780383773728`, 1, -12.96654801229199], 
     Hue[1.2416714020278383`, 1, -12.77705124173571], 
     Hue[1.1781780383773466`, 1, -12.592305595610053`], 
     Hue[1.241671402027795, 1, -12.402808825053746`], 
     Hue[1.1781780383772888`, 1, -12.218063178928167`], 
     Hue[1.2416714020276995`, 1, -12.02856640837179], 
     Hue[1.1791576852608698`, 1, -11.840896993366048`], 
     Hue[1.2421306115042285`, 1, -11.652953475027193`], 
     Hue[1.1791576852605883`, 1, -11.46665457668448], 
     Hue[1.2421306115037654`, 1, -11.27871105834529], 
     Hue[1.1791576852599688`, 1, -11.092412160003391`], 
     Hue[1.2421306115027473`, 1, -10.904468641663469`], 
     Hue[1.1796475087004512`, 1, -10.716707858883181`], 
     Hue[1.2442047076370568`, 1, -10.524036058055358`], 
     Hue[1.1800148762788147`, 1, -10.341369028875317`], 
     Hue[1.2443711710673762`, 1, -10.149296829083688`], 
     Hue[1.184055919667026, 1, -9.955066065570799], 
     Hue[1.2444266588681594`, 1, -9.77488880830612], 
     Hue[1.1840559196518847`, 1, -9.580823648908703], 
     Hue[1.2444266588440032`, 1, -9.400646391626672], 
     Hue[1.184055919618593, 1, -9.20658123227043], 
     Hue[1.2444266587908897`, 1, -9.026403974950256], 
     Hue[1.1840559195453932`, 1, -8.832338815684539], 
     Hue[1.2462022686483585`, 1, -8.646862227177937], 
     Hue[1.1840559193844475`, 1, -8.458096399213826], 
     Hue[1.2462022683886205`, 1, -8.272619810514467], 
     Hue[1.1840559190305715`, 1, -8.083853982996345], 
     Hue[1.2462022678175277`, 1, -7.898377393873177], 
     Hue[1.1840559182524948`, 1, -7.70961156733567], 
     Hue[1.2462022665618502`, 1, -7.524134977280647], 
     Hue[1.184055916541716, 1, -7.335369152899244], 
     Hue[1.2462022638009573`, 1, -7.149892560795334], 
     Hue[1.1840559127801795`, 1, -6.961126741154621], 
     Hue[1.2470900626552675`, 1, -6.7730004788159786`], 
     Hue[1.1840559045095864`, 1, -6.586884335328526], 
     Hue[1.2470900492317598`, 1, -6.398758062866583], 
     Hue[1.186015179498808, 1, -6.20679440405332], 
     Hue[1.2479625174206963`, 1, -6.021911665261907], 
     Hue[1.186015138804093, 1, -5.8325520390119125`], 
     Hue[1.2479624521637636`, 1, -5.647669251073408], 
     Hue[1.1860150493275352`, 1, -5.458309735873556], 
     Hue[1.2483985569538185`, 1, -5.27212484691336], 
     Hue[1.1860148525931207`, 1, -5.084067568843481], 
     Hue[1.2486163642978942`, 1, -4.89723144196538], 
     Hue[1.186014420028485, 1, -4.709825701080085], 
     Hue[1.2523237542570471`, 1, -4.511922031157854], 
     Hue[1.1869931004922671`, 1, -4.3326607038315], 
     Hue[1.249247331802314, 1, -4.146856819269032], 
     Hue[1.186990990946918, 1, -3.9584209185967048`], 
     Hue[1.2527167062395141`, 1, -3.762249150434892], 
     Hue[1.1874761389946764`, 1, -3.5827223578317646`], 
     Hue[1.2529080833069814`, 1, -3.387412403755384], 
     Hue[1.1877107674477445`, 1, -3.2077616166681127`], 
     Hue[1.2529908364790001`, 1, -3.0128720740332087`], 
     Hue[1.187929196528651, 1, -2.83282736797453], 
     Hue[1.2530519435177259`, 1, -2.6383351744441965`], 
     Hue[1.1917987004043322`, 1, -2.446935359644825], 
     Hue[1.2511565091608658`, 1, -2.2695136015582777`], 
     Hue[1.1916856037891166`, 1, -2.072822328143981], 
     Hue[1.2543832785141167`, 1, -1.8850703601564158`], 
     Hue[1.1914371520206488`, 1, -1.6988651125728904`], 
     Hue[1.2539880415061035`, 1, -1.5107969139396473`], 
     Hue[1.1908919255823294`, 1, -1.3252532312603915`], 
     Hue[1.2531188568465204`, 1, -1.1364965692275788`], 
     Hue[1.1896982333929855`, 1, -0.9524137162862412], 
     Hue[1.2512071750500722`, 1, -0.7621766063252211], 
     Hue[1.1889749902430837`, 1, -0.5753828057291293], 
     Hue[1.2477601308886999`, 1, -0.38551569275947184`], 
     Hue[1.1846155575742656`, 1, -0.20380380866706682`], 
     Hue[1.2376004137705086`, 1, -0.015755746639329216`], 
     Hue[1.1772217645777465`, 1, 0.17183686938091103`], 
     Hue[1.2194644805727846`, 1, 0.3585076736191668], 
     Hue[1.159837762792744, 1, 0.5462057873354584], 
     Hue[1.1828087913782317`, 1, 0.7342532010767333], 
     Hue[1.1098483196950726`, 1, 0.7339114836736973], 
     Hue[1.1171749786178438`, 1, 0.9220579795470193], 
     Hue[1.0685017144297513`, 1, 0.9216024527347425], 
     Hue[1.3643109462823715`, 1, -17.27618334189528], 
     Hue[1.3016135457249054`, 1, -17.089062133554293`], 
     Hue[1.3614026195963564`, 1, -16.91062086407678], 
     Hue[1.3016135457249054`, 1, -16.714819716872324`], 
     Hue[1.3614026195963564`, 1, -16.53637844739481], 
     Hue[1.3016135457249054`, 1, -16.34057730019035], 
     Hue[1.3618771360556536`, 1, -16.16071983016143], 
     Hue[1.3016135457249054`, 1, -15.966334883508381`], 
     Hue[1.3622330234001265`, 1, -15.7854152630659], 
     Hue[1.3016135457249052`, 1, -15.592092466826411`], 
     Hue[1.3661477841893284`, 1, -15.399489191834807`], 
     Hue[1.3016135457249052`, 1, -15.217850050144438`], 
     Hue[1.3661477841893281`, 1, -15.025246775152837`], 
     Hue[1.301613545724905, 1, -14.843607633462467`], 
     Hue[1.366147784189328, 1, -14.651004358470864`], 
     Hue[1.3016135457249043`, 1, -14.469365216780497`], 
     Hue[1.3661477841893275`, 1, -14.276761941788891`], 
     Hue[1.3016135457249032`, 1, -14.095122800098524`], 
     Hue[1.366147784189326, 1, -13.902519525106916`], 
     Hue[1.303572839492321, 1, -13.715032845655893`], 
     Hue[1.3670662031428003`, 1, -13.525536075099632`], 
     Hue[1.3035728394923154`, 1, -13.340790428973916`], 
     Hue[1.3670662031427936`, 1, -13.151293658417643`], 
     Hue[1.3035728394923027`, 1, -12.966548012291932`], 
     Hue[1.367066203142779, 1, -12.777051241735633`], 
     Hue[1.3035728394922752`, 1, -12.592305595609933`], 
     Hue[1.3670662031427467`, 1, -12.402808825053574`], 
     Hue[1.3035728394922148`, 1, -12.218063178927897`], 
     Hue[1.367066203142676, 1, -12.028566408371411`], 
     Hue[1.3045524863757914`, 1, -11.840896993365453`], 
     Hue[1.3675254126192604`, 1, -11.652953475026358`], 
     Hue[1.3045524863754974`, 1, -11.46665457668317], 
     Hue[1.3675254126189176`, 1, -11.278711058343458`], 
     Hue[1.304552486374851, 1, -11.09241216000051], 
     Hue[1.3675254126181637`, 1, -10.904468641659436`], 
     Hue[1.30504230981528, 1, -10.716707858876829`], 
     Hue[1.3695995087531077`, 1, -10.52403605804642], 
     Hue[1.3054096773935313`, 1, -10.341369028861314`], 
     Hue[1.3697659721847777`, 1, -10.14929682906402], 
     Hue[1.309450720781741, 1, -9.955066065539192], 
     Hue[1.369821459988528, 1, -9.774888808262864], 
     Hue[1.3094507207663408`, 1, -9.580823648839207], 
     Hue[1.3698214599708893`, 1, -9.400646391531568], 
     Hue[1.3094507207324795`, 1, -9.206581232117626], 
     Hue[1.3698214599321068`, 1, -9.02640397474115], 
     Hue[1.3094507206580277`, 1, -8.832338815348564], 
     Hue[1.3715970698234685`, 1, -8.646862226714987], 
     Hue[1.3094507204943286`, 1, -8.458096398475107], 
     Hue[1.3715970696358681`, 1, -8.272619809496563], 
     Hue[1.3094507201343992`, 1, -8.083853981372107], 
     Hue[1.3715970692233856`, 1, -7.898377391635086], 
     Hue[1.3094507193430125`, 1, -7.709611563764407], 
     Hue[1.3715970683164493`, 1, -7.524134972359692], 
     Hue[1.3094507176029686`, 1, -7.3353691450470135`], 
     Hue[1.3715970663223436`, 1, -7.149892549975497], 
     Hue[1.3094507137770863`, 1, -6.961126723889705], 
     Hue[1.3724848669245726`, 1, -6.7730004549451674`], 
     Hue[1.3094507053650135`, 1, -6.586884297367683], 
     Hue[1.3724848572822979`, 1, -6.3987580103811705`], 
     Hue[1.311409980384671, 1, -6.206794319539088], 
     Hue[1.3733573340818657`, 1, -6.0219115494790145`], 
     Hue[1.3114099394153487`, 1, -5.832551853188149], 
     Hue[1.3733572874606106`, 1, -5.647668996498312], 
     Hue[1.311409849334944, 1, -5.458309327297745], 
     Hue[1.37379343394684, 1, -5.272124286254001], 
     Hue[1.3114096512725373`, 1, -5.0840666704966395`], 
     Hue[1.3740113330429886`, 1, -4.897230208220395], 
     Hue[1.3114092157865782`, 1, -4.709823725860289], 
     Hue[1.3777189542017525`, 1, -4.511919281519849], 
     Hue[1.3123878987598436`, 1, -4.332656333911772], 
     Hue[1.3746429544957361`, 1, -4.146850840721495], 
     Hue[1.3123857857585857`, 1, -3.958411310334638], 
     Hue[1.37811345134827, 1, -3.762235838452985], 
     Hue[1.312870947851876, 1, -3.582701166733221], 
     Hue[1.378307176034856, 1, -3.387383112671217], 
     Hue[1.3131056086640962`, 1, -3.2077149515771897`], 
     Hue[1.378395091526917, 1, -3.0128076432516435`], 
     Hue[1.3132973500294438`, 1, -2.832804585303018], 
     Hue[1.3784566833203218`, 1, -2.6382259332712854`], 
     Hue[1.317195693794932, 1, -2.4467038701687], 
     Hue[1.376492030058503, 1, -2.2695126290111647`], 
     Hue[1.317085105367894, 1, -2.0723133258665216`], 
     Hue[1.3798818118245597`, 1, -1.8843804514095266`], 
     Hue[1.3168417091397417`, 1, -1.6977458622172092`], 
     Hue[1.379610068962326, 1, -1.5092771436411792`], 
     Hue[1.3163053771935334`, 1, -1.3227918937167906`], 
     Hue[1.3756504395865172`, 1, -1.1433046650225285`], 
     Hue[1.3151204948623845`, 1, -0.9470003323210519], 
     Hue[1.3735373898358505`, 1, -0.7674531794449262], 
     Hue[1.3105643224580978`, 1, -0.5755260038767549], 
     Hue[1.3688052990881527`, 1, -0.3899903985028417], 
     Hue[1.301891117668507, 1, -0.2042281256019538], 
     Hue[1.3570582395580024`, 1, -0.013663495843715845`], 
     Hue[1.4104613039106684`, 1, 0.17268045951436428`], 
     Hue[1.2860201791240815`, 1, 0.1708939574401961], 
     Hue[1.3310006574448912`, 1, 0.3587108376963509], 
     Hue[1.3735445271175393`, 1, 0.5464678054671753], 
     Hue[1.254104500151374, 1, 0.5461387660826678], 
     Hue[1.2811325092983878`, 1, 0.733936616379938], 
     Hue[1.3010210180066342`, 1, 0.9216408134968229], 
     Hue[1.3143641147374716`, 1, 1.109526264889492], 
     Hue[1.1913012795043756`, 1, 0.9220612268138512], 
     Hue[1.1822631478615317`, 1, 1.1094463738191478`], 
     Hue[1.1437529400735107`, 1, 1.2971778139421593`], 
     Hue[1.0930176959740552`, 1, 1.1092985778503137`], 
     Hue[1.02900864527345, 1, 1.1093962405271682`], 
     Hue[1.4897057473973032`, 1, -17.27618334189528], 
     Hue[1.4270083468398365`, 1, -17.089062133554293`], 
     Hue[1.4867974207112875`, 1, -16.91062086407678], 
     Hue[1.4270083468398365`, 1, -16.714819716872324`], 
     Hue[1.4867974207112875`, 1, -16.53637844739481], 
     Hue[1.4270083468398365`, 1, -16.34057730019035], 
     Hue[1.4872719371705854`, 1, -16.16071983016143], 
     Hue[1.4270083468398365`, 1, -15.966334883508381`], 
     Hue[1.4876278245150585`, 1, -15.7854152630659], 
     Hue[1.4270083468398365`, 1, -15.592092466826411`], 
     Hue[1.4915425853042596`, 1, -15.399489191834807`], 
     Hue[1.4270083468398365`, 1, -15.217850050144438`], 
     Hue[1.4915425853042596`, 1, -15.025246775152837`], 
     Hue[1.4270083468398362`, 1, -14.843607633462467`], 
     Hue[1.4915425853042596`, 1, -14.65100435847086], 
     Hue[1.427008346839836, 1, -14.469365216780494`], 
     Hue[1.4915425853042596`, 1, -14.276761941788891`], 
     Hue[1.4270083468398356`, 1, -14.095122800098519`], 
     Hue[1.4915425853042594`, 1, -13.902519525106912`], 
     Hue[1.4289676406072553`, 1, -13.715032845655884`], 
     Hue[1.4924610042577373`, 1, -13.525536075099625`], 
     Hue[1.4289676406072527`, 1, -13.340790428973897`], 
     Hue[1.4924610042577369`, 1, -13.151293658417627`], 
     Hue[1.4289676406072471`, 1, -12.966548012291891`], 
     Hue[1.4924610042577358`, 1, -12.777051241735599`], 
     Hue[1.4289676406072345`, 1, -12.592305595609842`], 
     Hue[1.4924610042577338`, 1, -12.402808825053496`], 
     Hue[1.4289676406072067`, 1, -12.218063178927697`], 
     Hue[1.4924610042577293`, 1, -12.02856640837124], 
     Hue[1.4299472874908568`, 1, -11.84089699336501], 
     Hue[1.4929202137344604`, 1, -11.652953475025983`], 
     Hue[1.4299472874907238`, 1, -11.466654576682199`], 
     Hue[1.49292021373444, 1, -11.278711058342628`], 
     Hue[1.4299472874904313`, 1, -11.092412159998375`], 
     Hue[1.4929202137343944`, 1, -10.904468641657617`], 
     Hue[1.4304371109316483`, 1, -10.71670785887213], 
     Hue[1.4949943098709513`, 1, -10.52403605804248], 
     Hue[1.4308044785116374`, 1, -10.341369028850982`], 
     Hue[1.4951607733061223`, 1, -10.149296829055373`], 
     Hue[1.4348455219040277`, 1, -9.955066065516439], 
     Hue[1.4952162611175681`, 1, -9.774888808243858], 
     Hue[1.4348455218974436`, 1, -9.580823648789183], 
     Hue[1.4952162611168418`, 1, -9.400646391489781], 
     Hue[1.4348455218829672`, 1, -9.206581232007636], 
     Hue[1.4952162611152446`, 1, -9.026403974649266], 
     Hue[1.4348455218511378`, 1, -8.832338815106723], 
     Hue[1.4969918710908032`, 1, -8.646862226515756], 
     Hue[1.4348455217811533`, 1, -8.458096397943367], 
     Hue[1.4969918710858927`, 1, -8.272619809058511], 
     Hue[1.4348455216272764`, 1, -8.083853980202958], 
     Hue[1.4969918710750965`, 1, -7.8983773906719295`], 
     Hue[1.434845521288943, 1, -7.709611561193767], 
     Hue[1.496991871051358, 1, -7.524134970241975], 
     Hue[1.43484552054504, 1, -7.335369139394877], 
     Hue[1.4969918709991634`, 1, -7.149892545319209], 
     Hue[1.4348455189094, 1, -6.961126711462195], 
     Hue[1.497879675934056, 1, -6.773000444781262], 
     Hue[1.4348455153130737`, 1, -6.586884270042973], 
     Hue[1.4978796757551982`, 1, -6.398757988033513], 
     Hue[1.4368048014112058`, 1, -6.2067942594423045`], 
     Hue[1.4987521736622196`, 1, -6.021911500701088], 
     Hue[1.4368047843104692`, 1, -5.832551721051653], 
     Hue[1.498752173150547, 1, -5.64766888924887], 
     Hue[1.4368047467105787`, 1, -5.458309036765369], 
     Hue[1.499188421746159, 1, -5.272124051320402], 
     Hue[1.436804664038517, 1, -5.084066031694008], 
     Hue[1.4994065454266734`, 1, -4.897229692636993], 
     Hue[1.4368044822644641`, 1, -4.709822321302009], 
     Hue[0.503114689709751, 1, -4.511918185831841], 
     Hue[1.4377837357877254`, 1, -4.332653245548408], 
     Hue[0.5000397551154614, 1, -4.146848361910234], 
     Hue[1.4377828645638266`, 1, -3.9584045197377993`], 
     Hue[0.503512785544912, 1, -3.7622305617204788`], 
     Hue[1.4382707878460412`, 1, -3.5826862356303826`], 
     Hue[0.5037119618387544, 1, -3.387371532354382], 
     Hue[1.4385115229146859`, 1, -3.2076821195827128`], 
     Hue[0.503811867004583, 1, -3.0127822017528603`], 
     Hue[1.4386860327625055`, 1, -2.8328237845405617`], 
     Hue[0.50388740262357, 1, -2.638207153921199], 
     Hue[1.442647055874347, 1, -2.44654519289643], 
     Hue[0.5019914366985361, 1, -2.2693872978103116`], 
     Hue[1.4426042760025284`, 1, -2.0719640800575476`], 
     Hue[0.5021489439935956, 1, -1.8941557614246973`], 
     Hue[1.4425099997908084`, 1, -1.6969762336196028`], 
     Hue[0.5021541937368043, 1, -1.5187544334981269`], 
     Hue[1.442301667328246, 1, -1.3210912857474864`], 
     Hue[0.5018005773156256, 1, -1.143043728435982], 
     Hue[1.4377638153235701`, 1, -0.9555134587563037], 
     Hue[0.5003280137057897, 1, -0.7675987366207049], 
     Hue[1.434811272847587, 1, -0.5792140623376154], 
     Hue[1.497777057500449, 1, -0.3884309098362113], 
     Hue[1.4271919588252409`, 1, -0.20383911277993416`], 
     Hue[1.4881458621896893`, 1, -0.014387103445581806`], 
     Hue[0.5528208373805228, 1, 0.17259196764356066`], 
     Hue[1.465582228846852, 1, 0.3584126999841668], 
     Hue[0.5281814731293138, 1, 0.5462661580831774], 
     Hue[1.4160600989682333`, 1, 0.7339702492931668], 
     Hue[1.4629514516386657`, 1, 0.9216665988025728], 
     Hue[0.5233597174975431, 1, 1.109502188648886], 
     Hue[1.3215545846732761`, 1, 1.297375590301822], 
     Hue[0.9972897037723811, 1, 1.2970079386666757`], 
     Hue[1.0092985732810411`, 1, 1.1092879424400355`], 
     Hue[0.6151005485122343, 1, -17.27618334189528], 
     Hue[0.5524031479547682, 1, -17.089062133554293`], 
     Hue[0.6121922218262192, 1, -16.91062086407678], 
     Hue[0.5524031479547682, 1, -16.714819716872324`], 
     Hue[0.6121922218262192, 1, -16.53637844739481], 
     Hue[0.5524031479547682, 1, -16.34057730019035], 
     Hue[0.6126667382855171, 1, -16.16071983016143], 
     Hue[0.5524031479547682, 1, -15.966334883508381`], 
     Hue[0.6130226256299902, 1, -15.7854152630659], 
     Hue[0.5524031479547682, 1, -15.592092466826411`], 
     Hue[0.6169373864191914, 1, -15.399489191834807`], 
     Hue[0.5524031479547682, 1, -15.217850050144438`], 
     Hue[0.6169373864191915, 1, -15.025246775152837`], 
     Hue[0.5524031479547683, 1, -14.843607633462467`], 
     Hue[0.6169373864191918, 1, -14.651004358470864`], 
     Hue[0.5524031479547685, 1, -14.469365216780494`], 
     Hue[0.6169373864191924, 1, -14.276761941788891`], 
     Hue[0.552403147954769, 1, -14.095122800098519`], 
     Hue[0.6169373864191936, 1, -13.902519525106916`], 
     Hue[0.5543624417221908, 1, -13.715032845655884`], 
     Hue[0.6178558053726744, 1, -13.52553607509963], 
     Hue[0.554362441722193, 1, -13.340790428973897`], 
     Hue[0.6178558053726804, 1, -13.15129365841764], 
     Hue[0.5543624417221974, 1, -12.966548012291888`], 
     Hue[0.6178558053726937, 1, -12.777051241735627`], 
     Hue[0.5543624417222072, 1, -12.592305595609835`], 
     Hue[0.6178558053727231, 1, -12.402808825053558`], 
     Hue[0.5543624417222286, 1, -12.218063178927682`], 
     Hue[0.6178558053727876, 1, -12.028566408371377`], 
     Hue[0.5553420886059882, 1, -11.840896993364984`], 
     Hue[0.6183150148496711, 1, -11.652953475026285`], 
     Hue[0.5553420886060945, 1, -11.466654576682139`], 
     Hue[0.6183150148499849, 1, -11.278711058343298`], 
     Hue[0.5553420886063284, 1, -11.092412159998242`], 
     Hue[0.6183150148506749, 1, -10.904468641659086`], 
     Hue[0.5558319120487092, 1, -10.716707858871857`], 
     Hue[0.6203891109888725, 1, -10.524036058045866`], 
     Hue[0.5561992796312616, 1, -10.34136902885041], 
     Hue[0.6205555744276315, 1, -10.149296829062843`], 
     Hue[0.5602403230295508, 1, -9.95506606551595], 
     Hue[0.6206110622469655, 1, -9.7748888082603], 
     Hue[0.5602403230356632, 1, -9.580823648788108], 
     Hue[0.6206110622635794, 1, -9.400646391525932], 
     Hue[0.5602403230491027, 1, -9.206581232005277], 
     Hue[0.6206110623001089, 1, -9.026403974728755], 
     Hue[0.5602403230786523, 1, -8.832338815101537], 
     Hue[0.6223866723605522, 1, -8.646862226697653], 
     Hue[0.5602403231436242, 1, -8.45809639793196], 
     Hue[0.6223866725412257, 1, -8.272619809458455], 
     Hue[0.5602403232864792, 1, -8.083853980177878], 
     Hue[0.6223866729384775, 1, -7.898377391551295], 
     Hue[0.5602403236005787, 1, -7.709611561138623], 
     Hue[0.6223866738119259, 1, -7.524134972175459], 
     Hue[0.560240324291198, 1, -7.335369139273632], 
     Hue[0.6223866757324013, 1, -7.14989254957042], 
     Hue[0.5602403258096815, 1, -6.961126711195608], 
     Hue[0.6232744850314658, 1, -6.773000454313846], 
     Hue[0.560240329148413, 1, -6.5868842694568235`], 
     Hue[0.6232744944214257, 1, -6.398758008993067], 
     Hue[0.5621996308445265, 1, -6.206794259177964], 
     Hue[0.6241470134941136, 1, -6.021911547672945], 
     Hue[0.5621996476898372, 1, -5.8325517204704385`], 
     Hue[0.6241470593935524, 1, -5.6476689925272545`], 
     Hue[0.5621996847281152, 1, -5.458309035487438], 
     Hue[0.6245834103385655, 1, -5.272124280559615], 
     Hue[0.5621997661653416, 1, -5.084066028884178], 
     Hue[0.62480175908723, 1, -4.897230199052456], 
     Hue[0.56219994522432, 1, -4.709822315123924], 
     Hue[0.6285104101363128, 1, -4.5119193898035475`], 
     Hue[0.5631800011135297, 1, -4.332653258779229], 
     Hue[0.6254365553200045, 1, -4.146850843702421], 
     Hue[0.5631808851221389, 1, -3.9584045488295407`], 
     Hue[0.6289120373023263, 1, -3.7622364303236644`], 
     Hue[0.563672689567319, 1, -3.5826863650212672`], 
     Hue[0.6291165558437395, 1, -3.3873844895557133`], 
     Hue[0.5639219612142433, 1, -3.2076824763778236`], 
     Hue[0.6292282090399919, 1, -3.0128107541889193`], 
     Hue[0.5641152600489063, 1, -2.8328246887765722`], 
     Hue[0.6293295861111563, 1, -2.638270053259541], 
     Hue[0.5681194513270614, 1, -2.446553028886729], 
     Hue[0.6274897590983286, 1, -2.2695203995717943`], 
     Hue[0.5681698057912948, 1, -2.0719813335105375`], 
     Hue[0.6311393766618744, 1, -1.884428828176666], 
     Hue[0.5682807674662091, 1, -1.697014286848136], 
     Hue[0.6314303958815852, 1, -1.5093838841117633`], 
     Hue[0.5685259370663659, 1, -1.3211755268858736`], 
     Hue[0.6286945885797264, 1, -1.1433178402986155`], 
     Hue[0.5649504772760785, 1, -0.9555590623854566], 
     Hue[0.6318119093583182, 1, -0.7601543463692026], 
     Hue[0.5641635387285859, 1, -0.5791760199312219], 
     Hue[0.6299839780483247, 1, -0.3913079162322948], 
     Hue[0.5623837655448327, 1, -0.19985954566427888`], 
     Hue[0.6302666407796836, 1, -0.01553495577327002], 
     Hue[0.6276238313316189, 1, 0.35883934070050494`], 
     Hue[0.6102729927077057, 1, 0.7344674333478771], 
     Hue[0.8773000903772898, 1, 1.109450565836327], 
     Hue[0.9489055682885668, 1, 1.1093428105225682`], 
     Hue[0.9248098148794981, 1, 1.297110998923844], 
     Hue[0.9757378801251865, 1, 1.1093266832880242`], 
     Hue[0.9912759735468806, 1, 1.109662543039157], 
     Hue[0.7404953496271661, 1, -17.27618334189528], 
     Hue[0.6777979490696999, 1, -17.089062133554293`], 
     Hue[0.737587022941151, 1, -16.91062086407678], 
     Hue[0.6777979490696999, 1, -16.714819716872324`], 
     Hue[0.737587022941151, 1, -16.53637844739481], 
     Hue[0.6777979490696999, 1, -16.34057730019035], 
     Hue[0.7380615394004483, 1, -16.16071983016143], 
     Hue[0.6777979490696999, 1, -15.966334883508381`], 
     Hue[0.7384174267449213, 1, -15.7854152630659], 
     Hue[0.6777979490697, 1, -15.592092466826411`], 
     Hue[0.7423321875341232, 1, -15.399489191834807`], 
     Hue[0.6777979490697001, 1, -15.217850050144438`], 
     Hue[0.7423321875341233, 1, -15.025246775152837`], 
     Hue[0.6777979490697004, 1, -14.843607633462467`], 
     Hue[0.7423321875341238, 1, -14.651004358470864`], 
     Hue[0.6777979490697008, 1, -14.469365216780497`], 
     Hue[0.7423321875341247, 1, -14.276761941788894`], 
     Hue[0.6777979490697019, 1, -14.095122800098522`], 
     Hue[0.7423321875341264, 1, -13.902519525106923`], 
     Hue[0.679757242837125, 1, -13.715032845655891`], 
     Hue[0.7432506064876079, 1, -13.525536075099646`], 
     Hue[0.6797572428371303, 1, -13.340790428973913`], 
     Hue[0.743250606487617, 1, -13.151293658417675`], 
     Hue[0.6797572428371425, 1, -12.966548012291927`], 
     Hue[0.7432506064876367, 1, -12.7770512417357], 
     Hue[0.6797572428371688, 1, -12.592305595609917`], 
     Hue[0.7432506064876802, 1, -12.402808825053723`], 
     Hue[0.6797572428372268, 1, -12.218063178927864`], 
     Hue[0.7432506064877756, 1, -12.028566408371741`], 
     Hue[0.6807368897210673, 1, -11.840896993365387`], 
     Hue[0.7437098159647275, 1, -11.65295347502709], 
     Hue[0.6807368897213504, 1, -11.466654576683023`], 
     Hue[0.7437098159651908, 1, -11.278711058345065`], 
     Hue[0.6807368897219727, 1, -11.092412160000189`], 
     Hue[0.7437098159662094, 1, -10.904468641662973`], 
     Hue[0.6812267131652074, 1, -10.716707858876168`], 
     Hue[0.7457839121051093, 1, -10.524036058054577`], 
     Hue[0.6815940807496395, 1, -10.341369028859935`], 
     Hue[0.745950375545429, 1, -10.149296829082026`], 
     Hue[0.6856351241520686, 1, -9.955066065538015], 
     Hue[0.7460058633681947, 1, -9.774888808302501], 
     Hue[0.6856351241672753, 1, -9.58082364883662], 
     Hue[0.7460058633923585, 1, -9.400646391618718], 
     Hue[0.6856351242007108, 1, -9.206581232111937], 
     Hue[0.7460058634454878, 1, -9.02640397493277], 
     Hue[0.6856351242742261, 1, -8.832338815336058], 
     Hue[0.7477814735414815, 1, -8.646862227153488], 
     Hue[0.6856351244358664, 1, -8.458096398447609], 
     Hue[0.7477814738012681, 1, -8.272619810460707], 
     Hue[0.6856351247912691, 1, -8.083853981311647], 
     Hue[0.7477814743724682, 1, -7.898377393754976], 
     Hue[0.6856351255727031, 1, -7.709611563631474], 
     Hue[0.7477814756283813, 1, -7.5241349770207515`], 
     Hue[0.6856351272908633, 1, -7.335369144754728], 
     Hue[0.747781478389792, 1, -7.1498925602238925`], 
     Hue[0.6856351310686293, 1, -6.961126723247047], 
     Hue[0.748669289512737, 1, -6.773000477925373], 
     Hue[0.6856351393749076, 1, -6.586884295954654], 
     Hue[0.7486693029380196, 1, -6.398758060908384], 
     Hue[0.6875944519966299, 1, -6.206794318901841], 
     Hue[0.7495418307616708, 1, -6.021911662714083], 
     Hue[0.6875944928610487, 1, -5.832551851787017], 
     Hue[0.7495418960236816, 1, -5.647669245471438], 
     Hue[0.6875945827107997, 1, -5.458309324217038], 
     Hue[0.7499782892434759, 1, -5.272124838880304], 
     Hue[0.6875947802660629, 1, -5.084066663722995], 
     Hue[0.7501967309104596, 1, -4.8972314290322245`], 
     Hue[0.687595214636961, 1, -4.70982371096686], 
     Hue[0.753905573724782, 1, -4.511922183912005], 
     Hue[0.6885758318563874, 1, -4.33265636580691], 
     Hue[0.7508321770125808, 1, -4.146856823474124], 
     Hue[0.6885779501078082, 1, -3.9584113804641197`], 
     Hue[0.7543085836906491, 1, -3.762249985340288], 
     Hue[0.6890724680949127, 1, -3.582701478636241], 
     Hue[0.7545151862832129, 1, -3.387414345886013], 
     Hue[0.6893277059619053, 1, -3.20771581158375], 
     Hue[0.7546314195931549, 1, -3.012876461433658], 
     Hue[0.689564747682508, 1, -2.8328068125471875`], 
     Hue[0.7547552970226121, 1, -2.6383775392678874`], 
     Hue[0.6935670893278643, 1, -2.44672274734374], 
     Hue[0.753029314186338, 1, -2.269525125108334], 
     Hue[0.6936807719572794, 1, -2.0723548555443125`], 
     Hue[0.7566216679513696, 1, -1.8851384045414037`], 
     Hue[0.6939309400670288, 1, -1.6978372901128764`], 
     Hue[0.757016588341682, 1, -1.5109465188541276`], 
     Hue[0.6944820084184944, 1, -1.322993475161072], 
     Hue[0.7578845998917281, 1, -1.1368254657158496`], 
     Hue[0.6956985392182284, 1, -0.9474462259920975], 
     Hue[0.7597913990124832, 1, -0.7628993963824282], 
     Hue[0.6983965783488262, 1, -0.5704212056992528], 
     Hue[0.7639732937504715, 1, -0.38959058163780247`], 
     Hue[0.6990944193715346, 1, -0.20442263451711828`], 
     Hue[0.773751140972645, 1, -0.016944744986367777`], 
     Hue[0.7076569080658368, 1, 0.17075572422597685`], 
     Hue[0.8006782858919514, 1, 0.358574602914715], 
     Hue[0.72803027422026, 1, 0.5462581291175553], 
     Hue[0.8658901507420977, 1, -17.27618334189528], 
     Hue[0.8031927501846311, 1, -17.089062133554293`], 
     Hue[0.8629818240560827, 1, -16.91062086407678], 
     Hue[0.8031927501846311, 1, -16.714819716872324`], 
     Hue[0.8629818240560827, 1, -16.53637844739481], 
     Hue[0.8031927501846311, 1, -16.34057730019035], 
     Hue[0.86345634051538, 1, -16.16071983016143], 
     Hue[0.8031927501846312, 1, -15.966334883508381`], 
     Hue[0.863812227859853, 1, -15.7854152630659], 
     Hue[0.8031927501846312, 1, -15.592092466826411`], 
     Hue[0.8677269886490548, 1, -15.399489191834807`], 
     Hue[0.8031927501846313, 1, -15.217850050144438`], 
     Hue[0.8677269886490551, 1, -15.025246775152837`], 
     Hue[0.8031927501846315, 1, -14.843607633462467`], 
     Hue[0.8677269886490553, 1, -14.651004358470864`], 
     Hue[0.8031927501846321, 1, -14.469365216780497`], 
     Hue[0.867726988649056, 1, -14.276761941788898`], 
     Hue[0.8031927501846332, 1, -14.095122800098528`], 
     Hue[0.8677269886490573, 1, -13.90251952510693], 
     Hue[0.8051520439520569, 1, -13.715032845655903`], 
     Hue[0.8686454076025376, 1, -13.525536075099662`], 
     Hue[0.8051520439520625, 1, -13.340790428973937`], 
     Hue[0.8686454076025443, 1, -13.15129365841771], 
     Hue[0.8051520439520751, 1, -12.966548012291982`], 
     Hue[0.8686454076025588, 1, -12.77705124173578], 
     Hue[0.8051520439521025, 1, -12.59230559561004], 
     Hue[0.8686454076025908, 1, -12.402808825053896`], 
     Hue[0.8051520439521629, 1, -12.218063178928134`], 
     Hue[0.8686454076026611, 1, -12.028566408372118`], 
     Hue[0.8061316908360068, 1, -11.840896993365982`], 
     Hue[0.8691046170795557, 1, -11.65295347502792], 
     Hue[0.8061316908362997, 1, -11.466654576684336`], 
     Hue[0.8691046170798955, 1, -11.278711058346891`], 
     Hue[0.8061316908369437, 1, -11.09241216000307], 
     Hue[0.8691046170806425, 1, -10.904468641666991`], 
     Hue[0.8066215142802206, 1, -10.716707858882524`], 
     Hue[0.8711787132188918, 1, -10.524036058063482`], 
     Hue[0.8069888818647395, 1, -10.341369028873943`], 
     Hue[0.8713451766578251, 1, -10.149296829101619`], 
     Hue[0.8110299252671114, 1, -9.955066065569627], 
     Hue[0.8714006644775457, 1, -9.774888808345592], 
     Hue[0.8110299252824511, 1, -9.580823648906128], 
     Hue[0.8714006644950195, 1, -9.400646391713464], 
     Hue[0.811029925316179, 1, -9.206581232264766], 
     Hue[0.8714006645334397, 1, -9.026403975141088], 
     Hue[0.8110299253903376, 1, -8.832338815672085], 
     Hue[0.8731762745946987, 1, -8.646862227614632], 
     Hue[0.8110299255533919, 1, -8.45809639918644], 
     Hue[0.8731762747805065, 1, -8.272619811474643], 
     Hue[0.8110299259119038, 1, -8.083853982936136], 
     Hue[0.8731762751890473, 1, -7.898377395984341], 
     Hue[0.811029926700174, 1, -7.709611567203283], 
     Hue[0.8731762760873168, 1, -7.524134981922521], 
     Hue[0.8110299284333653, 1, -7.335369152608162], 
     Hue[0.8731762780623669, 1, -7.149892571001549], 
     Hue[0.8110299322441803, 1, -6.961126740514607], 
     Hue[0.8740640873940894, 1, -6.773000501701596], 
     Hue[0.8110299406231241, 1, -6.586884333921313], 
     Hue[0.8740640969431902, 1, -6.398758113185816], 
     Hue[0.8129892530596322, 1, -6.206794403418697], 
     Hue[0.8749366159461804, 1, -6.021911778030846], 
     Hue[0.8129892938617858, 1, -5.83255203761655], 
     Hue[0.8749366621119322, 1, -5.647669499021503], 
     Hue[0.8129893835745712, 1, -5.458309732805534], 
     Hue[0.8753730126196527, 1, -5.272125397263768], 
     Hue[0.8129895808283885, 1, -5.084067562097744], 
     Hue[0.8755913602996607, 1, -4.897232657746072], 
     Hue[0.8129900145350575, 1, -4.70982568624808], 
     Hue[0.8792999668779042, 1, -4.5119249215704365`], 
     Hue[0.8139706212579535, 1, -4.332660735594775], 
     Hue[0.8762261366635633, 1, -4.146862777247112], 
     Hue[0.8139727254255399, 1, -3.9584209884347104`], 
     Hue[0.8797013964109734, 1, -3.7622632383060104`], 
     Hue[0.8144671902543725, 1, -3.5827226684232834`], 
     Hue[0.8799055974575024, 1, -3.387443504587683], 
     Hue[0.8147223081405665, 1, -3.2077624729666443`], 
     Hue[0.8800165474362939, 1, -3.0129405904144635`], 
     Hue[0.8149858507170473, 1, -2.83282962697683], 
     Hue[0.8801396665252516, 1, -2.6384861001036706`], 
     Hue[0.8189588379010116, 1, -2.446954140810835], 
     Hue[0.8784564028060564, 1, -2.269602154996959], 
     Hue[0.8190687418155417, 1, -2.072863598365265], 
     Hue[0.8819098176631932, 1, -1.8858230124553528`], 
     Hue[0.8193101433089591, 1, -1.6989557362235697`], 
     Hue[0.8821760728837319, 1, -1.512448874222646], 
     Hue[0.8198397223702245, 1, -1.325451914459779], 
     Hue[0.8827580846687003, 1, -1.1401146311334711`], 
     Hue[0.8209983184525568, 1, -0.9528477784533569], 
     Hue[0.8856714599098252, 1, -0.7652806977860069], 
     Hue[0.8255048047315159, 1, -0.5766814305257886], 
     Hue[0.8939609098854933, 1, -0.3847229604791089], 
     Hue[0.8349536572255332, 1, -0.2005502655063316], 
     Hue[0.9053363026980363, 1, -0.016723641611813944`], 
     Hue[0.8553527367365817, 1, 0.17275131429097357`], 
     Hue[0.9368264517058611, 1, 0.3586256757517886], 
     Hue[0.9098393335985332, 1, 0.5475067795559664], 
     Hue[0.8984094789968501, 1, 0.7342584105714809], 
     Hue[0.9730399689105569, 1, 0.9217281621259781], 
     Hue[0.991284951857029, 1, -17.27618334189528], 
     Hue[0.9285875512995628, 1, -17.089062133554293`], 
     Hue[0.9883766251710139, 1, -16.91062086407678], 
     Hue[0.9285875512995628, 1, -16.714819716872324`], 
     Hue[0.9883766251710139, 1, -16.53637844739481], 
     Hue[0.9285875512995628, 1, -16.34057730019035], 
     Hue[0.9888511416303117, 1, -16.16071983016143], 
     Hue[0.9285875512995628, 1, -15.966334883508381`], 
     Hue[0.9892070289747847, 1, -15.7854152630659], 
     Hue[0.9285875512995628, 1, -15.592092466826411`], 
     Hue[0.993121789763986, 1, -15.399489191834807`], 
     Hue[0.9285875512995629, 1, -15.217850050144438`], 
     Hue[0.993121789763986, 1, -15.025246775152837`], 
     Hue[0.928587551299563, 1, -14.843607633462467`], 
     Hue[0.993121789763986, 1, -14.651004358470868`], 
     Hue[0.9285875512995633, 1, -14.469365216780501`], 
     Hue[0.993121789763986, 1, -14.276761941788898`], 
     Hue[0.9285875512995638, 1, -14.095122800098533`], 
     Hue[0.9931217897639861, 1, -13.902519525106934`], 
     Hue[0.930546845066986, 1, -13.715032845655912`], 
     Hue[0.9940402087174641, 1, -13.52553607509967], 
     Hue[0.9305468450669886, 1, -13.340790428973957`], 
     Hue[0.9940402087174646, 1, -13.151293658417725`], 
     Hue[0.9305468450669941, 1, -12.966548012292023`], 
     Hue[0.9940402087174652, 1, -12.777051241735814`], 
     Hue[0.9305468450670065, 1, -12.59230559561013], 
     Hue[0.9940402087174669, 1, -12.402808825053972`], 
     Hue[0.9305468450670337, 1, -12.218063178928332`], 
     Hue[0.9940402087174705, 1, -12.028566408372287`], 
     Hue[0.9315264919508027, 1, -11.840896993366421`], 
     Hue[0.9944994181942174, 1, -11.652953475028289`], 
     Hue[0.931526491950933, 1, -11.466654576685297`], 
     Hue[0.9944994181942334, 1, -11.278711058347701`], 
     Hue[0.9315264919512192, 1, -11.092412160005187`], 
     Hue[0.9944994181942686, 1, -10.904468641668771`], 
     Hue[0.9320163153937, 1, -10.71670785888718], 
     Hue[0.9965735143308981, 1, -10.524036058067335`], 
     Hue[0.9323836829764622, 1, -10.341369028884182`], 
     Hue[0.996739977766315, 1, -10.149296829110076`], 
     Hue[0.936424726374613, 1, -9.95506606559216], 
     Hue[0.9967954655783064, 1, -9.774888808364178], 
     Hue[0.9364247263810461, 1, -9.580823648955672], 
     Hue[0.9967954655787932, 1, -9.400646391754332], 
     Hue[0.9364247263951907, 1, -9.206581232373699], 
     Hue[0.9967954655798631, 1, -9.026403975230945], 
     Hue[0.9364247264262908, 1, -8.832338815911598], 
     Hue[0.9985710755565717, 1, -8.64686222780934], 
     Hue[0.9364247264946716, 1, -8.458096399713064], 
     Hue[0.9985710755589042, 1, -8.27261981190275], 
     Hue[0.936424726645022, 1, -8.083853984094034], 
     Hue[0.998571075564033, 1, -7.898377396925633], 
     Hue[0.9364247269756016, 1, -7.709611569749186], 
     Hue[0.9985710755753098, 1, -7.524134983992163], 
     Hue[0.9364247277024563, 1, -7.335369158205913], 
     Hue[0.9985710756001044, 1, -7.149892575552127], 
     Hue[0.9364247293006115, 1, -6.961126752822536], 
     Hue[0.9994588805810675, 1, -6.773000511631215], 
     Hue[0.9364247328145189, 1, -6.586884360983094], 
     Hue[0.9994588806267143, 1, -6.398758135018339], 
     Hue[0.9383840340641435, 1, -6.20679446292284], 
     Hue[1.0003313784354357`, 1, -6.0219118256672335`], 
     Hue[0.9383840507593844, 1, -5.832552168449897], 
     Hue[1.0003313782995527`, 1, -5.647669603760862], 
     Hue[0.938384087467639, 1, -5.458310020472179], 
     Hue[1.0007676262787686`, 1, -5.272125626656183], 
     Hue[0.9383841681789409, 1, -5.084068194597186], 
     Hue[1.000985748454121, 1, -4.897233161118814], 
     Hue[0.9383843456403919, 1, -4.709827076936595], 
     Hue[1.0046938300143702`, 1, -4.511925989503736], 
     Hue[0.939364376243917, 1, -4.332663793032759], 
     Hue[1.0016189301818539`, 1, -4.146865196577122], 
     Hue[0.9393652263888631, 1, -3.9584277107801773`], 
     Hue[1.0050916473913147`, 1, -3.7622683798286545`], 
     Hue[0.9398569031152428, 1, -3.5827374473002136`], 
     Hue[1.005290377171751, 1, -3.3874547852188055`], 
     Hue[0.9401058876072549, 1, -3.2077949632243348`], 
     Hue[1.0053892969705203`, 1, -3.0129653633147866`], 
     Hue[0.9442776697316373, 1, -2.821198855529194], 
     Hue[1.0033607539498395`, 1, -2.644883314061514], 
     Hue[0.9442965603478612, 1, -2.4471108645279784`], 
     Hue[1.003765516628347, 1, -2.2696660088770537`], 
     Hue[0.944338052507205, 1, -2.073207834878655], 
     Hue[1.0070671183365665`, 1, -1.886080781023553], 
     Hue[0.9444290743365147, 1, -1.6997108992380603`], 
     Hue[1.007049649055729, 1, -1.5130132043675906`], 
     Hue[0.9446282058831198, 1, -1.3271040312026299`], 
     Hue[1.007011540738884, 1, -1.1413437874428054`], 
     Hue[0.9470029412357118, 1, -0.9507029475511193], 
     Hue[1.0092925642887036`, 1, -0.7656407304333548], 
     Hue[0.9493512852368164, 1, -0.5801681474959901], 
     Hue[1.0141540864244005`, 1, -0.3883442973278004], 
     Hue[0.9582102589347758, 1, -0.2031012853723244], 
     Hue[1.0221895288338565`, 1, -0.013814055259288027`], 
     Hue[0.9752967555320627, 1, 0.17172656805084807`], 
     Hue[1.0363925356693129`, 1, 0.3589101684921653], 
     Hue[1.0077484179427323`, 1, 0.5470030542273732], 
     Hue[0.9983851295269743, 1, 0.7344659193192276], 
     Hue[1.0105217446893395`, 1, 0.9216839586343237], 
     Hue[1.1166797529719608`, 1, -17.27618334189528], 
     Hue[1.0539823524144947`, 1, -17.089062133554293`], 
     Hue[1.1137714262859455`, 1, -16.91062086407678], 
     Hue[1.0539823524144947`, 1, -16.714819716872324`], 
     Hue[1.1137714262859455`, 1, -16.53637844739481], 
     Hue[1.0539823524144947`, 1, -16.34057730019035], 
     Hue[1.114245942745243, 1, -16.16071983016143], 
     Hue[1.0539823524144944`, 1, -15.966334883508381`], 
     Hue[1.1146018300897158`, 1, -15.7854152630659], 
     Hue[1.0539823524144944`, 1, -15.592092466826411`], 
     Hue[1.1185165908789176`, 1, -15.399489191834807`], 
     Hue[1.0539823524144944`, 1, -15.217850050144438`], 
     Hue[1.1185165908789174`, 1, -15.025246775152837`], 
     Hue[1.0539823524144944`, 1, -14.843607633462467`], 
     Hue[1.1185165908789172`, 1, -14.651004358470864`], 
     Hue[1.0539823524144942`, 1, -14.469365216780501`], 
     Hue[1.1185165908789167`, 1, -14.276761941788898`], 
     Hue[1.0539823524144938`, 1, -14.095122800098533`], 
     Hue[1.1185165908789154`, 1, -13.90251952510693], 
     Hue[1.0559416461819133`, 1, -13.715032845655912`], 
     Hue[1.11943500983239, 1, -13.525536075099664`], 
     Hue[1.0559416461819113`, 1, -13.340790428973957`], 
     Hue[1.1194350098323838`, 1, -13.15129365841771], 
     Hue[1.0559416461819067`, 1, -12.966548012292025`], 
     Hue[1.1194350098323702`, 1, -12.777051241735785`], 
     Hue[1.0559416461818967`, 1, -12.592305595610135`], 
     Hue[1.1194350098323407`, 1, -12.402808825053908`], 
     Hue[1.0559416461818745`, 1, -12.218063178928343`], 
     Hue[1.1194350098322754`, 1, -12.028566408372146`], 
     Hue[1.0569212930655347`, 1, -11.840896993366442`], 
     Hue[1.1198942193088712`, 1, -11.652953475027978`], 
     Hue[1.0569212930654255`, 1, -11.466654576685345`], 
     Hue[1.119894219308554, 1, -11.278711058347016`], 
     Hue[1.0569212930651852`, 1, -11.092412160005292`], 
     Hue[1.1198942193078567`, 1, -10.904468641667265`], 
     Hue[1.057411116506501, 1, -10.716707858887391`], 
     Hue[1.1219683154428517`, 1, -10.524036058063862`], 
     Hue[1.0577784840866993`, 1, -10.341369028884616`], 
     Hue[1.1221347788746943`, 1, -10.149296829102413`], 
     Hue[1.0618195274789515`, 1, -9.955066065592334], 
     Hue[1.1221902666788275`, 1, -9.77488880834731], 
     Hue[1.061819527472687, 1, -9.580823648956054], 
     Hue[1.12219026666204, 1, -9.40064639171724], 
     Hue[1.0618195274589128`, 1, -9.20658123237454], 
     Hue[1.1221902666251296`, 1, -9.02640397514939], 
     Hue[1.0618195274286273`, 1, -8.83233881591345], 
     Hue[1.1239658765172984`, 1, -8.646862227622867], 
     Hue[1.0618195273620377`, 1, -8.458096399717139], 
     Hue[1.1239658763347813`, 1, -8.272619811492746], 
     Hue[1.0618195272156252`, 1, -8.083853984102996], 
     Hue[1.1239658759334756`, 1, -7.898377396024144], 
     Hue[1.0618195268937043`, 1, -7.709611569768891], 
     Hue[1.1239658750511143`, 1, -7.524134982010039], 
     Hue[1.0618195261858878`, 1, -7.335369158249233], 
     Hue[1.123965873111042, 1, -7.149892571193978], 
     Hue[1.061819524629592, 1, -6.961126752917786], 
     Hue[1.124853673745606, 1, -6.773000501862717], 
     Hue[1.0618195212077222`, 1, -6.5868843611925225`], 
     Hue[1.1248536642608993`, 1, -6.398758113540079], 
     Hue[1.063778806861213, 1, -6.206794462348571], 
     Hue[1.1257261409914912`, 1, -6.021911777551214], 
     Hue[1.0637787896110704`, 1, -5.832552167187237], 
     Hue[1.1257260946340486`, 1, -5.6476694979669215`], 
     Hue[1.0637787516827393`, 1, -5.458310017695938], 
     Hue[1.1261622406880158`, 1, -5.272125391877775], 
     Hue[1.0637786682888253`, 1, -5.084068188493003], 
     Hue[1.1263801387294636`, 1, -4.897232642517916], 
     Hue[1.0637784849290608`, 1, -4.709827063515235], 
     Hue[1.1300877158757812`, 1, -4.511924758401499], 
     Hue[1.0647577132964403`, 1, -4.3326637364447205`], 
     Hue[1.1270117406057172`, 1, -4.146862655859951], 
     Hue[1.064756808472246, 1, -3.958427586361803], 
     Hue[1.130482017830531, 1, -3.762262380516984], 
     Hue[1.0652446051653197`, 1, -3.582737107706003], 
     Hue[1.1306754301013973`, 1, -3.387441542543537], 
     Hue[1.0654850571873045`, 1, -3.207794143713228], 
     Hue[1.1307626586865813`, 1, -3.0129361932230116`], 
     Hue[1.0696372238850613`, 1, -2.821194254005154], 
     Hue[1.1287087532567432`, 1, -2.6448217876070297`], 
     Hue[1.0696138876941037`, 1, -2.4471007534897664`], 
     Hue[1.1290121570860299`, 1, -2.269664627059373], 
     Hue[1.0695626291844955`, 1, -2.073185634642112], 
     Hue[1.1322330030986885`, 1, -1.885761122553639], 
     Hue[1.069450173670713, 1, -1.6996622372323242`], 
     Hue[1.1319419402257445`, 1, -1.5123132707389548`], 
     Hue[1.069204107349274, 1, -1.3269977581141912`], 
     Hue[1.131305387273052, 1, -1.1398187621381608`], 
     Hue[1.0705896856674035`, 1, -0.9504044001528145], 
     Hue[1.130693642412985, 1, -0.7670452454922363], 
     Hue[1.070801516928892, 1, -0.5794217648459055], 
     Hue[1.1304965017209152`, 1, -0.392315922727984], 
     Hue[1.0740058545958258`, 1, -0.20321752254882886`], 
     Hue[1.1306148791223403`, 1, -0.013759671988504474`], 
     Hue[1.0784778593054962`, 1, 0.1710899993964391], 
     Hue[1.126041690371545, 1, 0.35841695001387086`], 
     Hue[1.0829975038931208`, 1, 0.5461610030977345], 
     Hue[1.0536339435828965`, 1, 0.7341851603105826], 
     Hue[1.0364386938353831`, 1, 0.9216013689954958], 
     Hue[1.2420745540868925`, 1, -17.27618334189528], 
     Hue[1.1793771535294257`, 1, -17.089062133554293`], 
     Hue[1.2391662274008772`, 1, -16.91062086407678], 
     Hue[1.1793771535294257`, 1, -16.714819716872324`], 
     Hue[1.2391662274008772`, 1, -16.53637844739481], 
     Hue[1.1793771535294257`, 1, -16.34057730019035], 
     Hue[1.2396407438601746`, 1, -16.16071983016143], 
     Hue[1.1793771535294257`, 1, -15.966334883508381`], 
     Hue[1.2399966312046475`, 1, -15.7854152630659], 
     Hue[1.1793771535294257`, 1, -15.592092466826411`], 
     Hue[1.2439113919938494`, 1, -15.399489191834807`], 
     Hue[1.1793771535294255`, 1, -15.217850050144438`], 
     Hue[1.2439113919938491`, 1, -15.025246775152837`], 
     Hue[1.1793771535294253`, 1, -14.843607633462467`], 
     Hue[1.2439113919938487`, 1, -14.651004358470864`], 
     Hue[1.1793771535294248`, 1, -14.469365216780497`], 
     Hue[1.2439113919938478`, 1, -14.276761941788894`], 
     Hue[1.1793771535294237`, 1, -14.09512280009853], 
     Hue[1.243911391993846, 1, -13.902519525106923`], 
     Hue[1.1813364472968422`, 1, -13.715032845655905`], 
     Hue[1.2448298109473193`, 1, -13.525536075099648`], 
     Hue[1.1813364472968368`, 1, -13.34079042897394], 
     Hue[1.2448298109473104`, 1, -13.151293658417677`], 
     Hue[1.1813364472968246`, 1, -12.966548012291987`], 
     Hue[1.2448298109472906`, 1, -12.777051241735709`], 
     Hue[1.1813364472967982`, 1, -12.592305595610052`], 
     Hue[1.244829810947247, 1, -12.402808825053743`], 
     Hue[1.1813364472967398`, 1, -12.21806317892816], 
     Hue[1.2448298109471514`, 1, -12.02856640837178], 
     Hue[1.18231609418032, 1, -11.840896993366036`], 
     Hue[1.2452890204236804`, 1, -11.652953475027168`], 
     Hue[1.1823160941800355`, 1, -11.46665457668445], 
     Hue[1.245289020423217, 1, -11.27871105834524], 
     Hue[1.1823160941794104`, 1, -11.092412160003324`], 
     Hue[1.2452890204221978`, 1, -10.904468641663358`], 
     Hue[1.1828059176198802`, 1, -10.716707858883034`], 
     Hue[1.247363116556507, 1, -10.524036058055112`], 
     Hue[1.1831732851982169`, 1, -10.341369028874988`], 
     Hue[1.2475295799868236`, 1, -10.149296829083147`], 
     Hue[1.1872143285863703`, 1, -9.955066065570048], 
     Hue[1.2475850677876017`, 1, -9.774888808304924], 
     Hue[1.1872143285710999`, 1, -9.580823648907051], 
     Hue[1.247585067763433, 1, -9.400646391624047], 
     Hue[1.187214328537524, 1, -9.206581232266798], 
     Hue[1.247585067710293, 1, -9.026403974944484], 
     Hue[1.1872143284637002`, 1, -8.832338815676554], 
     Hue[1.2493606775677513`, 1, -8.646862227165101], 
     Hue[1.1872143283013814`, 1, -8.458096399196265], 
     Hue[1.2493606773079415`, 1, -8.272619810486246], 
     Hue[1.187214327944487, 1, -8.083853982957738], 
     Hue[1.2493606767366905`, 1, -7.898377393811127], 
     Hue[1.1872143271597728`, 1, -7.7096115672507795`], 
     Hue[1.2493606754806654`, 1, -7.524134977144214], 
     Hue[1.1872143254344005`, 1, -7.335369152712594], 
     Hue[1.2493606727190087`, 1, -7.149892560495352], 
     Hue[1.1872143216407771`, 1, -6.961126740744226], 
     Hue[1.250248471572862, 1, -6.7730004781526665`], 
     Hue[1.1872143132996333`, 1, -6.586884334426182], 
     Hue[1.2502484581471265`, 1, -6.398758061408142], 
     Hue[1.1891735881385166`, 1, -6.206794402034307], 
     Hue[1.2511209263370375`, 1, -6.021911662037464], 
     Hue[1.189173547108464, 1, -5.832552034572653], 
     Hue[1.2511208610763747`, 1, -5.6476692439837395`], 
     Hue[1.1891734568945895`, 1, -5.458309726112838], 
     Hue[1.2515569658725396`, 1, -5.272124831282258], 
     Hue[1.18917325853901, 1, -5.084067547382345], 
     Hue[1.251774773231516, 1, -4.897231407549738], 
     Hue[1.1891728224098466`, 1, -4.7098256538930015`], 
     Hue[1.2554821638128595`, 1, -4.51192195372672], 
     Hue[1.1901514951628738`, 1, -4.332660599176148], 
     Hue[1.252405741012432, 1, -4.146856652228811], 
     Hue[1.1901493685361855`, 1, -3.9584206884905973`], 
     Hue[1.2558751185535346`, 1, -3.7622487751879365`], 
     Hue[1.1906344793347075`, 1, -3.582721849711376], 
     Hue[1.2560665000323439`, 1, -3.387411577683631], 
     Hue[1.190869025904197, 1, -3.2077604970952223`], 
     Hue[1.256149262888955, 1, -3.0128702566120342`], 
     Hue[1.191083449921516, 1, -2.8328363242013745`], 
     Hue[1.256208837450519, 1, -2.6383358178016136`], 
     Hue[1.194956410819381, 1, -2.446929749296652], 
     Hue[1.2543149681590315`, 1, -2.2695049073631255`], 
     Hue[1.1948424743483497`, 1, -2.072809999061298], 
     Hue[1.2575419325866908`, 1, -1.885050839621918], 
     Hue[1.1945921662633725`, 1, -1.6988380359728061`], 
     Hue[1.2571469537927218`, 1, -1.510753985880856], 
     Hue[1.1940428117190423`, 1, -1.325193851004353], 
     Hue[1.2562782000095025`, 1, -1.1364021488662164`], 
     Hue[1.1928398213560802`, 1, -0.9522839049853136], 
     Hue[1.2543668028706272`, 1, -0.7619688843497725], 
     Hue[1.1920957474503133`, 1, -0.575096173127916], 
     Hue[1.250917900746403, 1, -0.38505644938090167`], 
     Hue[1.1872417160835789`, 1, -0.20470221283991563`], 
     Hue[1.240552572923616, 1, -0.015435496136618987`], 
     Hue[1.1795837469569745`, 1, 0.17081836645570103`], 
     Hue[1.2220547072002017`, 1, 0.35855995513239436`], 
     Hue[1.1619673681046652`, 1, 0.5461326511566265], 
     Hue[1.1850027829001595`, 1, 0.7350739860766892], 
     Hue[1.1114642604449356`, 1, 0.7340272391978137], 
     Hue[1.1186882889522431`, 1, 0.9220777509996326], 
     Hue[1.069488097873694, 1, 0.9223323073896448], 
     Hue[1.3674693552018242`, 1, -17.27618334189528], 
     Hue[1.3047719546443575`, 1, -17.089062133554293`], 
     Hue[1.3645610285158085`, 1, -16.91062086407678], 
     Hue[1.3047719546443575`, 1, -16.714819716872324`], 
     Hue[1.3645610285158085`, 1, -16.53637844739481], 
     Hue[1.3047719546443575`, 1, -16.34057730019035], 
     Hue[1.3650355449751064`, 1, -16.16071983016143], 
     Hue[1.3047719546443575`, 1, -15.966334883508381`], 
     Hue[1.3653914323195793`, 1, -15.7854152630659], 
     Hue[1.3047719546443575`, 1, -15.592092466826411`], 
     Hue[1.3693061931087804`, 1, -15.399489191834807`], 
     Hue[1.3047719546443572`, 1, -15.217850050144438`], 
     Hue[1.3693061931087804`, 1, -15.025246775152837`], 
     Hue[1.304771954644357, 1, -14.843607633462467`], 
     Hue[1.36930619310878, 1, -14.651004358470864`], 
     Hue[1.3047719546443566`, 1, -14.469365216780497`], 
     Hue[1.3693061931087795`, 1, -14.276761941788891`], 
     Hue[1.3047719546443552`, 1, -14.095122800098524`], 
     Hue[1.3693061931087782`, 1, -13.902519525106916`], 
     Hue[1.306731248411774, 1, -13.715032845655893`], 
     Hue[1.3702246120622532`, 1, -13.525536075099632`], 
     Hue[1.3067312484117681`, 1, -13.340790428973914`], 
     Hue[1.3702246120622465`, 1, -13.151293658417643`], 
     Hue[1.3067312484117557`, 1, -12.96654801229193], 
     Hue[1.3702246120622321`, 1, -12.777051241735633`], 
     Hue[1.3067312484117284`, 1, -12.592305595609929`], 
     Hue[1.3702246120622004`, 1, -12.40280882505357], 
     Hue[1.3067312484116682`, 1, -12.21806317892789], 
     Hue[1.3702246120621309`, 1, -12.028566408371404`], 
     Hue[1.3077108952952452`, 1, -11.840896993365439`], 
     Hue[1.3706838215387178`, 1, -11.652953475026342`], 
     Hue[1.3077108952949534`, 1, -11.466654576683139`], 
     Hue[1.3706838215383812`, 1, -11.27871105834342], 
     Hue[1.3077108952943117`, 1, -11.092412160000439`], 
     Hue[1.3706838215376411`, 1, -10.904468641659356`], 
     Hue[1.3082007187347517`, 1, -10.716707858876674`], 
     Hue[1.3727579176726168`, 1, -10.52403605804624], 
     Hue[1.308568086313026, 1, -10.341369028860974`], 
     Hue[1.3729243811043554`, 1, -10.14929682906363], 
     Hue[1.3126091297012963`, 1, -9.955066065538432], 
     Hue[1.3729798689082573`, 1, -9.774888808262002], 
     Hue[1.3126091296860187`, 1, -9.58082364883754], 
     Hue[1.3729798688909498`, 1, -9.400646391529671], 
     Hue[1.3126091296524274`, 1, -9.206581232113962], 
     Hue[1.372979868852896, 1, -9.026403974736976], 
     Hue[1.3126091295785693`, 1, -8.832338815340508], 
     Hue[1.3747554787459269`, 1, -8.646862226705807], 
     Hue[1.312609129416176, 1, -8.458096398457393], 
     Hue[1.3747554785619303`, 1, -8.272619809476378], 
     Hue[1.3126091290591166`, 1, -8.08385398133316], 
     Hue[1.3747554781573714`, 1, -7.898377391590706], 
     Hue[1.3126091282740406`, 1, -7.7096115636787745`], 
     Hue[1.374755477267857, 1, -7.52413497226211], 
     Hue[1.3126091265478728`, 1, -7.33536914485873], 
     Hue[1.374755475312057, 1, -7.149892549760939], 
     Hue[1.3126091227524994`, 1, -6.961126723475721], 
     Hue[1.3756432760002586`, 1, -6.773000454473369], 
     Hue[1.312609114407508, 1, -6.586884296457445], 
     Hue[1.3756432665452656`, 1, -6.398758009343814], 
     Hue[1.314568389586346, 1, -6.206794317523149], 
     Hue[1.376515743764969, 1, -6.021911547198071], 
     Hue[1.3145683489553317`, 1, -5.832551848755647], 
     Hue[1.376515698059123, 1, -5.647668991483135], 
     Hue[1.3145682596187729`, 1, -5.458309317551877], 
     Hue[1.3769518465783617`, 1, -5.272124275227038], 
     Hue[1.3145680631918752`, 1, -5.0840666490681095`], 
     Hue[1.3771697501466056`, 1, -4.897230183975244], 
     Hue[1.314567631301926, 1, -4.709823678744686], 
     Hue[1.3808773819610662`, 1, -4.511919228249876], 
     Hue[1.315546322485941, 1, -4.332656229947281], 
     Hue[1.3778014032950296`, 1, -4.146850723513674], 
     Hue[1.3155442272329851`, 1, -3.9584110817424882`], 
     Hue[1.3812719517914946`, 1, -3.7622355809501045`], 
     Hue[1.3160294290869645`, 1, -3.5827006632213916`], 
     Hue[1.3814657866800575`, 1, -3.3873825464970606`], 
     Hue[1.316264177382912, 1, -3.2077138434583654`], 
     Hue[1.3815539445285545`, 1, -3.01280639824786], 
     Hue[1.3164561117842046`, 1, -2.832802146687243], 
     Hue[1.3816160697113864`, 1, -2.638223195020557], 
     Hue[1.3203549429939587`, 1, -2.4466984325503445`], 
     Hue[1.3796525385387597`, 1, -2.269506600212793], 
     Hue[1.320245359649862, 1, -2.0723013624021656`], 
     Hue[1.3830450399498075`, 1, -1.8843671916416695`], 
     Hue[1.320004164915556, 1, -1.6977195209968092`], 
     Hue[1.3827790768555643`, 1, -1.5092478821680235`], 
     Hue[1.3194726324316053`, 1, -1.3227337988879657`], 
     Hue[1.378831218077815, 1, -1.1432397567278498`], 
     Hue[1.318298100578402, 1, -0.9468717426433093], 
     Hue[1.3767445170237027`, 1, -0.7673080364520883], 
     Hue[1.313761994068642, 1, -0.5752414041111065], 
     Hue[1.3720683467150763`, 1, -0.3896596612608816], 
     Hue[1.3051238948635981`, 1, -0.20359300187095908`], 
     Hue[1.3604292452132007`, 1, -0.012884074277460078`], 
     Hue[1.4140443640173985`, 1, 0.1734598196964896], 
     Hue[1.2889154998631576`, 1, 0.1708125840397401], 
     Hue[1.334103072190274, 1, 0.35880534904367933`], 
     Hue[1.3773466039360702`, 1, 0.5481810478560916], 
     Hue[1.2567702807206858`, 1, 0.5461746803867178], 
     Hue[1.2840435755698274`, 1, 0.7340715513364942], 
     Hue[1.304376899894174, 1, 0.9218943964880908], 
     Hue[1.318404063166755, 1, 1.1092861575853532`], 
     Hue[1.1935804809015433`, 1, 0.9216687278959734], 
     Hue[1.185006663208545, 1, 1.1093757430574873`], 
     Hue[1.1480874229428886`, 1, 1.2970631659582135`], 
     Hue[1.0947343703837389`, 1, 1.1097372700960562`], 
     Hue[1.0307188970879475`, 1, 1.1095285219741282`], 
     Hue[1.4928641563167553`, 1, -17.27618334189528], 
     Hue[1.4301667557592892`, 1, -17.089062133554293`], 
     Hue[1.4899558296307402`, 1, -16.91062086407678], 
     Hue[1.4301667557592892`, 1, -16.714819716872324`], 
     Hue[1.4899558296307402`, 1, -16.53637844739481], 
     Hue[1.4301667557592892`, 1, -16.34057730019035], 
     Hue[1.4904303460900374`, 1, -16.16071983016143], 
     Hue[1.4301667557592892`, 1, -15.966334883508381`], 
     Hue[1.4907862334345106`, 1, -15.7854152630659], 
     Hue[1.4301667557592892`, 1, -15.592092466826411`], 
     Hue[1.4947009942237124`, 1, -15.399489191834807`], 
     Hue[1.4301667557592892`, 1, -15.217850050144438`], 
     Hue[1.4947009942237124`, 1, -15.025246775152837`], 
     Hue[1.430166755759289, 1, -14.843607633462467`], 
     Hue[1.4947009942237124`, 1, -14.65100435847086], 
     Hue[1.4301667557592888`, 1, -14.469365216780494`], 
     Hue[1.4947009942237122`, 1, -14.276761941788891`], 
     Hue[1.4301667557592883`, 1, -14.095122800098519`], 
     Hue[1.4947009942237122`, 1, -13.902519525106912`], 
     Hue[1.4321260495267076`, 1, -13.715032845655884`], 
     Hue[1.49561941317719, 1, -13.525536075099625`], 
     Hue[1.4321260495267052`, 1, -13.340790428973897`], 
     Hue[1.4956194131771898`, 1, -13.151293658417627`], 
     Hue[1.4321260495266996`, 1, -12.966548012291891`], 
     Hue[1.4956194131771894`, 1, -12.777051241735599`], 
     Hue[1.4321260495266874`, 1, -12.59230559560984], 
     Hue[1.495619413177188, 1, -12.402808825053496`], 
     Hue[1.432126049526661, 1, -12.218063178927693`], 
     Hue[1.4956194131771854`, 1, -12.02856640837124], 
     Hue[1.4331056964103142`, 1, -11.840896993365005`], 
     Hue[1.4960786226539209`, 1, -11.652953475025981`], 
     Hue[1.433105696410187, 1, -11.466654576682185`], 
     Hue[1.4960786226539096`, 1, -11.278711058342626`], 
     Hue[1.433105696409907, 1, -11.092412159998343`], 
     Hue[1.4960786226538842`, 1, -10.904468641657614`], 
     Hue[1.4335955198511512`, 1, -10.716707858872063`], 
     Hue[1.4981527187904866`, 1, -10.524036058042476`], 
     Hue[1.4339628874312003`, 1, -10.341369028850833`], 
     Hue[1.4983191822257567`, 1, -10.149296829055363`], 
     Hue[1.438003930823732, 1, -9.955066065516121], 
     Hue[1.498374670037421, 1, -9.774888808243833], 
     Hue[1.4380039308174506`, 1, -9.580823648788483], 
     Hue[1.498374670037174, 1, -9.400646391489726], 
     Hue[1.4380039308036392`, 1, -9.206581232006098], 
     Hue[1.4983746700366314`, 1, -9.02640397464915], 
     Hue[1.4380039307732715`, 1, -8.832338815103347], 
     Hue[0.5001502800145567, 1, -8.64686222651564], 
     Hue[1.4380039307065013`, 1, -8.458096397935938], 
     Hue[0.5001502800148021, 1, -8.27261980905826], 
     Hue[1.4380039305596921`, 1, -8.083853980186625], 
     Hue[0.5001502800153415, 1, -7.898377390671372], 
     Hue[1.4380039302368988`, 1, -7.709611561157856], 
     Hue[0.5001502800165274, 1, -7.524134970240749], 
     Hue[1.4380039295271638`, 1, -7.335369139315916], 
     Hue[0.5001502800191351, 1, -7.149892545316514], 
     Hue[1.4380039279666503`, 1, -6.961126711288581], 
     Hue[0.5010380850757656, 1, -6.773000444779007], 
     Hue[1.438003924535506, 1, -6.586884269661244], 
     Hue[0.5010380851633343, 1, -6.398757988028554], 
     Hue[1.4399632110085347`, 1, -6.206794258617431], 
     Hue[0.5019105836620661, 1, -6.021911500707803], 
     Hue[1.4399631947203875`, 1, -5.83255171923798], 
     Hue[0.5019105844454923, 1, -5.647668889263631], 
     Hue[1.4399631589071613`, 1, -5.458309032777593], 
     Hue[0.5023468359029639, 1, -5.272124051395792], 
     Hue[1.439963080163494, 1, -5.084066022925953], 
     Hue[0.5025649658773651, 1, -4.897229692850152], 
     Hue[1.4399629070269375`, 1, -4.709822302023339], 
     Hue[0.50627312457024, 1, -4.511918188115867], 
     Hue[1.4409421798442201`, 1, -4.332653203542323], 
     Hue[0.5031982200027636, 1, -4.146848363609457], 
     Hue[1.4409413507409248`, 1, -3.9584044273754015`], 
     Hue[0.5066713201820641, 1, -3.7622305737290382`], 
     Hue[1.441429367371112, 1, -3.5826860334788293`], 
     Hue[0.5068706475249176, 1, -3.3873715598263647`], 
     Hue[1.4416703077767958`, 1, -3.207681676090444], 
     Hue[0.5069708848903307, 1, -3.012782263343169], 
     Hue[1.441845269709066, 1, -2.8328228108687545`], 
     Hue[0.5070471514099975, 1, -2.638207291343427], 
     Hue[1.4458073498569732`, 1, -2.446543136500548], 
     Hue[0.5051527591654066, 1, -2.2693874930066764`], 
     Hue[1.445766832232526, 1, -2.07195955212727], 
     Hue[0.5053137722143535, 1, -1.894156210674215], 
     Hue[1.4456775399617066`, 1, -1.6969662465236064`], 
     Hue[0.50532675140157, 1, -1.518755426106012], 
     Hue[1.4454802137587568`, 1, -1.3210691738883378`], 
     Hue[0.5049901932661769, 1, -1.1430457157237461`], 
     Hue[1.4409652296832611`, 1, -0.95546204752102], 
     Hue[0.503555222819094, 1, -0.7676012417399836], 
     Hue[1.438063940473946, 1, -0.57909533112383], 
     Hue[0.5010883271218367, 1, -0.3884292836520067], 
     Hue[1.4305537480146007`, 1, -0.20354821614274377`], 
     Hue[1.4916395764631973`, 1, -0.014323466004407592`], 
     Hue[0.556447959727681, 1, 0.17209196591530562`], 
     Hue[1.4693261689383865`, 1, 0.35842195981453084`], 
     Hue[0.5333035189081159, 1, 0.5480385118247914], 
     Hue[1.4200465999926077`, 1, 0.7338704192940522], 
     Hue[1.4680282394320714`, 1, 0.9216438339278302], 
     Hue[0.530804496528006, 1, 1.1095784560830864`], 
     Hue[1.3267302176528737`, 1, 1.2972546146163593`], 
     Hue[0.9953320593036955, 1, 1.2972992845800677`], 
     Hue[1.0085077868342247`, 1, 1.1094932875337582`], 
     Hue[0.618258957431687, 1, -17.27618334189528], 
     Hue[0.5555615568742204, 1, -17.089062133554293`], 
     Hue[0.6153506307456719, 1, -16.91062086407678], 
     Hue[0.5555615568742204, 1, -16.714819716872324`], 
     Hue[0.615350630745672, 1, -16.53637844739481], 
     Hue[0.5555615568742204, 1, -16.34057730019035], 
     Hue[0.6158251472049693, 1, -16.16071983016143], 
     Hue[0.5555615568742204, 1, -15.966334883508381`], 
     Hue[0.6161810345494423, 1, -15.7854152630659], 
     Hue[0.5555615568742204, 1, -15.592092466826411`], 
     Hue[0.6200957953386441, 1, -15.399489191834807`], 
     Hue[0.5555615568742205, 1, -15.217850050144438`], 
     Hue[0.6200957953386443, 1, -15.025246775152837`], 
     Hue[0.5555615568742205, 1, -14.843607633462467`], 
     Hue[0.6200957953386446, 1, -14.651004358470864`], 
     Hue[0.5555615568742207, 1, -14.469365216780494`], 
     Hue[0.6200957953386451, 1, -14.276761941788891`], 
     Hue[0.5555615568742212, 1, -14.095122800098519`], 
     Hue[0.6200957953386463, 1, -13.902519525106916`], 
     Hue[0.5575208506416431, 1, -13.715032845655884`], 
     Hue[0.6210142142921266, 1, -13.52553607509963], 
     Hue[0.5575208506416454, 1, -13.340790428973897`], 
     Hue[0.6210142142921328, 1, -13.151293658417641`], 
     Hue[0.55752085064165, 1, -12.96654801229189], 
     Hue[0.6210142142921464, 1, -12.777051241735627`], 
     Hue[0.5575208506416603, 1, -12.592305595609835`], 
     Hue[0.6210142142921764, 1, -12.402808825053562`], 
     Hue[0.5575208506416831, 1, -12.218063178927684`], 
     Hue[0.6210142142922424, 1, -12.028566408371383`], 
     Hue[0.5585004975254452, 1, -11.84089699336499], 
     Hue[0.6214734237691288, 1, -11.652953475026301`], 
     Hue[0.5585004975255573, 1, -11.46665457668215], 
     Hue[0.6214734237694494, 1, -11.278711058343331`], 
     Hue[0.558500497525804, 1, -11.092412159998267`], 
     Hue[0.621473423770154, 1, -10.904468641659161`], 
     Hue[0.558990320968213, 1, -10.716707858871914`], 
     Hue[0.6235475199083849, 1, -10.524036058046036`], 
     Hue[0.5593576885508278, 1, -10.341369028850538`], 
     Hue[0.6237139833472146, 1, -10.14929682906322], 
     Hue[0.5633987319492564, 1, -9.955066065516261], 
     Hue[0.6237694711667054, 1, -9.77488880826113], 
     Hue[0.5633987319556726, 1, -9.580823648788789], 
     Hue[0.6237694711836645, 1, -9.400646391527754], 
     Hue[0.5633987319697801, 1, -9.206581232006771], 
     Hue[0.6237694712209528, 1, -9.026403974732764], 
     Hue[0.5633987320007985, 1, -8.832338815104828], 
     Hue[0.6255450812830659, 1, -8.646862226706672], 
     Hue[0.5633987320689994, 1, -8.458096397939196], 
     Hue[0.6255450814674088, 1, -8.272619809478282], 
     Hue[0.5633987322189546, 1, -8.083853980193782], 
     Hue[0.6255450818727284, 1, -7.898377391594891], 
     Hue[0.5633987325486656, 1, -7.709611561173596], 
     Hue[0.6255450827639161, 1, -7.524134972271313], 
     Hue[0.5633987332736099, 1, -7.335369139350523], 
     Hue[0.6255450847233947, 1, -7.149892549781176], 
     Hue[0.563398734867565, 1, -6.961126711364675], 
     Hue[0.6264328941082238, 1, -6.773000454782462], 
     Hue[0.5633987383722381, 1, -6.586884269828555], 
     Hue[0.6264329036867498, 1, -6.398758010023428], 
     Hue[0.5653580404380375, 1, -6.206794260030254], 
     Hue[0.6273054231740273, 1, -6.0219115499633595`], 
     Hue[0.5653580580913606, 1, -5.832551722344393], 
     Hue[0.6273054699850522, 1, -5.647668997563255], 
     Hue[0.5653580969062388, 1, -5.458309039607756], 
     Hue[0.6277418229342748, 1, -5.272124291692931], 
     Hue[0.5653581822497307, 1, -5.084066037943658], 
     Hue[0.6279601760895901, 1, -4.897230223598309], 
     Hue[0.5653583698975503, 1, -4.70982233504336], 
     Hue[0.6316688368106498, 1, -4.511919446295547], 
     Hue[0.5663384447937359, 1, -4.332653303487016], 
     Hue[0.628595003312114, 1, -4.146850963307253], 
     Hue[0.5663393704718369, 1, -3.958404647132374], 
     Hue[0.6320705320410032, 1, -3.762236704765673], 
     Hue[0.5668312668336426, 1, -3.5826865833887007`], 
     Hue[0.6322751534381319, 1, -3.3873850944777883`], 
     Hue[0.5670807406234188, 1, -3.207682959011593], 
     Hue[0.6323870327800822, 1, -3.012812086044481], 
     Hue[0.5672744841963087, 1, -2.8328257542909334`], 
     Hue[0.6324889070524355, 1, -2.6382729852201745`], 
     Hue[0.5712796778429132, 1, -2.446555569032186], 
     Hue[0.630650174785437, 1, -2.2695267032223096`], 
     Hue[0.5713322132628529, 1, -2.071986926310937], 
     Hue[0.6343021896512498, 1, -1.884443313565664], 
     Hue[0.5714479785303787, 1, -1.6970266212934468`], 
     Hue[0.6345984846067881, 1, -1.5094158401623547`], 
     Hue[0.5717037499759633, 1, -1.3212028290094617`], 
     Hue[0.6318874060472863, 1, -1.1433472976684371`], 
     Hue[0.5681512129812802, 1, -0.9556151957120405], 
     Hue[0.6350170512619757, 1, -0.7603094081923039], 
     Hue[0.5674156241357861, 1, -0.5792986547480163], 
     Hue[0.6332452308389993, 1, -0.3916414907046928], 
     Hue[0.5657512998692265, 1, -0.20012530354342073`], 
     Hue[0.6336512750663916, 1, -0.016271912502853203`], 
     Hue[0.6318574554533375, 1, 0.35850527402864796`], 
     Hue[0.6163524861543648, 1, 0.7343781622397207], 
     Hue[0.8738401880121895, 1, 1.1093018894662154`], 
     Hue[0.947898673094591, 1, 1.1094388065761398`], 
     Hue[0.9227127069274325, 1, 1.2970413545711], 
     Hue[0.9752572783732083, 1, 1.1093510045546229`], 
     Hue[0.9908934698083961, 1, 1.1093496333721422`], 
     Hue[0.7436537585466187, 1, -17.27618334189528], 
     Hue[0.6809563579891521, 1, -17.089062133554293`], 
     Hue[0.740745431860603, 1, -16.91062086407678], 
     Hue[0.6809563579891521, 1, -16.714819716872324`], 
     Hue[0.740745431860603, 1, -16.53637844739481], 
     Hue[0.6809563579891521, 1, -16.34057730019035], 
     Hue[0.741219948319901, 1, -16.16071983016143], 
     Hue[0.6809563579891521, 1, -15.966334883508381`], 
     Hue[0.741575835664374, 1, -15.7854152630659], 
     Hue[0.6809563579891522, 1, -15.592092466826411`], 
     Hue[0.7454905964535754, 1, -15.399489191834807`], 
     Hue[0.6809563579891522, 1, -15.217850050144438`], 
     Hue[0.7454905964535755, 1, -15.025246775152837`], 
     Hue[0.6809563579891524, 1, -14.843607633462467`], 
     Hue[0.7454905964535758, 1, -14.651004358470864`], 
     Hue[0.680956357989153, 1, -14.469365216780497`], 
     Hue[0.7454905964535767, 1, -14.276761941788894`], 
     Hue[0.6809563579891542, 1, -14.095122800098522`], 
     Hue[0.7454905964535785, 1, -13.902519525106923`], 
     Hue[0.6829156517565778, 1, -13.715032845655891`], 
     Hue[0.7464090154070606, 1, -13.525536075099648`], 
     Hue[0.6829156517565832, 1, -13.340790428973913`], 
     Hue[0.7464090154070696, 1, -13.151293658417675`], 
     Hue[0.6829156517565953, 1, -12.966548012291927`], 
     Hue[0.7464090154070895, 1, -12.777051241735704`], 
     Hue[0.6829156517566219, 1, -12.592305595609918`], 
     Hue[0.7464090154071329, 1, -12.402808825053729`], 
     Hue[0.6829156517566806, 1, -12.21806317892787], 
     Hue[0.7464090154072285, 1, -12.02856640837175], 
     Hue[0.6838952986405216, 1, -11.840896993365401`], 
     Hue[0.7468682248841799, 1, -11.652953475027113`], 
     Hue[0.6838952986408071, 1, -11.466654576683053`], 
     Hue[0.7468682248846434, 1, -11.278711058345115`], 
     Hue[0.6838952986414352, 1, -11.092412160000258`], 
     Hue[0.7468682248856626, 1, -10.904468641663083`], 
     Hue[0.6843851220846827, 1, -10.716707858876319`], 
     Hue[0.7489423210245628, 1, -10.524036058054824`], 
     Hue[0.684752489669141, 1, -10.341369028860266`], 
     Hue[0.7491087844648839, 1, -10.149296829082568`], 
     Hue[0.6887935330716266, 1, -9.955066065538768], 
     Hue[0.7491642722876536, 1, -9.774888808303695], 
     Hue[0.6887935330869595, 1, -9.58082364883828], 
     Hue[0.7491642723118246, 1, -9.400646391621345], 
     Hue[0.6887935331206723, 1, -9.206581232115585], 
     Hue[0.7491642723649699, 1, -9.026403974938543], 
     Hue[0.6887935331947976, 1, -8.832338815344078], 
     Hue[0.7509398824609509, 1, -8.646862227166324], 
     Hue[0.6887935333577788, 1, -8.458096398465242], 
     Hue[0.7509398827207583, 1, -8.27261981048893], 
     Hue[0.6887935337161302, 1, -8.083853981350419], 
     Hue[0.7509398832920038, 1, -7.898377393817031], 
     Hue[0.688793534504047, 1, -7.709611563716721], 
     Hue[0.7509398845480171, 1, -7.524134977157199], 
     Hue[0.6887935362364617, 1, -7.335369144942162], 
     Hue[0.750939887309648, 1, -7.149892560523901], 
     Hue[0.6887935400455693, 1, -6.961126723659162], 
     Hue[0.7518276984318422, 1, -6.773000478588706], 
     Hue[0.6887935484207591, 1, -6.586884296860785], 
     Hue[0.7518277118567086, 1, -6.398758062366874], 
     Hue[0.6907528611890998, 1, -6.20679432092904], 
     Hue[0.7527002396735135, 1, -6.021911665938459], 
     Hue[0.6907529023807925, 1, -5.832551856244276], 
     Hue[0.7527003049264013, 1, -5.647669252560961], 
     Hue[0.6907529929501277, 1, -5.45830933401734], 
     Hue[0.7531366981116756, 1, -5.272124854510656], 
     Hue[0.690753192087555, 1, -5.084066685271211], 
     Hue[0.7533551397012407, 1, -4.897231463445749], 
     Hue[0.6907536299371717, 1, -4.709823758345619], 
     Hue[0.7570639817500535, 1, -4.511922261320402], 
     Hue[0.691734254675389, 1, -4.332656470880923], 
     Hue[0.7539905850840591, 1, -4.146856990497365], 
     Hue[0.6917363895877078, 1, -3.9584116114956744`], 
     Hue[0.7574669879581664, 1, -3.7622503604661883`], 
     Hue[0.6922309438855245, 1, -3.5827019888059066`], 
     Hue[0.7576735846023677, 1, -3.387415171675599], 
     Hue[0.6924862615389853, 1, -3.207716935767162], 
     Hue[0.7577898047464183, 1, -3.0128782781964754`], 
     Hue[0.6927234782784457, 1, -2.8328092892209176`], 
     Hue[0.7579136526164034, 1, -2.6383815358600815`], 
     Hue[0.6967261761092975, 1, -2.4467283829724424`], 
     Hue[0.7561876387571398, 1, -2.269533816573059], 
     Hue[0.6968406687163187, 1, -2.07236725312769], 
     Hue[0.7597797398305222, 1, -1.8851579092616013`], 
     Hue[0.6970926077650168, 1, -1.6978645797627723`], 
     Hue[0.7601742206697062, 1, -1.5109893931853617`], 
     Hue[0.6976475213496036, 1, -1.3230536256335867`], 
     Hue[0.7610411297491976, 1, -1.1369196763433116`], 
     Hue[0.6988722684603534, 1, -0.9475791887139564], 
     Hue[0.7629448497264653, 1, -0.7631062151067531], 
     Hue[0.7015871845127029, 1, -0.5707168985232263], 
     Hue[0.7671168394721002, 1, -0.39004330112155894`], 
     Hue[0.7028548786448408, 1, -0.20366946222163573`], 
     Hue[0.7775280181873198, 1, -0.016309357280369863`], 
     Hue[0.7118149755387756, 1, 0.17126692314580905`], 
     Hue[0.805005669518421, 1, 0.3590793772762293], 
     Hue[0.7335260170003126, 1, 0.5463336109619846], 
     Hue[0.86904855966155, 1, -17.27618334189528], 
     Hue[0.8063511591040838, 1, -17.089062133554293`], 
     Hue[0.8661402329755348, 1, -16.91062086407678], 
     Hue[0.8063511591040838, 1, -16.714819716872324`], 
     Hue[0.8661402329755348, 1, -16.53637844739481], 
     Hue[0.8063511591040838, 1, -16.34057730019035], 
     Hue[0.8666147494348322, 1, -16.16071983016143], 
     Hue[0.8063511591040838, 1, -15.966334883508381`], 
     Hue[0.8669706367793052, 1, -15.7854152630659], 
     Hue[0.806351159104084, 1, -15.592092466826411`], 
     Hue[0.870885397568507, 1, -15.399489191834807`], 
     Hue[0.806351159104084, 1, -15.217850050144438`], 
     Hue[0.8708853975685071, 1, -15.025246775152837`], 
     Hue[0.8063511591040843, 1, -14.843607633462467`], 
     Hue[0.8708853975685075, 1, -14.651004358470864`], 
     Hue[0.8063511591040848, 1, -14.469365216780497`], 
     Hue[0.870885397568508, 1, -14.276761941788898`], 
     Hue[0.806351159104086, 1, -14.095122800098528`], 
     Hue[0.8708853975685094, 1, -13.90251952510693], 
     Hue[0.808310452871509, 1, -13.715032845655903`], 
     Hue[0.8718038165219902, 1, -13.525536075099662`], 
     Hue[0.8083104528715146, 1, -13.340790428973937`], 
     Hue[0.8718038165219968, 1, -13.15129365841771], 
     Hue[0.808310452871527, 1, -12.966548012291982`], 
     Hue[0.871803816522011, 1, -12.777051241735782`], 
     Hue[0.8083104528715543, 1, -12.592305595610043`], 
     Hue[0.8718038165220423, 1, -12.4028088250539], 
     Hue[0.8083104528716142, 1, -12.21806317892814], 
     Hue[0.8718038165221114, 1, -12.028566408372125`], 
     Hue[0.8092900997554576, 1, -11.840896993365998`], 
     Hue[0.8722630259990032, 1, -11.652953475027937`], 
     Hue[0.8092900997557484, 1, -11.466654576684368`], 
     Hue[0.8722630259993366, 1, -11.278711058346929`], 
     Hue[0.8092900997563875, 1, -11.09241216000314], 
     Hue[0.8722630260000697, 1, -10.904468641667071`], 
     Hue[0.8097799231996535, 1, -10.716707858882677`], 
     Hue[0.874337122138287, 1, -10.52403605806366], 
     Hue[0.810147290784148, 1, -10.341369028874283`], 
     Hue[0.8745035855771508, 1, -10.149296829102008`], 
     Hue[0.8141883341864586, 1, -9.955066065570383], 
     Hue[0.8745590733967191, 1, -9.774888808346446], 
     Hue[0.8141883342016725, 1, -9.580823648907787], 
     Hue[0.8745590734138581, 1, -9.400646391715343], 
     Hue[0.8141883342351237, 1, -9.206581232268414], 
     Hue[0.8745590734515419, 1, -9.02640397514522], 
     Hue[0.814188334308674, 1, -8.832338815680108], 
     Hue[0.8763346835111142, 1, -8.646862227623725], 
     Hue[0.8141883344703909, 1, -8.458096399204083], 
     Hue[0.8763346836932819, 1, -8.27261981149463], 
     Hue[0.8141883348259622, 1, -8.083853982974924], 
     Hue[0.8763346840938189, 1, -7.89837739602829], 
     Hue[0.8141883356077666, 1, -7.709611567288568], 
     Hue[0.8763346849744906, 1, -7.524134982019151], 
     Hue[0.8141883373267413, 1, -7.335369152795683], 
     Hue[0.8763346869108478, 1, -7.149892571214015], 
     Hue[0.8141883411062985, 1, -6.961126740926914], 
     Hue[0.8772224961557468, 1, -6.773000502168744], 
     Hue[0.8141883494165142, 1, -6.586884334827863], 
     Hue[0.8772225055156947, 1, -6.398758114212949], 
     Hue[0.8161476616901729, 1, -6.206794405426178], 
     Hue[0.878095024094437, 1, -6.021911780289062], 
     Hue[0.8161477021460002, 1, -5.832552042030453], 
     Hue[0.8780950693357346, 1, -5.647669503986699], 
     Hue[0.8161477910973071, 1, -5.458309742510501], 
     Hue[0.8785314177905584, 1, -5.27212540818021], 
     Hue[0.816147986676835, 1, -5.084067583436299], 
     Hue[0.878749760954749, 1, -4.897232681747418], 
     Hue[0.8161484167021704, 1, -4.709825733165639], 
     Hue[0.882458356781352, 1, -4.51192497427861], 
     Hue[0.8171290150252318, 1, -4.332660839113699], 
     Hue[0.8793845053155296, 1, -4.146862893262279], 
     Hue[0.8171311010286781, 1, -3.9584212160419945`], 
     Hue[0.8828597129558077, 1, -3.7622634930560928`], 
     Hue[0.8176255251733029, 1, -3.5827231697220707`], 
     Hue[0.8830638027825471, 1, -3.3874440646157638`], 
     Hue[0.8178805535145145, 1, -3.207763576071347], 
     Hue[0.8831745081745304, 1, -3.012941821507055], 
     Hue[0.818143898175302, 1, -2.8328320541457153`], 
     Hue[0.8832970888777285, 1, -2.638488805873405], 
     Hue[0.8221163868817756, 1, -2.4469595474165553`], 
     Hue[0.881612687846611, 1, -2.269608104885389], 
     Hue[0.8222252578452444, 1, -2.0728754782565284`], 
     Hue[0.8850633662086467, 1, -1.8858360483097656`], 
     Hue[0.8224643800742746, 1, -1.6989818193179713`], 
     Hue[0.885323799009737, 1, -1.5124774309853237`], 
     Hue[0.8229889089293541, 1, -1.3255090822616535`], 
     Hue[0.885893024408283, 1, -1.1401769128018022`], 
     Hue[0.8241362176767845, 1, -0.9529725930189159], 
     Hue[0.8887773780214053, 1, -0.7654149674680049], 
     Hue[0.8286153549031494, 1, -0.576953011609757], 
     Hue[0.8969973403778811, 1, -0.385003592428629], 
     Hue[0.8379947664380643, 1, -0.20112990119812046`], 
     Hue[0.9089724397819429, 1, -0.015286367875510631`], 
     Hue[0.8582018081612239, 1, 0.17158815882198142`], 
     Hue[0.9395747472840115, 1, 0.3584400024433647], 
     Hue[0.9125042292732457, 1, 0.5465386478236496], 
     Hue[0.9027929338100422, 1, 0.7338487085115664], 
     Hue[0.9750897537926272, 1, 0.9218184644620283], 
     Hue[0.9944433607764817, 1, -17.27618334189528], 
     Hue[0.9317459602190161, 1, -17.089062133554293`], 
     Hue[0.9915350340904666, 1, -16.91062086407678], 
     Hue[0.9317459602190161, 1, -16.714819716872324`], 
     Hue[0.9915350340904666, 1, -16.53637844739481], 
     Hue[0.9317459602190161, 1, -16.34057730019035], 
     Hue[0.9920095505497639, 1, -16.16071983016143], 
     Hue[0.9317459602190161, 1, -15.966334883508381`], 
     Hue[0.9923654378942369, 1, -15.7854152630659], 
     Hue[0.9317459602190161, 1, -15.592092466826411`], 
     Hue[0.9962801986834386, 1, -15.399489191834807`], 
     Hue[0.9317459602190162, 1, -15.217850050144438`], 
     Hue[0.9962801986834386, 1, -15.025246775152837`], 
     Hue[0.9317459602190163, 1, -14.843607633462467`], 
     Hue[0.9962801986834386, 1, -14.651004358470868`], 
     Hue[0.9317459602190166, 1, -14.469365216780501`], 
     Hue[0.9962801986834388, 1, -14.276761941788898`], 
     Hue[0.931745960219017, 1, -14.095122800098533`], 
     Hue[0.9962801986834388, 1, -13.902519525106934`], 
     Hue[0.9337052539864387, 1, -13.715032845655912`], 
     Hue[0.9971986176369173, 1, -13.52553607509967], 
     Hue[0.9337052539864411, 1, -13.340790428973957`], 
     Hue[0.9971986176369174, 1, -13.151293658417725`], 
     Hue[0.9337052539864464, 1, -12.966548012292023`], 
     Hue[0.9971986176369179, 1, -12.777051241735814`], 
     Hue[0.9337052539864582, 1, -12.592305595610132`], 
     Hue[0.9971986176369185, 1, -12.402808825053972`], 
     Hue[0.9337052539864842, 1, -12.218063178928334`], 
     Hue[0.9971986176369203, 1, -12.028566408372287`], 
     Hue[0.9346849008702512, 1, -11.840896993366426`], 
     Hue[0.9976578271136624, 1, -11.652953475028289`], 
     Hue[0.9346849008703758, 1, -11.466654576685311`], 
     Hue[0.9976578271136692, 1, -11.278711058347703`], 
     Hue[0.9346849008706496, 1, -11.092412160005217`], 
     Hue[0.9976578271136842, 1, -10.904468641668775`], 
     Hue[0.9351747243131018, 1, -10.716707858887245`], 
     Hue[0.9997319232502688, 1, -10.524036058067336`], 
     Hue[0.9355420918958044, 1, -10.341369028884328`], 
     Hue[0.9998983866855858, 1, -10.149296829110082`], 
     Hue[0.9395831352938119, 1, -9.95506606559247], 
     Hue[0.999953874497358, 1, -9.77488880836419], 
     Hue[0.9395831352999413, 1, -9.580823648956352], 
     Hue[0.999953874497365, 1, -9.400646391754359], 
     Hue[0.9395831353134182, 1, -9.206581232375198], 
     Hue[0.9999538744973804, 1, -9.026403975231005], 
     Hue[0.9395831353430504, 1, -8.832338815914897], 
     Hue[1.0017294844717222`, 1, -8.646862227809327], 
     Hue[0.9395831354082033, 1, -8.458096399720317], 
     Hue[1.0017294844688989`, 1, -8.272619811902722], 
     Hue[0.9395831355514568, 1, -8.083853984109984], 
     Hue[1.0017294844626914`, 1, -7.898377396925574], 
     Hue[0.9395831358664322, 1, -7.709611569784253], 
     Hue[1.0017294844490428`, 1, -7.524134983992034], 
     Hue[0.9395831365589773, 1, -7.335369158283014], 
     Hue[1.001729484419033, 1, -7.149892575551843], 
     Hue[0.9395831380816951, 1, -6.961126752992063], 
     Hue[1.0026172892782654`, 1, -6.773000511626889], 
     Hue[0.9395831414297366, 1, -6.586884361355832], 
     Hue[1.00261728905749, 1, -6.398758135008826], 
     Hue[0.9415424423030109, 1, -6.206794463727599], 
     Hue[1.0034897862745715`, 1, -6.021911825628527], 
     Hue[0.9415424581824157, 1, -5.832552170219339], 
     Hue[1.0034897848436828`, 1, -5.647669603675756], 
     Hue[0.9415424930968704, 1, -5.458310024362698], 
     Hue[1.003926029961395, 1, -5.272125626425702], 
     Hue[0.9415425698641013, 1, -5.084068203151352], 
     Hue[1.0041441458436955`, 1, -4.8972331605641966`], 
     Hue[0.9415427386536441, 1, -4.709827095744774], 
     Hue[1.0078522130020817`, 1, -4.511925986451719], 
     Hue[0.9425227498890689, 1, -4.332663833994419], 
     Hue[1.0047772831438428`, 1, -4.1468651932208065`], 
     Hue[0.9425235577506234, 1, -3.9584278008412914`], 
     Hue[1.008249930649166, 1, -3.7622683641001444`], 
     Hue[0.943015140781144, 1, -3.582737644346671], 
     Hue[1.0084485094778382`, 1, -3.387454749564018], 
     Hue[0.9432639192046708, 1, -3.20779539535423], 
     Hue[1.0085470973926112`, 1, -3.0129652837519787`], 
     Hue[0.947435218892688, 1, -2.8211997637640307`], 
     Hue[1.006517841558813, 1, -2.6448831916385487`], 
     Hue[0.947453079432316, 1, -2.4471128601862677`], 
     Hue[1.0069210146156486`, 1, -2.2696657170971317`], 
     Hue[0.9474923088003646, 1, -2.0732122164995204`], 
     Hue[1.0102190057170444`, 1, -1.8860797229927895`], 
     Hue[0.9475783653395022, 1, -1.6997205029302445`], 
     Hue[1.0101937541868362`, 1, -1.5130108895193437`], 
     Hue[0.9477666275731054, 1, -1.3271250016871086`], 
     Hue[1.010138668840875, 1, -1.1413387525363439`], 
     Hue[0.9501169790998276, 1, -0.9507473039990917], 
     Hue[1.0123820425948051`, 1, -0.7656267004008421], 
     Hue[0.9526521030751722, 1, -0.5795592881020555], 
     Hue[1.01724003378067, 1, -0.38805900057208853`], 
     Hue[0.9611501030510833, 1, -0.20327016795456654`], 
     Hue[1.0250152120768983`, 1, -0.013665702509591204`], 
     Hue[0.9779635164827333, 1, 0.17150954731596435`], 
     Hue[1.0386115395107476`, 1, 0.3586581036225207], 
     Hue[1.009812893127442, 1, 0.5471833617982944], 
     Hue[0.9999181730813879, 1, 0.7344400618133653], 
     Hue[1.0111835488307621`, 1, 0.9217495940654652], 
     Hue[1.1198381618914135`, 1, -17.27618334189528], 
     Hue[1.0571407613339472`, 1, -17.089062133554293`], 
     Hue[1.1169298352053978`, 1, -16.91062086407678], 
     Hue[1.0571407613339472`, 1, -16.714819716872324`], 
     Hue[1.1169298352053978`, 1, -16.53637844739481], 
     Hue[1.0571407613339472`, 1, -16.34057730019035], 
     Hue[1.117404351664695, 1, -16.16071983016143], 
     Hue[1.0571407613339472`, 1, -15.966334883508381`], 
     Hue[1.117760239009168, 1, -15.7854152630659], 
     Hue[1.0571407613339472`, 1, -15.592092466826411`], 
     Hue[1.1216749997983697`, 1, -15.399489191834807`], 
     Hue[1.0571407613339472`, 1, -15.217850050144438`], 
     Hue[1.1216749997983697`, 1, -15.025246775152837`], 
     Hue[1.0571407613339472`, 1, -14.843607633462467`], 
     Hue[1.1216749997983693`, 1, -14.651004358470864`], 
     Hue[1.057140761333947, 1, -14.469365216780501`], 
     Hue[1.1216749997983688`, 1, -14.276761941788898`], 
     Hue[1.0571407613339465`, 1, -14.095122800098533`], 
     Hue[1.1216749997983675`, 1, -13.90251952510693], 
     Hue[1.0591000551013665`, 1, -13.715032845655912`], 
     Hue[1.1225934187518436`, 1, -13.525536075099664`], 
     Hue[1.0591000551013643`, 1, -13.340790428973957`], 
     Hue[1.1225934187518374`, 1, -13.15129365841771], 
     Hue[1.0591000551013594`, 1, -12.966548012292025`], 
     Hue[1.1225934187518236`, 1, -12.777051241735784`], 
     Hue[1.059100055101349, 1, -12.592305595610133`], 
     Hue[1.1225934187517934`, 1, -12.402808825053905`], 
     Hue[1.0591000551013257`, 1, -12.218063178928341`], 
     Hue[1.1225934187517268`, 1, -12.02856640837214], 
     Hue[1.0600797019849826`, 1, -11.840896993366437`], 
     Hue[1.1230526282283178`, 1, -11.652953475027962`], 
     Hue[1.0600797019848676`, 1, -11.466654576685333`], 
     Hue[1.123052628227994, 1, -11.27871105834698], 
     Hue[1.0600797019846147`, 1, -11.092412160005264`], 
     Hue[1.123052628227282, 1, -10.904468641667188`], 
     Hue[1.0605695254259024`, 1, -10.71670785888733], 
     Hue[1.125126724362246, 1, -10.52403605806369], 
     Hue[1.0609368930060394`, 1, -10.341369028884483`], 
     Hue[1.1252931877940167`, 1, -10.149296829102035`], 
     Hue[1.064977936398152, 1, -9.955066065592018], 
     Hue[1.1253486755979945`, 1, -9.774888808346471], 
     Hue[1.0649779363915848`, 1, -9.580823648955358], 
     Hue[1.1253486755808653`, 1, -9.400646391715398], 
     Hue[1.0649779363771454`, 1, -9.206581232373008], 
     Hue[1.1253486755432032`, 1, -9.02640397514534], 
     Hue[1.0649779363453973`, 1, -8.83233881591008], 
     Hue[1.1271242854337191`, 1, -8.646862227613758], 
     Hue[1.0649779362755918`, 1, -8.45809639970973], 
     Hue[1.1271242852475687`, 1, -8.272619811472719], 
     Hue[1.0649779361221083`, 1, -8.083853984086705], 
     Hue[1.1271242848382748`, 1, -7.898377395980114], 
     Hue[1.06497793578464, 1, -7.709611569733073], 
     Hue[1.1271242839383488`, 1, -7.524134981913227], 
     Hue[1.0649779350426394`, 1, -7.33536915817048], 
     Hue[1.127124281959657, 1, -7.149892570981112], 
     Hue[1.0649779334111822`, 1, -6.96112675274463], 
     Hue[1.128012082509318, 1, -6.773000501389466], 
     Hue[1.064977929824053, 1, -6.586884360811795], 
     Hue[1.128012072837922, 1, -6.398758112499525], 
     Hue[1.0669372151094745`, 1, -6.206794461476363], 
     Hue[1.128884549158135, 1, -6.021911775238395], 
     Hue[1.0669371970547568`, 1, -5.83255216526949], 
     Hue[1.1288845018982792`, 1, -5.647669492881665], 
     Hue[1.0669371573573854`, 1, -5.458310013479339], 
     Hue[1.129320645968406, 1, -5.272125380636193], 
     Hue[1.0669370700738396`, 1, -5.084068179221877], 
     Hue[1.1295385396480082`, 1, -4.897232617734163], 
     Hue[1.0669368781618622`, 1, -4.709827043130662], 
     Hue[1.1332461072290019`, 1, -4.511924701387772], 
     Hue[1.0679160876060982`, 1, -4.332663690711755], 
     Hue[1.1301701108519921`, 1, -4.146862535109858], 
     Hue[1.0679151412949959`, 1, -3.958427485810116], 
     Hue[1.1336403418465515`, 1, -3.762262103576899], 
     Hue[1.0684028464864905`, 1, -3.5827368844112266`], 
     Hue[1.1338336523621266`, 1, -3.387440932208335], 
     Hue[1.0686430973090404`, 1, -3.207793650361321], 
     Hue[1.1339206572131308`, 1, -3.012934849847529], 
     Hue[1.0727948105593357`, 1, -2.82119307625518], 
     Hue[1.1318662588638337`, 1, -2.644818906301711], 
     Hue[1.072770489154663, 1, -2.4470981655540402`], 
     Hue[1.1321685800827113`, 1, -2.269658268328766], 
     Hue[1.0727170660925338`, 1, -2.0731799522759067`], 
     Hue[1.1353870533771246`, 1, -1.88574658792711], 
     Hue[1.0725998593536836`, 1, -1.699649780847673], 
     Hue[1.1350907618151143`, 1, -1.5122814186320082`], 
     Hue[1.072343385145559, 1, -1.3269705504367024`], 
     Hue[1.1344426986744445`, 1, -1.1397492360534447`], 
     Hue[1.0737059957355468`, 1, -0.9503431918734273], 
     Hue[1.133805602863305, 1, -0.7668933780822977], 
     Hue[1.073868040636668, 1, -0.5792877725009775], 
     Hue[1.1335525004418527`, 1, -0.3919820331563557], 
     Hue[1.0769633614016438`, 1, -0.20290971034196392`], 
     Hue[1.1335460515396298`, 1, -0.013018285784580641`], 
     Hue[1.081200662996875, 1, 0.171803010327514], 
     Hue[1.1284821150331754`, 1, 0.35907978974422194`], 
     Hue[1.085017284641174, 1, 0.5468462805849915], 
     Hue[1.0550093080675234`, 1, 0.7343007120163436], 
     Hue[1.03716977504832, 1, 0.9219881115738098], 
     Hue[1.2452329630063446`, 1, -17.27618334189528], 
     Hue[1.182535562448879, 1, -17.089062133554293`], 
     Hue[1.2423246363203295`, 1, -16.91062086407678], 
     Hue[1.182535562448879, 1, -16.714819716872324`], 
     Hue[1.2423246363203295`, 1, -16.53637844739481], 
     Hue[1.182535562448879, 1, -16.34057730019035], 
     Hue[1.2427991527796267`, 1, -16.16071983016143], 
     Hue[1.182535562448879, 1, -15.966334883508381`], 
     Hue[1.2431550401240998`, 1, -15.7854152630659], 
     Hue[1.182535562448879, 1, -15.592092466826411`], 
     Hue[1.2470698009133014`, 1, -15.399489191834807`], 
     Hue[1.182535562448879, 1, -15.217850050144438`], 
     Hue[1.2470698009133012`, 1, -15.025246775152837`], 
     Hue[1.1825355624488787`, 1, -14.843607633462467`], 
     Hue[1.2470698009133008`, 1, -14.651004358470864`], 
     Hue[1.182535562448878, 1, -14.469365216780497`], 
     Hue[1.2470698009133, 1, -14.276761941788894`], 
     Hue[1.182535562448877, 1, -14.09512280009853], 
     Hue[1.247069800913298, 1, -13.902519525106923`], 
     Hue[1.1844948562162956`, 1, -13.715032845655905`], 
     Hue[1.247988219866773, 1, -13.525536075099648`], 
     Hue[1.1844948562162898`, 1, -13.34079042897394], 
     Hue[1.2479882198667642`, 1, -13.151293658417677`], 
     Hue[1.1844948562162778`, 1, -12.966548012291986`], 
     Hue[1.2479882198667445`, 1, -12.777051241735707`], 
     Hue[1.184494856216251, 1, -12.59230559561005], 
     Hue[1.247988219866701, 1, -12.402808825053738`], 
     Hue[1.184494856216192, 1, -12.218063178928153`], 
     Hue[1.2479882198666052`, 1, -12.02856640837177], 
     Hue[1.185474503099771, 1, -11.840896993366021`], 
     Hue[1.248447429343133, 1, -11.652953475027147`], 
     Hue[1.1854745030994842`, 1, -11.466654576684418`], 
     Hue[1.2484474293426693`, 1, -11.278711058345191`], 
     Hue[1.1854745030988536`, 1, -11.092412160003255`], 
     Hue[1.2484474293416499`, 1, -10.904468641663248`], 
     Hue[1.1859643265393107`, 1, -10.716707858882883`], 
     Hue[1.25052152547596, 1, -10.524036058054865`], 
     Hue[1.1863316941176212`, 1, -10.341369028874656`], 
     Hue[1.2506879889062752`, 1, -10.149296829082603`], 
     Hue[1.1903727375057205`, 1, -9.95506606556929], 
     Hue[1.250743476707051, 1, -9.774888808303729], 
     Hue[1.1903727374903266`, 1, -9.580823648905387], 
     Hue[1.2507434766828802`, 1, -9.400646391621422], 
     Hue[1.19037273745648, 1, -9.206581232263135], 
     Hue[1.2507434766297347`, 1, -9.026403974938711], 
     Hue[1.190372737382061, 1, -8.832338815668502], 
     Hue[1.2525190864872275`, 1, -8.646862227152265], 
     Hue[1.1903727372184332`, 1, -8.45809639917856], 
     Hue[1.2525190862274482`, 1, -8.272619810458021], 
     Hue[1.1903727368586605`, 1, -8.083853982918809], 
     Hue[1.2525190856562642`, 1, -7.89837739374907], 
     Hue[1.1903727360676182`, 1, -7.709611567165186], 
     Hue[1.2525190844003866`, 1, -7.524134977007766], 
     Hue[1.190372734328332, 1, -7.335369152524394], 
     Hue[1.2525190816390532`, 1, -7.149892560195345], 
     Hue[1.1903727305041154`, 1, -6.961126740330427], 
     Hue[1.2534068804948657`, 1, -6.773000477489376], 
     Hue[1.190372722095706, 1, -6.586884333516353], 
     Hue[1.2534068670721896`, 1, -6.3987580599497464`], 
     Hue[1.1923319967917037`, 1, -6.206794399999123], 
     Hue[1.2542793352748194`, 1, -6.021911658813473], 
     Hue[1.1923319554424714`, 1, -5.83255203009784], 
     Hue[1.2542792700361263`, 1, -5.6476692368950605`], 
     Hue[1.1923318645268068`, 1, -5.4583097162739485`], 
     Hue[1.2547153748951894`, 1, -5.27212481565419], 
     Hue[1.1923316646281759`, 1, -5.084067525749329], 
     Hue[1.2549331823939607`, 1, -4.897231373141709], 
     Hue[1.1923312251062335`, 1, -4.709825606327997], 
     Hue[1.2586405738833752`, 1, -4.511921876348507], 
     Hue[1.1933098905321178`, 1, -4.33266049369752], 
     Hue[1.2555641513331173`, 1, -4.146856485238637], 
     Hue[1.193307747661533, 1, -3.958420456574224], 
     Hue[1.2590335333618534`, 1, -3.7622484002156096`], 
     Hue[1.1937928230665134`, 1, -3.5827213376290663`], 
     Hue[1.259224922248635, 1, -3.387410752235395], 
     Hue[1.1940272918334558`, 1, -3.207759368829576], 
     Hue[1.2593077013794212`, 1, -3.0128684405776296`], 
     Hue[1.1942415451137882`, 1, -2.8328338386228067`], 
     Hue[1.2593673119299604`, 1, -2.638331822445129], 
     Hue[1.198114158658382, 1, -2.4469240986268286`], 
     Hue[1.2574734849571145`, 1, -2.269496217686867], 
     Hue[1.1979994271075816`, 1, -2.072797581016757], 
     Hue[1.2607007164281412`, 1, -1.8850313366509328`], 
     Hue[1.197747360829028, 1, -1.6988107622988127`], 
     Hue[1.260306151531852, 1, -1.5107110922206075`], 
     Hue[1.197194092330338, 1, -1.3251340303893693`], 
     Hue[1.259438171333322, 1, -1.1363077837115936`], 
     Hue[1.1959822668345366`, 1, -0.9521530920732346], 
     Hue[1.2575278135348826`, 1, -0.7617611847517343], 
     Hue[1.195218373850147, 1, -0.5748072166978517], 
     Hue[1.2540787273650622`, 1, -0.38459681425881453`], 
     Hue[1.1903156193862103`, 1, -0.20407921828631337`], 
     Hue[1.2436943812627266`, 1, -0.014435201969192457`], 
     Hue[1.1823396933302703`, 1, 0.17137590301505146`], 
     Hue[1.2247358838847553`, 1, 0.35900444601119563`], 
     Hue[1.164236720051381, 1, 0.5468839924786394], 
     Hue[1.1870777264603245`, 1, 0.7343089581092144], 
     Hue[1.113083006679471, 1, 0.7340716087426951], 
     Hue[1.1202209584748657`, 1, 0.9219868706594659], 
     Hue[1.070495578018599, 1, 0.9216898537206584], 
     Hue[1.3706277641212763`, 1, -17.27618334189528], 
     Hue[1.3079303635638109`, 1, -17.089062133554293`], 
     Hue[1.3677194374352613`, 1, -16.91062086407678], 
     Hue[1.3079303635638109`, 1, -16.714819716872324`], 
     Hue[1.3677194374352613`, 1, -16.53637844739481], 
     Hue[1.3079303635638109`, 1, -16.34057730019035], 
     Hue[1.3681939538945584`, 1, -16.16071983016143], 
     Hue[1.3079303635638106`, 1, -15.966334883508381`], 
     Hue[1.3685498412390316`, 1, -15.7854152630659], 
     Hue[1.3079303635638106`, 1, -15.592092466826411`], 
     Hue[1.3724646020282332`, 1, -15.399489191834807`], 
     Hue[1.3079303635638106`, 1, -15.217850050144438`], 
     Hue[1.372464602028233, 1, -15.025246775152837`], 
     Hue[1.3079303635638104`, 1, -14.843607633462467`], 
     Hue[1.3724646020282327`, 1, -14.651004358470864`], 
     Hue[1.3079303635638098`, 1, -14.469365216780497`], 
     Hue[1.3724646020282323`, 1, -14.276761941788891`], 
     Hue[1.3079303635638087`, 1, -14.095122800098524`], 
     Hue[1.372464602028231, 1, -13.902519525106916`], 
     Hue[1.3098896573312266`, 1, -13.715032845655893`], 
     Hue[1.3733830209817064`, 1, -13.525536075099632`], 
     Hue[1.3098896573312209`, 1, -13.340790428973914`], 
     Hue[1.3733830209817, 1, -13.151293658417643`], 
     Hue[1.3098896573312087`, 1, -12.966548012291929`], 
     Hue[1.373383020981686, 1, -12.77705124173563], 
     Hue[1.3098896573311816`, 1, -12.592305595609925`], 
     Hue[1.3733830209816549`, 1, -12.402808825053567`], 
     Hue[1.3098896573311218`, 1, -12.218063178927885`], 
     Hue[1.3733830209815865`, 1, -12.028566408371397`], 
     Hue[1.3108693042147004`, 1, -11.840896993365424`], 
     Hue[1.3738422304581759`, 1, -11.652953475026324`], 
     Hue[1.3108693042144108`, 1, -11.466654576683107`], 
     Hue[1.3738422304578457`, 1, -11.278711058343383`], 
     Hue[1.3108693042137742`, 1, -11.09241216000037], 
     Hue[1.3738422304571196`, 1, -10.904468641659276`], 
     Hue[1.311359127654224, 1, -10.716707858876523`], 
     Hue[1.3759163265921288`, 1, -10.524036058046065`], 
     Hue[1.311726495232524, 1, -10.341369028860639`], 
     Hue[1.3760827900239363`, 1, -10.149296829063244`], 
     Hue[1.3157675386208558`, 1, -9.955066065537682], 
     Hue[1.376138277827991, 1, -9.774888808261155], 
     Hue[1.315767538605707, 1, -9.580823648835889], 
     Hue[1.3761382778110218`, 1, -9.40064639152781], 
     Hue[1.3157675385723993`, 1, -9.206581232110327], 
     Hue[1.3761382777737117`, 1, -9.026403974732881], 
     Hue[1.315767538499164, 1, -8.832338815332516], 
     Hue[1.3779138876684454`, 1, -8.646862226696806], 
     Hue[1.3157675383381398`, 1, -8.458096398439826], 
     Hue[1.3779138874881247`, 1, -8.27261980945659], 
     Hue[1.3157675379840914`, 1, -8.083853981294531], 
     Hue[1.377913887091649, 1, -7.898377391547192], 
     Hue[1.3157675372056354`, 1, -7.709611563593845], 
     Hue[1.3779138862199065`, 1, -7.524134972166439], 
     Hue[1.315767535494023, 1, -7.335369144671991], 
     Hue[1.3779138843031826`, 1, -7.149892549550583], 
     Hue[1.3157675317306536`, 1, -6.961126723065132], 
     Hue[1.3788016850790508`, 1, -6.773000454010916], 
     Hue[1.3157675234560298`, 1, -6.586884295554674], 
     Hue[1.3788016758150632`, 1, -6.398758008327006], 
     Hue[1.31772679880137, 1, -6.206794315524321], 
     Hue[1.3796741534630883`, 1, -6.021911544962803], 
     Hue[1.3177267585246644`, 1, -5.8325518443607685`], 
     Hue[1.3796741086906508`, 1, -5.647668986568386], 
     Hue[1.3177266699671328`, 1, -5.458309307888732], 
     Hue[1.3801102592824697`, 1, -5.272124264422089], 
     Hue[1.3177264752530982`, 1, -5.084066627821462], 
     Hue[1.3803281674098145`, 1, -4.897230160219561], 
     Hue[1.3177260471292416`, 1, -4.7098236320289875`], 
     Hue[1.384035810070858, 1, -4.511919176106152], 
     Hue[1.3187047469003728`, 1, -4.332656126880143], 
     Hue[1.3809598528657872`, 1, -4.146850608690753], 
     Hue[1.31870267022088, 1, -3.958410855123274], 
     Hue[1.3844304539288945`, 1, -3.762235328918301], 
     Hue[1.3191879136557427`, 1, -3.582700164091059], 
     Hue[1.3846244010504234`, 1, -3.387381992381397], 
     Hue[1.3194227534387406`, 1, -3.2077127450195535`], 
     Hue[1.3847128057229106`, 1, -3.012805179789911], 
     Hue[1.3196148896871938`, 1, -2.8327997294378795`], 
     Hue[1.384775474127433, 1, -2.6382205152013034`], 
     Hue[1.3235142282011345`, 1, -2.446693045719594], 
     Hue[1.3828130867433648`, 1, -2.2695006969554763`], 
     Hue[1.3234056932069802`, 1, -2.072289510352973], 
     Hue[1.386208355556568, 1, -1.8843542199836214`], 
     Hue[1.3231667954933946`, 1, -1.6976934235183478`], 
     Hue[1.3859482785191017`, 1, -1.509219254583728], 
     Hue[1.3226402744107786`, 1, -1.3226762339639986`], 
     Hue[1.3819607370972884`, 1, -1.1433325221468518`], 
     Hue[1.321476568158243, 1, -0.946744288217443], 
     Hue[1.379952629417693, 1, -0.7671658101291752], 
     Hue[1.3169615986867862`, 1, -0.5749590482446738], 
     Hue[1.3753337187569281`, 1, -0.3893351744724953], 
     Hue[1.3083610868605884`, 1, -0.20296167938656962`], 
     Hue[1.3638060942219856`, 1, -0.012117029925124978`], 
     Hue[1.4167471166023295`, 1, 0.1711729251775056], 
     Hue[1.2921991683135041`, 1, 0.17224770833684477`], 
     Hue[1.3371267625524874`, 1, 0.35849865169493345`], 
     Hue[1.3803729933880664`, 1, 0.5463680124830637], 
     Hue[1.2594909264190235`, 1, 0.5464448686725207], 
     Hue[1.286993512626677, 1, 0.7343268352238648], 
     Hue[1.307738842240156, 1, 0.9218571695917899], 
     Hue[1.3225067914129747`, 1, 1.1093860561846014`], 
     Hue[1.1958840164026188`, 1, 0.92177398195486], 
     Hue[1.1877635477327664`, 1, 1.109435408972214], 
     Hue[1.152357103592261, 1, 1.2970409057825312`], 
     Hue[1.0966334267245457`, 1, 1.1095875667598993`], 
     Hue[1.0326662517080687`, 1, 1.109324151734225], 
     Hue[1.496022565236208, 1, -17.27618334189528], 
     Hue[1.433325164678742, 1, -17.089062133554293`], 
     Hue[1.4931142385501928`, 1, -16.91062086407678], 
     Hue[1.433325164678742, 1, -16.714819716872324`], 
     Hue[1.4931142385501928`, 1, -16.53637844739481], 
     Hue[1.433325164678742, 1, -16.34057730019035], 
     Hue[1.49358875500949, 1, -16.16071983016143], 
     Hue[1.433325164678742, 1, -15.966334883508381`], 
     Hue[1.493944642353963, 1, -15.7854152630659], 
     Hue[1.433325164678742, 1, -15.592092466826411`], 
     Hue[1.4978594031431647`, 1, -15.399489191834807`], 
     Hue[1.4333251646787417`, 1, -15.217850050144438`], 
     Hue[1.4978594031431647`, 1, -15.025246775152837`], 
     Hue[1.4333251646787417`, 1, -14.843607633462467`], 
     Hue[1.4978594031431647`, 1, -14.65100435847086], 
     Hue[1.4333251646787415`, 1, -14.469365216780494`], 
     Hue[1.4978594031431647`, 1, -14.276761941788891`], 
     Hue[1.433325164678741, 1, -14.095122800098519`], 
     Hue[1.4978594031431647`, 1, -13.902519525106912`], 
     Hue[1.4352844584461608`, 1, -13.715032845655884`], 
     Hue[1.4987778220966435`, 1, -13.525536075099625`], 
     Hue[1.4352844584461586`, 1, -13.340790428973897`], 
     Hue[1.4987778220966435`, 1, -13.151293658417627`], 
     Hue[1.4352844584461533`, 1, -12.96654801229189], 
     Hue[1.4987778220966432`, 1, -12.777051241735599`], 
     Hue[1.4352844584461417`, 1, -12.592305595609838`], 
     Hue[1.498777822096643, 1, -12.402808825053496`], 
     Hue[1.4352844584461164`, 1, -12.218063178927691`], 
     Hue[1.4987778220966423`, 1, -12.02856640837124], 
     Hue[1.4362641053297716`, 1, -11.840896993364998`], 
     Hue[1.499237031573381, 1, -11.652953475025981`], 
     Hue[1.43626410532965, 1, -11.466654576682172`], 
     Hue[1.4992370315733787`, 1, -11.278711058342626`], 
     Hue[1.4362641053293825`, 1, -11.092412159998313`], 
     Hue[1.4992370315733738`, 1, -10.904468641657612`], 
     Hue[1.4367539287706539`, 1, -10.716707858871999`], 
     Hue[0.5013111277100224, 1, -10.524036058042476`], 
     Hue[1.4371212963507651`, 1, -10.341369028850691`], 
     Hue[0.501477591145391, 1, -10.149296829055363`], 
     Hue[1.441162339743439, 1, -9.955066065515819], 
     Hue[0.5015330789572726, 1, -9.774888808243833], 
     Hue[1.4411623397374624`, 1, -9.580823648787817], 
     Hue[0.5015330789575054, 1, -9.400646391489726], 
     Hue[1.4411623397243214`, 1, -9.206581232004636], 
     Hue[0.5015330789580174, 1, -9.026403974649147], 
     Hue[1.4411623396954276`, 1, -8.832338815100128], 
     Hue[0.5033086889383089, 1, -8.64686222651578], 
     Hue[1.4411623396318984`, 1, -8.45809639792886], 
     Hue[0.5033086889437097, 1, -8.272619809058565], 
     Hue[1.4411623394922146`, 1, -8.083853980171062], 
     Hue[0.5033086889555848, 1, -7.898377390672047], 
     Hue[1.4411623391850883`, 1, -7.709611561123638], 
     Hue[0.5033086889816947, 1, -7.524134970242231], 
     Hue[1.441162338509801, 1, -7.335369139240682], 
     Hue[0.5033086890391034, 1, -7.1498925453197755`], 
     Hue[1.4411623370250282`, 1, -6.961126711123161], 
     Hue[0.5041964942174465, 1, -6.773000444789916], 
     Hue[1.4411623337604174`, 1, -6.586884269297532], 
     Hue[0.504196494571407, 1, -6.3987579880525365`], 
     Hue[1.443121620611215, 1, -6.206794257832866], 
     Hue[0.5050689936616553, 1, -6.021911500778499], 
     Hue[1.4431216051420719`, 1, -5.832551717512935], 
     Hue[0.5050689957398717, 1, -5.647668889419075], 
     Hue[1.4431215711296137`, 1, -5.458309028984685], 
     Hue[0.5055052500582364, 1, -5.272124051781343], 
     Hue[1.4431214963453503`, 1, -5.0840660145863605`], 
     Hue[0.5057233863243693, 1, -4.897229693746191], 
     Hue[1.4431213319144738`, 1, -4.709822283686746], 
     Hue[0.5094315594104339, 1, -4.511918191935773], 
     Hue[1.444100624173095, 1, -4.332653163625463], 
     Hue[0.5063566848677454, 1, -4.146848368623009], 
     Hue[1.4440998375169434`, 1, -3.958404339606746], 
     Hue[0.5098298547146098, 1, -3.7622305931809548`], 
     Hue[1.444587948206805, 1, -3.5826858414713936`], 
     Hue[0.5100293329738808, 1, -3.3873716036854304`], 
     Hue[1.4448290955142733`, 1, -3.2076812549523934`], 
     Hue[0.5101299022464398, 1, -3.012782360993323], 
     Hue[1.445004512969664, 1, -2.8328218864383885`], 
     Hue[0.5102068990177907, 1, -2.638207508123589], 
     Hue[1.4489676571568217`, 1, -2.446541192208546], 
     Hue[0.5083140797567789, 1, -2.2693878608735476`], 
     Hue[1.448929417827657, 1, -2.0719552709925813`], 
     Hue[0.5084785961642921, 1, -1.8941570407788466`], 
     Hue[1.448845145107565, 1, -1.6969568035647888`], 
     Hue[0.5084992995840798, 1, -1.51875726019973], 
     Hue[1.448658905050627, 1, -1.321048265733918], 
     Hue[0.5081797894145826, 1, -1.1430495690276434`], 
     Hue[1.4441669864130127`, 1, -0.9554132232765558], 
     Hue[0.5067824001061213, 1, -0.7676079095848152], 
     Hue[1.441317424682129, 1, -0.5789823467715047], 
     Hue[0.5043995739925857, 1, -0.3884371487457323], 
     Hue[1.433917674186652, 1, -0.20327004229532686`], 
     Hue[1.4951337152089699`, 1, -0.014281806387415052`], 
     Hue[0.5600706409245436, 1, 0.17156081262840306`], 
     Hue[1.473209370096389, 1, 0.35881677263504363`], 
     Hue[0.5375318263073996, 1, 0.5473159571144711], 
     Hue[1.4241184489299143`, 1, 0.733980408527599], 
     Hue[1.4731580297635114`, 1, 0.9215710358528181], 
     Hue[0.5384356981931222, 1, 1.1095804849550353`], 
     Hue[1.3319596287706903`, 1, 1.2970899846596766`], 
     Hue[0.9932929221533973, 1, 1.2971392476174892`], 
     Hue[1.0075359267863038`, 1, 1.109375408512418], 
     Hue[0.6214173663511395, 1, -17.27618334189528], 
     Hue[0.5587199657936737, 1, -17.089062133554293`], 
     Hue[0.618509039665124, 1, -16.91062086407678], 
     Hue[0.5587199657936737, 1, -16.714819716872324`], 
     Hue[0.618509039665124, 1, -16.53637844739481], 
     Hue[0.5587199657936737, 1, -16.34057730019035], 
     Hue[0.6189835561244215, 1, -16.16071983016143], 
     Hue[0.5587199657936737, 1, -15.966334883508381`], 
     Hue[0.6193394434688945, 1, -15.7854152630659], 
     Hue[0.5587199657936737, 1, -15.592092466826411`], 
     Hue[0.6232542042580962, 1, -15.399489191834807`], 
     Hue[0.5587199657936737, 1, -15.217850050144438`], 
     Hue[0.6232542042580964, 1, -15.025246775152837`], 
     Hue[0.5587199657936739, 1, -14.843607633462467`], 
     Hue[0.6232542042580966, 1, -14.651004358470864`], 
     Hue[0.5587199657936739, 1, -14.469365216780494`], 
     Hue[0.6232542042580973, 1, -14.276761941788891`], 
     Hue[0.5587199657936744, 1, -14.095122800098519`], 
     Hue[0.6232542042580986, 1, -13.902519525106916`], 
     Hue[0.5606792595610965, 1, -13.715032845655884`], 
     Hue[0.6241726232115803, 1, -13.525536075099632`], 
     Hue[0.5606792595610988, 1, -13.340790428973897`], 
     Hue[0.6241726232115865, 1, -13.151293658417641`], 
     Hue[0.5606792595611036, 1, -12.96654801229189], 
     Hue[0.6241726232116005, 1, -12.777051241735629`], 
     Hue[0.5606792595611145, 1, -12.592305595609837`], 
     Hue[0.6241726232116311, 1, -12.402808825053565`], 
     Hue[0.5606792595611385, 1, -12.218063178927688`], 
     Hue[0.6241726232116984, 1, -12.02856640837139], 
     Hue[0.5616589064449033, 1, -11.840896993364996`], 
     Hue[0.6246318326885871, 1, -11.652953475026317`], 
     Hue[0.5616589064450211, 1, -11.466654576682163`], 
     Hue[0.6246318326889141, 1, -11.278711058343367`], 
     Hue[0.5616589064452805, 1, -11.092412159998295`], 
     Hue[0.6246318326896333, 1, -10.904468641659237`], 
     Hue[0.5621487298877166, 1, -10.716707858871974`], 
     Hue[0.6267059288278964, 1, -10.52403605804621], 
     Hue[0.5625160974703933, 1, -10.341369028850673`], 
     Hue[0.6268723922667958, 1, -10.149296829063603`], 
     Hue[0.5665571408689603, 1, -9.955066065516586], 
     Hue[0.6269278800864397, 1, -9.774888808261977], 
     Hue[0.5665571408756777, 1, -9.580823648789503], 
     Hue[0.6269278801037372, 1, -9.400646391529616], 
     Hue[0.5665571408904475, 1, -9.206581232008341], 
     Hue[0.6269278801417695, 1, -9.026403974736855], 
     Hue[0.5665571409229223, 1, -8.832338815108276], 
     Hue[0.6287034902055177, 1, -8.64686222671587], 
     Hue[0.5665571409943256, 1, -8.458096397946777], 
     Hue[0.6287034903934573, 1, -8.272619809498504], 
     Hue[0.5665571411513222, 1, -8.083853980210456], 
     Hue[0.6287034908066853, 1, -7.898377391639353], 
     Hue[0.5665571414965145, 1, -7.709611561210257], 
     Hue[0.628703491715261, 1, -7.524134972369077], 
     Hue[0.5665571422554985, 1, -7.335369139431131], 
     Hue[0.6287034937129714, 1, -7.149892549996129], 
     Hue[0.5665571439242973, 1, -6.961126711541907], 
     Hue[0.6295913031818339, 1, -6.773000455260304], 
     Hue[0.5665571475935318, 1, -6.58688427021824], 
     Hue[0.6295913129451538, 1, -6.3987580110740705`], 
     Hue[0.5685164500257487, 1, -6.206794260922295], 
     Hue[0.6304638328385638, 1, -6.021911552298361], 
     Hue[0.5685164684801322, 1, -5.832551724305751], 
     Hue[0.6304638805427403, 1, -5.647669002697288], 
     Hue[0.568516509056325, 1, -5.458309043920254], 
     Hue[0.6309002354552367, 1, -5.272124303041775], 
     Hue[0.5685165982724734, 1, -5.0840660474256865`], 
     Hue[0.6311185929271572, 1, -4.897230248618025], 
     Hue[0.5685167944352356, 1, -4.70982235589187], 
     Hue[0.6348272631058807, 1, -4.511919503827926], 
     Hue[0.5694968881698359, 1, -4.332653350244668], 
     Hue[0.6317534505012752, 1, -4.146851085202545], 
     Hue[0.569497855152853, 1, -3.958404749942394], 
     Hue[0.6352290249379603, 1, -3.762236984236119], 
     Hue[0.5699898426147674, 1, -3.582686811683627], 
     Hue[0.6354337469728615, 1, -3.3873857104545744`], 
     Hue[0.5702395167499126, 1, -3.2076834634940017`], 
     Hue[0.6355458475808711, 1, -3.0128134422041626`], 
     Hue[0.5704337010949942, 1, -2.8328268678857906`], 
     Hue[0.6356482083087522, 1, -2.638275970613013], 
     Hue[0.5744398870919272, 1, -2.4465582163683006`], 
     Hue[0.6338105481122529, 1, -2.2695331244663173`], 
     Hue[0.5744945826649703, 1, -2.071992755043352], 
     Hue[0.6374649051946473, 1, -1.8844580568244942`], 
     Hue[0.5746151053833466, 1, -1.6970394756941631`], 
     Hue[0.6377663576573862, 1, -1.5094483626830282`], 
     Hue[0.5748813752529047, 1, -1.3212312802163366`], 
     Hue[0.6384326022616498, 1, -1.1335205858648114`], 
     Hue[0.5714139832619747, 1, -0.9554898624656778], 
     Hue[0.6382467717414854, 1, -0.7603931513054332], 
     Hue[0.5706668260339669, 1, -0.5794269416678646], 
     Hue[0.6365041015895667, 1, -0.3919810412890865], 
     Hue[0.5691167853006023, 1, -0.2004040431901679], 
     Hue[0.6370302663159394, 1, -0.017021873485603134`], 
     Hue[0.6368899354997649, 1, 0.35990565593166957`], 
     Hue[0.6223913543269993, 1, 0.7340718802227209], 
     Hue[0.8700361553832762, 1, 1.109418527107455], 
     Hue[0.9469201330936845, 1, 1.1093061676400275`], 
     Hue[0.9205509798902437, 1, 1.2973139429321794`], 
     Hue[0.9747745064670651, 1, 1.10930531346195], 
     Hue[0.9905745353135256, 1, 1.1095937643789398`], 
     Hue[0.7468121674660709, 1, -17.27618334189528], 
     Hue[0.6841147669086054, 1, -17.089062133554293`], 
     Hue[0.7439038407800558, 1, -16.91062086407678], 
     Hue[0.6841147669086054, 1, -16.714819716872324`], 
     Hue[0.7439038407800558, 1, -16.53637844739481], 
     Hue[0.6841147669086054, 1, -16.34057730019035], 
     Hue[0.7443783572393529, 1, -16.16071983016143], 
     Hue[0.6841147669086054, 1, -15.966334883508381`], 
     Hue[0.7447342445838259, 1, -15.7854152630659], 
     Hue[0.6841147669086054, 1, -15.592092466826411`], 
     Hue[0.748649005373028, 1, -15.399489191834807`], 
     Hue[0.6841147669086056, 1, -15.217850050144438`], 
     Hue[0.7486490053730283, 1, -15.025246775152837`], 
     Hue[0.6841147669086058, 1, -14.843607633462467`], 
     Hue[0.7486490053730286, 1, -14.651004358470864`], 
     Hue[0.6841147669086063, 1, -14.469365216780497`], 
     Hue[0.7486490053730295, 1, -14.276761941788894`], 
     Hue[0.6841147669086074, 1, -14.095122800098522`], 
     Hue[0.7486490053730313, 1, -13.902519525106923`], 
     Hue[0.6860740606760307, 1, -13.715032845655891`], 
     Hue[0.7495674243265142, 1, -13.525536075099648`], 
     Hue[0.6860740606760363, 1, -13.340790428973913`], 
     Hue[0.7495674243265231, 1, -13.151293658417677`], 
     Hue[0.6860740606760485, 1, -12.966548012291927`], 
     Hue[0.749567424326543, 1, -12.777051241735705`], 
     Hue[0.6860740606760753, 1, -12.592305595609922`], 
     Hue[0.7495674243265864, 1, -12.402808825053734`], 
     Hue[0.6860740606761344, 1, -12.218063178927876`], 
     Hue[0.7495674243266821, 1, -12.028566408371761`], 
     Hue[0.687053707559977, 1, -11.840896993365416`], 
     Hue[0.7500266338036324, 1, -11.652953475027134`], 
     Hue[0.687053707560265, 1, -11.466654576683087`], 
     Hue[0.7500266338040961, 1, -11.278711058345165`], 
     Hue[0.6870537075608982, 1, -11.092412160000325`], 
     Hue[0.7500266338051155, 1, -10.904468641663195`], 
     Hue[0.6875435310041568, 1, -10.716707858876468`], 
     Hue[0.7521007299440161, 1, -10.524036058055069`], 
     Hue[0.6879108985886415, 1, -10.3413690288606], 
     Hue[0.7522671933843356, 1, -10.149296829083111`], 
     Hue[0.6919519419911793, 1, -9.95506606553953], 
     Hue[0.7523226812071033, 1, -9.774888808304889], 
     Hue[0.6919519420066322, 1, -9.580823648839951], 
     Hue[0.752322681231272, 1, -9.40064639162397], 
     Hue[0.6919519420406093, 1, -9.206581232119262], 
     Hue[0.7523226812844124, 1, -9.026403974944316], 
     Hue[0.6919519421153152, 1, -8.832338815352161], 
     Hue[0.7540982913803345, 1, -8.646862227179158], 
     Hue[0.6919519422795732, 1, -8.458096398483018], 
     Hue[0.7540982916400601, 1, -8.272619810517151], 
     Hue[0.691951942640732, 1, -8.083853981389503], 
     Hue[0.7540982922111263, 1, -7.898377393879081], 
     Hue[0.6919519434348216, 1, -7.709611563802654], 
     Hue[0.7540982934667451, 1, -7.52413497729363], 
     Hue[0.6919519451808085, 1, -7.335369145131108], 
     Hue[0.7540982962275086, 1, -7.149892560823877], 
     Hue[0.6919519490197575, 1, -6.961126724074602], 
     Hue[0.7549861073465367, 1, -6.7730004792518885`], 
     Hue[0.6919519574605607, 1, -6.586884297774223], 
     Hue[0.7549861207657003, 1, -6.398758063825032], 
     Hue[0.6939112703680382, 1, -6.2067943229720095`], 
     Hue[0.7558586485639198, 1, -6.0219116691617485`], 
     Hue[0.6939113118707829, 1, -5.83255186073621], 
     Hue[0.7558587137819874, 1, -5.647669259648097], 
     Hue[0.6939114031240358, 1, -5.45830934389388], 
     Hue[0.7562951068759624, 1, -5.272124870134896], 
     Hue[0.6939116037652053, 1, -5.084066706987052], 
     Hue[0.7565135482632379, 1, -4.897231497844873], 
     Hue[0.6939120449211114, 1, -4.709823806092935], 
     Hue[0.760222389260825, 1, -4.511922338660588], 
     Hue[0.6948926767930266, 1, -4.332656576757403], 
     Hue[0.7571489920451938, 1, -4.14685715743744], 
     Hue[0.6948948275254678, 1, -3.9584118442915326`], 
     Hue[0.7606253897324563, 1, -3.762250735242427], 
     Hue[0.6953894162707901, 1, -3.5827025028349775`], 
     Hue[0.7608319774331137, 1, -3.3874159966733695`], 
     Hue[0.6956448096119953, 1, -3.2077180684124613`], 
     Hue[0.7609481778252364, 1, -3.0128800931871345`], 
     Hue[0.6958821923407806, 1, -2.8328117844464877`], 
     Hue[0.7610719816492023, 1, -2.6383855284737328`], 
     Hue[0.6998852252713368, 1, -2.446734057577105], 
     Hue[0.7593459055610132, 1, -2.2695425011724506`], 
     Hue[0.7000004826779689, 1, -2.0723797360960168`], 
     Hue[0.762937682127796, 1, -1.8851773893846973`], 
     Hue[0.7002540930160921, 1, -1.6978920556339128`], 
     Hue[0.7633315682644163, 1, -1.5110322092382364`], 
     Hue[0.7008126312192375, 1, -1.323114178159366], 
     Hue[0.7641970345151621, 1, -1.1370137385956742`], 
     Hue[0.702045102395126, 1, -0.9477129990201036], 
     Hue[0.7660969315165601, 1, -0.7633126103424757], 
     Hue[0.7047757799310094, 1, -0.5710142719249809], 
     Hue[0.7702574105919309, 1, -0.3904946269935883], 
     Hue[0.7060768948258698, 1, -0.20431479308664513`], 
     Hue[0.7808589297293255, 1, -0.016727664096503503`], 
     Hue[0.7165400718826853, 1, 0.1730414066943432], 
     Hue[0.8088305495600575, 1, 0.35871647128279993`], 
     Hue[0.7394705823670233, 1, 0.5470780271083674], 
     Hue[0.8722069685810027, 1, -17.27618334189528], 
     Hue[0.8095095680235368, 1, -17.089062133554293`], 
     Hue[0.8692986418949873, 1, -16.91062086407678], 
     Hue[0.8095095680235368, 1, -16.714819716872324`], 
     Hue[0.8692986418949873, 1, -16.53637844739481], 
     Hue[0.8095095680235368, 1, -16.34057730019035], 
     Hue[0.8697731583542846, 1, -16.16071983016143], 
     Hue[0.8095095680235368, 1, -15.966334883508381`], 
     Hue[0.8701290456987576, 1, -15.7854152630659], 
     Hue[0.8095095680235369, 1, -15.592092466826411`], 
     Hue[0.8740438064879594, 1, -15.399489191834807`], 
     Hue[0.809509568023537, 1, -15.217850050144438`], 
     Hue[0.8740438064879597, 1, -15.025246775152837`], 
     Hue[0.8095095680235372, 1, -14.843607633462467`], 
     Hue[0.8740438064879599, 1, -14.651004358470864`], 
     Hue[0.8095095680235378, 1, -14.469365216780497`], 
     Hue[0.8740438064879605, 1, -14.276761941788898`], 
     Hue[0.8095095680235389, 1, -14.095122800098528`], 
     Hue[0.8740438064879618, 1, -13.90251952510693], 
     Hue[0.8114688617909622, 1, -13.715032845655903`], 
     Hue[0.8749622254414434, 1, -13.525536075099662`], 
     Hue[0.8114688617909678, 1, -13.340790428973937`], 
     Hue[0.8749622254414499, 1, -13.15129365841771], 
     Hue[0.8114688617909801, 1, -12.966548012291984`], 
     Hue[0.8749622254414638, 1, -12.777051241735782`], 
     Hue[0.8114688617910071, 1, -12.592305595610046`], 
     Hue[0.8749622254414946, 1, -12.402808825053903`], 
     Hue[0.8114688617910666, 1, -12.218063178928144`], 
     Hue[0.8749622254415622, 1, -12.028566408372132`], 
     Hue[0.8124485086749087, 1, -11.84089699336601], 
     Hue[0.8754214349184501, 1, -11.652953475027953`], 
     Hue[0.8124485086751971, 1, -11.466654576684398`], 
     Hue[0.8754214349187771, 1, -11.278711058346964`], 
     Hue[0.8124485086758313, 1, -11.092412160003208`], 
     Hue[0.8754214349194961, 1, -10.90446864166715], 
     Hue[0.8129383321190851, 1, -10.716707858882831`], 
     Hue[0.8774955310576817, 1, -10.524036058063833`], 
     Hue[0.8133056997035554, 1, -10.341369028874619`], 
     Hue[0.8776619944964738, 1, -10.14929682910239], 
     Hue[0.8173467431058014, 1, -9.95506606557113], 
     Hue[0.8777174823158858, 1, -9.774888808347285], 
     Hue[0.8173467431208834, 1, -9.580823648909433], 
     Hue[0.8777174823326831, 1, -9.400646391717189], 
     Hue[0.8173467431540449, 1, -9.206581232272033], 
     Hue[0.8777174823696159, 1, -9.026403975149274], 
     Hue[0.8173467432269579, 1, -8.832338815688065], 
     Hue[0.8794930924274691, 1, -8.646862227632633], 
     Hue[0.8173467433872736, 1, -8.458096399221574], 
     Hue[0.8794930926059248, 1, -8.272619811514218], 
     Hue[0.8173467437397641, 1, -8.083853983013388], 
     Hue[0.8794930929983005, 1, -7.8983773960713615`], 
     Hue[0.8173467445147949, 1, -7.709611567373135], 
     Hue[0.8794930938610275, 1, -7.524134982113853], 
     Hue[0.8173467462188764, 1, -7.335369152981621], 
     Hue[0.8794930957579292, 1, -7.149892571422236], 
     Hue[0.817346749965687, 1, -6.961126741335744], 
     Hue[0.8803809049143289, 1, -6.773000502626457], 
     Hue[0.8173467582039022, 1, -6.586884335726767], 
     Hue[0.880380914081438, 1, -6.398758115219332], 
     Hue[0.8193060703074233, 1, -6.2067944074161545`], 
     Hue[0.8812534322278309, 1, -6.02191178250116], 
     Hue[0.8193061104009925, 1, -5.832552046405866], 
     Hue[0.881253476526858, 1, -5.647669508850496], 
     Hue[0.8193061985557915, 1, -5.458309752130839], 
     Hue[0.8816898228896213, 1, -5.272125418872499], 
     Hue[0.81930639238401, 1, -5.084067604588777], 
     Hue[0.8819081614518844, 1, -4.897232705254597], 
     Hue[0.8193068185586668, 1, -4.70982577967406], 
     Hue[0.8856167463380992, 1, -4.511925025850215], 
     Hue[0.8202874081072186, 1, -4.332660941714859], 
     Hue[0.8825428732040771, 1, -4.146863006869828], 
     Hue[0.8202894751250829, 1, -3.9584214416312724`], 
     Hue[0.8860180278251358, 1, -3.762263742285308], 
     Hue[0.8207838567739064, 1, -3.582723666539178], 
     Hue[0.8862220044246185, 1, -3.387444612476185], 
     Hue[0.8210387915870724, 1, -3.2077646692711337`], 
     Hue[0.8863324608179873, 1, -3.0129430258152166`], 
     Hue[0.8213019295706505, 1, -2.83283445942011], 
     Hue[0.8864544934454236, 1, -2.6384914526863685`], 
     Hue[0.8252739001042201, 1, -2.4469649019833124`], 
     Hue[0.8847689337985539, 1, -2.269613927833758], 
     Hue[0.8253816953570279, 1, -2.07288724348387], 
     Hue[0.8882168293035266, 1, -1.8858487938584585`], 
     Hue[0.8256184447076025, 1, -1.699007649122873], 
     Hue[0.8884713386492831, 1, -1.5125053499907637`], 
     Hue[0.8261377194756339, 1, -1.3255656875422261`], 
     Hue[0.8890275607970993, 1, -1.1402377949874836`], 
     Hue[0.8272733020843814, 1, -0.9530961444170469], 
     Hue[0.8918824432479296, 1, -0.7655461183373689], 
     Hue[0.8317241645744953, 1, -0.5772215974625716], 
     Hue[0.9000320718901377, 1, -0.3852770707007589], 
     Hue[0.841032334998834, 1, -0.20170205207818093`], 
     Hue[0.9118474221996861, 1, -0.015820135021511028`], 
     Hue[0.8615439141335345, 1, 0.17158265334887646`], 
     Hue[0.9433353815291717, 1, 0.36075297988416455`], 
     Hue[0.9160162222286736, 1, 0.5471624719013216], 
     Hue[0.907618389482178, 1, 0.7341096958116775], 
     Hue[0.9769214448461486, 1, 0.9218821428466104], 
     Hue[0.9976017696959342, 1, -17.27618334189528], 
     Hue[0.9349043691384683, 1, -17.089062133554293`], 
     Hue[0.9946934430099187, 1, -16.91062086407678], 
     Hue[0.9349043691384683, 1, -16.714819716872324`], 
     Hue[0.9946934430099187, 1, -16.53637844739481], 
     Hue[0.9349043691384683, 1, -16.34057730019035], 
     Hue[0.995167959469216, 1, -16.16071983016143], 
     Hue[0.9349043691384683, 1, -15.966334883508381`], 
     Hue[0.995523846813689, 1, -15.7854152630659], 
     Hue[0.9349043691384683, 1, -15.592092466826411`], 
     Hue[0.9994386076028908, 1, -15.399489191834807`], 
     Hue[0.9349043691384683, 1, -15.217850050144438`], 
     Hue[0.9994386076028908, 1, -15.025246775152837`], 
     Hue[0.9349043691384684, 1, -14.843607633462467`], 
     Hue[0.9994386076028908, 1, -14.651004358470868`], 
     Hue[0.9349043691384686, 1, -14.469365216780501`], 
     Hue[0.9994386076028908, 1, -14.276761941788898`], 
     Hue[0.9349043691384692, 1, -14.095122800098533`], 
     Hue[0.9994386076028908, 1, -13.902519525106934`], 
     Hue[0.9368636629058913, 1, -13.715032845655912`], 
     Hue[1.0003570265563695`, 1, -13.52553607509967], 
     Hue[0.9368636629058936, 1, -13.340790428973957`], 
     Hue[1.0003570265563695`, 1, -13.151293658417725`], 
     Hue[0.9368636629058987, 1, -12.966548012292025`], 
     Hue[1.0003570265563695`, 1, -12.777051241735814`], 
     Hue[0.9368636629059099, 1, -12.592305595610132`], 
     Hue[1.0003570265563695`, 1, -12.402808825053972`], 
     Hue[0.9368636629059348, 1, -12.218063178928338`], 
     Hue[1.0003570265563693`, 1, -12.028566408372287`], 
     Hue[0.9378433097896987, 1, -11.840896993366433`], 
     Hue[1.0008162360331068`, 1, -11.652953475028289`], 
     Hue[0.9378433097898174, 1, -11.466654576685324`], 
     Hue[1.0008162360331045`, 1, -11.278711058347703`], 
     Hue[0.9378433097900788, 1, -11.092412160005248`], 
     Hue[1.0008162360330992`, 1, -10.904468641668775`], 
     Hue[0.9383331332325037, 1, -10.71670785888731], 
     Hue[1.002890332169639, 1, -10.524036058067335`], 
     Hue[0.9387005008151448, 1, -10.341369028884467`], 
     Hue[1.003056795604856, 1, -10.149296829110076`], 
     Hue[0.9427415442130089, 1, -9.955066065592765], 
     Hue[1.0031122834164101`, 1, -9.77488880836418], 
     Hue[0.9427415442188324, 1, -9.580823648957002], 
     Hue[1.0031122834159376`, 1, -9.400646391754334], 
     Hue[0.9427415442316363, 1, -9.206581232376626], 
     Hue[1.0031122834148984`, 1, -9.026403975230949], 
     Hue[0.9427415442597887, 1, -8.832338815918035], 
     Hue[1.0048878933868743`, 1, -8.646862227809061], 
     Hue[0.9427415443216882, 1, -8.458096399727218], 
     Hue[1.0048878933788965`, 1, -8.272619811902135], 
     Hue[0.9427415444577883, 1, -8.083853984125158], 
     Hue[1.004887893361355, 1, -7.898377396924283], 
     Hue[0.9427415447570354, 1, -7.709611569817619], 
     Hue[1.0048878933227863`, 1, -7.524134983989199], 
     Hue[0.9427415454149983, 1, -7.3353691583563725`], 
     Hue[1.0048878932379843`, 1, -7.149892575545608], 
     Hue[0.9427415468616793, 1, -6.961126753153359], 
     Hue[1.005775697975536, 1, -6.773000511609399], 
     Hue[0.9427415500425362, 1, -6.58688436171048], 
     Hue[1.0057756974884253`, 1, -6.3987581349703735`], 
     Hue[0.9447008505366612, 1, -6.2067944644918915`], 
     Hue[1.006648194114176, 1, -6.021911825525848], 
     Hue[0.9447008655939766, 1, -5.832552171899811], 
     Hue[1.0066481913888456`, 1, -5.647669603449993], 
     Hue[0.944700898700882, 1, -5.458310028057591], 
     Hue[1.007084433646585, 1, -5.272125625885125], 
     Hue[0.9447009714938108, 1, -5.084068211275397], 
     Hue[1.0073025432392266`, 1, -4.897233159326851], 
     Hue[0.9447011315449766, 1, -4.709827113607234], 
     Hue[1.011010596015192, 1, -4.511925981864552], 
     Hue[0.9456811232688248, 1, -4.33266387285897], 
     Hue[1.0079356361391651`, 1, -4.14686518655122], 
     Hue[0.9456818885288812, 1, -3.9584278862915436`], 
     Hue[1.011408214036325, 1, -3.7622683409329225`], 
     Hue[0.9461733771707725, 1, -3.5827378312125955`], 
     Hue[1.0116066420753982`, 1, -3.3874546975356985`], 
     Hue[0.9464219480038808, 1, -3.2077958050550874`], 
     Hue[1.0117048984632449`, 1, -3.012965168174474], 
     Hue[0.9505927621874798, 1, -2.8212006209146443`], 
     Hue[1.0096749302409207`, 1, -2.6448829910198457`], 
     Hue[0.9506095856353489, 1, -2.4471147435891583`], 
     Hue[1.0100765151109659`, 1, -2.26966525313774], 
     Hue[0.9506465368522221, 1, -2.07321635161467], 
     Hue[1.0133709013793593`, 1, -1.8860782797349873`], 
     Hue[0.9507275946392946, 1, -1.699729566134405], 
     Hue[1.0133378773480908`, 1, -1.513007731819392], 
     Hue[0.9509049154678033, 1, -1.3271447910492393`], 
     Hue[1.0132658357343984`, 1, -1.141331884293834], 
     Hue[0.953230738739976, 1, -0.9507890573966706], 
     Hue[1.015471622815331, 1, -0.7656086791166341], 
     Hue[0.9557125047033747, 1, -0.579645900488388], 
     Hue[1.0202465126127545`, 1, -0.3880053521572562], 
     Hue[0.964089014678482, 1, -0.20342692139869167`], 
     Hue[1.0278417205666277`, 1, -0.013499686126058341`], 
     Hue[0.98062934058388, 1, 0.17131722069007516`], 
     Hue[1.0410556706824292`, 1, 0.3592030753851232], 
     Hue[1.0118777802508168`, 1, 0.5474061019396915], 
     Hue[1.0014512171205572`, 1, 0.7344609311138541], 
     Hue[1.0119359461105886`, 1, 0.9222720773100113], 
     Hue[1.1229965708108656`, 1, -17.27618334189528], 
     Hue[1.0602991702534, 1, -17.089062133554293`], 
     Hue[1.1200882441248505`, 1, -16.91062086407678], 
     Hue[1.0602991702534, 1, -16.714819716872324`], 
     Hue[1.1200882441248505`, 1, -16.53637844739481], 
     Hue[1.0602991702534, 1, -16.34057730019035], 
     Hue[1.1205627605841475`, 1, -16.16071983016143], 
     Hue[1.0602991702534, 1, -15.966334883508381`], 
     Hue[1.1209186479286204`, 1, -15.7854152630659], 
     Hue[1.0602991702534, 1, -15.592092466826411`], 
     Hue[1.1248334087178224`, 1, -15.399489191834807`], 
     Hue[1.0602991702534, 1, -15.217850050144438`], 
     Hue[1.1248334087178224`, 1, -15.025246775152837`], 
     Hue[1.0602991702534, 1, -14.843607633462467`], 
     Hue[1.124833408717822, 1, -14.651004358470864`], 
     Hue[1.0602991702533997`, 1, -14.469365216780501`], 
     Hue[1.1248334087178216`, 1, -14.276761941788898`], 
     Hue[1.060299170253399, 1, -14.095122800098533`], 
     Hue[1.1248334087178202`, 1, -13.90251952510693], 
     Hue[1.0622584640208188`, 1, -13.715032845655912`], 
     Hue[1.1257518276712961`, 1, -13.525536075099662`], 
     Hue[1.0622584640208166`, 1, -13.340790428973957`], 
     Hue[1.1257518276712897`, 1, -13.15129365841771], 
     Hue[1.0622584640208115`, 1, -12.966548012292025`], 
     Hue[1.1257518276712757`, 1, -12.777051241735782`], 
     Hue[1.0622584640208004`, 1, -12.592305595610133`], 
     Hue[1.1257518276712446`, 1, -12.402808825053901`], 
     Hue[1.062258464020776, 1, -12.218063178928338`], 
     Hue[1.1257518276711767`, 1, -12.02856640837213], 
     Hue[1.0632381109044304`, 1, -11.840896993366432`], 
     Hue[1.126211037147765, 1, -11.652953475027944`], 
     Hue[1.0632381109043096`, 1, -11.46665457668532], 
     Hue[1.1262110371474348`, 1, -11.278711058346946`], 
     Hue[1.063238110904044, 1, -11.092412160005237`], 
     Hue[1.1262110371467084`, 1, -10.904468641667108`], 
     Hue[1.0637279343453039`, 1, -10.716707858887268`], 
     Hue[1.1282851332816406`, 1, -10.524036058063512`], 
     Hue[1.0640953019253794`, 1, -10.341369028884344`], 
     Hue[1.1284515967133424`, 1, -10.149296829101644`], 
     Hue[1.068136345317354, 1, -9.955066065591685], 
     Hue[1.1285070845171672`, 1, -9.774888808345617], 
     Hue[1.068136345310487, 1, -9.580823648954627], 
     Hue[1.128507084499703, 1, -9.400646391713519], 
     Hue[1.0681363452953883`, 1, -9.206581232371406], 
     Hue[1.128507084461304, 1, -9.026403975141209], 
     Hue[1.06813634526219, 1, -8.832338815906553], 
     Hue[1.1302826943502016`, 1, -8.646862227604473], 
     Hue[1.0681363451891959`, 1, -8.458096399701974], 
     Hue[1.130282694160491, 1, -8.272619811452303], 
     Hue[1.0681363450287018`, 1, -8.083853984069652], 
     Hue[1.1302826937433699`, 1, -7.898377395935223], 
     Hue[1.0681363446758192`, 1, -7.709611569695572], 
     Hue[1.130282692826234, 1, -7.524134981814524], 
     Hue[1.0681363438999267`, 1, -7.335369158088029], 
     Hue[1.1302826908097017`, 1, -7.149892570764092], 
     Hue[1.0681363421939507`, 1, -6.961126752563341], 
     Hue[1.1311704912762086`, 1, -6.773000500907083], 
     Hue[1.0681363384429745`, 1, -6.586884360413193], 
     Hue[1.1311704814219319`, 1, -6.398758111438898], 
     Hue[1.0700956233636667`, 1, -6.206794460564577], 
     Hue[1.1320429573403037`, 1, -6.021911772881447], 
     Hue[1.070095604511484, 1, -5.832552163264721], 
     Hue[1.1320429091966457`, 1, -5.647669487699382], 
     Hue[1.0700955630607052`, 1, -5.458310009071404], 
     Hue[1.1324790513242555`, 1, -5.272125369181308], 
     Hue[1.0700954719219002`, 1, -5.08406816953005], 
     Hue[1.132696940732911, 1, -4.897232592481449], 
     Hue[1.0700952715332845`, 1, -4.709827021821092], 
     Hue[1.1364044989647524`, 1, -4.511924643344938], 
     Hue[1.0710744622266353`, 1, -4.332663642938102], 
     Hue[1.1333284819087122`, 1, -4.146862412093181], 
     Hue[1.0710734748012483`, 1, -3.9584273807716084`], 
     Hue[1.1367986677205224`, 1, -3.7622618216630395`], 
     Hue[1.071561089325153, 1, -3.5827366512350878`], 
     Hue[1.1369918787171565`, 1, -3.387440310938576], 
     Hue[1.071801140782829, 1, -3.207793135267077], 
     Hue[1.1370786647500695`, 1, -3.0129334824308573`], 
     Hue[1.0759524052220166`, 1, -2.8211918500503614`], 
     Hue[1.1350237837952122`, 1, -2.644815972063369], 
     Hue[1.0759271081577446`, 1, -2.44709547112945], 
     Hue[1.1353250456956108`, 1, -2.2696517932212688`], 
     Hue[1.075871541466589, 1, -2.0731740360119613`], 
     Hue[1.1385412008865405`, 1, -1.885731797916905], 
     Hue[1.0757496291066062`, 1, -1.6996368113553808`], 
     Hue[1.1382397957908474`, 1, -1.5122490044766563`], 
     Hue[1.0754828453650775`, 1, -1.3269422202153904`], 
     Hue[1.1375804703423522`, 1, -1.1396784718167743`], 
     Hue[1.0768227099610486`, 1, -0.9502795267931512], 
     Hue[1.1369185525860797`, 1, -0.7667387790299507], 
     Hue[1.0769354203222479`, 1, -0.5791484807724905], 
     Hue[1.1366105956715435`, 1, -0.39164209368801894`], 
     Hue[1.0799226886000743`, 1, -0.20259059599143803`], 
     Hue[1.1351666011372703`, 1, -0.016927450035087332`], 
     Hue[1.0839269613656188`, 1, 0.1725392938047009], 
     Hue[1.1309164958783944`, 1, 0.3597022121474702], 
     Hue[1.0868513095438552`, 1, 0.5465943088199926], 
     Hue[1.0563080453717963`, 1, 0.7339352625217899], 
     Hue[1.0378572113804179`, 1, 0.9215974348313658], 
     Hue[1.2483913719257973`, 1, -17.27618334189528], 
     Hue[1.1856939713683314`, 1, -17.089062133554293`], 
     Hue[1.2454830452397818`, 1, -16.91062086407678], 
     Hue[1.1856939713683314`, 1, -16.714819716872324`], 
     Hue[1.2454830452397818`, 1, -16.53637844739481], 
     Hue[1.1856939713683314`, 1, -16.34057730019035], 
     Hue[1.2459575616990792`, 1, -16.16071983016143], 
     Hue[1.1856939713683314`, 1, -15.966334883508381`], 
     Hue[1.2463134490435521`, 1, -15.7854152630659], 
     Hue[1.1856939713683314`, 1, -15.592092466826411`], 
     Hue[1.2502282098327537`, 1, -15.399489191834807`], 
     Hue[1.1856939713683312`, 1, -15.217850050144438`], 
     Hue[1.2502282098327537`, 1, -15.025246775152837`], 
     Hue[1.185693971368331, 1, -14.843607633462467`], 
     Hue[1.2502282098327533`, 1, -14.651004358470864`], 
     Hue[1.1856939713683305`, 1, -14.469365216780497`], 
     Hue[1.2502282098327524`, 1, -14.276761941788894`], 
     Hue[1.1856939713683294`, 1, -14.095122800098528`], 
     Hue[1.2502282098327506`, 1, -13.902519525106923`], 
     Hue[1.1876532651357476`, 1, -13.715032845655903`], 
     Hue[1.2511466287862252`, 1, -13.525536075099648`], 
     Hue[1.1876532651357419`, 1, -13.34079042897394], 
     Hue[1.2511466287862163`, 1, -13.151293658417677`], 
     Hue[1.1876532651357297`, 1, -12.966548012291984`], 
     Hue[1.2511466287861965`, 1, -12.777051241735705`], 
     Hue[1.1876532651357028`, 1, -12.592305595610046`], 
     Hue[1.251146628786153, 1, -12.402808825053732`], 
     Hue[1.1876532651356435`, 1, -12.218063178928148`], 
     Hue[1.2511466287860573`, 1, -12.02856640837176], 
     Hue[1.1886329120192214`, 1, -11.840896993366007`], 
     Hue[1.2516058382625852`, 1, -11.652953475027124`], 
     Hue[1.1886329120189323`, 1, -11.466654576684387`], 
     Hue[1.2516058382621216`, 1, -11.27871105834514], 
     Hue[1.1886329120182964`, 1, -11.092412160003185`], 
     Hue[1.2516058382611024`, 1, -10.904468641663138`], 
     Hue[1.189122735458742, 1, -10.716707858882732`], 
     Hue[1.2536799343954137`, 1, -10.52403605805462], 
     Hue[1.1894901030370275`, 1, -10.341369028874322`], 
     Hue[1.2538463978257304`, 1, -10.149296829082061`], 
     Hue[1.1935311464250749`, 1, -9.955066065568527], 
     Hue[1.2539018856265096`, 1, -9.774888808302537], 
     Hue[1.1935311464095641`, 1, -9.580823648903706], 
     Hue[1.2539018856023456`, 1, -9.400646391618796], 
     Hue[1.19353114637546, 1, -9.206581232259445], 
     Hue[1.2539018855492157`, 1, -9.026403974932938], 
     Hue[1.193531146300475, 1, -8.832338815660385], 
     Hue[1.2556774954067909`, 1, -8.646862227139433], 
     Hue[1.1935311461356026`, 1, -8.458096399160716], 
     Hue[1.255677495147144, 1, -8.272619810429806], 
     Hue[1.1935311457730933`, 1, -8.083853982879575], 
     Hue[1.255677494576252, 1, -7.898377393687034], 
     Hue[1.1935311449760344`, 1, -7.7096115670789205`], 
     Hue[1.255677493321016, 1, -7.524134976871365], 
     Hue[1.1935311432235192`, 1, -7.335369152334722], 
     Hue[1.255677490561094, 1, -7.149892559895432], 
     Hue[1.1935311393702157`, 1, -6.9611267399133885`], 
     Hue[1.25656528942128, 1, -6.7730004768263665`], 
     Hue[1.1935311308978518`, 1, -6.586884332599395], 
     Hue[1.2565652760069494`, 1, -6.3987580584919685`], 
     Hue[1.1954904054584754`, 1, -6.206794397948571], 
     Hue[1.2574377442340323`, 1, -6.021911655591202], 
     Hue[1.195490363806347, 1, -5.832552025589236], 
     Hue[1.2574376790430006`, 1, -5.647669229810164], 
     Hue[1.1954902722246952`, 1, -5.458309706360762], 
     Hue[1.257873784021727, 1, -5.272124800035311], 
     Hue[1.1954900708617338`, 1, -5.084067503952952], 
     Hue[1.2580915917851303`, 1, -4.897231338754844], 
     Hue[1.195489628120097, 1, -4.709825558403804], 
     Hue[1.26179898446814, 1, -4.511921799053686], 
     Hue[1.1964682866053347`, 1, -4.3326603874371505`], 
     Hue[1.2587225627638208`, 1, -4.14685631836427], 
     Hue[1.1964661283346947`, 1, -3.9584202229389085`], 
     Hue[1.2621919506621582`, 1, -3.7622480256655813`], 
     Hue[1.1969511702157756`, 1, -3.5827208217864683`], 
     Hue[1.2623833499506456`, 1, -3.3874099277357486`], 
     Hue[1.197185565291878, 1, -3.2077582323153697`], 
     Hue[1.2624661519388924`, 1, -3.0128666266452004`], 
     Hue[1.1973996568908911`, 1, -2.8328313349422256`], 
     Hue[1.2625258129624375`, 1, -2.6383278317246157`], 
     Hue[1.2012719441828503`, 1, -2.4469184098578234`], 
     Hue[1.2606320595158, 1, -2.2694875359522433`], 
     Hue[1.201156462645934, 1, -2.0727850788871196`], 
     Hue[1.2638596299067437`, 1, -1.8850118589292502`], 
     Hue[1.200902737010756, 1, -1.6987833022257568`], 
     Hue[1.2634656344899104`, 1, -1.5106682498752912`], 
     Hue[1.200345770353986, 1, -1.3250737926530187`], 
     Hue[1.26259877057604, 1, -1.136213511028158], 
     Hue[1.1991255767310967`, 1, -0.9520213274909997], 
     Hue[1.260690207829998, 1, -0.761553589649618], 
     Hue[1.1983428864850925`, 1, -0.5745160423716931], 
     Hue[1.2572426186743746`, 1, -0.38413696837218425`], 
     Hue[1.193393466370257, 1, -0.20345063855750523`], 
     Hue[1.2468427945854952`, 1, -0.01343201067258959], 
     Hue[1.1848115812423834`, 1, 0.17075681168986867`], 
     Hue[1.2275910257143265`, 1, 0.36024402400616895`], 
     Hue[1.166324791929062, 1, 0.5464162153297303], 
     Hue[1.1892243620838092`, 1, 0.7341928124572177], 
     Hue[1.1147466766431378`, 1, 0.7344778178828281], 
     Hue[1.121768082197576, 1, 0.9219675076417906], 
     Hue[1.0715076392912717`, 1, 0.9217502177432065], 
     Hue[1.3737861730407288`, 1, -17.27618334189528], 
     Hue[1.311088772483263, 1, -17.089062133554293`], 
     Hue[1.3708778463547135`, 1, -16.91062086407678], 
     Hue[1.311088772483263, 1, -16.714819716872324`], 
     Hue[1.3708778463547135`, 1, -16.53637844739481], 
     Hue[1.311088772483263, 1, -16.34057730019035], 
     Hue[1.3713523628140107`, 1, -16.16071983016143], 
     Hue[1.311088772483263, 1, -15.966334883508381`], 
     Hue[1.3717082501584836`, 1, -15.7854152630659], 
     Hue[1.3110887724832627`, 1, -15.592092466826411`], 
     Hue[1.3756230109476855`, 1, -15.399489191834807`], 
     Hue[1.3110887724832627`, 1, -15.217850050144438`], 
     Hue[1.3756230109476852`, 1, -15.025246775152837`], 
     Hue[1.3110887724832625`, 1, -14.843607633462467`], 
     Hue[1.375623010947685, 1, -14.651004358470864`], 
     Hue[1.311088772483262, 1, -14.469365216780497`], 
     Hue[1.3756230109476844`, 1, -14.276761941788891`], 
     Hue[1.3110887724832607`, 1, -14.095122800098522`], 
     Hue[1.375623010947683, 1, -13.902519525106916`], 
     Hue[1.3130480662506794`, 1, -13.715032845655893`], 
     Hue[1.3765414299011591`, 1, -13.525536075099632`], 
     Hue[1.3130480662506736`, 1, -13.340790428973913`], 
     Hue[1.3765414299011527`, 1, -13.151293658417641`], 
     Hue[1.3130480662506614`, 1, -12.966548012291927`], 
     Hue[1.376541429901139, 1, -12.777051241735629`], 
     Hue[1.3130480662506345`, 1, -12.592305595609924`], 
     Hue[1.3765414299011085`, 1, -12.402808825053564`], 
     Hue[1.3130480662505755`, 1, -12.218063178927878`], 
     Hue[1.3765414299010414`, 1, -12.02856640837139], 
     Hue[1.3140277131341547`, 1, -11.84089699336541], 
     Hue[1.3770006393776335`, 1, -11.652953475026308`], 
     Hue[1.3140277131338673`, 1, -11.466654576683077`], 
     Hue[1.3770006393773098`, 1, -11.278711058343347`], 
     Hue[1.3140277131332359`, 1, -11.0924121600003], 
     Hue[1.3770006393765981`, 1, -10.904468641659198`], 
     Hue[1.314517536573698, 1, -10.71670785887637], 
     Hue[1.3790747355116402`, 1, -10.524036058045894`], 
     Hue[1.3148849041520236`, 1, -10.341369028860305`], 
     Hue[1.3792411989435194`, 1, -10.149296829062866`], 
     Hue[1.318925947540421, 1, -9.955066065536936], 
     Hue[1.379296686747731, 1, -9.774888808260323], 
     Hue[1.3189259475254071`, 1, -9.580823648834249], 
     Hue[1.379296686731107, 1, -9.400646391525985], 
     Hue[1.3189259474923956`, 1, -9.206581232106727], 
     Hue[1.379296686694555, 1, -9.026403974728868], 
     Hue[1.3189259474198118`, 1, -8.832338815324597], 
     Hue[1.3810722965910238`, 1, -8.646862226687988], 
     Hue[1.3189259472602204`, 1, -8.458096398422411], 
     Hue[1.3810722964144504`, 1, -8.272619809437202], 
     Hue[1.3189259469093224`, 1, -8.08385398125624], 
     Hue[1.3810722960262134`, 1, -7.898377391504568], 
     Hue[1.3189259461377931`, 1, -7.709611563509649], 
     Hue[1.3810722951725865`, 1, -7.524134972072718], 
     Hue[1.31892594444141, 1, -7.335369144486871], 
     Hue[1.3810722932956936`, 1, -7.149892549344517], 
     Hue[1.3189259407115266`, 1, -6.9611267226581015`], 
     Hue[1.3819600941608865`, 1, -6.77300045355799], 
     Hue[1.318925932510529, 1, -6.586884294659723], 
     Hue[1.3819600850915523`, 1, -6.398758007331146], 
     Hue[1.320885208029625, 1, -6.206794313543391], 
     Hue[1.382832563175915, 1, -6.021911542774089], 
     Hue[1.3208851681230895`, 1, -5.832551840005243], 
     Hue[1.3828325193545177`, 1, -5.647668981755999], 
     Hue[1.3208850803794598`, 1, -5.458309298312113], 
     Hue[1.383268672057673, 1, -5.272124253843407], 
     Hue[1.3208848874549683`, 1, -5.084066606765064], 
     Hue[1.383486584829328, 1, -4.897230136962702], 
     Hue[1.3208844632658034`, 1, -4.709823585731591], 
     Hue[1.3871942385235714`, 1, -4.5119191251092134`], 
     Hue[1.3218631719970386`, 1, -4.332656024750947], 
     Hue[1.384118303192, 1, -4.146850496297954], 
     Hue[1.3218611147088566`, 1, -3.958410630566247], 
     Hue[1.3875889577237581`, 1, -3.7622350824568436`], 
     Hue[1.32234640152843, 1, -3.5826996695388127`], 
     Hue[1.3877830190650418`, 1, -3.3873814505425255`], 
     Hue[1.322581336765802, 1, -3.207711656693462], 
     Hue[1.3878716749318636`, 1, -3.012803988358046], 
     Hue[1.3227736835932973`, 1, -2.8327973345075224`], 
     Hue[1.3879348961763607`, 1, -2.6382178948708503`], 
     Hue[1.3266735490723036`, 1, -2.4466877118013466`], 
     Hue[1.3859736738296082`, 1, -2.2694949215734024`], 
     Hue[1.3265661052858337`, 1, -2.0722777744034078`], 
     Hue[1.3860630667527452`, 1, -1.8942426654029092`], 
     Hue[1.3263295992327444`, 1, -1.697667580141528], 
     Hue[1.3891176696936758`, 1, -1.5091912723936904`], 
     Hue[1.3258082996030205`, 1, -1.3226192220113215`], 
     Hue[1.3851423587061462`, 1, -1.1432703152215977`], 
     Hue[1.3246558902422987`, 1, -0.946618021141832], 
     Hue[1.383161707386729, 1, -0.7670265618310386], 
     Hue[1.3201631228838824`, 1, -0.5746790560853845], 
     Hue[1.3786013734356508`, 1, -0.3890170924596392], 
     Hue[1.3116026778433234`, 1, -0.20233444266956102`], 
     Hue[1.3671887100110645`, 1, -0.01136279484567737], 
     Hue[1.4203387615423324`, 1, 0.1718992511381363], 
     Hue[1.2948371648197046`, 1, 0.17105773803743307`], 
     Hue[1.340291755685884, 1, 0.35873204941568704`], 
     Hue[1.3839537237868456`, 1, 0.5468940466433453], 
     Hue[1.2621320144357981`, 1, 0.5461368124704157], 
     Hue[1.2899031217395827`, 1, 0.7340850371163532], 
     Hue[1.3111285050102908`, 1, 0.9217758099627164], 
     Hue[1.3267197774350155`, 1, 1.1104317691959333`], 
     Hue[1.198208261842666, 1, 0.9215630922404692], 
     Hue[1.1905672950901183`, 1, 1.1092931545301163`], 
     Hue[1.1565696862760195`, 1, 1.297124426882168], 
     Hue[1.0984241317639005`, 1, 1.1099102849037292`], 
     Hue[1.0343622773800758`, 1, 1.1092848570686484`], 
     Hue[1.49918097415566, 1, -17.27618334189528], 
     Hue[1.4364835735981947`, 1, -17.089062133554293`], 
     Hue[1.496272647469645, 1, -16.91062086407678], 
     Hue[1.4364835735981947`, 1, -16.714819716872324`], 
     Hue[1.496272647469645, 1, -16.53637844739481], 
     Hue[1.4364835735981947`, 1, -16.34057730019035], 
     Hue[1.4967471639289425`, 1, -16.16071983016143], 
     Hue[1.4364835735981947`, 1, -15.966334883508381`], 
     Hue[1.4971030512734154`, 1, -15.7854152630659], 
     Hue[1.4364835735981947`, 1, -15.592092466826411`], 
     Hue[0.5010178120626172, 1, -15.399489191834807`], 
     Hue[1.4364835735981947`, 1, -15.217850050144438`], 
     Hue[0.5010178120626172, 1, -15.025246775152837`], 
     Hue[1.4364835735981945`, 1, -14.843607633462467`], 
     Hue[0.5010178120626172, 1, -14.65100435847086], 
     Hue[1.4364835735981942`, 1, -14.469365216780494`], 
     Hue[0.5010178120626172, 1, -14.276761941788891`], 
     Hue[1.4364835735981938`, 1, -14.095122800098519`], 
     Hue[0.5010178120626172, 1, -13.902519525106912`], 
     Hue[1.4384428673656136`, 1, -13.715032845655884`], 
     Hue[0.501936231016096, 1, -13.525536075099625`], 
     Hue[1.438442867365611, 1, -13.340790428973897`], 
     Hue[0.5019362310160961, 1, -13.151293658417627`], 
     Hue[1.4384428673656062`, 1, -12.96654801229189], 
     Hue[0.5019362310160964, 1, -12.777051241735599`], 
     Hue[1.4384428673655951`, 1, -12.592305595609837`], 
     Hue[0.5019362310160969, 1, -12.402808825053496`], 
     Hue[1.4384428673655711`, 1, -12.218063178927688`], 
     Hue[0.5019362310160981, 1, -12.02856640837124], 
     Hue[1.4394225142492292`, 1, -11.840896993364993`], 
     Hue[0.502395440492841, 1, -11.652953475025981`], 
     Hue[1.4394225142491133`, 1, -11.466654576682158`], 
     Hue[0.502395440492848, 1, -11.278711058342626`], 
     Hue[1.4394225142488584`, 1, -11.092412159998284`], 
     Hue[0.5023954404928633, 1, -10.904468641657614`], 
     Hue[1.4399123376901573`, 1, -10.716707858871935`], 
     Hue[0.5044695366295575, 1, -10.52403605804248], 
     Hue[1.44027970527033, 1, -10.341369028850554`], 
     Hue[0.5046360000650254, 1, -10.149296829055372`], 
     Hue[1.4443207486631482`, 1, -9.955066065515531], 
     Hue[0.5046914878771254, 1, -9.774888808243857], 
     Hue[1.4443207486574787`, 1, -9.580823648787185], 
     Hue[0.5046914878778378, 1, -9.400646391489778], 
     Hue[1.4443207486450131`, 1, -9.206581232003243], 
     Hue[0.5046914878794042, 1, -9.026403974649261], 
     Hue[1.4443207486176046`, 1, -8.832338815097069], 
     Hue[0.5064670978620607, 1, -8.646862226516173], 
     Hue[1.4443207485573413`, 1, -8.458096397922137], 
     Hue[0.5064670978726149, 1, -8.272619809059432], 
     Hue[1.444320748424838, 1, -8.083853980156277], 
     Hue[0.5064670978958209, 1, -7.898377390673953], 
     Hue[1.4443207481334994`, 1, -7.709611561091131], 
     Hue[0.5064670979468446, 1, -7.524134970246421], 
     Hue[1.4443207474929258`, 1, -7.335369139169205], 
     Hue[0.5064670980590318, 1, -7.149892545328988], 
     Hue[1.4443207460844787`, 1, -6.961126710966002], 
     Hue[0.5073549033590115, 1, -6.773000444813982], 
     Hue[1.444320742987687, 1, -6.586884268951983], 
     Hue[0.5073549039792247, 1, -6.398757988105454], 
     Hue[1.4462800302189769`, 1, -6.2067942570889185`], 
     Hue[0.5082274036605614, 1, -6.021911500913151], 
     Hue[1.4462800155749298`, 1, -5.832551715877196], 
     Hue[0.5082274070327496, 1, -5.647668889715138], 
     Hue[1.4462799833766338`, 1, -5.458309025388138], 
     Hue[0.508663664209914, 1, -5.272124052476901], 
     Hue[1.4462799125812251`, 1, -5.084066006678514], 
     Hue[0.5088818067631453, 1, -4.897229695324757], 
     Hue[1.4462797569207844`, 1, -4.709822266299452], 
     Hue[0.5125899942201262, 1, -4.5119181972900515`], 
     Hue[1.447259068760404, 1, -4.3326531258135486`], 
     Hue[0.5095151496883767, 1, -4.146848376948917], 
     Hue[1.44725832486122, 1, -3.9584042564664017`], 
     Hue[0.512988389093076, 1, -3.762230620068568], 
     Hue[1.4477465302854096`, 1, -3.5826856596837153`], 
     Hue[0.5131880180767175, 1, -3.3873716639142977`], 
     Hue[1.44798788597789, 1, -3.207680856334525], 
     Hue[0.5132889188331662, 1, -3.0127824946648207`], 
     Hue[1.4481637622155064`, 1, -2.8328210116140866`], 
     Hue[0.5133666449191, 1, -2.638207804176097], 
     Hue[1.4521279770251092`, 1, -2.4465393607888606`], 
     Hue[0.5114753973228536, 1, -2.269388401265255], 
     Hue[1.4520920311373624`, 1, -2.07195123835281], 
     Hue[0.5116434133017536, 1, -1.894158251407701], 
     Hue[1.45201281157893, 1, -1.6969479085269794`], 
     Hue[0.5116718326413615, 1, -1.5187599350375203`], 
     Hue[1.4518377330806194`, 1, -1.3210285698371325`], 
     Hue[0.5113693531136102, 1, -1.1430552867394448`], 
     Hue[1.447369067835866, 1, -0.955367006853922], 
     Hue[0.5100095166931327, 1, -0.7676187371789256], 
     Hue[1.4445716851507262`, 1, -0.5788751620383168], 
     Hue[0.507710728909197, 1, -0.3884545010774574], 
     Hue[1.4372836435977845`, 1, -0.20300474613560415`], 
     Hue[1.4986281011640878`, 1, -0.014262152572312337`], 
     Hue[0.5636886249561339, 1, 0.17099892716614995`], 
     Hue[1.476949518487042, 1, 0.3586967678368642], 
     Hue[0.5416903040750667, 1, 0.5463502773114449], 
     Hue[1.428182990802944, 1, 0.7339104323204029], 
     Hue[1.4784044569668127`, 1, 0.9216585116566425], 
     Hue[0.546298620238238, 1, 1.1095699040085485`], 
     Hue[1.3372842265462022`, 1, 1.2977857373659956`], 
     Hue[0.9913271474943476, 1, 1.297069272775367], 
     Hue[1.006938048375609, 1, 1.1096249284941784`], 
     Hue[0.6245757752705916, 1, -17.27618334189528], 
     Hue[0.561878374713126, 1, -17.089062133554293`], 
     Hue[0.6216674485845766, 1, -16.91062086407678], 
     Hue[0.5618783747131261, 1, -16.714819716872324`], 
     Hue[0.6216674485845766, 1, -16.53637844739481], 
     Hue[0.5618783747131261, 1, -16.34057730019035], 
     Hue[0.6221419650438739, 1, -16.16071983016143], 
     Hue[0.5618783747131261, 1, -15.966334883508381`], 
     Hue[0.6224978523883469, 1, -15.7854152630659], 
     Hue[0.5618783747131261, 1, -15.592092466826411`], 
     Hue[0.6264126131775489, 1, -15.399489191834807`], 
     Hue[0.5618783747131262, 1, -15.217850050144438`], 
     Hue[0.6264126131775491, 1, -15.025246775152837`], 
     Hue[0.5618783747131262, 1, -14.843607633462467`], 
     Hue[0.6264126131775494, 1, -14.651004358470864`], 
     Hue[0.5618783747131264, 1, -14.469365216780494`], 
     Hue[0.62641261317755, 1, -14.276761941788891`], 
     Hue[0.5618783747131268, 1, -14.095122800098519`], 
     Hue[0.6264126131775514, 1, -13.902519525106916`], 
     Hue[0.5638376684805484, 1, -13.715032845655884`], 
     Hue[0.6273310321310326, 1, -13.525536075099632`], 
     Hue[0.5638376684805508, 1, -13.340790428973897`], 
     Hue[0.6273310321310389, 1, -13.151293658417643`], 
     Hue[0.5638376684805559, 1, -12.96654801229189], 
     Hue[0.6273310321310531, 1, -12.77705124173563], 
     Hue[0.5638376684805674, 1, -12.592305595609838`], 
     Hue[0.6273310321310843, 1, -12.402808825053569`], 
     Hue[0.5638376684805925, 1, -12.21806317892769], 
     Hue[0.6273310321311529, 1, -12.028566408371399`], 
     Hue[0.5648173153643602, 1, -11.840896993365], 
     Hue[0.6277902416080445, 1, -11.652953475026333`], 
     Hue[0.5648173153644838, 1, -11.466654576682176`], 
     Hue[0.627790241608378, 1, -11.278711058343402`], 
     Hue[0.5648173153647557, 1, -11.092412159998323`], 
     Hue[0.6277902416091115, 1, -10.904468641659317`], 
     Hue[0.5653071388072197, 1, -10.71670785887204], 
     Hue[0.6298643377474058, 1, -10.52403605804639], 
     Hue[0.5656745063899575, 1, -10.341369028850815`], 
     Hue[0.6300308011863742, 1, -10.149296829063996`], 
     Hue[0.5697155497886621, 1, -9.955066065516926], 
     Hue[0.6300862890061691, 1, -9.774888808262839], 
     Hue[0.5697155497956781, 1, -9.580823648790249], 
     Hue[0.6300862890237982, 1, -9.400646391531513], 
     Hue[0.5697155498111046, 1, -9.206581232009981], 
     Hue[0.6300862890625596, 1, -9.026403974741026], 
     Hue[0.569715549845023, 1, -8.832338815111884], 
     Hue[0.6318618991279091, 1, -8.646862226725242], 
     Hue[0.5697155499196006, 1, -8.458096397954707], 
     Hue[0.6318618993193714, 1, -8.272619809519114], 
     Hue[0.5697155500835763, 1, -8.083853980227891], 
     Hue[0.631861899740345, 1, -7.898377391684668], 
     Hue[0.5697155504441143, 1, -7.709611561248592], 
     Hue[0.631861900665951, 1, -7.524134972468709], 
     Hue[0.569715551236839, 1, -7.335369139515419], 
     Hue[0.6318619027011065, 1, -7.149892550215195], 
     Hue[0.5697155529798247, 1, -6.961126711727235], 
     Hue[0.6327497122522376, 1, -6.77300045574718], 
     Hue[0.5697155568121754, 1, -6.586884270625723], 
     Hue[0.6327497221965068, 1, -6.3987580121445795`], 
     Hue[0.5716748596073975, 1, -6.206794261853738], 
     Hue[0.6336222424874274, 1, -6.021911554677028], 
     Hue[0.5716748788555739, 1, -5.83255172635374], 
     Hue[0.6336222910659692, 1, -5.647669007927333], 
     Hue[0.5716749211771022, 1, -5.458309048423231], 
     Hue[0.6340586479000321, 1, -5.272124314601678], 
     Hue[0.5716750142307727, 1, -5.08406605732653], 
     Hue[0.6342770095968111, 1, -4.897230274101752], 
     Hue[0.5716752188312261, 1, -4.709822377661243], 
     Hue[0.6379856890151618, 1, -4.511919562378027], 
     Hue[0.5726553312282605, 1, -4.3326533990337674`], 
     Hue[0.6349118968724194, 1, -4.1468512093402925`], 
     Hue[0.5726563391353503, 1, -3.9584048572191097`], 
     Hue[0.6383875159601274, 1, -3.7622372686249284`], 
     Hue[0.573148416844975, 1, -3.5826870498161103`], 
     Hue[0.6385923363752279, 1, -3.387386337243412], 
     Hue[0.5733982894490773, 1, -3.207683989626241], 
     Hue[0.6387046532825359, 1, -3.01281482213349], 
     Hue[0.5735929104265838, 1, -2.83282802912193], 
     Hue[0.6388074895287772, 1, -2.6382790082603993`], 
     Hue[0.5776000783642052, 1, -2.446560969848969], 
     Hue[0.6369708783054719, 1, -2.2695396607656546`], 
     Hue[0.5776569124335447, 1, -2.071998817395106], 
     Hue[0.6406275215983028, 1, -1.8844730520996456`], 
     Hue[0.5777821445704392, 1, -1.6970528449041111`], 
     Hue[0.640934011317462, 1, -1.5094814386356104`], 
     Hue[0.578058805225413, 1, -1.3212608688910172`], 
     Hue[0.6416113058395323, 1, -1.133593822588381], 
     Hue[0.5746139263288061, 1, -0.9555510866101178], 
     Hue[0.6414497530867184, 1, -0.7605536415245304], 
     Hue[0.5739171053289776, 1, -0.5795608210238168], 
     Hue[0.6397605520316192, 1, -0.39232640828897436`], 
     Hue[0.5724801272431652, 1, -0.200695609024796], 
     Hue[0.6409223035990068, 1, -0.01645654533697316], 
     Hue[0.6411737378985626, 1, 0.35963516629653514`], 
     Hue[0.6288092604445719, 1, 0.7342753940917904], 
     Hue[0.8660597729459893, 1, 1.109452435003217], 
     Hue[0.9458887434116827, 1, 1.109304417476081], 
     Hue[0.9183689337143223, 1, 1.297348028837666], 
     Hue[0.9742785474077998, 1, 1.1093523710894395`], 
     Hue[0.9902059044305799, 1, 1.1093870879723744`], 
     Hue[0.7499705763855232, 1, -17.27618334189528], 
     Hue[0.6872731758280575, 1, -17.089062133554293`], 
     Hue[0.7470622496995081, 1, -16.91062086407678], 
     Hue[0.6872731758280575, 1, -16.714819716872324`], 
     Hue[0.7470622496995081, 1, -16.53637844739481], 
     Hue[0.6872731758280575, 1, -16.34057730019035], 
     Hue[0.7475367661588055, 1, -16.16071983016143], 
     Hue[0.6872731758280575, 1, -15.966334883508381`], 
     Hue[0.7478926535032785, 1, -15.7854152630659], 
     Hue[0.6872731758280576, 1, -15.592092466826411`], 
     Hue[0.7518074142924804, 1, -15.399489191834807`], 
     Hue[0.6872731758280577, 1, -15.217850050144438`], 
     Hue[0.7518074142924807, 1, -15.025246775152837`], 
     Hue[0.6872731758280579, 1, -14.843607633462467`], 
     Hue[0.7518074142924811, 1, -14.651004358470864`], 
     Hue[0.6872731758280585, 1, -14.469365216780497`], 
     Hue[0.7518074142924819, 1, -14.276761941788894`], 
     Hue[0.6872731758280596, 1, -14.095122800098522`], 
     Hue[0.7518074142924838, 1, -13.902519525106923`], 
     Hue[0.689232469595483, 1, -13.715032845655893`], 
     Hue[0.7527258332459662, 1, -13.525536075099648`], 
     Hue[0.6892324695954886, 1, -13.340790428973914`], 
     Hue[0.7527258332459752, 1, -13.151293658417677`], 
     Hue[0.6892324695955008, 1, -12.966548012291929`], 
     Hue[0.752725833245995, 1, -12.777051241735707`], 
     Hue[0.6892324695955279, 1, -12.592305595609925`], 
     Hue[0.7527258332460385, 1, -12.402808825053738`], 
     Hue[0.6892324695955875, 1, -12.218063178927881`], 
     Hue[0.7527258332461341, 1, -12.028566408371772`], 
     Hue[0.6902121164794308, 1, -11.84089699336543], 
     Hue[0.7531850427230845, 1, -11.652953475027159`], 
     Hue[0.690212116479721, 1, -11.46665457668312], 
     Hue[0.753185042723548, 1, -11.278711058345216`], 
     Hue[0.6902121164803595, 1, -11.092412160000395`], 
     Hue[0.7531850427245672, 1, -10.904468641663305`], 
     Hue[0.6907019399236298, 1, -10.716707858876623`], 
     Hue[0.7552591388634664, 1, -10.524036058055316`], 
     Hue[0.6910693075081391, 1, -10.341369028860935`], 
     Hue[0.7554256023037839, 1, -10.149296829083655`], 
     Hue[0.6951103509107271, 1, -9.955066065540295], 
     Hue[0.7554810901265463, 1, -9.774888808306084], 
     Hue[0.6951103509262941, 1, -9.580823648841635], 
     Hue[0.7554810901507033, 1, -9.400646391626596], 
     Hue[0.6951103509605219, 1, -9.206581232122968], 
     Hue[0.7554810902038178, 1, -9.026403974950087], 
     Hue[0.6951103510357791, 1, -8.832338815360307], 
     Hue[0.7572567002996338, 1, -8.646862227191987], 
     Hue[0.6951103512012493, 1, -8.458096398500928], 
     Hue[0.7572567005591756, 1, -8.27261981054536], 
     Hue[0.6951103515650732, 1, -8.083853981428883], 
     Hue[0.7572567011298375, 1, -7.898377393941101], 
     Hue[0.6951103523650228, 1, -7.709611563889241], 
     Hue[0.7572567023845672, 1, -7.524134977429989], 
     Hue[0.6951103541238943, 1, -7.335369145321489], 
     Hue[0.7572567051433761, 1, -7.149892561123697], 
     Hue[0.695110357991173, 1, -6.9611267244932025`], 
     Hue[0.7581445162568236, 1, -6.77300047991466], 
     Hue[0.6951103664942655, 1, -6.58688429869461], 
     Hue[0.7581445296649999, 1, -6.398758065282284], 
     Hue[0.697069679533342, 1, -6.206794325029944], 
     Hue[0.7590170574328998, 1, -6.021911672382683], 
     Hue[0.6970697213307948, 1, -5.832551865261046], 
     Hue[0.759017122590464, 1, -5.647669266730055], 
     Hue[0.6970698132320292, 1, -5.458309353842769], 
     Hue[0.759453515536396, 1, -5.2721248857468686`], 
     Hue[0.697070015297927, 1, -5.084066728861965], 
     Hue[0.7596719565965904, 1, -4.897231532216053], 
     Hue[0.6970704595863912, 1, -4.709823854190005], 
     Hue[0.7633807962576515, 1, -4.511922415902107], 
     Hue[0.6980510982041037, 1, -4.3326566833946565`], 
     Hue[0.7603073978967582, 1, -4.146857324228607], 
     Hue[0.6980532639096632, 1, -3.9584120787600154`], 
     Hue[0.7637837890163377, 1, -3.762251109521415], 
     Hue[0.6985478852257276, 1, -3.582703020521002], 
     Hue[0.7639903647818154, 1, -3.3874168205544466`], 
     Hue[0.6988033501261817, 1, -3.2077192090734883`], 
     Hue[0.764106538843862, 1, -3.0128819056909295`], 
     Hue[0.6990408897495717, 1, -2.8328142972406924`], 
     Hue[0.7642302841531359, 1, -2.6383895155367636`], 
     Hue[0.7030442365630507, 1, -2.4467397689203185`], 
     Hue[0.7625041146570843, 1, -2.2695511754873916`], 
     Hue[0.703160213294727, 1, -2.072392299520317], 
     Hue[0.7660954950427984, 1, -1.8851968372461665`], 
     Hue[0.7034153946369952, 1, -1.6979197068430365`], 
     Hue[0.7664886316202683, 1, -1.5110749501862115`], 
     Hue[0.7039773355263093, 1, -1.323175108590288], 
     Hue[0.7673523155443309, 1, -1.1371076156140856`], 
     Hue[0.7052170360224839, 1, -0.9478476027861054], 
     Hue[0.7692476486409306, 1, -0.7635185018626287], 
     Hue[0.7079623561570478, 1, -0.5713132022514358], 
     Hue[0.7733950224721154, 1, -0.3909443883210231], 
     Hue[0.7095606470824721, 1, -0.20426928013792112`], 
     Hue[0.7842527097651073, 1, -0.016972590066890225`], 
     Hue[0.7197973641266101, 1, 0.17158555368091344`], 
     Hue[0.8132038874997555, 1, 0.3594182231239851], 
     Hue[0.744687159473614, 1, 0.5467559509153047], 
     Hue[0.8753653775004548, 1, -17.27618334189528], 
     Hue[0.8126679769429891, 1, -17.089062133554293`], 
     Hue[0.8724570508144397, 1, -16.91062086407678], 
     Hue[0.8126679769429891, 1, -16.714819716872324`], 
     Hue[0.8724570508144397, 1, -16.53637844739481], 
     Hue[0.8126679769429891, 1, -16.34057730019035], 
     Hue[0.8729315672737369, 1, -16.16071983016143], 
     Hue[0.8126679769429891, 1, -15.966334883508381`], 
     Hue[0.8732874546182099, 1, -15.7854152630659], 
     Hue[0.8126679769429892, 1, -15.592092466826411`], 
     Hue[0.8772022154074121, 1, -15.399489191834807`], 
     Hue[0.8126679769429893, 1, -15.217850050144438`], 
     Hue[0.8772022154074122, 1, -15.025246775152837`], 
     Hue[0.8126679769429895, 1, -14.843607633462467`], 
     Hue[0.8772022154074124, 1, -14.651004358470864`], 
     Hue[0.8126679769429901, 1, -14.469365216780497`], 
     Hue[0.877202215407413, 1, -14.276761941788898`], 
     Hue[0.8126679769429912, 1, -14.095122800098528`], 
     Hue[0.8772022154074143, 1, -13.90251952510693], 
     Hue[0.8146272707104143, 1, -13.715032845655905`], 
     Hue[0.8781206343608954, 1, -13.525536075099664`], 
     Hue[0.8146272707104198, 1, -13.34079042897394], 
     Hue[0.8781206343609016, 1, -13.15129365841771], 
     Hue[0.8146272707104321, 1, -12.966548012291986`], 
     Hue[0.8781206343609154, 1, -12.777051241735784`], 
     Hue[0.8146272707104589, 1, -12.592305595610048`], 
     Hue[0.8781206343609455, 1, -12.402808825053906`], 
     Hue[0.8146272707105179, 1, -12.218063178928151`], 
     Hue[0.8781206343610117, 1, -12.028566408372141`], 
     Hue[0.8156069175943588, 1, -11.840896993366025`], 
     Hue[0.8785798438378967, 1, -11.652953475027969`], 
     Hue[0.8156069175946448, 1, -11.46665457668443], 
     Hue[0.8785798438382171, 1, -11.278711058347], 
     Hue[0.8156069175952736, 1, -11.092412160003278`], 
     Hue[0.8785798438389215, 1, -10.904468641667227`], 
     Hue[0.8160967410385157, 1, -10.71670785888298], 
     Hue[0.880653939977074, 1, -10.524036058064002`], 
     Hue[0.8164641086229595, 1, -10.34136902887495], 
     Hue[0.8808204034157943, 1, -10.149296829102763`], 
     Hue[0.8205051520251392, 1, -9.955066065571872], 
     Hue[0.880875891235048, 1, -9.774888808348107], 
     Hue[0.8205051520400835, 1, -9.580823648911062], 
     Hue[0.8808758912514971, 1, -9.400646391718993], 
     Hue[0.8205051520729421, 1, -9.20658123227562], 
     Hue[0.8808758912876643, 1, -9.026403975153245], 
     Hue[0.820505152145189, 1, -8.832338815695948], 
     Hue[0.8826515013437668, 1, -8.646862227641357], 
     Hue[0.8205051523040405, 1, -8.458096399238912], 
     Hue[0.8826515015184404, 1, -8.272619811533401], 
     Hue[0.8205051526533116, 1, -8.083853983051505], 
     Hue[0.8826515019025001, 1, -7.8983773961135375`], 
     Hue[0.8205051534212635, 1, -7.709611567456949], 
     Hue[0.8826515027469428, 1, -7.524134982206587], 
     Hue[0.8205051551097806, 1, -7.335369153165906], 
     Hue[0.8826515046036421, 1, -7.14989257162613], 
     Hue[0.8205051588223693, 1, -6.961126741740936], 
     Hue[0.8835393136699002, 1, -6.773000503074551], 
     Hue[0.8205051669853397, 1, -6.586884336617673], 
     Hue[0.8835393226405603, 1, -6.398758116204569], 
     Hue[0.8224644789115028, 1, -6.206794409387841], 
     Hue[0.884411840346671, 1, -6.021911784666269], 
     Hue[0.8224645186270247, 1, -5.832552050741068], 
     Hue[0.8844118836859826, 1, -5.647669513610978], 
     Hue[0.8224646059505999, 1, -5.458309761662759], 
     Hue[0.8848482279183449, 1, -5.272125429336428], 
     Hue[0.8224647979511787, 1, -5.084067625546847], 
     Hue[0.8850665617943826, 1, -4.8972327282583485`], 
     Hue[0.8224652201073286, 1, -4.709825825755028], 
     Hue[0.8887751355557721, 1, -4.511925076264943], 
     Hue[0.8234458005101521, 1, -4.332661043357851], 
     Hue[0.8857012403453651, 1, -4.146863118025024], 
     Hue[0.8234478477284709, 1, -3.958421665113711], 
     Hue[0.8891763410559943, 1, -3.762263985895528], 
     Hue[0.8239421850866404, 1, -3.5827241586789826`], 
     Hue[0.8893802024653401, 1, -3.3874451479532777`], 
     Hue[0.8241970224255597, 1, -3.2077657521356384`], 
     Hue[0.8894904055463311, 1, -3.0129442028650937`], 
     Hue[0.824459945051953, 1, -2.8328368418534824`], 
     Hue[0.8896118806237742, 1, -2.638494039502219], 
     Hue[0.8284313779219781, 1, -2.4469702024060345`], 
     Hue[0.8879251415133499, 1, -2.2696196215583697`], 
     Hue[0.828538055131595, 1, -2.0728988894314284`], 
     Hue[0.8913702088931911, 1, -1.8858612441292564`], 
     Hue[0.8287723389406314, 1, -1.6990332155503156`], 
     Hue[0.891618696071179, 1, -1.5125326204706935`], 
     Hue[0.8292861578882899, 1, -1.325621708416773], 
     Hue[0.8921617031775108, 1, -1.1402972547956745`], 
     Hue[0.8304095805360469, 1, -0.9532183859665884], 
     Hue[0.8949866762420426, 1, -0.7656741039107497], 
     Hue[0.8348312553014317, 1, -0.5774870922931954], 
     Hue[0.9030651504502243, 1, -0.38554331208859516`], 
     Hue[0.8440664178673213, 1, -0.20226654422687673`], 
     Hue[0.9147195390060338, 1, -0.016337969882121994`], 
     Hue[0.864627359982905, 1, 0.17102789178960465`], 
     Hue[0.9458085427667182, 1, 0.3600237558088901], 
     Hue[0.9186509499197628, 1, 0.5463111474612566], 
     Hue[0.912290357982985, 1, 0.7344778670489442], 
     Hue[0.9782949355639565, 1, 0.9215750668260004], 
     Hue[1.0007601786153864`, 1, -17.27618334189528], 
     Hue[0.9380627780579206, 1, -17.089062133554293`], 
     Hue[0.9978518519293713, 1, -16.91062086407678], 
     Hue[0.9380627780579205, 1, -16.714819716872324`], 
     Hue[0.9978518519293713, 1, -16.53637844739481], 
     Hue[0.9380627780579206, 1, -16.34057730019035], 
     Hue[0.9983263683886685, 1, -16.16071983016143], 
     Hue[0.9380627780579206, 1, -15.966334883508381`], 
     Hue[0.9986822557331415, 1, -15.7854152630659], 
     Hue[0.9380627780579206, 1, -15.592092466826411`], 
     Hue[1.0025970165223435`, 1, -15.399489191834807`], 
     Hue[0.9380627780579206, 1, -15.217850050144438`], 
     Hue[1.0025970165223435`, 1, -15.025246775152837`], 
     Hue[0.9380627780579207, 1, -14.843607633462467`], 
     Hue[1.0025970165223435`, 1, -14.651004358470868`], 
     Hue[0.9380627780579209, 1, -14.469365216780501`], 
     Hue[1.0025970165223435`, 1, -14.276761941788898`], 
     Hue[0.9380627780579214, 1, -14.095122800098533`], 
     Hue[1.0025970165223435`, 1, -13.902519525106934`], 
     Hue[0.9400220718253431, 1, -13.715032845655912`], 
     Hue[1.0035154354758216`, 1, -13.52553607509967], 
     Hue[0.9400220718253454, 1, -13.340790428973957`], 
     Hue[1.0035154354758213`, 1, -13.151293658417725`], 
     Hue[0.9400220718253502, 1, -12.966548012292025`], 
     Hue[1.003515435475821, 1, -12.777051241735814`], 
     Hue[0.940022071825361, 1, -12.592305595610133`], 
     Hue[1.00351543547582, 1, -12.402808825053972`], 
     Hue[0.9400220718253847, 1, -12.218063178928341`], 
     Hue[1.0035154354758178`, 1, -12.028566408372287`], 
     Hue[0.941001718709146, 1, -11.840896993366439`], 
     Hue[1.0039746449525513`, 1, -11.652953475028289`], 
     Hue[0.9410017187092591, 1, -11.466654576685338`], 
     Hue[1.0039746449525397`, 1, -11.278711058347703`], 
     Hue[0.9410017187095077, 1, -11.092412160005274`], 
     Hue[1.0039746449525142`, 1, -10.904468641668773`], 
     Hue[0.9414915421519048, 1, -10.71670785888737], 
     Hue[1.0060487410890084`, 1, -10.524036058067328`], 
     Hue[0.9418589097344842, 1, -10.3413690288846], 
     Hue[1.0062152045241268`, 1, -10.149296829110062`], 
     Hue[0.9458999531322045, 1, -9.955066065593046], 
     Hue[1.0062706923354632`, 1, -9.774888808364144], 
     Hue[0.9458999531377196, 1, -9.580823648957619], 
     Hue[1.006270692334511, 1, -9.400646391754256], 
     Hue[0.9458999531498455, 1, -9.20658123237798], 
     Hue[1.0062706923324176`, 1, -9.026403975230778], 
     Hue[0.9458999531765072, 1, -8.832338815921013], 
     Hue[1.0080463023020296`, 1, -8.646862227808539], 
     Hue[0.9458999532351289, 1, -8.458096399733765], 
     Hue[1.0080463022889, 1, -8.27261981190099], 
     Hue[0.9458999533640221, 1, -8.083853984139552], 
     Hue[1.0080463022600317`, 1, -7.898377396921764], 
     Hue[0.9458999536474231, 1, -7.709611569849268], 
     Hue[1.008046302196558, 1, -7.524134983983655], 
     Hue[0.9458999542705445, 1, -7.335369158425961], 
     Hue[1.008046302056997, 1, -7.14989257553342], 
     Hue[0.9458999556406188, 1, -6.961126753306362], 
     Hue[1.008934106672967, 1, -6.773000511578757], 
     Hue[0.9458999586530387, 1, -6.586884362046896], 
     Hue[1.0089341059197128`, 1, -6.398758134902998], 
     Hue[0.9478592587653653, 1, -6.2067944652154186`], 
     Hue[1.009806601954676, 1, -6.021911825359236], 
     Hue[0.9478592729946616, 1, -5.832552173490648], 
     Hue[1.009806597935977, 1, -5.647669603083659], 
     Hue[0.94785930428098, 1, -5.458310031555406], 
     Hue[1.0102428373363992`, 1, -5.272125625034664], 
     Hue[0.9478593730709407, 1, -5.084068218966119], 
     Hue[1.010460940645254, 1, -4.897233157407268], 
     Hue[0.9478595243207019, 1, -4.709827130516942], 
     Hue[1.0141689790639017`, 1, -4.511925975744039], 
     Hue[0.9488394963971803, 1, -4.3326639096111075`], 
     Hue[1.0110939891898423`, 1, -4.14686517657099], 
     Hue[0.9488402187544074, 1, -3.9584279670972844`], 
     Hue[1.0145664976022215`, 1, -3.7622683103361076`], 
     Hue[0.9493316123520609, 1, -3.5827380078244238`], 
     Hue[1.014764775073221, 1, -3.3874546291543277`], 
     Hue[0.9495799741545317, 1, -3.207796192165681], 
     Hue[1.014862700421658, 1, -3.012965016627735], 
     Hue[0.9537502999566514, 1, -2.8212014266440386`], 
     Hue[1.0128320205154309`, 1, -2.644882712284212], 
     Hue[0.9537660797050566, 1, -2.4471165139976323`], 
     Hue[1.0132320192564994`, 1, -2.269664617180582], 
     Hue[0.9538007383034126, 1, -2.073220238608589], 
     Hue[1.0165228078727129`, 1, -1.8860764518114934`], 
     Hue[0.9538767658228553, 1, -1.6997380853434552`], 
     Hue[1.0164820240896273`, 1, -1.5130037324776666`], 
     Hue[0.954043077356455, 1, -1.3271633917918628`], 
     Hue[1.016393053362053, 1, -1.1413231852611128`], 
     Hue[0.9563442370718804, 1, -0.9508281926765096], 
     Hue[1.0185613303224381`, 1, -0.7655866727699805], 
     Hue[0.9587723838712148, 1, -0.5797268588293847], 
     Hue[1.0232533396325398`, 1, -0.3879431401907527], 
     Hue[0.9670270639602442, 1, -0.20357150795705437`], 
     Hue[1.030669147607423, 1, -0.01331603455983088], 
     Hue[0.9832943415705929, 1, 0.17114960403254476`], 
     Hue[1.0435018497328765`, 1, 0.3597814162117673], 
     Hue[1.0139431665502352`, 1, 0.5476713061651385], 
     Hue[1.002984252561474, 1, 0.7345285313199721], 
     Hue[1.0124687198606503`, 1, 0.9217382274308028], 
     Hue[1.126154979730318, 1, -17.27618334189528], 
     Hue[1.0634575791728522`, 1, -17.089062133554293`], 
     Hue[1.1232466530443028`, 1, -16.91062086407678], 
     Hue[1.0634575791728522`, 1, -16.714819716872324`], 
     Hue[1.1232466530443028`, 1, -16.53637844739481], 
     Hue[1.0634575791728522`, 1, -16.34057730019035], 
     Hue[1.1237211695036, 1, -16.16071983016143], 
     Hue[1.0634575791728522`, 1, -15.966334883508381`], 
     Hue[1.124077056848073, 1, -15.7854152630659], 
     Hue[1.063457579172852, 1, -15.592092466826411`], 
     Hue[1.127991817637275, 1, -15.399489191834807`], 
     Hue[1.063457579172852, 1, -15.217850050144438`], 
     Hue[1.127991817637275, 1, -15.025246775152837`], 
     Hue[1.063457579172852, 1, -14.843607633462467`], 
     Hue[1.1279918176372745`, 1, -14.651004358470864`], 
     Hue[1.0634575791728518`, 1, -14.469365216780501`], 
     Hue[1.127991817637274, 1, -14.276761941788898`], 
     Hue[1.0634575791728513`, 1, -14.095122800098533`], 
     Hue[1.1279918176372727`, 1, -13.90251952510693], 
     Hue[1.0654168729402709`, 1, -13.715032845655912`], 
     Hue[1.128910236590748, 1, -13.525536075099662`], 
     Hue[1.0654168729402684`, 1, -13.340790428973957`], 
     Hue[1.1289102365907413`, 1, -13.15129365841771], 
     Hue[1.065416872940263, 1, -12.966548012292023`], 
     Hue[1.128910236590727, 1, -12.77705124173578], 
     Hue[1.0654168729402516`, 1, -12.592305595610132`], 
     Hue[1.1289102365906956`, 1, -12.402808825053897`], 
     Hue[1.0654168729402258`, 1, -12.218063178928336`], 
     Hue[1.1289102365906263`, 1, -12.028566408372123`], 
     Hue[1.0663965198238778`, 1, -11.840896993366425`], 
     Hue[1.1293694460672117`, 1, -11.652953475027928`], 
     Hue[1.0663965198237513`, 1, -11.466654576685308`], 
     Hue[1.129369446066875, 1, -11.27871105834691], 
     Hue[1.0663965198234733`, 1, -11.092412160005207`], 
     Hue[1.1293694460661345`, 1, -10.904468641667028`], 
     Hue[1.0668863432647058`, 1, -10.716707858887203`], 
     Hue[1.1314435422010363`, 1, -10.524036058063334`], 
     Hue[1.0672537108447209`, 1, -10.341369028884198`], 
     Hue[1.1316100056326701`, 1, -10.14929682910125], 
     Hue[1.071294754236559, 1, -9.955066065591339], 
     Hue[1.1316654934363461`, 1, -9.774888808344746], 
     Hue[1.0712947542293945`, 1, -9.580823648953865], 
     Hue[1.131665493418554, 1, -9.400646391711604], 
     Hue[1.071294754213642, 1, -9.206581232369727], 
     Hue[1.1316654933794335`, 1, -9.026403975136999], 
     Hue[1.0712947541790065`, 1, -8.832338815902869], 
     Hue[1.1334411032667469`, 1, -8.646862227595014], 
     Hue[1.071294754102853, 1, -8.458096399693872], 
     Hue[1.1334411030735514`, 1, -8.272619811431504], 
     Hue[1.0712947539354116`, 1, -8.083853984051837], 
     Hue[1.133441102648767, 1, -7.898377395889491], 
     Hue[1.0712947535672537`, 1, -7.709611569656405], 
     Hue[1.133441101714782, 1, -7.5241349817139715`], 
     Hue[1.071294752757775, 1, -7.335369158001911], 
     Hue[1.1334410996612039`, 1, -7.149892570543007], 
     Hue[1.0712947509779516`, 1, -6.9611267523739935`], 
     Hue[1.1343289000463361`, 1, -6.773000500415761], 
     Hue[1.0712947470646057`, 1, -6.586884359996868], 
     Hue[1.1343288900130595`, 1, -6.398758110358613], 
     Hue[1.0732540316240529`, 1, -6.206794459613571], 
     Hue[1.1352013655382887`, 1, -6.0219117704812986`], 
     Hue[1.0732540119818292`, 1, -5.832552161173719], 
     Hue[1.1352013165297876`, 1, -5.647669482422112], 
     Hue[1.0732539687939666`, 1, -5.458310004473866], 
     Hue[1.1356374567569685`, 1, -5.272125357517629], 
     Hue[1.073253873835793, 1, -5.08406815942134], 
     Hue[1.1358553419872566`, 1, -4.897232566769717], 
     Hue[1.0732536650494515`, 1, -4.709826999594913], 
     Hue[1.1395628910898004`, 1, -4.511924584295853], 
     Hue[1.0742328371715586`, 1, -4.332663593142575], 
     Hue[1.1364868537907873`, 1, -4.14686228685836], 
     Hue[1.074231809020701, 1, -3.958427271287639], 
     Hue[1.139956995485149, 1, -3.7622615348864104`], 
     Hue[1.074719333746703, 1, -3.582736408269385], 
     Hue[1.1401501092383852`, 1, -3.3874396789788346`], 
     Hue[1.0749591877525448`, 1, -3.207792598633204], 
     Hue[1.1402366814554834`, 1, -3.012932091511085], 
     Hue[1.0791100081935796`, 1, -2.821190575872836], 
     Hue[1.138181328399066, 1, -2.644812986045584], 
     Hue[1.0790837454073363`, 1, -2.4470926712734693`], 
     Hue[1.1384815546903604`, 1, -2.269645204277409], 
     Hue[1.0790260568513992`, 1, -2.0731678881627476`], 
     Hue[1.1416954473074772`, 1, -1.885716758300309], 
     Hue[1.0788994863107975`, 1, -1.699623333779311], 
     Hue[1.1413890458558986`, 1, -1.5122160408108594`], 
     Hue[1.0786224953694885`, 1, -1.3269127782075356`], 
     Hue[1.1407187104527643`, 1, -1.1396064962071712`], 
     Hue[1.0799398442847679`, 1, -0.950213428022048], 
     Hue[1.1400325096926123`, 1, -0.7665815040032786], 
     Hue[1.0800036895616694`, 1, -0.5790039352793597], 
     Hue[1.1396708277743188`, 1, -0.3912962131479374], 
     Hue[1.0828839041274727`, 1, -0.20226026035214661`], 
     Hue[1.1379867994488495`, 1, -0.01659686876459676], 
     Hue[1.0866568776494887`, 1, 0.1732987688499038], 
     Hue[1.133031752919737, 1, 0.35886387486492355`], 
     Hue[1.0886611604951024`, 1, 0.5461990411407747], 
     Hue[1.057655804945144, 1, 0.7338456798579986], 
     Hue[1.0385890068094765`, 1, 0.9218612460890668], 
     Hue[1.2515497808452496`, 1, -17.27618334189528], 
     Hue[1.1888523802877837`, 1, -17.089062133554293`], 
     Hue[1.2486414541592343`, 1, -16.91062086407678], 
     Hue[1.1888523802877837`, 1, -16.714819716872324`], 
     Hue[1.2486414541592343`, 1, -16.53637844739481], 
     Hue[1.1888523802877837`, 1, -16.34057730019035], 
     Hue[1.2491159706185315`, 1, -16.16071983016143], 
     Hue[1.1888523802877837`, 1, -15.966334883508381`], 
     Hue[1.2494718579630044`, 1, -15.7854152630659], 
     Hue[1.1888523802877837`, 1, -15.592092466826411`], 
     Hue[1.2533866187522065`, 1, -15.399489191834807`], 
     Hue[1.1888523802877835`, 1, -15.217850050144438`], 
     Hue[1.2533866187522062`, 1, -15.025246775152837`], 
     Hue[1.1888523802877833`, 1, -14.843607633462467`], 
     Hue[1.2533866187522058`, 1, -14.651004358470864`], 
     Hue[1.1888523802877828`, 1, -14.469365216780497`], 
     Hue[1.253386618752205, 1, -14.276761941788894`], 
     Hue[1.1888523802877817`, 1, -14.095122800098528`], 
     Hue[1.2533866187522031`, 1, -13.902519525106923`], 
     Hue[1.1908116740551997`, 1, -13.715032845655903`], 
     Hue[1.2543050377056775`, 1, -13.525536075099648`], 
     Hue[1.190811674055194, 1, -13.340790428973937`], 
     Hue[1.2543050377056684`, 1, -13.151293658417675`], 
     Hue[1.1908116740551817`, 1, -12.966548012291984`], 
     Hue[1.2543050377056486`, 1, -12.777051241735702`], 
     Hue[1.1908116740551544`, 1, -12.592305595610043`], 
     Hue[1.2543050377056053`, 1, -12.402808825053727`], 
     Hue[1.1908116740550947`, 1, -12.218063178928142`], 
     Hue[1.2543050377055096`, 1, -12.028566408371749`], 
     Hue[1.1917913209386717`, 1, -11.840896993365993`], 
     Hue[1.2547642471820377`, 1, -11.6529534750271], 
     Hue[1.1917913209383801`, 1, -11.466654576684356`], 
     Hue[1.2547642471815743`, 1, -11.27871105834509], 
     Hue[1.1917913209377393`, 1, -11.092412160003116`], 
     Hue[1.2547642471805553`, 1, -10.904468641663026`], 
     Hue[1.1922811443781742`, 1, -10.716707858882577`], 
     Hue[1.2568383433148687`, 1, -10.524036058054373`], 
     Hue[1.192648511956436, 1, -10.341369028873983`], 
     Hue[1.257004806745189, 1, -10.14929682908152], 
     Hue[1.1966895553444352`, 1, -9.955066065567756], 
     Hue[1.2570602945459763`, 1, -9.774888808301343], 
     Hue[1.1966895553288133`, 1, -9.580823648902015], 
     Hue[1.2570602945218288`, 1, -9.400646391616172], 
     Hue[1.1966895552944654`, 1, -9.206581232255726], 
     Hue[1.257060294468735, 1, -9.026403974927169], 
     Hue[1.1966895552189436`, 1, -8.832338815652209], 
     Hue[1.2588359043264399`, 1, -8.64686222712661], 
     Hue[1.1966895550528918`, 1, -8.45809639914274], 
     Hue[1.2588359040670283`, 1, -8.272619810401611], 
     Hue[1.196689554687789, 1, -8.08385398284005], 
     Hue[1.258835903496653, 1, -7.898377393625039], 
     Hue[1.196689553885027, 1, -7.7096115669920176`], 
     Hue[1.258835902242553, 1, -7.524134976735058], 
     Hue[1.196689552119973, 1, -7.33536915214365], 
     Hue[1.258835899485129, 1, -7.149892559595732], 
     Hue[1.1966895482391, 1, -6.961126739493271], 
     Hue[1.2597236983521016`, 1, -6.7730004761639], 
     Hue[1.196689539706118, 1, -6.586884331675671], 
     Hue[1.2597236849513989`, 1, -6.398758057035386], 
     Hue[1.1986488141389304`, 1, -6.206794395883458], 
     Hue[1.260596153214662, 1, -6.02191165237192], 
     Hue[1.198648772200309, 1, -5.832552021048617], 
     Hue[1.260596088096964, 1, -5.647669222731841], 
     Hue[1.1986486799887355`, 1, -5.458309696377181], 
     Hue[1.2610321932520714`, 1, -5.272124784431771], 
     Hue[1.198648477240741, 1, -5.0840674820017995`], 
     Hue[1.2612500014048398`, 1, -4.897231304402683], 
     Hue[1.198648031453763, 1, -4.709825510139293], 
     Hue[1.2649573955664994`, 1, -4.511921721872699], 
     Hue[1.199626683387585, 1, -4.332660280436886], 
     Hue[1.2618809753035545`, 1, -4.146856151671428], 
     Hue[1.199624510566797, 1, -3.9584199876766535`], 
     Hue[1.2653503704511544`, 1, -3.7622476516853514`], 
     Hue[1.200109520806829, 1, -3.5827203023867025`], 
     Hue[1.2655417831310085`, 1, -3.3874091045093984`], 
     Hue[1.2003438463328562`, 1, -3.2077570880000543`], 
     Hue[1.2656246145511074`, 1, -3.012864815529139], 
     Hue[1.2005577853700726`, 1, -2.8328288141450386`], 
     Hue[1.2656843405123412`, 1, -2.6383238472119155`], 
     Hue[1.2044297676394944`, 1, -2.4469126852272556`], 
     Hue[1.2637906917730124`, 1, -2.2694788655792424`], 
     Hue[1.2043135815101031`, 1, -2.0727724975829425`], 
     Hue[1.267018672839639, 1, -1.8849924141345962`], 
     Hue[1.204058296031027, 1, -1.6987556665051613`], 
     Hue[1.2666254023206205`, 1, -1.5106254757502102`], 
     Hue[1.2034978485754377`, 1, -1.3250131612127125`], 
     Hue[1.2657599972469693`, 1, -1.1361193680881836`], 
     Hue[1.2022697576288655`, 1, -0.9518886616269941], 
     Hue[1.263853985994595, 1, -0.7613461813359961], 
     Hue[1.1995883386136403`, 1, -0.5801990392750256], 
     Hue[1.2596491643675134`, 1, -0.3861779864165107], 
     Hue[1.1964753021194796`, 1, -0.2028166820799815], 
     Hue[1.2499978587797214`, 1, -0.012426300892240505`], 
     Hue[1.1874845199906463`, 1, 0.17093238694147972`], 
     Hue[1.2298257311832719`, 1, 0.35841654167728576`], 
     Hue[1.1684884959919868`, 1, 0.5463630915349806], 
     Hue[1.191452974767816, 1, 0.7348330854211631], 
     Hue[1.1163212015579316`, 1, 0.7338497163694127], 
     Hue[1.1233376641343413`, 1, 0.9217311512100659], 
     Hue[1.0725299397073171`, 1, 0.9218217278444552], 
     Hue[1.376944581960181, 1, -17.27618334189528], 
     Hue[1.3142471814027155`, 1, -17.089062133554293`], 
     Hue[1.374036255274166, 1, -16.91062086407678], 
     Hue[1.3142471814027155`, 1, -16.714819716872324`], 
     Hue[1.374036255274166, 1, -16.53637844739481], 
     Hue[1.3142471814027155`, 1, -16.34057730019035], 
     Hue[1.3745107717334633`, 1, -16.16071983016143], 
     Hue[1.3142471814027155`, 1, -15.966334883508381`], 
     Hue[1.3748666590779361`, 1, -15.7854152630659], 
     Hue[1.3142471814027155`, 1, -15.592092466826411`], 
     Hue[1.378781419867138, 1, -15.399489191834807`], 
     Hue[1.3142471814027152`, 1, -15.217850050144438`], 
     Hue[1.378781419867138, 1, -15.025246775152837`], 
     Hue[1.314247181402715, 1, -14.843607633462467`], 
     Hue[1.3787814198671378`, 1, -14.651004358470864`], 
     Hue[1.3142471814027146`, 1, -14.469365216780497`], 
     Hue[1.378781419867137, 1, -14.276761941788891`], 
     Hue[1.3142471814027135`, 1, -14.095122800098522`], 
     Hue[1.3787814198671358`, 1, -13.902519525106916`], 
     Hue[1.3162064751701317`, 1, -13.715032845655891`], 
     Hue[1.3796998388206116`, 1, -13.52553607509963], 
     Hue[1.3162064751701261`, 1, -13.340790428973913`], 
     Hue[1.3796998388206054`, 1, -13.151293658417641`], 
     Hue[1.316206475170114, 1, -12.966548012291927`], 
     Hue[1.3796998388205919`, 1, -12.777051241735627`], 
     Hue[1.3162064751700873`, 1, -12.59230559560992], 
     Hue[1.379699838820562, 1, -12.40280882505356], 
     Hue[1.3162064751700286`, 1, -12.218063178927872`], 
     Hue[1.3796998388204964`, 1, -12.02856640837138], 
     Hue[1.317186122053609, 1, -11.840896993365396`], 
     Hue[1.3801590482970916`, 1, -11.652953475026292`], 
     Hue[1.3171861220533243`, 1, -11.466654576683045`], 
     Hue[1.3801590482967745`, 1, -11.278711058343314`], 
     Hue[1.3171861220526984`, 1, -11.092412160000233`], 
     Hue[1.3801590482960773`, 1, -10.904468641659122`], 
     Hue[1.3176759454931726`, 1, -10.71670785887622], 
     Hue[1.3822331444311533`, 1, -10.524036058045725`], 
     Hue[1.3180433130715254`, 1, -10.341369028859972`], 
     Hue[1.3823996078631053`, 1, -10.149296829062497`], 
     Hue[1.3220843564599911`, 1, -9.955066065536197], 
     Hue[1.3824550956674775`, 1, -9.774888808259512], 
     Hue[1.322084356445118, 1, -9.580823648832625], 
     Hue[1.382455095651205, 1, -9.400646391524198], 
     Hue[1.3220843564124156`, 1, -9.206581232103156], 
     Hue[1.3824550956154258`, 1, -9.026403974724941], 
     Hue[1.3220843563405122`, 1, -8.83233881531675], 
     Hue[1.384230705513661, 1, -8.646862226679358], 
     Hue[1.3220843561824165`, 1, -8.458096398405154], 
     Hue[1.384230705340904, 1, -8.272619809418226], 
     Hue[1.3220843558348068`, 1, -8.083853981218297], 
     Hue[1.3842307049610592`, 1, -7.898377391462845], 
     Hue[1.322084355070508, 1, -7.709611563426225], 
     Hue[1.384230704125884, 1, -7.524134971980984], 
     Hue[1.3220843533900228`, 1, -7.335369144303441], 
     Hue[1.3842307022895608`, 1, -7.149892549142815], 
     Hue[1.322084349695094, 1, -6.961126722254789], 
     Hue[1.3851185032457023`, 1, -6.773000453114769], 
     Hue[1.3220843415709522`, 1, -6.586884293772948], 
     Hue[1.3851184943745933`, 1, -6.398758006356628], 
     Hue[1.3240436172709904`, 1, -6.20679431158114], 
     Hue[1.3859909729031383`, 1, -6.021911540632794], 
     Hue[1.3240435777503405`, 1, -5.8325518356907855`], 
     Hue[1.385990930050038, 1, -5.64766897704787], 
     Hue[1.3240434908551668`, 1, -5.4583092888257925`], 
     Hue[1.3864270849024531`, 1, -5.272124243495159], 
     Hue[1.3240432997961935`, 1, -5.084066585907207], 
     Hue[1.3866450024018004`, 1, -4.897230114213824], 
     Hue[1.3240428797087702`, 1, -4.7098235398707295`], 
     Hue[1.3903526673115134`, 1, -4.5119190752791445`], 
     Hue[1.3250215977695672`, 1, -4.332655923599914], 
     Hue[1.387276754257362, 1, -4.146850386379541], 
     Hue[1.3250195606829092`, 1, -3.958410408159846], 
     Hue[1.3907474631387227`, 1, -3.762234841662808], 
     Hue[1.325504892673941, 1, -3.582699179759439], 
     Hue[1.3909416406415673`, 1, -3.3873809211939108`], 
     Hue[1.325739927295452, 1, -3.207710578908821], 
     Hue[1.3910305519741288`, 1, -3.0128028244218665`], 
     Hue[1.325932493351091, 1, -2.8327949628399995`], 
     Hue[1.391094335459097, 1, -2.6382153350630846`], 
     Hue[1.3298329052492182`, 1, -2.4466824328997667`], 
     Hue[1.3891342989393425`, 1, -2.269489276350366], 
     Hue[1.3297265951018558`, 1, -2.072266159192738], 
     Hue[1.389224746428526, 1, -1.8942350669190031`], 
     Hue[1.32949257442379, 1, -1.697642001128542], 
     Hue[1.3922872460423024`, 1, -1.5091639468479279`], 
     Hue[1.3289767043240368`, 1, -1.3225627858912616`], 
     Hue[1.3883243954066968`, 1, -1.143209497778605], 
     Hue[1.3278360591088259`, 1, -0.9464929931116017], 
     Hue[1.3863717308468422`, 1, -0.7668903517326411], 
     Hue[1.3233665523607367`, 1, -0.5744015468542456], 
     Hue[1.3818712677050287`, 1, -0.3887055670900579], 
     Hue[1.3148486498093113`, 1, -0.2017115765975226], 
     Hue[1.3687484955638853`, 1, -0.016932425640616255`], 
     Hue[1.4238751462695014`, 1, 0.17238940818296866`], 
     Hue[1.297919186096621, 1, 0.17160357182511943`], 
     Hue[1.3434094218424775`, 1, 0.35869896461251793`], 
     Hue[1.3872581437122473`, 1, 0.5461288120469454], 
     Hue[1.2648487515628943`, 1, 0.546186659703562], 
     Hue[1.2928631721787047`, 1, 0.7340553913448035], 
     Hue[1.3145490627651928`, 1, 0.9216824659149181], 
     Hue[1.3308374975778647`, 1, 1.1094380948972131`], 
     Hue[1.2005572044783308`, 1, 0.9216231529185821], 
     Hue[1.1933670463873098`, 1, 1.1094803762554548`], 
     Hue[1.1608219058812677`, 1, 1.297015825799235], 
     Hue[1.1003907273846494`, 1, 1.1096430096851715`], 
     Hue[1.0357483818721829`, 1, 1.109560392406301], 
     Hue[0.5023393830751127, 1, -17.27618334189528], 
     Hue[1.439641982517647, 1, -17.089062133554293`], 
     Hue[1.4994310563890978`, 1, -16.91062086407678], 
     Hue[1.439641982517647, 1, -16.714819716872324`], 
     Hue[1.4994310563890978`, 1, -16.53637844739481], 
     Hue[1.439641982517647, 1, -16.34057730019035], 
     Hue[1.499905572848395, 1, -16.16071983016143], 
     Hue[1.439641982517647, 1, -15.966334883508381`], 
     Hue[0.5002614601928677, 1, -15.7854152630659], 
     Hue[1.439641982517647, 1, -15.592092466826411`], 
     Hue[0.5041762209820699, 1, -15.399489191834807`], 
     Hue[1.439641982517647, 1, -15.217850050144438`], 
     Hue[0.5041762209820699, 1, -15.025246775152837`], 
     Hue[1.4396419825176467`, 1, -14.843607633462467`], 
     Hue[0.5041762209820699, 1, -14.65100435847086], 
     Hue[1.4396419825176467`, 1, -14.469365216780494`], 
     Hue[0.5041762209820699, 1, -14.276761941788891`], 
     Hue[1.4396419825176463`, 1, -14.095122800098519`], 
     Hue[0.5041762209820699, 1, -13.902519525106912`], 
     Hue[1.441601276285066, 1, -13.715032845655884`], 
     Hue[0.5050946399355486, 1, -13.525536075099625`], 
     Hue[1.4416012762850638`, 1, -13.340790428973897`], 
     Hue[0.5050946399355489, 1, -13.151293658417627`], 
     Hue[1.4416012762850592`, 1, -12.96654801229189], 
     Hue[0.5050946399355495, 1, -12.777051241735599`], 
     Hue[1.4416012762850487`, 1, -12.592305595609837`], 
     Hue[0.5050946399355509, 1, -12.402808825053496`], 
     Hue[1.4416012762850257`, 1, -12.218063178927686`], 
     Hue[0.5050946399355539, 1, -12.02856640837124], 
     Hue[1.4425809231686864`, 1, -11.840896993364987`], 
     Hue[0.5055538494123012, 1, -11.652953475025981`], 
     Hue[1.4425809231685762`, 1, -11.466654576682146`], 
     Hue[0.5055538494123173, 1, -11.278711058342628`], 
     Hue[1.442580923168334, 1, -11.092412159998258`], 
     Hue[0.5055538494123529, 1, -10.904468641657616`], 
     Hue[1.4430707466096615`, 1, -10.716707858871876`], 
     Hue[0.5076279455490929, 1, -10.524036058042489`], 
     Hue[1.443438114189896, 1, -10.341369028850425`], 
     Hue[0.5077944089846599, 1, -10.149296829055395`], 
     Hue[1.447479157582859, 1, -9.95506606551526], 
     Hue[0.507849896796978, 1, -9.774888808243904], 
     Hue[1.447479157577499, 1, -9.580823648786584], 
     Hue[0.5078498967981697, 1, -9.400646391489882], 
     Hue[1.4474791575657138`, 1, -9.206581232001927], 
     Hue[0.50784989680079, 1, -9.026403974649488], 
     Hue[1.4474791575398016`, 1, -8.832338815094172], 
     Hue[0.5096255067858092, 1, -8.646862226516824], 
     Hue[1.4474791574828274`, 1, -8.458096397915769], 
     Hue[0.5096255068015128, 1, -8.272619809060858], 
     Hue[1.447479157357557, 1, -8.083853980142276], 
     Hue[0.5096255068360406, 1, -7.898377390677088], 
     Hue[1.4474791570821213`, 1, -7.709611561060345], 
     Hue[0.5096255069119577, 1, -7.524134970253317], 
     Hue[1.4474791564765133`, 1, -7.335369139101512], 
     Hue[0.5096255070788791, 1, -7.149892545344149], 
     Hue[1.4474791551449464`, 1, -6.961126710817166], 
     Hue[0.5105133125003732, 1, -6.773000444851198], 
     Hue[1.4474791522171935`, 1, -6.586884268624732], 
     Hue[0.5105133133865947, 1, -6.398757988187283], 
     Hue[1.44943843983155, 1, -6.206794256385882], 
     Hue[0.5113858136583599, 1, -6.021911501111706], 
     Hue[1.4494384260183655`, 1, -5.832551714331409], 
     Hue[0.5113858183231919, 1, -5.647668890151707], 
     Hue[1.4494383956469117`, 1, -5.45830902198937], 
     Hue[0.511822078355937, 1, -5.272124053482193], 
     Hue[1.449438328868238, 1, -5.08406599920553], 
     Hue[0.5120402271891578, 1, -4.897229697585227], 
     Hue[1.449438182039534, 1, -4.709822249868303], 
     Hue[0.5157484289891197, 1, -4.511918204176596], 
     Hue[1.4504175135921011`, 1, -4.332653090121473], 
     Hue[0.5126736144426405, 1, -4.1468483885839], 
     Hue[1.450416812742868, 1, -3.9584041779871137`], 
     Hue[0.5161469232680505, 1, -3.7622306543812867`], 
     Hue[1.4509051135387243`, 1, -3.5826854881874057`], 
     Hue[0.5163467027246363, 1, -3.387371740489236], 
     Hue[1.4511466790173446`, 1, -3.2076804803939325`], 
     Hue[0.5164479344110697, 1, -3.0127826643049618`], 
     Hue[1.4513230171154352`, 1, -2.8328201867409115`], 
     Hue[0.5165263885867479, 1, -2.638208179384068], 
     Hue[1.455288308708068, 1, -2.4465376429653336`], 
     Hue[0.5146367107150347, 1, -2.2693891139678124`], 
     Hue[1.4552546704999978`, 1, -2.071947455808731], 
     Hue[0.5148082210878269, 1, -1.8941598420782102`], 
     Hue[1.4551805357013512`, 1, -1.6969395649748644`], 
     Hue[0.5148443449367187, 1, -1.5187634495376312`], 
     Hue[1.4550166896674628`, 1, -1.321010094257036], 
     Hue[0.514558871730333, 1, -1.1430628664729288`], 
     Hue[1.4505714561256111`, 1, -0.9553234179831269], 
     Hue[0.513236543736672, 1, -0.7676337196898042], 
     Hue[1.4478266811389295`, 1, -0.5787738270410367], 
     Hue[0.5110217227264178, 1, -0.38848133173544785`], 
     Hue[1.4406515610352297`, 1, -0.20275247586557277`], 
     Hue[0.5021225568309002, 1, -0.014264517762822226`], 
     Hue[0.5678603629387649, 1, 0.1718954086982062], 
     Hue[1.4808385668583757`, 1, 0.3589876510416681], 
     Hue[0.5463288357124056, 1, 0.5465657611204567], 
     Hue[1.4323728645500526`, 1, 0.734197343430073], 
     Hue[1.4836953627268832`, 1, 0.9216494466004802], 
     Hue[0.5545005612695156, 1, 1.1097153922265461`], 
     Hue[1.3426151763325103`, 1, 1.2972205352010453`], 
     Hue[0.9894291924252037, 1, 1.2971101102848082`], 
     Hue[1.0059952212200665`, 1, 1.109300750513719], 
     Hue[0.6277341841900445, 1, -17.27618334189528], 
     Hue[0.5650367836325787, 1, -17.089062133554293`], 
     Hue[0.6248258575040292, 1, -16.91062086407678], 
     Hue[0.5650367836325787, 1, -16.714819716872324`], 
     Hue[0.6248258575040292, 1, -16.53637844739481], 
     Hue[0.5650367836325787, 1, -16.34057730019035], 
     Hue[0.6253003739633265, 1, -16.16071983016143], 
     Hue[0.5650367836325787, 1, -15.966334883508381`], 
     Hue[0.6256562613077994, 1, -15.7854152630659], 
     Hue[0.5650367836325787, 1, -15.592092466826411`], 
     Hue[0.6295710220970017, 1, -15.399489191834807`], 
     Hue[0.5650367836325787, 1, -15.217850050144438`], 
     Hue[0.6295710220970017, 1, -15.025246775152837`], 
     Hue[0.5650367836325789, 1, -14.843607633462467`], 
     Hue[0.6295710220970019, 1, -14.651004358470864`], 
     Hue[0.5650367836325791, 1, -14.469365216780494`], 
     Hue[0.6295710220970026, 1, -14.276761941788891`], 
     Hue[0.5650367836325796, 1, -14.095122800098519`], 
     Hue[0.6295710220970039, 1, -13.902519525106916`], 
     Hue[0.5669960774000016, 1, -13.715032845655884`], 
     Hue[0.6304894410504855, 1, -13.525536075099632`], 
     Hue[0.566996077400004, 1, -13.340790428973897`], 
     Hue[0.6304894410504921, 1, -13.151293658417643`], 
     Hue[0.5669960774000093, 1, -12.966548012291891`], 
     Hue[0.6304894410505066, 1, -12.777051241735633`], 
     Hue[0.5669960774000213, 1, -12.59230559560984], 
     Hue[0.6304894410505384, 1, -12.402808825053572`], 
     Hue[0.5669960774000475, 1, -12.218063178927693`], 
     Hue[0.6304894410506082, 1, -12.028566408371406`], 
     Hue[0.5679757242838177, 1, -11.840896993365007`], 
     Hue[0.6309486505275027, 1, -11.65295347502635], 
     Hue[0.567975724283947, 1, -11.466654576682188`], 
     Hue[0.6309486505278425, 1, -11.278711058343438`], 
     Hue[0.5679757242842314, 1, -11.092412159998354`], 
     Hue[0.63094865052859, 1, -10.904468641659399`], 
     Hue[0.5684655477267229, 1, -10.716707858872105`], 
     Hue[0.6330227466669147, 1, -10.524036058046569`], 
     Hue[0.5688329153095208, 1, -10.341369028850965`], 
     Hue[0.6331892101059502, 1, -10.149296829064395`], 
     Hue[0.5728739587083616, 1, -9.95506606551728], 
     Hue[0.6332446979258928, 1, -9.774888808263718], 
     Hue[0.5728739587156735, 1, -9.580823648791027], 
     Hue[0.6332446979438466, 1, -9.400646391533446], 
     Hue[0.5728739587317504, 1, -9.206581232011692], 
     Hue[0.633244697983322, 1, -9.026403974745275], 
     Hue[0.5728739587670992, 1, -8.832338815115644], 
     Hue[0.6350203080502377, 1, -8.646862226734788], 
     Hue[0.5728739588448217, 1, -8.458096397962981], 
     Hue[0.6350203082451474, 1, -8.2726198095401], 
     Hue[0.5728739590157121, 1, -8.083853980246081], 
     Hue[0.6350203086737007, 1, -7.898377391730812], 
     Hue[0.5728739593914538, 1, -7.709611561288585], 
     Hue[0.6350203096159726, 1, -7.524134972570173], 
     Hue[0.572873960217607, 1, -7.335369139603356], 
     Hue[0.6350203116877717, 1, -7.149892550438282], 
     Hue[0.572873962034093, 1, -6.961126711920584], 
     Hue[0.6359081213193746, 1, -6.7730004562429], 
     Hue[0.5728739660280509, 1, -6.586884271050846], 
     Hue[0.6359081314406767, 1, -6.398758013234534], 
     Hue[0.5748332691827227, 1, -6.206794262824215], 
     Hue[0.6367806521203325, 1, -6.021911557098425], 
     Hue[0.5748332892171121, 1, -5.832551728487557], 
     Hue[0.6367807015541094, 1, -5.6476690132513285`], 
     Hue[0.5748333332673091, 1, -5.458309053114915], 
     Hue[0.6372170602672733, 1, -5.272124326368087], 
     Hue[0.5748334301218565, 1, -5.084066067642289], 
     Hue[0.6374354260955015, 1, -4.897230300039455], 
     Hue[0.5748336430794263, 1, -4.7098224003429054`], 
     Hue[0.6411441145318031, 1, -4.511919621922792], 
     Hue[0.5758137739555642, 1, -4.332653449835103], 
     Hue[0.6380703424107972, 1, -4.146851335671604], 
     Hue[0.5758148223897661, 1, -3.9584049689202674`], 
     Hue[0.641546005075174, 1, -3.7622375578200877`], 
     Hue[0.5763069894591567, 1, -3.5826872976923454`], 
     Hue[0.6417509215741614, 1, -3.3873869745973826`], 
     Hue[0.576557058577617, 1, -3.207684537200973], 
     Hue[0.6418634497288427, 1, -3.0128162252886286`], 
     Hue[0.5767521118756869, 1, -2.832829237541354], 
     Hue[0.641966750369096, 1, -2.638282096964108], 
     Hue[0.580760250956977, 1, -2.446563828386183], 
     Hue[0.6401311646089002, 1, -2.269546309536892], 
     Hue[0.5808192010203159, 1, -2.07200511096101], 
     Hue[0.6437900372081233, 1, -1.8844882934386658`], 
     Hue[0.5809490926726459, 1, -1.6970667235719004`], 
     Hue[0.6441014419605584, 1, -1.5095150547655296`], 
     Hue[0.5812360323042337, 1, -1.3212915829580345`], 
     Hue[0.6447895122633163, 1, -1.133668242685635], 
     Hue[0.5778134432014339, 1, -0.9556147819752134], 
     Hue[0.6446516286571851, 1, -0.7607167202171279], 
     Hue[0.577166423420306, 1, -0.5797002306473753], 
     Hue[0.6432473807864021, 1, -0.39203145800410555`], 
     Hue[0.5758412326395745, 1, -0.20099983885585737`], 
     Hue[0.6445488224490159, 1, -0.01657387469405469], 
     Hue[0.6451162223545863, 1, 0.3586151776226999], 
     Hue[0.6349680968688802, 1, 0.7338884617143252], 
     Hue[0.8619034747901471, 1, 1.1093831561825227`], 
     Hue[0.9448302650511163, 1, 1.1093136062469235`], 
     Hue[0.9161810169835236, 1, 1.2970312921986613`], 
     Hue[0.9737762616977748, 1, 1.1093840219698756`], 
     Hue[0.9898656633764543, 1, 1.10945679289541], 
     Hue[0.7531289853049761, 1, -17.27618334189528], 
     Hue[0.6904315847475103, 1, -17.089062133554293`], 
     Hue[0.7502206586189608, 1, -16.91062086407678], 
     Hue[0.6904315847475103, 1, -16.714819716872324`], 
     Hue[0.7502206586189608, 1, -16.53637844739481], 
     Hue[0.6904315847475103, 1, -16.34057730019035], 
     Hue[0.7506951750782581, 1, -16.16071983016143], 
     Hue[0.6904315847475103, 1, -15.966334883508381`], 
     Hue[0.751051062422731, 1, -15.7854152630659], 
     Hue[0.6904315847475104, 1, -15.592092466826411`], 
     Hue[0.7549658232119332, 1, -15.399489191834807`], 
     Hue[0.6904315847475104, 1, -15.217850050144438`], 
     Hue[0.7549658232119334, 1, -15.025246775152837`], 
     Hue[0.6904315847475107, 1, -14.843607633462467`], 
     Hue[0.7549658232119338, 1, -14.651004358470864`], 
     Hue[0.6904315847475113, 1, -14.469365216780497`], 
     Hue[0.7549658232119346, 1, -14.276761941788894`], 
     Hue[0.6904315847475124, 1, -14.095122800098524`], 
     Hue[0.7549658232119365, 1, -13.902519525106923`], 
     Hue[0.6923908785149357, 1, -13.715032845655893`], 
     Hue[0.7558842421654192, 1, -13.52553607509965], 
     Hue[0.6923908785149415, 1, -13.340790428973914`], 
     Hue[0.7558842421654282, 1, -13.151293658417677`], 
     Hue[0.6923908785149538, 1, -12.96654801229193], 
     Hue[0.7558842421654479, 1, -12.777051241735709`], 
     Hue[0.6923908785149813, 1, -12.592305595609927`], 
     Hue[0.7558842421654914, 1, -12.402808825053743`], 
     Hue[0.6923908785150412, 1, -12.218063178927888`], 
     Hue[0.7558842421655869, 1, -12.028566408371782`], 
     Hue[0.6933705253988856, 1, -11.840896993365444`], 
     Hue[0.7563434516425374, 1, -11.65295347502718], 
     Hue[0.6933705253991782, 1, -11.46665457668315], 
     Hue[0.7563434516430005, 1, -11.278711058345266`], 
     Hue[0.6933705253998215, 1, -11.092412160000464`], 
     Hue[0.7563434516440192, 1, -10.904468641663417`], 
     Hue[0.6938603488431021, 1, -10.716707858876775`], 
     Hue[0.7584175477829158, 1, -10.524036058055563`], 
     Hue[0.6942277164276347, 1, -10.341369028861275`], 
     Hue[0.7585840112232287, 1, -10.149296829084197`], 
     Hue[0.6982687598302698, 1, -9.955066065541068], 
     Hue[0.7586394990459815, 1, -9.774888808307276], 
     Hue[0.6982687598459447, 1, -9.580823648843333], 
     Hue[0.7586394990701172, 1, -9.400646391629218], 
     Hue[0.6982687598804096, 1, -9.206581232126698], 
     Hue[0.758639499123185, 1, -9.026403974955855], 
     Hue[0.6982687599561885, 1, -8.832338815368512], 
     Hue[0.760415109218848, 1, -8.646862227204803], 
     Hue[0.6982687601228058, 1, -8.458096398518968], 
     Hue[0.7604151094781039, 1, -8.27261981057354], 
     Hue[0.6982687604891517, 1, -8.083853981468545], 
     Hue[0.7604151100481367, 1, -7.898377394003062], 
     Hue[0.6982687612946463, 1, -7.709611563976449], 
     Hue[0.7604151113014833, 1, -7.524134977566228], 
     Hue[0.6982687630657096, 1, -7.335369145513234], 
     Hue[0.7604151140572512, 1, -7.149892561423248], 
     Hue[0.6982687669597951, 1, -6.961126724914796], 
     Hue[0.7613029251627058, 1, -6.773000480576757], 
     Hue[0.6982687755218283, 1, -6.586884299621582], 
     Hue[0.7613029385546145, 1, -6.398758066738055], 
     Hue[0.7002280886849146, 1, -6.206794327102033], 
     Hue[0.762175466280475, 1, -6.021911675599994], 
     Hue[0.7002281307606153, 1, -5.8325518698170065`], 
     Hue[0.7621755313518763, 1, -5.647669273804046], 
     Hue[0.7002282232736399, 1, -5.458309363860087], 
     Hue[0.7626119240930792, 1, -5.272124901340428], 
     Hue[0.700228426684691, 1, -5.084066750887338], 
     Hue[0.7628303647015302, 1, -4.897231566545751], 
     Hue[0.7002288739307487, 1, -4.709823902617886], 
     Hue[0.7665392027412906, 1, -4.511922493014539], 
     Hue[0.7012095189037011, 1, -4.332656790750688], 
     Hue[0.7634658026399606, 1, -4.146857490805184], 
     Hue[0.7012116987294797, 1, -3.958412314808781], 
     Hue[0.7669421858136116, 1, -3.762251483155765], 
     Hue[0.7017063507267036, 1, -3.5827035416600896`], 
     Hue[0.7671487466569953, 1, -3.387417642994393], 
     Hue[0.7019618830297703, 1, -3.207720357300933], 
     Hue[0.7672648878212961, 1, -3.0128837149941514`], 
     Hue[0.7021995703914441, 1, -2.8328168266134366`], 
     Hue[0.7673885601707743, 1, -2.638393495479365], 
     Hue[0.7062032097484562, 1, -2.44674551475035], 
     Hue[0.7656622661271881, 1, -2.2695598361031886`], 
     Hue[0.7063198600520801, 1, -2.0724049384406333`], 
     Hue[0.7692531788259803, 1, -1.8852162451960608`], 
     Hue[0.7065765115175934, 1, -1.6979475224412381`], 
     Hue[0.7696454113431119, 1, -1.51111759924134], 
     Hue[0.7071416319333159, 1, -1.3232363926461093`], 
     Hue[0.7705069744341255, 1, -1.1372012706559695`], 
     Hue[0.7083880647149539, 1, -0.947982945658284], 
     Hue[0.7723970058777907, 1, -0.7637238098448957], 
     Hue[0.7111469056186956, 1, -0.5716135656643884], 
     Hue[0.7765296915232451, 1, -0.39139241574129935`], 
     Hue[0.7129063989875764, 1, -0.20457503851087355`], 
     Hue[0.7892648437017091, 1, -0.013289431825857179`], 
     Hue[0.7236229134167157, 1, 0.1714022153747855], 
     Hue[0.8167198691197219, 1, 0.35859751622732516`], 
     Hue[0.7505110573002954, 1, 0.5473370192276901], 
     Hue[0.8785237864199077, 1, -17.27618334189528], 
     Hue[0.8158263858624419, 1, -17.089062133554293`], 
     Hue[0.8756154597338924, 1, -16.91062086407678], 
     Hue[0.8158263858624419, 1, -16.714819716872324`], 
     Hue[0.8756154597338924, 1, -16.53637844739481], 
     Hue[0.8158263858624419, 1, -16.34057730019035], 
     Hue[0.8760899761931897, 1, -16.16071983016143], 
     Hue[0.8158263858624419, 1, -15.966334883508381`], 
     Hue[0.8764458635376627, 1, -15.7854152630659], 
     Hue[0.815826385862442, 1, -15.592092466826411`], 
     Hue[0.8803606243268649, 1, -15.399489191834807`], 
     Hue[0.8158263858624422, 1, -15.217850050144438`], 
     Hue[0.880360624326865, 1, -15.025246775152837`], 
     Hue[0.8158263858624424, 1, -14.843607633462467`], 
     Hue[0.8803606243268652, 1, -14.651004358470864`], 
     Hue[0.8158263858624428, 1, -14.469365216780497`], 
     Hue[0.8803606243268658, 1, -14.276761941788898`], 
     Hue[0.8158263858624439, 1, -14.09512280009853], 
     Hue[0.8803606243268671, 1, -13.90251952510693], 
     Hue[0.8177856796298674, 1, -13.715032845655905`], 
     Hue[0.8812790432803483, 1, -13.525536075099664`], 
     Hue[0.8177856796298728, 1, -13.34079042897394], 
     Hue[0.8812790432803544, 1, -13.15129365841771], 
     Hue[0.8177856796298849, 1, -12.966548012291987`], 
     Hue[0.8812790432803679, 1, -12.777051241735785`], 
     Hue[0.8177856796299114, 1, -12.592305595610052`], 
     Hue[0.8812790432803974, 1, -12.40280882505391], 
     Hue[0.81778567962997, 1, -12.218063178928158`], 
     Hue[0.8812790432804622, 1, -12.028566408372148`], 
     Hue[0.8187653265138096, 1, -11.84089699336604], 
     Hue[0.8817382527573442, 1, -11.652953475027985`], 
     Hue[0.8187653265140931, 1, -11.46665457668446], 
     Hue[0.8817382527576578, 1, -11.278711058347035`], 
     Hue[0.8187653265147163, 1, -11.092412160003345`], 
     Hue[0.8817382527583475, 1, -10.904468641667302`], 
     Hue[0.8192551499579459, 1, -10.716707858883131`], 
     Hue[0.8838123488964659, 1, -10.52403605806417], 
     Hue[0.8196225175423622, 1, -10.34136902887528], 
     Hue[0.8839788123351128, 1, -10.149296829103129`], 
     Hue[0.8236635609444722, 1, -9.955066065572607], 
     Hue[0.884034300154205, 1, -9.77488880834891], 
     Hue[0.8236635609592728, 1, -9.580823648912679], 
     Hue[0.8840343001702995, 1, -9.40064639172076], 
     Hue[0.8236635609918157, 1, -9.206581232279172], 
     Hue[0.8840343002056869, 1, -9.02640397515713], 
     Hue[0.8236635610633682, 1, -8.83233881570376], 
     Hue[0.8858099102600072, 1, -8.646862227649894], 
     Hue[0.8236635612206928, 1, -8.458096399256087], 
     Hue[0.8858099104308299, 1, -8.272619811552168], 
     Hue[0.8236635615666069, 1, -8.083853983089268], 
     Hue[0.8858099108064226, 1, -7.8983773961548005`], 
     Hue[0.8236635623271775, 1, -7.7096115675399775`], 
     Hue[0.8858099116322482, 1, -7.524134982297315], 
     Hue[0.8236635639994652, 1, -7.335369153348464], 
     Hue[0.8858099134480139, 1, -7.149892571825618], 
     Hue[0.82366356767637, 1, -6.961126742142331], 
     Hue[0.8866977224225249, 1, -6.773000503512851], 
     Hue[0.823663575760881, 1, -6.586884337500231], 
     Hue[0.8866977311932034, 1, -6.3987581171682715`], 
     Hue[0.8256228875025347, 1, -6.2067944113404625`], 
     Hue[0.887570248451274, 1, -6.021911786783536], 
     Hue[0.8256229268243693, 1, -5.832552055034348], 
     Hue[0.8875702908138027, 1, -5.6476695182662695`], 
     Hue[0.8256230132823322, 1, -5.458309771102508], 
     Hue[0.8880066328782621, 1, -5.272125439567874], 
     Hue[0.8256232033796607, 1, -5.084067646302256], 
     Hue[0.8882249619856228, 1, -4.897232750749614], 
     Hue[0.8256236213510578, 1, -4.709825871390396], 
     Hue[0.8919335244421288, 1, -4.51192512550294], 
     Hue[0.8266041922405363, 1, -4.332661144002651], 
     Hue[0.8888596067558453, 1, -4.1468632266841], 
     Hue[0.8266062188531442, 1, -3.9584218864013074`], 
     Hue[0.8923346526860659, 1, -3.762264223790833], 
     Hue[0.8271005101432554, 1, -3.5827246459477093`], 
     Hue[0.8925383969877535, 1, -3.3874456708362555`], 
     Hue[0.8273552461001437, 1, -3.2077668242385666`], 
     Hue[0.8926483425423415, 1, -3.012945352193568], 
     Hue[0.8276198583707993, 1, -2.832833492197719], 
     Hue[0.892770028070788, 1, -2.638494246802381], 
     Hue[0.8315888207025786, 1, -2.4469754466010745`], 
     Hue[0.8910813118573931, 1, -2.269625183826374], 
     Hue[0.8316943379800295, 1, -2.0729104115308123`], 
     Hue[0.8945235069552566, 1, -1.8858733942659478`], 
     Hue[0.8319260645710231, 1, -1.6990585086184515`], 
     Hue[0.894765875613004, 1, -1.5125592319106567`], 
     Hue[0.8324342281876048, 1, -1.3256771232419744`], 
     Hue[0.8952954610328829, 1, -1.140355269883585], 
     Hue[0.8335450621832081, 1, -0.9533392715536093], 
     Hue[0.8980900979175894, 1, -0.7657988789026935], 
     Hue[0.8379366491825675, 1, -0.5777494017395828], 
     Hue[0.9060966224348984, 1, -0.38580223588112106`], 
     Hue[0.8470970707014078, 1, -0.20282320736673198`], 
     Hue[0.9175888833610272, 1, -0.01683977060681241], 
     Hue[0.868691868676009, 1, 0.172766986765146], 
     Hue[0.9483180426059006, 1, 0.3594244966929301], 
     Hue[0.9221156829053749, 1, 0.5470670840716434], 
     Hue[0.9160692985053464, 1, 0.7341398823907008], 
     Hue[0.9798214719103815, 1, 0.9215747962255602], 
     Hue[1.0039185875348393`, 1, -17.27618334189528], 
     Hue[0.9412211869773736, 1, -17.089062133554293`], 
     Hue[1.001010260848824, 1, -16.91062086407678], 
     Hue[0.9412211869773736, 1, -16.714819716872324`], 
     Hue[1.001010260848824, 1, -16.53637844739481], 
     Hue[0.9412211869773736, 1, -16.34057730019035], 
     Hue[1.0014847773081212`, 1, -16.16071983016143], 
     Hue[0.9412211869773736, 1, -15.966334883508381`], 
     Hue[1.0018406646525941`, 1, -15.7854152630659], 
     Hue[0.9412211869773736, 1, -15.592092466826411`], 
     Hue[1.0057554254417964`, 1, -15.399489191834807`], 
     Hue[0.9412211869773737, 1, -15.217850050144438`], 
     Hue[1.0057554254417964`, 1, -15.025246775152837`], 
     Hue[0.9412211869773737, 1, -14.843607633462467`], 
     Hue[1.0057554254417964`, 1, -14.651004358470868`], 
     Hue[0.9412211869773739, 1, -14.469365216780501`], 
     Hue[1.0057554254417964`, 1, -14.276761941788898`], 
     Hue[0.9412211869773743, 1, -14.095122800098533`], 
     Hue[1.0057554254417962`, 1, -13.902519525106934`], 
     Hue[0.9431804807447961, 1, -13.715032845655912`], 
     Hue[1.0066738443952745`, 1, -13.52553607509967], 
     Hue[0.9431804807447982, 1, -13.340790428973957`], 
     Hue[1.006673844395274, 1, -13.151293658417725`], 
     Hue[0.9431804807448029, 1, -12.966548012292025`], 
     Hue[1.0066738443952734`, 1, -12.777051241735814`], 
     Hue[0.9431804807448131, 1, -12.592305595610135`], 
     Hue[1.0066738443952716`, 1, -12.402808825053972`], 
     Hue[0.9431804807448355, 1, -12.218063178928343`], 
     Hue[1.0066738443952674`, 1, -12.028566408372287`], 
     Hue[0.9441601276285942, 1, -11.840896993366444`], 
     Hue[1.0071330538719967`, 1, -11.652953475028287`], 
     Hue[0.9441601276287015, 1, -11.466654576685348`], 
     Hue[1.007133053871976, 1, -11.2787110583477], 
     Hue[0.9441601276289374, 1, -11.092412160005301`], 
     Hue[1.0071330538719303`, 1, -10.90446864166877], 
     Hue[0.9446499510713061, 1, -10.716707858887426`], 
     Hue[1.009207150008379, 1, -10.524036058067317`], 
     Hue[0.9450173186538233, 1, -10.341369028884726`], 
     Hue[1.0093736134433982`, 1, -10.149296829110035`], 
     Hue[0.9490583620513984, 1, -9.95506606559331], 
     Hue[1.0094291012545165`, 1, -9.774888808364086], 
     Hue[0.9490583620566029, 1, -9.580823648958201], 
     Hue[1.0094291012530854`, 1, -9.400646391754126], 
     Hue[0.9490583620680461, 1, -9.20658123237926], 
     Hue[1.0094291012499386`, 1, -9.026403975230494], 
     Hue[0.9490583620932064, 1, -8.832338815923828], 
     Hue[1.0112047112171894`, 1, -8.646862227807764], 
     Hue[0.9490583621485272, 1, -8.458096399739953], 
     Hue[1.0112047111989133`, 1, -8.272619811899283], 
     Hue[0.9490583622701627, 1, -8.08385398415316], 
     Hue[1.0112047111587295`, 1, -7.898377396918012], 
     Hue[0.9490583625376059, 1, -7.709611569879189], 
     Hue[1.011204711070376, 1, -7.524134983975407], 
     Hue[0.9490583631256406, 1, -7.33536915849175], 
     Hue[1.0112047108761109`, 1, -7.149892575515289], 
     Hue[0.9490583644185688, 1, -6.961126753451016], 
     Hue[1.0120925153706457`, 1, -6.7730005115349705`], 
     Hue[0.9490583672613652, 1, -6.58688436236495], 
     Hue[1.012092514351545, 1, -6.398758134806724], 
     Hue[0.9510176669893947, 1, -6.206794465897895], 
     Hue[1.012965009796497, 1, -6.021911825128758], 
     Hue[0.9510176803850684, 1, -5.832552174991227], 
     Hue[1.012965004486012, 1, -5.647669602576901], 
     Hue[0.9510177098384792, 1, -5.458310034854764], 
     Hue[1.0134012410328985`, 1, -5.272125623874654], 
     Hue[0.9510177745983822, 1, -5.084068226220491], 
     Hue[1.0136193380663119`, 1, -4.897233154806199], 
     Hue[0.951017916987177, 1, -4.709827146467238], 
     Hue[1.0173273621583994`, 1, -4.511925968092591], 
     Hue[0.9519978692882292, 1, -4.332663944236362], 
     Hue[1.0142523423178742`, 1, -4.146865163284045], 
     Hue[0.9519985484581893, 1, -3.9584280432267], 
     Hue[1.0177247813962158`, 1, -3.762268272321747], 
     Hue[0.9524898463934183, 1, -3.5827381741126256`], 
     Hue[1.0179229085799373`, 1, -3.38745454444682], 
     Hue[0.9527379978073123, 1, -3.2077965565336743`], 
     Hue[1.0180205035067396`, 1, -3.0129648291713753`], 
     Hue[0.9569078325430109, 1, -2.8212021806354377`], 
     Hue[1.0159891129009861`, 1, -2.6448823555411396`], 
     Hue[0.956922562394279, 1, -2.4471181707170278`], 
     Hue[1.01638752819303, 1, -2.2696638094747197`], 
     Hue[0.9569549148048803, 1, -2.0732238759627704`], 
     Hue[1.0196747277421472`, 1, -1.8860742399332817`], 
     Hue[0.9570258824992364, 1, -1.699746057261178], 
     Hue[1.0196261999527956`, 1, -1.5129988930266582`], 
     Hue[0.9571811210741406, 1, -1.3271807968698492`], 
     Hue[1.0195203336488043`, 1, -1.1413126586629525`], 
     Hue[0.9594574910968889, 1, -0.9508646957234113], 
     Hue[1.0216511904509695`, 1, -0.7655606889207378], 
     Hue[0.9618317760830087, 1, -0.5798021370284283], 
     Hue[1.0262605663622504`, 1, -0.38787238245448985`], 
     Hue[0.9699643211142144, 1, -0.20370389288749147`], 
     Hue[1.033497586551125, 1, -0.013114779373968322`], 
     Hue[0.9859586329883037, 1, 0.17100671110735255`], 
     Hue[1.0455103166165527`, 1, 0.35883514780797265`], 
     Hue[1.0160091396020463`, 1, 0.5479790120143174], 
     Hue[1.0042718425344765`, 1, 0.7338662733935861], 
     Hue[1.0130933726165687`, 1, 0.9216566763730215], 
     Hue[1.129313388649771, 1, -17.27618334189528], 
     Hue[1.0666159880923052`, 1, -17.089062133554293`], 
     Hue[1.1264050619637558`, 1, -16.91062086407678], 
     Hue[1.0666159880923052`, 1, -16.714819716872324`], 
     Hue[1.1264050619637558`, 1, -16.53637844739481], 
     Hue[1.0666159880923052`, 1, -16.34057730019035], 
     Hue[1.126879578423053, 1, -16.16071983016143], 
     Hue[1.0666159880923052`, 1, -15.966334883508381`], 
     Hue[1.1272354657675259`, 1, -15.7854152630659], 
     Hue[1.0666159880923052`, 1, -15.592092466826411`], 
     Hue[1.131150226556728, 1, -15.399489191834807`], 
     Hue[1.066615988092305, 1, -15.217850050144438`], 
     Hue[1.1311502265567277`, 1, -15.025246775152837`], 
     Hue[1.066615988092305, 1, -14.843607633462467`], 
     Hue[1.1311502265567275`, 1, -14.651004358470864`], 
     Hue[1.0666159880923047`, 1, -14.469365216780501`], 
     Hue[1.1311502265567268`, 1, -14.276761941788898`], 
     Hue[1.0666159880923043`, 1, -14.095122800098533`], 
     Hue[1.1311502265567255`, 1, -13.90251952510693], 
     Hue[1.0685752818597238`, 1, -13.715032845655912`], 
     Hue[1.132068645510201, 1, -13.525536075099662`], 
     Hue[1.0685752818597214`, 1, -13.340790428973957`], 
     Hue[1.1320686455101943`, 1, -13.15129365841771], 
     Hue[1.0685752818597158`, 1, -12.966548012292023`], 
     Hue[1.1320686455101796`, 1, -12.777051241735778`], 
     Hue[1.0685752818597036`, 1, -12.59230559561013], 
     Hue[1.1320686455101476`, 1, -12.402808825053894`], 
     Hue[1.0685752818596768`, 1, -12.218063178928332`], 
     Hue[1.132068645510077, 1, -12.028566408372116`], 
     Hue[1.0695549287433261`, 1, -11.840896993366417`], 
     Hue[1.1325278549866595`, 1, -11.65295347502791], 
     Hue[1.069554928743194, 1, -11.466654576685292`], 
     Hue[1.1325278549863167`, 1, -11.278711058346873`], 
     Hue[1.0695549287429036`, 1, -11.092412160005177`], 
     Hue[1.1325278549855624`, 1, -10.904468641666949`], 
     Hue[1.0700447521841088`, 1, -10.716707858887133`], 
     Hue[1.134601951120434, 1, -10.52403605806315], 
     Hue[1.0704121197640635`, 1, -10.341369028884047`], 
     Hue[1.1347684145520014`, 1, -10.149296829100846`], 
     Hue[1.0744531631557661`, 1, -9.955066065590977], 
     Hue[1.1348239023555315`, 1, -9.774888808343858], 
     Hue[1.0744531631483074`, 1, -9.580823648953071], 
     Hue[1.134823902337418, 1, -9.400646391709653], 
     Hue[1.0744531631319074`, 1, -9.20658123236798], 
     Hue[1.1348239022975914`, 1, -9.026403975132709], 
     Hue[1.0744531630958487`, 1, -8.832338815899028], 
     Hue[1.136599512183356, 1, -8.646862227585384], 
     Hue[1.0744531630165652`, 1, -8.458096399685427], 
     Hue[1.1365995119867514`, 1, -8.272619811410328], 
     Hue[1.0744531628422425`, 1, -8.083853984033272], 
     Hue[1.1365995115544714`, 1, -7.898377395842936], 
     Hue[1.0744531624589542`, 1, -7.709611569615588], 
     Hue[1.1365995106040052`, 1, -7.524134981611609], 
     Hue[1.0744531616162079`, 1, -7.335369157912164], 
     Hue[1.1365995085141896`, 1, -7.149892570317939], 
     Hue[1.0744531597632385`, 1, -6.9611267521766615`], 
     Hue[1.1374873088197603`, 1, -6.773000499915691], 
     Hue[1.074453155689064, 1, -6.5868843595629905`], 
     Hue[1.137487298611435, 1, -6.398758109259097], 
     Hue[1.076412439890892, 1, -6.206794458623721], 
     Hue[1.1383597737523743`, 1, -6.021911768038895], 
     Hue[1.0764124194663625`, 1, -5.8325521589973075`], 
     Hue[1.13835972389833, 1, -5.647669477051936], 
     Hue[1.0764123745584238`, 1, -5.458309999688535], 
     Hue[1.1387958622679184`, 1, -5.27212534564975], 
     Hue[1.0764122758182761`, 1, -5.084068148899729], 
     Hue[1.1390137434140644`, 1, -4.897232540609095], 
     Hue[1.0764120587164283`, 1, -4.70982697646088], 
     Hue[1.1427212836107594`, 1, -4.511924524263772], 
     Hue[1.0773912124542473`, 1, -4.332663541344783], 
     Hue[1.1396452265128025`, 1, -4.146862159454711], 
     Hue[1.077390143982769, 1, -3.9584271574013172`], 
     Hue[1.1431153251723918`, 1, -3.7622612433599256`], 
     Hue[1.0778775798159121`, 1, -3.5827361556097683`], 
     Hue[1.143308343996072, 1, -3.387439036577896], 
     Hue[1.07811723836069, 1, -3.2077920406708857`], 
     Hue[1.1433947074838526`, 1, -3.0129306776355556`], 
     Hue[1.082267619791237, 1, -2.821189254223616], 
     Hue[1.1413388930158637`, 1, -2.6448099494223376`], 
     Hue[1.0822404016002873`, 1, -2.447089767084991], 
     Hue[1.1416381078156332`, 1, -2.2696385040825895`], 
     Hue[1.0821806137761798`, 1, -2.073161511131442], 
     Hue[1.144849794282149, 1, -1.885701474953217], 
     Hue[1.0820494343142575`, 1, -1.6996093533410137`], 
     Hue[1.144538515631126, 1, -1.5121825403904146`], 
     Hue[1.0817623424510405`, 1, -1.326882235596685], 
     Hue[1.1438574270115296`, 1, -1.139533336486857], 
     Hue[1.083057414507952, 1, -0.9501449195736329], 
     Hue[1.143147491965581, 1, -0.7664216097479051], 
     Hue[1.0830728816987047`, 1, -0.5788541834498979], 
     Hue[1.142733236593655, 1, -0.3909445027686318], 
     Hue[1.085847075711792, 1, -0.20191878750891168`], 
     Hue[1.1407714611347373`, 1, -0.016397394008776045`], 
     Hue[1.088527886553479, 1, 0.1709567655896035], 
     Hue[1.1354147307491014`, 1, 0.3592141942714817], 
     Hue[1.0906706880656343`, 1, 0.5468019804001027], 
     Hue[1.0591743490956576`, 1, 0.734813680609451], 
     Hue[1.0393166692300986`, 1, 0.9219822691482528], 
     Hue[1.2547081897647026`, 1, -17.27618334189528], 
     Hue[1.1920107892072367`, 1, -17.089062133554293`], 
     Hue[1.2517998630786873`, 1, -16.91062086407678], 
     Hue[1.1920107892072367`, 1, -16.714819716872324`], 
     Hue[1.2517998630786873`, 1, -16.53637844739481], 
     Hue[1.1920107892072367`, 1, -16.34057730019035], 
     Hue[1.2522743795379845`, 1, -16.16071983016143], 
     Hue[1.1920107892072367`, 1, -15.966334883508381`], 
     Hue[1.2526302668824574`, 1, -15.7854152630659], 
     Hue[1.1920107892072367`, 1, -15.592092466826411`], 
     Hue[1.2565450276716597`, 1, -15.399489191834807`], 
     Hue[1.1920107892072367`, 1, -15.217850050144438`], 
     Hue[1.2565450276716592`, 1, -15.025246775152837`], 
     Hue[1.1920107892072365`, 1, -14.843607633462467`], 
     Hue[1.256545027671659, 1, -14.651004358470864`], 
     Hue[1.1920107892072358`, 1, -14.469365216780497`], 
     Hue[1.256545027671658, 1, -14.276761941788894`], 
     Hue[1.1920107892072347`, 1, -14.095122800098528`], 
     Hue[1.2565450276716563`, 1, -13.902519525106923`], 
     Hue[1.193970082974653, 1, -13.715032845655903`], 
     Hue[1.2574634466251307`, 1, -13.525536075099646`], 
     Hue[1.1939700829746471`, 1, -13.340790428973937`], 
     Hue[1.2574634466251218`, 1, -13.151293658417675`], 
     Hue[1.1939700829746347`, 1, -12.966548012291982`], 
     Hue[1.2574634466251018`, 1, -12.7770512417357], 
     Hue[1.1939700829746074`, 1, -12.592305595610041`], 
     Hue[1.2574634466250585`, 1, -12.402808825053723`], 
     Hue[1.1939700829745472`, 1, -12.218063178928135`], 
     Hue[1.257463446624963, 1, -12.028566408371738`], 
     Hue[1.194949729858123, 1, -11.840896993365977`], 
     Hue[1.2579226561014911`, 1, -11.652953475027077`], 
     Hue[1.1949497298578293`, 1, -11.466654576684324`], 
     Hue[1.257922656101028, 1, -11.278711058345039`], 
     Hue[1.1949497298571838`, 1, -11.092412160003047`], 
     Hue[1.2579226561000099`, 1, -10.904468641662916`], 
     Hue[1.1954395532976085`, 1, -10.716707858882422`], 
     Hue[1.259996752234326, 1, -10.524036058054126`], 
     Hue[1.1958069208758475`, 1, -10.341369028873643`], 
     Hue[1.260163215664652, 1, -10.149296829080976`], 
     Hue[1.1998479642638007`, 1, -9.955066065566982], 
     Hue[1.260218703465451, 1, -9.77488880830015], 
     Hue[1.1998479642480742`, 1, -9.580823648900314], 
     Hue[1.2602187034413297`, 1, -9.400646391613549], 
     Hue[1.1998479642134956`, 1, -9.206581232251983], 
     Hue[1.260218703388293, 1, -9.026403974921402], 
     Hue[1.199847964137467, 1, -8.832338815643977], 
     Hue[1.2619943132461742`, 1, -8.6468622271138], 
     Hue[1.199847963970301, 1, -8.458096399124639], 
     Hue[1.2619943129870999`, 1, -8.272619810373447], 
     Hue[1.1998479636027481`, 1, -8.083853982800253], 
     Hue[1.2619943124174657`, 1, -7.898377393563114], 
     Hue[1.1998479627945997`, 1, -7.709611566904514], 
     Hue[1.2619943111649956`, 1, -7.524134976598902], 
     Hue[1.1998479610177017`, 1, -7.335369151951251], 
     Hue[1.2619943084111553`, 1, -7.1498925592963625`], 
     Hue[1.1998479571107876`, 1, -6.961126739070241], 
     Hue[1.2628821072873258`, 1, -6.773000475502237], 
     Hue[1.1998479485205478`, 1, -6.586884330745543], 
     Hue[1.2628820939055285`, 1, -6.39875805558057], 
     Hue[1.2018072228331635`, 1, -6.206794393804598], 
     Hue[1.2637545622166846`, 1, -6.021911649156896], 
     Hue[1.2018071806245645`, 1, -5.83255201647777], 
     Hue[1.2637544971979644`, 1, -5.647669215662877], 
     Hue[1.2018070878193827`, 1, -5.458309686327139], 
     Hue[1.2641906025861012`, 1, -5.272124768849715], 
     Hue[1.2018068837661986`, 1, -5.084067459904514], 
     Hue[1.2644084112528147`, 1, -4.897231270098756], 
     Hue[1.2018064351094313`, 1, -4.709825461553472], 
     Hue[1.2681158071775953`, 1, -4.511921644835938], 
     Hue[1.202785080883648, 1, -4.332660172738861], 
     Hue[1.2650393889508935`, 1, -4.146855985225756], 
     Hue[1.2027828943683514`, 1, -3.9584197508801013`], 
     Hue[1.2685087927245675`, 1, -3.762247278422201], 
     Hue[1.2032678748626542`, 1, -3.582719779634288], 
     Hue[1.2687002217801977`, 1, -3.387408282880549], 
     Hue[1.2035021350067987`, 1, -3.2077559363341592`], 
     Hue[1.2687830891950593`, 1, -3.012863007942747], 
     Hue[1.2037159306620084`, 1, -2.832826277223421], 
     Hue[1.268842894533616, 1, -2.638319870476507], 
     Hue[1.207587629260122, 1, -2.4469069269870083`], 
     Hue[1.2669493816439388`, 1, -2.2694702099837514`], 
     Hue[1.2074707842141406`, 1, -2.0727598420466666`], 
     Hue[1.2701778449928804`, 1, -1.8849730099336053`], 
     Hue[1.2072140390411235`, 1, -1.6987278659610914`], 
     Hue[1.2697854545650313`, 1, -1.5105827867328692`], 
     Hue[1.2066503296265252`, 1, -1.3249521596569618`], 
     Hue[1.268921850606284, 1, -1.1360253921569223`], 
     Hue[1.2054148157877724`, 1, -0.9517551452996151], 
     Hue[1.2670191477157902`, 1, -0.7611390422448663], 
     Hue[1.2026589767496791`, 1, -0.5800893348222997], 
     Hue[1.2627953885861642`, 1, -0.385796208548868], 
     Hue[1.1995611706885119`, 1, -0.20217756082237814`], 
     Hue[1.2516758484418231`, 1, -0.016899549599841412`], 
     Hue[1.1900610163086918`, 1, 0.17069155339144682`], 
     Hue[1.2325922037012824`, 1, 0.35912048168190414`], 
     Hue[1.1706474332106036`, 1, 0.5462110338543341], 
     Hue[1.1935604101742845`, 1, 0.7338825558874532], 
     Hue[1.1179744901958093`, 1, 0.7339313823767273], 
     Hue[1.1249199339198925`, 1, 0.9216417865289087], 
     Hue[1.0735662245961775`, 1, 0.921604199421924], 
     Hue[1.3801029908796343`, 1, -17.27618334189528], 
     Hue[1.3174055903221684`, 1, -17.089062133554293`], 
     Hue[1.377194664193619, 1, -16.91062086407678], 
     Hue[1.3174055903221684`, 1, -16.714819716872324`], 
     Hue[1.377194664193619, 1, -16.53637844739481], 
     Hue[1.3174055903221684`, 1, -16.34057730019035], 
     Hue[1.3776691806529162`, 1, -16.16071983016143], 
     Hue[1.3174055903221684`, 1, -15.966334883508381`], 
     Hue[1.378025067997389, 1, -15.7854152630659], 
     Hue[1.3174055903221684`, 1, -15.592092466826411`], 
     Hue[1.3819398287865914`, 1, -15.399489191834807`], 
     Hue[1.3174055903221682`, 1, -15.217850050144438`], 
     Hue[1.3819398287865912`, 1, -15.025246775152837`], 
     Hue[1.317405590322168, 1, -14.843607633462467`], 
     Hue[1.381939828786591, 1, -14.651004358470864`], 
     Hue[1.3174055903221675`, 1, -14.469365216780497`], 
     Hue[1.3819398287865903`, 1, -14.276761941788891`], 
     Hue[1.3174055903221664`, 1, -14.095122800098522`], 
     Hue[1.3819398287865892`, 1, -13.902519525106916`], 
     Hue[1.3193648840895849`, 1, -13.715032845655891`], 
     Hue[1.3828582477400648`, 1, -13.52553607509963], 
     Hue[1.3193648840895793`, 1, -13.340790428973913`], 
     Hue[1.3828582477400588`, 1, -13.15129365841764], 
     Hue[1.3193648840895673`, 1, -12.966548012291927`], 
     Hue[1.3828582477400455`, 1, -12.777051241735625`], 
     Hue[1.319364884089541, 1, -12.592305595609917`], 
     Hue[1.3828582477400162`, 1, -12.402808825053556`], 
     Hue[1.3193648840894827`, 1, -12.218063178927865`], 
     Hue[1.382858247739952, 1, -12.028566408371375`], 
     Hue[1.3203445309730644`, 1, -11.840896993365382`], 
     Hue[1.3833174572165503`, 1, -11.652953475026278`], 
     Hue[1.3203445309727821`, 1, -11.466654576683014`], 
     Hue[1.3833174572162399`, 1, -11.278711058343278`], 
     Hue[1.3203445309721618`, 1, -11.092412160000165`], 
     Hue[1.3833174572155578`, 1, -10.904468641659047`], 
     Hue[1.320834354412649, 1, -10.71670785887607], 
     Hue[1.3853915533506678`, 1, -10.52403605804556], 
     Hue[1.32120172199103, 1, -10.341369028859646`], 
     Hue[1.3855580167826942`, 1, -10.149296829062136`], 
     Hue[1.3252427653795664`, 1, -9.955066065535467], 
     Hue[1.3856135045872289`, 1, -9.774888808258716], 
     Hue[1.3252427653648398`, 1, -9.580823648831018], 
     Hue[1.3856135045713143`, 1, -9.40064639152245], 
     Hue[1.3252427653324597`, 1, -9.20658123209962], 
     Hue[1.385613504536322, 1, -9.026403974721097], 
     Hue[1.3252427652612648`, 1, -8.832338815308976], 
     Hue[1.3873891144363544`, 1, -8.646862226670919], 
     Hue[1.325242765104727, 1, -8.458096398388061], 
     Hue[1.3873891142674823`, 1, -8.27261980939967], 
     Hue[1.3252427647605427`, 1, -8.08385398118072], 
     Hue[1.3873891138961791`, 1, -7.898377391422044], 
     Hue[1.3252427640037752`, 1, -7.709611563343601], 
     Hue[1.3873891130797844`, 1, -7.524134971891271], 
     Hue[1.3252427623398495`, 1, -7.335369144121773], 
     Hue[1.3873891112847545`, 1, -7.149892548945561], 
     Hue[1.3252427586813305`, 1, -6.961126721855352], 
     Hue[1.3882769123334326`, 1, -6.773000452681432], 
     Hue[1.3252427506372437`, 1, -6.586884292894696], 
     Hue[1.388276903664042, 1, -6.398758005403834], 
     Hue[1.3272020265253397`, 1, -6.206794309638339], 
     Hue[1.3891493826444403`, 1, -6.021911538539758], 
     Hue[1.3272019874061385`, 1, -5.832551831419097], 
     Hue[1.389149340776513, 1, -5.647668972445852], 
     Hue[1.3272019013936407`, 1, -5.458309279433507], 
     Hue[1.3895854978152649`, 1, -5.27212423338142], 
     Hue[1.3272017122754263`, 1, -5.084066565256106], 
     Hue[1.3898034201238243`, 1, -4.8972300919818865`], 
     Hue[1.3272012964551791`, 1, -4.7098234944644615`], 
     Hue[1.3935110964268604`, 1, -4.511919026635569], 
     Hue[1.3281800242113229`, 1, -4.332655823466878], 
     Hue[1.3904352060452756`, 1, -4.146850278978804], 
     Hue[1.328178008128447, 1, -3.958410187991661], 
     Hue[1.3939059701357874`, 1, -3.7622346066310364`], 
     Hue[1.3286633870599023`, 1, -3.5826986949458473`], 
     Hue[1.3941002656962485`, 1, -3.387380404544098], 
     Hue[1.3288985249562082`, 1, -3.207709512090217], 
     Hue[1.394189436665332, 1, -3.0128016884401445`], 
     Hue[1.3290913188028983`, 1, -2.8327926153699963`], 
     Hue[1.3942537915697577`, 1, -2.638212836788046], 
     Hue[1.3329922963596785`, 1, -2.446677211097458], 
     Hue[1.3922949611993214`, 1, -2.269483763518851], 
     Hue[1.3328871618396296`, 1, -2.0722546693131783`], 
     Hue[1.392384892947353, 1, -1.8942325923052061`], 
     Hue[1.3326557192880528`, 1, -1.6976166966399002`], 
     Hue[1.3954570031520033`, 1, -1.5091372889362795`], 
     Hue[1.332145484734552, 1, -1.322506948250395], 
     Hue[1.391506837841972, 1, -1.1431500948490256`], 
     Hue[1.3310170666761134`, 1, -0.9463692553952023], 
     Hue[1.3895826792691721`, 1, -0.7667572387964696], 
     Hue[1.3265718719483601`, 1, -0.574126639124944], 
     Hue[1.3851433572660097`, 1, -0.3884007476707245], 
     Hue[1.317036241745629, 1, -0.20469390171262014`], 
     Hue[1.373437742551981, 1, -0.011729164647516832`], 
     Hue[1.4275220675299423`, 1, 0.17320604206319246`], 
     Hue[1.3006790229807708`, 1, 0.17082652060224424`], 
     Hue[1.3466569753153346`, 1, 0.35914788104917794`], 
     Hue[1.3908772564573235`, 1, 0.5466152417027168], 
     Hue[1.2675684901906883`, 1, 0.5461559035393729], 
     Hue[1.295830406684156, 1, 0.7339034112982588], 
     Hue[1.3180251860219394`, 1, 0.9218128220257024], 
     Hue[1.3350574824571628`, 1, 1.1092855837603712`], 
     Hue[1.2029281696058534`, 1, 0.9215652888985737], 
     Hue[1.19622706539698, 1, 1.1093123559247864`], 
     Hue[1.1650124931253196`, 1, 1.2970717112634442`], 
     Hue[1.102391565653644, 1, 1.1093047111538774`], 
     Hue[1.037191040711055, 1, 1.1097464175017795`], 
     Hue[0.5054977919945658, 1, -17.27618334189528], 
     Hue[1.4428003914371001`, 1, -17.089062133554293`], 
     Hue[0.5025894653085505, 1, -16.91062086407678], 
     Hue[1.4428003914371001`, 1, -16.714819716872324`], 
     Hue[0.5025894653085505, 1, -16.53637844739481], 
     Hue[1.4428003914371001`, 1, -16.34057730019035], 
     Hue[0.5030639817678477, 1, -16.16071983016143], 
     Hue[1.4428003914371001`, 1, -15.966334883508381`], 
     Hue[0.5034198691123207, 1, -15.7854152630659], 
     Hue[1.4428003914371001`, 1, -15.592092466826411`], 
     Hue[0.5073346299015229, 1, -15.399489191834807`], 
     Hue[1.4428003914371001`, 1, -15.217850050144438`], 
     Hue[0.5073346299015229, 1, -15.025246775152837`], 
     Hue[1.4428003914371, 1, -14.843607633462467`], 
     Hue[0.5073346299015229, 1, -14.65100435847086], 
     Hue[1.4428003914370997`, 1, -14.469365216780494`], 
     Hue[0.5073346299015229, 1, -14.276761941788891`], 
     Hue[1.4428003914370993`, 1, -14.095122800098519`], 
     Hue[0.5073346299015231, 1, -13.902519525106912`], 
     Hue[1.4447596852045193`, 1, -13.715032845655884`], 
     Hue[0.5082530488550017, 1, -13.525536075099625`], 
     Hue[1.444759685204517, 1, -13.340790428973897`], 
     Hue[0.5082530488550022, 1, -13.151293658417627`], 
     Hue[1.4447596852045126`, 1, -12.96654801229189], 
     Hue[0.5082530488550032, 1, -12.777051241735599`], 
     Hue[1.4447596852045026`, 1, -12.592305595609835`], 
     Hue[0.5082530488550054, 1, -12.402808825053496`], 
     Hue[1.4447596852044808`, 1, -12.218063178927682`], 
     Hue[0.5082530488550104, 1, -12.02856640837124], 
     Hue[1.4457393320881442`, 1, -11.840896993364982`], 
     Hue[0.5087122583317618, 1, -11.652953475025983`], 
     Hue[1.4457393320880398`, 1, -11.466654576682135`], 
     Hue[0.5087122583317871, 1, -11.27871105834263], 
     Hue[1.4457393320878105`, 1, -11.092412159998233`], 
     Hue[0.5087122583318429, 1, -10.90446864165762], 
     Hue[1.4462291555291662`, 1, -10.71670785887182], 
     Hue[0.5107863544686282, 1, -10.524036058042505`], 
     Hue[1.4465965231094633`, 1, -10.341369028850302`], 
     Hue[0.5109528179042946, 1, -10.149296829055427`], 
     Hue[1.450637566502572, 1, -9.955066065515002], 
     Hue[0.5110083057168306, 1, -9.774888808243976], 
     Hue[1.4506375664975235`, 1, -9.58082364878602], 
     Hue[0.5110083057185011, 1, -9.400646391490037], 
     Hue[1.4506375664864235`, 1, -9.206581232000683], 
     Hue[0.5110083057221741, 1, -9.026403974649831], 
     Hue[1.4506375664620172`, 1, -8.832338815091438], 
     Hue[0.5127839157095526, 1, -8.646862226517726], 
     Hue[1.4506375664083553`, 1, -8.45809639790976], 
     Hue[0.5127839157303993, 1, -8.272619809062844], 
     Hue[1.4506375662903668`, 1, -8.08385398012906], 
     Hue[0.5127839157762353, 1, -7.898377390681454], 
     Hue[1.4506375660309423`, 1, -7.7096115610312905`], 
     Hue[0.5127839158770162, 1, -7.524134970262915], 
     Hue[1.4506375654605386`, 1, -7.335369139037632], 
     Hue[0.5127839160986062, 1, -7.149892545365252], 
     Hue[1.4506375642063762`, 1, -6.961126710676711], 
     Hue[0.5136717216414441, 1, -6.77300044490155], 
     Hue[1.450637561448815, 1, -6.586884268315908], 
     Hue[0.5136717227933247, 1, -6.398757988297992], 
     Hue[1.4525968494486614`, 1, -6.2067942557240325`], 
     Hue[0.5145442236546265, 1, -6.021911501374085], 
     Hue[1.4525968364717794`, 1, -5.832551712876183], 
     Hue[0.5145442296102651, 1, -5.647668890728608], 
     Hue[1.4525968079391283`, 1, -5.458309018789717], 
     Hue[0.5149804924942472, 1, -5.272124054796822], 
     Hue[1.4525967452034874`, 1, -5.084065992170349], 
     Hue[0.5151986475978755, 1, -4.897229700526712], 
     Hue[1.4525966072643435`, 1, -4.709822234399772], 
     Hue[0.5189068637072356, 1, -4.511918212592695], 
     Hue[1.4535759586540438`, 1, -4.332653056563291], 
     Hue[0.5158320791085479, 1, -4.146848403523376], 
     Hue[1.4535753011307904`, 1, -3.9584041041997926`], 
     Hue[0.5193054571902009, 1, -3.7622306961055934`], 
     Hue[1.454063697898086, 1, -3.582685327050024], 
     Hue[0.519505386809026, 1, -3.3873718333800724`], 
     Hue[1.4543054744813195`, 1, -3.2076801272787723`], 
     Hue[0.5196069487411084, 1, -3.0127828698468653`], 
     Hue[1.45448227733606, 1, -2.8328194121442225`], 
     Hue[0.5196861294944428, 1, -2.63820863359937], 
     Hue[1.4584486514472434`, 1, -2.4465360394169275`], 
     Hue[0.5177980187863884, 1, -2.269389998699003], 
     Hue[1.4584173342434925`, 1, -2.0719439248619187`], 
     Hue[0.5179730169873729, 1, -1.8941618121563308`], 
     Hue[1.4583483137768707`, 1, -1.696931776252485], 
     Hue[0.5180168308420718, 1, -1.518767802278792], 
     Hue[1.458195766575297, 1, -1.3209928465551688`], 
     Hue[0.5177483326516987, 1, -1.143072305065042], 
     Hue[1.4537741333148266`, 1, -0.9552824752828399], 
     Hue[0.516463452437942, 1, -0.767652850431604], 
     Hue[1.45108237150761, 1, -0.5786783892214886], 
     Hue[0.5143324864010006, 1, -0.38851762694377645`], 
     Hue[1.4440213298782336`, 1, -0.20251337284172477`], 
     Hue[0.505616904645541, 1, -0.014288900369817448`], 
     Hue[0.5714688772688368, 1, 0.17126673196682363`], 
     Hue[1.4847301869187146`, 1, 0.3592252827492779], 
     Hue[0.5507454067210824, 1, 0.5461334774672932], 
     Hue[1.4364772315760879`, 1, 0.7339932375778806], 
     Hue[1.4890810844132885`, 1, 0.9217030199632356], 
     Hue[0.5629078185228371, 1, 1.10966886165917], 
     Hue[1.3481259940317922`, 1, 1.2987357553959484`], 
     Hue[0.9875600960753852, 1, 1.2971336044877382`], 
     Hue[1.0054076269194299`, 1, 1.1094148581170549`], 
     Hue[0.6308925931094974, 1, -17.27618334189528], 
     Hue[0.5681951925520317, 1, -17.089062133554293`], 
     Hue[0.6279842664234823, 1, -16.91062086407678], 
     Hue[0.5681951925520315, 1, -16.714819716872324`], 
     Hue[0.6279842664234823, 1, -16.53637844739481], 
     Hue[0.5681951925520317, 1, -16.34057730019035], 
     Hue[0.6284587828827796, 1, -16.16071983016143], 
     Hue[0.5681951925520317, 1, -15.966334883508381`], 
     Hue[0.6288146702272525, 1, -15.7854152630659], 
     Hue[0.5681951925520317, 1, -15.592092466826411`], 
     Hue[0.6327294310164546, 1, -15.399489191834807`], 
     Hue[0.5681951925520317, 1, -15.217850050144438`], 
     Hue[0.6327294310164548, 1, -15.025246775152837`], 
     Hue[0.5681951925520318, 1, -14.843607633462467`], 
     Hue[0.6327294310164551, 1, -14.651004358470864`], 
     Hue[0.568195192552032, 1, -14.469365216780494`], 
     Hue[0.6327294310164557, 1, -14.276761941788891`], 
     Hue[0.5681951925520325, 1, -14.095122800098519`], 
     Hue[0.6327294310164571, 1, -13.902519525106916`], 
     Hue[0.5701544863194546, 1, -13.715032845655884`], 
     Hue[0.6336478499699386, 1, -13.525536075099632`], 
     Hue[0.5701544863194572, 1, -13.340790428973897`], 
     Hue[0.6336478499699454, 1, -13.151293658417643`], 
     Hue[0.5701544863194629, 1, -12.966548012291891`], 
     Hue[0.6336478499699602, 1, -12.777051241735633`], 
     Hue[0.5701544863194753, 1, -12.59230559560984], 
     Hue[0.6336478499699925, 1, -12.402808825053576`], 
     Hue[0.5701544863195027, 1, -12.218063178927697`], 
     Hue[0.6336478499700637, 1, -12.028566408371413`], 
     Hue[0.5711341332032756, 1, -11.840896993365014`], 
     Hue[0.6341070594469611, 1, -11.652953475026367`], 
     Hue[0.5711341332034104, 1, -11.466654576682204`], 
     Hue[0.634107059447307, 1, -11.278711058343475`], 
     Hue[0.571134133203707, 1, -11.092412159998384`], 
     Hue[0.634107059448068, 1, -10.904468641659479`], 
     Hue[0.5716239566462258, 1, -10.716707858872176`], 
     Hue[0.6361811555864225, 1, -10.524036058046756`], 
     Hue[0.5719913242290837, 1, -10.341369028851119`], 
     Hue[0.6363476190255236, 1, -10.149296829064802`], 
     Hue[0.5760323676280592, 1, -9.955066065517647], 
     Hue[0.6364031068456109, 1, -9.774888808264611], 
     Hue[0.576032367635664, 1, -9.580823648791837], 
     Hue[0.6364031068638822, 1, -9.400646391535414], 
     Hue[0.5760323676523851, 1, -9.206581232013475], 
     Hue[0.6364031069040559, 1, -9.026403974749602], 
     Hue[0.5760323676891503, 1, -8.832338815119561], 
     Hue[0.6381787169725026, 1, -8.646862226744501], 
     Hue[0.576032367769987, 1, -8.458096397971595], 
     Hue[0.6381787171707829, 1, -8.272619809561458], 
     Hue[0.5760323679477249, 1, -8.083853980265019], 
     Hue[0.6381787176067473, 1, -7.898377391777774], 
     Hue[0.5760323683385222, 1, -7.709611561330223], 
     Hue[0.6381787185653138, 1, -7.524134972673424], 
     Hue[0.5760323691977787, 1, -7.335369139694907], 
     Hue[0.6381787206729407, 1, -7.149892550665306], 
     Hue[0.5760323710870496, 1, -6.961126712121879], 
     Hue[0.6390665303831867, 1, -6.77300045674727], 
     Hue[0.5760323752410419, 1, -6.586884271493439], 
     Hue[0.6390665406775362, 1, -6.398758014343505], 
     Hue[0.5779916787514667, 1, -6.206794263833345], 
     Hue[0.639939061736998, 1, -6.021911559561599], 
     Hue[0.5779916995641792, 1, -5.832551730706356], 
     Hue[0.6399391120065423, 1, -5.6476690186671785`], 
     Hue[0.577991745325698, 1, -5.458309057993457], 
     Hue[0.640375472555603, 1, -5.272124338336369], 
     Hue[0.5779918459429798, 1, -5.084066078368902], 
     Hue[0.6405938424202431, 1, -4.897230326420918], 
     Hue[0.5779920671738005, 1, -4.709822423927926], 
     Hue[0.6443025396492686, 1, -4.511919682438773], 
     Hue[0.5789722163384339, 1, -4.332653502628665], 
     Hue[0.6412287871019882, 1, -4.146851464146728], 
     Hue[0.578973304886826, 1, -3.958405085001874], 
     Hue[0.6447044922515189, 1, -3.7622378517076935`], 
     Hue[0.5794655603928415, 1, -3.582687555214685], 
     Hue[0.6449095025002465, 1, -3.3873876222654085`], 
     Hue[0.5797158239936424, 1, -3.2076851060024145`], 
     Hue[0.6450222367672078, 1, -3.0128176511166007`], 
     Hue[0.5799113051300278, 1, -2.832830492667463], 
     Hue[0.6451259904943465, 1, -2.63828523550582], 
     Hue[0.583920404174877, 1, -2.4465667908504596`], 
     Hue[0.643291406283752, 1, -2.2695530681523666`], 
     Hue[0.5839814468934812, 1, -2.072011633244337], 
     Hue[0.6469524504103363, 1, -1.8845037747925788`], 
     Hue[0.5841159463079975, 1, -1.697081106143168], 
     Hue[0.6472686460510888, 1, -1.5095491976073998`], 
     Hue[0.58441304898578, 1, -1.3213234098873679`], 
     Hue[0.647967213824886, 1, -1.1337438157442172`], 
     Hue[0.5810437419718623, 1, -0.955589036869749], 
     Hue[0.6478652033315018, 1, -0.7608453656855341], 
     Hue[0.5804147422202242, 1, -0.5798451059098868], 
     Hue[0.6464988325737333, 1, -0.39238886203112555`], 
     Hue[0.5792000100285737, 1, -0.20131656404210108`], 
     Hue[0.6480395765777418, 1, -0.017036875489711223`], 
     Hue[0.6503420666619792, 1, 0.3603344685741089], 
     Hue[0.6419201856934811, 1, 0.7346419144992287], 
     Hue[0.8573436135467472, 1, 1.1095124668157479`], 
     Hue[0.943753750939198, 1, 1.1092920270433542`], 
     Hue[0.9139112091435385, 1, 1.2971169892825156`], 
     Hue[0.9732676431041023, 1, 1.1093998099801665`], 
     Hue[0.9895018284943288, 1, 1.1092872362263577`], 
     Hue[0.7562873942244293, 1, -17.27618334189528], 
     Hue[0.6935899936669634, 1, -17.089062133554293`], 
     Hue[0.7533790675384138, 1, -16.91062086407678], 
     Hue[0.6935899936669634, 1, -16.714819716872324`], 
     Hue[0.7533790675384138, 1, -16.53637844739481], 
     Hue[0.6935899936669634, 1, -16.34057730019035], 
     Hue[0.7538535839977112, 1, -16.16071983016143], 
     Hue[0.6935899936669634, 1, -15.966334883508381`], 
     Hue[0.7542094713421842, 1, -15.7854152630659], 
     Hue[0.6935899936669634, 1, -15.592092466826411`], 
     Hue[0.7581242321313864, 1, -15.399489191834807`], 
     Hue[0.6935899936669635, 1, -15.217850050144438`], 
     Hue[0.7581242321313866, 1, -15.025246775152837`], 
     Hue[0.6935899936669638, 1, -14.843607633462467`], 
     Hue[0.7581242321313869, 1, -14.651004358470864`], 
     Hue[0.6935899936669643, 1, -14.469365216780497`], 
     Hue[0.7581242321313877, 1, -14.276761941788894`], 
     Hue[0.6935899936669654, 1, -14.095122800098524`], 
     Hue[0.7581242321313896, 1, -13.902519525106923`], 
     Hue[0.6955492874343888, 1, -13.715032845655893`], 
     Hue[0.7590426510848722, 1, -13.52553607509965], 
     Hue[0.6955492874343945, 1, -13.340790428973914`], 
     Hue[0.7590426510848811, 1, -13.151293658417679`], 
     Hue[0.695549287434407, 1, -12.966548012291932`], 
     Hue[0.7590426510849009, 1, -12.777051241735712`], 
     Hue[0.6955492874344346, 1, -12.59230559560993], 
     Hue[0.7590426510849444, 1, -12.402808825053748`], 
     Hue[0.6955492874344951, 1, -12.218063178927896`], 
     Hue[0.7590426510850398, 1, -12.028566408371793`], 
     Hue[0.6965289343183403, 1, -11.840896993365458`], 
     Hue[0.75950186056199, 1, -11.652953475027203`], 
     Hue[0.6965289343186349, 1, -11.466654576683181`], 
     Hue[0.7595018605624528, 1, -11.278711058345317`], 
     Hue[0.6965289343192829, 1, -11.092412160000535`], 
     Hue[0.7595018605634705, 1, -10.904468641663525`], 
     Hue[0.6970187577625737, 1, -10.71670785887693], 
     Hue[0.7615759567023636, 1, -10.52403605805581], 
     Hue[0.6973861253471283, 1, -10.341369028861617`], 
     Hue[0.7617424201426701, 1, -10.149296829084738`], 
     Hue[0.7014271687498077, 1, -9.955066065541844], 
     Hue[0.761797907965409, 1, -9.774888808308468], 
     Hue[0.7014271687655844, 1, -9.58082364884504], 
     Hue[0.761797907989514, 1, -9.40064639163184], 
     Hue[0.7014271688002729, 1, -9.206581232130455], 
     Hue[0.761797908042514, 1, -9.026403974961616], 
     Hue[0.7014271688765437, 1, -8.83233881537677], 
     Hue[0.7635735181379774, 1, -8.646862227217605], 
     Hue[0.7014271690442423, 1, -8.458096398537128], 
     Hue[0.763573518396845, 1, -8.272619810601684], 
     Hue[0.7014271694129658, 1, -8.083853981508474], 
     Hue[0.7635735189660242, 1, -7.898377394064945], 
     Hue[0.7014271702236883, 1, -7.70961156406424], 
     Hue[0.7635735202174943, 1, -7.524134977702288], 
     Hue[0.7014271720062459, 1, -7.335369145706266], 
     Hue[0.7635735229691358, 1, -7.149892561722408], 
     Hue[0.7014271759256048, 1, -6.961126725339221], 
     Hue[0.7644613340641887, 1, -6.773000481237919], 
     Hue[0.7014271845432068, 1, -6.586884300554773], 
     Hue[0.7644613474345561, 1, -6.398758068191771], 
     Hue[0.7033864978226647, 1, -6.206794329187461], 
     Hue[0.7653338751066731, 1, -6.021911678812415], 
     Hue[0.7033865401600439, 1, -5.832551874402295], 
     Hue[0.7653339400662862, 1, -5.647669280867284], 
     Hue[0.7033866332484264, 1, -5.4583093739418915`], 
     Hue[0.7657703325461553, 1, -5.272124916909431], 
     Hue[0.703386837924526, 1, -5.084066773054495], 
     Hue[0.7659887725783779, 1, -4.897231600820449], 
     Hue[0.7033872879520477, 1, -4.709823951357509], 
     Hue[0.7696976087127019, 1, -4.511922569967519], 
     Hue[0.7043679388871806, 1, -4.332656898783218], 
     Hue[0.7666242062764472, 1, -4.146857657101572], 
     Hue[0.7043701319747204, 1, -3.9584125523448677`], 
     Hue[0.7701005801290577, 1, -3.7622518559983398`], 
     Hue[0.7048648127514467, 1, -3.5827040660469898`], 
     Hue[0.7703071230693321, 1, -3.387418463669343], 
     Hue[0.7051204082739854, 1, -3.2077215126425065`], 
     Hue[0.7704232247812801, 1, -3.0128855203843656`], 
     Hue[0.7053582341596336, 1, -2.8328193715681254`], 
     Hue[0.7705468097551135, 1, -2.638397466734607], 
     Hue[0.7093621446066094, 1, -2.446751292802033], 
     Hue[0.7688203600758338, 1, -2.2695684796109115`], 
     Hue[0.7094794224686995, 1, -2.0724176478679954`], 
     Hue[0.7724107337785161, 1, -1.885235605602005], 
     Hue[0.7097374426212733, 1, -1.6979754914183733`], 
     Hue[0.7728019081498356, 1, -1.511160139660807], 
     Hue[0.7103055182670306, 1, -1.3232980059244637`], 
     Hue[0.7736610130234811, 1, -1.137294667109081], 
     Hue[0.7115581842183241, 1, -0.9481189730771147], 
     Hue[0.7755450085208446, 1, -0.7639284549004854], 
     Hue[0.7143294216153462, 1, -0.5719152381974064], 
     Hue[0.7796614351859493, 1, -0.3918385415109027], 
     Hue[0.7183727161234954, 1, -0.19936143690715946`], 
     Hue[0.7912190872012168, 1, -0.016963262736714446`], 
     Hue[0.7272908842514314, 1, 0.17089056124593638`], 
     Hue[0.8211448991414502, 1, 0.35951404247520813`], 
     Hue[0.7562710168773763, 1, 0.5478388027267211], 
     Hue[0.8816821953393607, 1, -17.27618334189528], 
     Hue[0.8189847947818949, 1, -17.089062133554293`], 
     Hue[0.8787738686533455, 1, -16.91062086407678], 
     Hue[0.8189847947818949, 1, -16.714819716872324`], 
     Hue[0.8787738686533455, 1, -16.53637844739481], 
     Hue[0.818984794781895, 1, -16.34057730019035], 
     Hue[0.8792483851126429, 1, -16.16071983016143], 
     Hue[0.818984794781895, 1, -15.966334883508381`], 
     Hue[0.8796042724571159, 1, -15.7854152630659], 
     Hue[0.818984794781895, 1, -15.592092466826411`], 
     Hue[0.883519033246318, 1, -15.399489191834807`], 
     Hue[0.8189847947818951, 1, -15.217850050144438`], 
     Hue[0.8835190332463181, 1, -15.025246775152837`], 
     Hue[0.8189847947818953, 1, -14.843607633462467`], 
     Hue[0.8835190332463184, 1, -14.651004358470864`], 
     Hue[0.8189847947818959, 1, -14.469365216780497`], 
     Hue[0.883519033246319, 1, -14.276761941788898`], 
     Hue[0.818984794781897, 1, -14.09512280009853], 
     Hue[0.8835190332463202, 1, -13.90251952510693], 
     Hue[0.8209440885493202, 1, -13.715032845655905`], 
     Hue[0.8844374521998011, 1, -13.525536075099664`], 
     Hue[0.8209440885493257, 1, -13.34079042897394], 
     Hue[0.8844374521998071, 1, -13.151293658417712`], 
     Hue[0.8209440885493376, 1, -12.96654801229199], 
     Hue[0.8844374521998202, 1, -12.777051241735787`], 
     Hue[0.820944088549364, 1, -12.592305595610053`], 
     Hue[0.884437452199849, 1, -12.402808825053912`], 
     Hue[0.8209440885494219, 1, -12.218063178928166`], 
     Hue[0.8844374521999125, 1, -12.028566408372154`], 
     Hue[0.8219237354332602, 1, -11.840896993366053`], 
     Hue[0.8848966616767913, 1, -11.652953475028001`], 
     Hue[0.8219237354335411, 1, -11.46665457668449], 
     Hue[0.884896661677098, 1, -11.278711058347069`], 
     Hue[0.8219237354341585, 1, -11.092412160003413`], 
     Hue[0.8848966616777727, 1, -10.904468641667377`], 
     Hue[0.8224135588773752, 1, -10.716707858883279`], 
     Hue[0.8869707578158565, 1, -10.52403605806433], 
     Hue[0.8227809264617627, 1, -10.341369028875608`], 
     Hue[0.8871372212544288, 1, -10.149296829103488`], 
     Hue[0.8268219698638006, 1, -9.955066065573334], 
     Hue[0.8871927090733568, 1, -9.774888808349695], 
     Hue[0.8268219698784518, 1, -9.58082364891428], 
     Hue[0.8871927090890902, 1, -9.400646391722491], 
     Hue[0.8268219699106659, 1, -9.206581232282689], 
     Hue[0.8871927091236838, 1, -9.026403975160934], 
     Hue[0.8268219699814959, 1, -8.832338815711495], 
     Hue[0.8889683191761915, 1, -8.646862227658236], 
     Hue[0.8268219701372319, 1, -8.458096399273092], 
     Hue[0.888968319343096, 1, -8.272619811570513], 
     Hue[0.8268219704796526, 1, -8.083853983126657], 
     Hue[0.8889683197100735, 1, -7.898377396195136], 
     Hue[0.8268219712325424, 1, -7.709611567622189], 
     Hue[0.888968320516957, 1, -7.524134982386003], 
     Hue[0.8268219728879421, 1, -7.335369153529222], 
     Hue[0.888968322291074, 1, -7.14989257202062], 
     Hue[0.8268219765277148, 1, -6.961126742539769], 
     Hue[0.8898561311722681, 1, -6.7730005039411845`], 
     Hue[0.8268219845305829, 1, -6.586884338374093], 
     Hue[0.889856139739511, 1, -6.398758118110062], 
     Hue[0.8287812960806489, 1, -6.206794413273248], 
     Hue[0.8907286565419601, 1, -6.02191178885213], 
     Hue[0.828781334993311, 1, -5.832552059284017], 
     Hue[0.8907286979110235, 1, -5.647669522814538], 
     Hue[0.8287814205516141, 1, -5.458309780446367], 
     Hue[0.891165037770932, 1, -5.272125449562808], 
     Hue[0.8287816086708312, 1, -5.084067666846831], 
     Hue[0.8913833620290417, 1, -4.897232772719538], 
     Hue[0.8287820222928778, 1, -4.709825916562193], 
     Hue[0.8950919130050587, 1, -4.511925173544817], 
     Hue[0.8297625833051414, 1, -4.332661243609622], 
     Hue[0.8920179724522577, 1, -4.146863332804265], 
     Hue[0.8297645885139887, 1, -3.9584221054069246`], 
     Hue[0.8954929627536616, 1, -3.762264455877557], 
     Hue[0.8302588319767849, 1, -3.5827251281534975`], 
     Hue[0.895696588076283, 1, -3.3874461809192864`], 
     Hue[0.8305134626838098, 1, -3.2077678851578657`], 
     Hue[0.8958062719918364, 1, -3.012946473348431], 
     Hue[0.8307778424810551, 1, -2.832835826158691], 
     Hue[0.8959273816747048, 1, -2.638496710594482], 
     Hue[0.8347462288272972, 1, -2.446980632507029], 
     Hue[0.8942374457116717, 1, -2.2696306124566226`], 
     Hue[0.834850544743467, 1, -2.072921805262877], 
     Hue[0.8976767254988287, 1, -1.8858852395301253`], 
     Hue[0.8350796234616703, 1, -1.6990835184553343`], 
     Hue[0.8979128816794271, 1, -1.5125851740538054`], 
     Hue[0.8355819345331911, 1, -1.3257319106237835`], 
     Hue[0.8984288439839794, 1, -1.1404118184676413`], 
     Hue[0.8366797564637886, 1, -0.9534587556463643], 
     Hue[0.901192729442126, 1, -0.7659203992359633], 
     Hue[0.8410403688482198, 1, -0.5780084328898694], 
     Hue[0.9091265345566488, 1, -0.3860537638631476], 
     Hue[0.8501243498314709, 1, -0.20337187485288166`], 
     Hue[0.9208293522281384, 1, -0.016327726612260784`], 
     Hue[0.8715093955275404, 1, 0.1716849719119392], 
     Hue[0.9507757156112394, 1, 0.3587383839943814], 
     Hue[0.9247216049639752, 1, 0.5463332406693115], 
     Hue[0.9197405862644711, 1, 0.7338817394147361], 
     Hue[0.9812404479249625, 1, 0.9215646570636706], 
     Hue[1.0070769964542923`, 1, -17.27618334189528], 
     Hue[0.9443795958968265, 1, -17.089062133554293`], 
     Hue[1.0041686697682772`, 1, -16.91062086407678], 
     Hue[0.9443795958968265, 1, -16.714819716872324`], 
     Hue[1.0041686697682772`, 1, -16.53637844739481], 
     Hue[0.9443795958968265, 1, -16.34057730019035], 
     Hue[1.0046431862275742`, 1, -16.16071983016143], 
     Hue[0.9443795958968265, 1, -15.966334883508381`], 
     Hue[1.0049990735720473`, 1, -15.7854152630659], 
     Hue[0.9443795958968265, 1, -15.592092466826411`], 
     Hue[1.0089138343612494`, 1, -15.399489191834807`], 
     Hue[0.9443795958968266, 1, -15.217850050144438`], 
     Hue[1.0089138343612494`, 1, -15.025246775152837`], 
     Hue[0.9443795958968267, 1, -14.843607633462467`], 
     Hue[1.0089138343612494`, 1, -14.651004358470868`], 
     Hue[0.9443795958968269, 1, -14.469365216780501`], 
     Hue[1.0089138343612494`, 1, -14.276761941788898`], 
     Hue[0.9443795958968273, 1, -14.095122800098533`], 
     Hue[1.0089138343612492`, 1, -13.902519525106934`], 
     Hue[0.9463388896642488, 1, -13.715032845655912`], 
     Hue[1.009832253314727, 1, -13.52553607509967], 
     Hue[0.9463388896642508, 1, -13.340790428973957`], 
     Hue[1.0098322533147266`, 1, -13.151293658417725`], 
     Hue[0.9463388896642552, 1, -12.966548012292026`], 
     Hue[1.0098322533147253`, 1, -12.777051241735814`], 
     Hue[0.9463388896642648, 1, -12.592305595610135`], 
     Hue[1.0098322533147226`, 1, -12.402808825053972`], 
     Hue[0.9463388896642861, 1, -12.218063178928345`], 
     Hue[1.0098322533147168`, 1, -12.028566408372287`], 
     Hue[0.9473185365480423, 1, -11.84089699336645], 
     Hue[1.0102914627914419`, 1, -11.652953475028287`], 
     Hue[0.9473185365481438, 1, -11.466654576685361`], 
     Hue[1.010291462791412, 1, -11.278711058347698`], 
     Hue[0.9473185365483667, 1, -11.092412160005326`], 
     Hue[1.010291462791346, 1, -10.904468641668762`], 
     Hue[0.947808359990707, 1, -10.716707858887482`], 
     Hue[1.0123655589277494`, 1, -10.5240360580673], 
     Hue[0.9481757275731616, 1, -10.341369028884845`], 
     Hue[1.0125320223626695`, 1, -10.149296829109998`], 
     Hue[0.9522167709705907, 1, -9.95506606559356], 
     Hue[1.0125875101735702`, 1, -9.774888808364004], 
     Hue[0.9522167709754825, 1, -9.580823648958749], 
     Hue[1.0125875101716604`, 1, -9.400646391753947], 
     Hue[0.9522167709862384, 1, -9.206581232380467], 
     Hue[1.0125875101674615`, 1, -9.026403975230096], 
     Hue[0.9522167710098876, 1, -8.832338815926478], 
     Hue[1.0143631201323549`, 1, -8.646862227806734], 
     Hue[0.9522167710618857, 1, -8.458096399745784], 
     Hue[1.0143631201089398`, 1, -8.272619811897018], 
     Hue[0.9522167711762156, 1, -8.083853984165978], 
     Hue[1.014363120057456, 1, -7.898377396913033], 
     Hue[0.9522167714275958, 1, -7.709611569907373], 
     Hue[1.0143631199442575`, 1, -7.524134983964459], 
     Hue[0.9522167719803122, 1, -7.335369158553717], 
     Hue[1.0143631196953649`, 1, -7.149892575491216], 
     Hue[0.9522167731955848, 1, -6.961126753587261], 
     Hue[1.0152509240686591`, 1, -6.77300051147806], 
     Hue[0.9522167758676383, 1, -6.586884362664513], 
     Hue[1.015250922784113, 1, -6.39875813468159], 
     Hue[0.9541760752090237, 1, -6.20679446653905], 
     Hue[1.0161234176400626`, 1, -6.021911824834504], 
     Hue[0.9541760877657995, 1, -5.832552176400954], 
     Hue[1.0161234110398827`, 1, -5.647669601929918], 
     Hue[0.9541761153747038, 1, -5.458310037954367], 
     Hue[1.0165596447381389`, 1, -5.272125622405552], 
     Hue[0.9541761760790465, 1, -5.084068233035655], 
     Hue[1.0167777355069278`, 1, -4.897233151524673], 
     Hue[0.9541763095508026, 1, -4.709827161451843], 
     Hue[1.0204857453088547`, 1, -4.511925958913221], 
     Hue[0.9551562419561594, 1, -4.332663976721096], 
     Hue[1.017410695545231, 1, -4.1468651466956175`], 
     Hue[0.9551568776714211, 1, -3.958428114649813], 
     Hue[1.0208830654675762`, 1, -3.7622682269048076`], 
     Hue[0.9556480793637026, 1, -3.582738330011739], 
     Hue[1.0210810427039783`, 1, -3.387454443446516], 
     Hue[0.9558960191138923, 1, -3.2077968980156832`], 
     Hue[1.0211783079569343`, 1, -3.0129646058791275`], 
     Hue[0.9600653602913999, 1, -2.8212028825924103`], 
     Hue[1.0191462079154026`, 1, -2.644881920930766], 
     Hue[0.9600790344603046, 1, -2.4471197130973037`], 
     Hue[1.0195430430594716`, 1, -2.2696628303364825`], 
     Hue[0.9601090680172361, 1, -2.073227262256304], 
     Hue[1.022826663527566, 1, -1.8860716449606898`], 
     Hue[0.9601749482982004, 1, -1.6997534788034365`], 
     Hue[1.0227704104680952`, 1, -1.5129932153208816`], 
     Hue[0.9603190544989069, 1, -1.3271969996924435`], 
     Hue[1.022647688497834, 1, -1.1413003084020936`], 
     Hue[0.9625705178963156, 1, -0.9508985533779779], 
     Hue[1.024741228490996, 1, -0.7655307364979516], 
     Hue[0.9648907169649736, 1, -0.5798717108449873], 
     Hue[1.029268244252984, 1, -0.38779309919141514`], 
     Hue[0.9729008564260396, 1, -0.20382404444324087`], 
     Hue[1.0350109646257502`, 1, -0.017036609467110386`], 
     Hue[0.9886223282187007, 1, 0.17088855360584954`], 
     Hue[1.0479627052326688`, 1, 0.35947233715857363`], 
     Hue[1.0174340663808343`, 1, 0.5461740186977924], 
     Hue[1.0057644786902546`, 1, 0.7338812848882645], 
     Hue[1.013848297850898, 1, 0.9222652823010264], 
     Hue[1.1324717975692238`, 1, -17.27618334189528], 
     Hue[1.069774397011758, 1, -17.089062133554293`], 
     Hue[1.1295634708832087`, 1, -16.91062086407678], 
     Hue[1.069774397011758, 1, -16.714819716872324`], 
     Hue[1.1295634708832087`, 1, -16.53637844739481], 
     Hue[1.069774397011758, 1, -16.34057730019035], 
     Hue[1.130037987342506, 1, -16.16071983016143], 
     Hue[1.069774397011758, 1, -15.966334883508381`], 
     Hue[1.1303938746869788`, 1, -15.7854152630659], 
     Hue[1.069774397011758, 1, -15.592092466826411`], 
     Hue[1.1343086354761809`, 1, -15.399489191834807`], 
     Hue[1.069774397011758, 1, -15.217850050144438`], 
     Hue[1.1343086354761807`, 1, -15.025246775152837`], 
     Hue[1.0697743970117577`, 1, -14.843607633462467`], 
     Hue[1.1343086354761804`, 1, -14.651004358470864`], 
     Hue[1.0697743970117575`, 1, -14.469365216780501`], 
     Hue[1.1343086354761798`, 1, -14.276761941788898`], 
     Hue[1.069774397011757, 1, -14.095122800098533`], 
     Hue[1.1343086354761784`, 1, -13.90251952510693], 
     Hue[1.0717336907791766`, 1, -13.715032845655912`], 
     Hue[1.1352270544296537`, 1, -13.525536075099662`], 
     Hue[1.071733690779174, 1, -13.340790428973957`], 
     Hue[1.1352270544296468`, 1, -13.151293658417709`], 
     Hue[1.0717336907791681`, 1, -12.966548012292023`], 
     Hue[1.135227054429632, 1, -12.777051241735776`], 
     Hue[1.0717336907791555`, 1, -12.592305595610128`], 
     Hue[1.1352270544295993`, 1, -12.402808825053892`], 
     Hue[1.0717336907791275`, 1, -12.218063178928329`], 
     Hue[1.1352270544295275`, 1, -12.028566408372109`], 
     Hue[1.0727133376627742`, 1, -11.840896993366412`], 
     Hue[1.1356862639061072`, 1, -11.652953475027894`], 
     Hue[1.0727133376626365`, 1, -11.46665457668528], 
     Hue[1.135686263905758, 1, -11.278711058346836`], 
     Hue[1.072713337662334, 1, -11.092412160005145`], 
     Hue[1.1356862639049905`, 1, -10.904468641666865`], 
     Hue[1.073203161103512, 1, -10.716707858887062`], 
     Hue[1.1377603600398327`, 1, -10.524036058062965`], 
     Hue[1.0735705286834072`, 1, -10.341369028883888`], 
     Hue[1.1379268234713351`, 1, -10.149296829100436`], 
     Hue[1.077611572074976, 1, -9.955066065590602], 
     Hue[1.1379823112747223`, 1, -9.774888808342956], 
     Hue[1.0776115720672257`, 1, -9.580823648952244], 
     Hue[1.1379823112562948`, 1, -9.400646391707669], 
     Hue[1.0776115720501849`, 1, -9.206581232366165], 
     Hue[1.1379823112157779`, 1, -9.026403975128344], 
     Hue[1.0776115720127168`, 1, -8.832338815895035], 
     Hue[1.1397579211000295`, 1, -8.646862227575586], 
     Hue[1.0776115719303347`, 1, -8.458096399676647], 
     Hue[1.139757920900093, 1, -8.27261981138879], 
     Hue[1.0776115717491992`, 1, -8.083853984013963], 
     Hue[1.1397579204604875`, 1, -7.898377395795577], 
     Hue[1.0776115713509316`, 1, -7.709611569573135], 
     Hue[1.1397579194939147`, 1, -7.524134981507477], 
     Hue[1.0776115704752496`, 1, -7.3353691578188185`], 
     Hue[1.1397579173686845`, 1, -7.149892570088977], 
     Hue[1.0776115685498637`, 1, -6.961126751971423], 
     Hue[1.1406457175965379`, 1, -6.773000499407071], 
     Hue[1.077611564316465, 1, -6.586884359111726], 
     Hue[1.140645707217184, 1, -6.398758108140782], 
     Hue[1.079570848164441, 1, -6.206794457595414], 
     Hue[1.1415181819828382`, 1, -6.021911765555198], 
     Hue[1.0795708269656492`, 1, -5.8325521567363445`], 
     Hue[1.1415181313028833`, 1, -5.647669471590966], 
     Hue[1.0795707803553192`, 1, -5.458309994717299], 
     Hue[1.1419542678584471`, 1, -5.272125333582345], 
     Hue[1.0795706778720817`, 1, -5.08406813796936], 
     Hue[1.1421721450162847`, 1, -4.897232514009883], 
     Hue[1.0795704525402217`, 1, -4.709826952428102], 
     Hue[1.1458796765340877`, 1, -4.511924463272333], 
     Hue[1.0805495880879474`, 1, -4.332663487565121], 
     Hue[1.1428036000890132`, 1, -4.146862029932401], 
     Hue[1.0805484797165763`, 1, -3.9584270391574856`], 
     Hue[1.1462736568134535`, 1, -3.7622609471983752`], 
     Hue[1.0810358275969054`, 1, -3.5827358933557063`], 
     Hue[1.1464665830588083`, 1, -3.3874383839886573`], 
     Hue[1.0812752927483342`, 1, -3.207791461599701], 
     Hue[1.1465527429859903`, 1, -3.0129292413606574`], 
     Hue[1.085425240328814, 1, -2.8211878856223853`], 
     Hue[1.1444964779782163`, 1, -2.6448068633875517`], 
     Hue[1.0853970774260362`, 1, -2.447086759703895], 
     Hue[1.1447947058028463`, 1, -2.2696316952660887`], 
     Hue[1.0853352137540266`, 1, -2.0731549074110003`], 
     Hue[1.1480042434137903`, 1, -1.8856859538478943`], 
     Hue[1.0851994764303814`, 1, -1.6995948754578032`], 
     Hue[1.1476882086538431`, 1, -1.5121485161842896`], 
     Hue[1.0849023938298494`, 1, -1.3268506039888825`], 
     Hue[1.1469966278511163`, 1, -1.1394590203921895`], 
     Hue[1.0861754362867164`, 1, -0.9500740263584133], 
     Hue[1.146263516851766, 1, -0.7662591540725088], 
     Hue[1.0856749601104634`, 1, -0.5801448839739314], 
     Hue[1.145623011677673, 1, -0.3911516487982727], 
     Hue[1.0888122708609487`, 1, -0.20156626479640405`], 
     Hue[1.1434009110403547`, 1, -0.016757310936488246`], 
     Hue[1.0909792052994898`, 1, 0.17070539178094923`], 
     Hue[1.137810117542184, 1, 0.3596017582078279], 
     Hue[1.0925282458207062`, 1, 0.5466113494816545], 
     Hue[1.0604948877488738`, 1, 0.7345192900148863], 
     Hue[1.0400239637580342`, 1, 0.9216268526345014], 
     Hue[1.2578665986841555`, 1, -17.27618334189528], 
     Hue[1.1951691981266896`, 1, -17.089062133554293`], 
     Hue[1.2549582719981403`, 1, -16.91062086407678], 
     Hue[1.1951691981266896`, 1, -16.714819716872324`], 
     Hue[1.2549582719981403`, 1, -16.53637844739481], 
     Hue[1.1951691981266896`, 1, -16.34057730019035], 
     Hue[1.2554327884574374`, 1, -16.16071983016143], 
     Hue[1.1951691981266896`, 1, -15.966334883508381`], 
     Hue[1.2557886758019103`, 1, -15.7854152630659], 
     Hue[1.1951691981266894`, 1, -15.592092466826411`], 
     Hue[1.2597034365911124`, 1, -15.399489191834807`], 
     Hue[1.1951691981266894`, 1, -15.217850050144438`], 
     Hue[1.2597034365911122`, 1, -15.025246775152837`], 
     Hue[1.1951691981266892`, 1, -14.843607633462467`], 
     Hue[1.259703436591112, 1, -14.651004358470864`], 
     Hue[1.1951691981266888`, 1, -14.469365216780497`], 
     Hue[1.259703436591111, 1, -14.276761941788894`], 
     Hue[1.1951691981266874`, 1, -14.095122800098528`], 
     Hue[1.259703436591109, 1, -13.902519525106923`], 
     Hue[1.1971284918941056`, 1, -13.715032845655903`], 
     Hue[1.2606218555445832`, 1, -13.525536075099646`], 
     Hue[1.1971284918940999`, 1, -13.340790428973937`], 
     Hue[1.2606218555445743`, 1, -13.151293658417673`], 
     Hue[1.1971284918940874`, 1, -12.96654801229198], 
     Hue[1.2606218555445545`, 1, -12.7770512417357], 
     Hue[1.1971284918940597`, 1, -12.592305595610037`], 
     Hue[1.2606218555445112`, 1, -12.40280882505372], 
     Hue[1.197128491893999, 1, -12.218063178928128`], 
     Hue[1.2606218555444157`, 1, -12.028566408371727`], 
     Hue[1.198108138777574, 1, -11.840896993365963`], 
     Hue[1.261081065020944, 1, -11.652953475027054`], 
     Hue[1.1981081387772783`, 1, -11.466654576684292`], 
     Hue[1.2610810650204818`, 1, -11.278711058344989`], 
     Hue[1.1981081387766284`, 1, -11.092412160002976`], 
     Hue[1.2610810650194648`, 1, -10.904468641662806`], 
     Hue[1.1985979622170433`, 1, -10.716707858882266`], 
     Hue[1.2631551611537848`, 1, -10.52403605805388], 
     Hue[1.198965329795261, 1, -10.3413690288733], 
     Hue[1.2633216245841181`, 1, -10.149296829080434`], 
     Hue[1.2030063731831713`, 1, -9.955066065566204], 
     Hue[1.2633771123849336`, 1, -9.77488880829896], 
     Hue[1.2030063731673462`, 1, -9.5808236488986], 
     Hue[1.2633771123608475`, 1, -9.40064639161093], 
     Hue[1.2030063731325509`, 1, -9.206581232248215], 
     Hue[1.263377112307889, 1, -9.026403974915645], 
     Hue[1.2030063730560454`, 1, -8.832338815635692], 
     Hue[1.2651527221659933`, 1, -8.64686222710101], 
     Hue[1.2030063728878309`, 1, -8.458096399106422], 
     Hue[1.2651527219073582`, 1, -8.272619810345324], 
     Hue[1.203006372517973, 1, -8.083853982760196], 
     Hue[1.2651527213386897`, 1, -7.898377393501282], 
     Hue[1.203006371704756, 1, -7.709611566816442], 
     Hue[1.2651527200883428`, 1, -7.524134976462951], 
     Hue[1.2030063699167142`, 1, -7.335369151757605], 
     Hue[1.2651527173391708`, 1, -7.149892558997441], 
     Hue[1.203006365985297, 1, -6.961126738644466], 
     Hue[1.2660405162269457`, 1, -6.773000474841639], 
     Hue[1.2030063573411827`, 1, -6.586884329809379], 
     Hue[1.2660405028693236`, 1, -6.398758054128094], 
     Hue[1.2049656315412631`, 1, -6.206794391712808], 
     Hue[1.266912971240067, 1, -6.021911645947394], 
     Hue[1.2049655890793085`, 1, -5.832552011878497], 
     Hue[1.2669129063459295`, 1, -5.6476692086060565`], 
     Hue[1.2049654957170655`, 1, -5.4583096762145935`], 
     Hue[1.2673490120236517`, 1, -5.272124753295279], 
     Hue[1.2049652904390487`, 1, -5.084067437669797], 
     Hue[1.2675668213286881`, 1, -4.897231235856571], 
     Hue[1.2049648390891747`, 1, -4.7098254126654755`], 
     Hue[1.2712742193003677`, 1, -4.511921567973741], 
     Hue[1.205943479098023, 1, -4.332660064385489], 
     Hue[1.268197803703977, 1, -4.1468558190928], 
     Hue[1.205941279749251, 1, -3.9584195126425], 
     Hue[1.271667217477144, 1, -3.762246906023125], 
     Hue[1.206426232404867, 1, -3.582719253735065], 
     Hue[1.2718586658865327`, 1, -3.3874074631727815`], 
     Hue[1.2066604313611087`, 1, -3.207754777771113], 
     Hue[1.2719415758450003`, 1, -3.012861204597951], 
     Hue[1.2068740928707606`, 1, -2.8328237251759276`], 
     Hue[1.2720014749697757`, 1, -2.6383159030848837`], 
     Hue[1.2107455292615408`, 1, -2.446901137402353], 
     Hue[1.2701081290210543`, 1, -2.2694615725762075`], 
     Hue[1.210628071239235, 1, -2.0727471172506826`], 
     Hue[1.2733371460815, 1, -1.8849536539787806`], 
     Hue[1.2103699671206338`, 1, -1.6986999114859846`], 
     Hue[1.2729457906515758`, 1, -1.5105401996862653`], 
     Hue[1.2098032159842078`, 1, -1.3248908117365563`], 
     Hue[1.2720843296647193`, 1, -1.1359316204776817`], 
     Hue[1.208560757141117, 1, -0.9516208297396125], 
     Hue[1.2701856921264372`, 1, -0.7609322549186148], 
     Hue[1.205729631113932, 1, -0.5799838150719239], 
     Hue[1.2659438853854614`, 1, -0.385417302141952], 
     Hue[1.2017591004699064`, 1, -0.20459511851620604`], 
     Hue[1.255957350671919, 1, -0.011779453100785542`], 
     Hue[1.1928518782415383`, 1, 0.17130189541042773`], 
     Hue[1.2353101210631179`, 1, 0.3595356571353161], 
     Hue[1.1729155418302957`, 1, 0.5466902429110774], 
     Hue[1.195789301120791, 1, 0.7341360942835587], 
     Hue[1.119672932225415, 1, 0.7343825784857169], 
     Hue[1.126503203516666, 1, 0.9221514532074601], 
     Hue[1.0746089367992206`, 1, 0.9217556840356851], 
     Hue[1.3832613997990868`, 1, -17.27618334189528], 
     Hue[1.320563999241621, 1, -17.089062133554293`], 
     Hue[1.3803530731130718`, 1, -16.91062086407678], 
     Hue[1.320563999241621, 1, -16.714819716872324`], 
     Hue[1.3803530731130718`, 1, -16.53637844739481], 
     Hue[1.320563999241621, 1, -16.34057730019035], 
     Hue[1.3808275895723692`, 1, -16.16071983016143], 
     Hue[1.320563999241621, 1, -15.966334883508381`], 
     Hue[1.381183476916842, 1, -15.7854152630659], 
     Hue[1.320563999241621, 1, -15.592092466826411`], 
     Hue[1.3850982377060441`, 1, -15.399489191834807`], 
     Hue[1.320563999241621, 1, -15.217850050144438`], 
     Hue[1.385098237706044, 1, -15.025246775152837`], 
     Hue[1.3205639992416207`, 1, -14.843607633462467`], 
     Hue[1.3850982377060437`, 1, -14.651004358470864`], 
     Hue[1.32056399924162, 1, -14.469365216780497`], 
     Hue[1.3850982377060432`, 1, -14.276761941788891`], 
     Hue[1.3205639992416192`, 1, -14.095122800098522`], 
     Hue[1.385098237706042, 1, -13.902519525106914`], 
     Hue[1.3225232930090374`, 1, -13.715032845655891`], 
     Hue[1.3860166566595176`, 1, -13.52553607509963], 
     Hue[1.3225232930090318`, 1, -13.34079042897391], 
     Hue[1.3860166566595116`, 1, -13.15129365841764], 
     Hue[1.32252329300902, 1, -12.966548012291925`], 
     Hue[1.3860166566594985`, 1, -12.777051241735625`], 
     Hue[1.3225232930089938`, 1, -12.592305595609915`], 
     Hue[1.38601665665947, 1, -12.402808825053555`], 
     Hue[1.3225232930089361`, 1, -12.218063178927858`], 
     Hue[1.3860166566594072`, 1, -12.028566408371368`], 
     Hue[1.3235029398925193`, 1, -11.840896993365368`], 
     Hue[1.3864758661360086`, 1, -11.652953475026262`], 
     Hue[1.3235029398922398`, 1, -11.466654576682984`], 
     Hue[1.3864758661357053`, 1, -11.278711058343246`], 
     Hue[1.3235029398916254`, 1, -11.092412160000098`], 
     Hue[1.3864758661350383`, 1, -10.904468641658973`], 
     Hue[1.3239927633321258`, 1, -10.716707858875923`], 
     Hue[1.3885499622701833`, 1, -10.5240360580454], 
     Hue[1.3243601309105364`, 1, -10.341369028859319`], 
     Hue[1.388716425702285, 1, -10.14929682906178], 
     Hue[1.3284011742991462`, 1, -9.955066065534744], 
     Hue[1.3887719135069854`, 1, -9.77488880825794], 
     Hue[1.3284011742845718`, 1, -9.580823648829426], 
     Hue[1.3887719134914347`, 1, -9.40064639152074], 
     Hue[1.3284011742525268`, 1, -9.206581232096122], 
     Hue[1.3887719134572432`, 1, -9.026403974717338], 
     Hue[1.3284011741820687`, 1, -8.83233881530128], 
     Hue[1.3905475233591034`, 1, -8.646862226662671], 
     Hue[1.3284011740271502`, 1, -8.458096398371145], 
     Hue[1.3905475231941826`, 1, -8.272619809381538], 
     Hue[1.3284011736865267`, 1, -8.083853981143521], 
     Hue[1.3905475228315671`, 1, -7.898377391382177], 
     Hue[1.3284011729375886`, 1, -7.709611563261812], 
     Hue[1.3905475220342742`, 1, -7.524134971803616], 
     Hue[1.3284011712908779`, 1, -7.335369143941942], 
     Hue[1.3905475202812445`, 1, -7.149892548752834], 
     Hue[1.3284011676702092`, 1, -6.961126721459949], 
     Hue[1.3914353214240105`, 1, -6.773000452258144], 
     Hue[1.3284011597093457`, 1, -6.586884292025312], 
     Hue[1.3914353129597528`, 1, -6.39875800447314], 
     Hue[1.3303604357925403`, 1, -6.2067943077157555`], 
     Hue[1.3923077923994964`, 1, -6.021911536495807], 
     Hue[1.3303603970901934`, 1, -5.832551827191858], 
     Hue[1.39230775153323, 1, -5.647668967951759], 
     Hue[1.3303603119942435`, 1, -5.4583092701389555`], 
     Hue[1.392743910794535, 1, -5.2721242235061725`], 
     Hue[1.3303601248912642`, 1, -5.084066544819891], 
     Hue[1.392961837991932, 1, -4.897230070275645], 
     Hue[1.3303597135019476`, 1, -4.709823449530671], 
     Hue[1.396669525861658, 1, -4.5119189791976435`], 
     Hue[1.3313384513154047`, 1, -4.332655724391274], 
     Hue[1.3935936585388582`, 1, -4.146850174138042], 
     Hue[1.3313364570302997`, 1, -3.9584099701484003`], 
     Hue[1.397064478676326, 1, -3.762234377454104], 
     Hue[1.3318218846526637`, 1, -3.58269821528899], 
     Hue[1.3972588941439632`, 1, -3.3873799007966294`], 
     Hue[1.3320571296737773`, 1, -3.207708456657919], 
     Hue[1.3973483288180806`, 1, -3.0128005808606426`], 
     Hue[1.332250159784853, 1, -2.832790293022695], 
     Hue[1.3974132640958041`, 1, -2.6382104010315297`], 
     Hue[1.3361517220176757`, 1, -2.4466720484546327`], 
     Hue[1.395455659721543, 1, -2.2694783852591405`], 
     Hue[1.3360478046532014`, 1, -2.072243309308056], 
     Hue[1.3955483490933616`, 1, -1.8942207503974375`], 
     Hue[1.3358190319790582`, 1, -1.697591676730288], 
     Hue[1.3986269365355677`, 1, -1.509111309383713], 
     Hue[1.3353146368416617`, 1, -1.3224517315109663`], 
     Hue[1.3946896764807277`, 1, -1.143092130900216], 
     Hue[1.334198904504831, 1, -0.9462468588110506], 
     Hue[1.3927945316882466`, 1, -0.7666272807404273], 
     Hue[1.3277851666346145`, 1, -0.5801506148624174], 
     Hue[1.3874969634316727`, 1, -0.3910212135673723], 
     Hue[1.3201705315024832`, 1, -0.20448354408175828`], 
     Hue[1.376776012027904, 1, -0.011220101133827542`], 
     Hue[1.4311290821119933`, 1, 0.1738391424082485], 
     Hue[1.3036658897397766`, 1, 0.17091366515868922`], 
     Hue[1.350046545311964, 1, 0.3601204936011778], 
     Hue[1.3945510507252346`, 1, 0.5472231036645128], 
     Hue[1.270344502753992, 1, 0.5463598928911004], 
     Hue[1.2988372325549018`, 1, 0.7338720643518097], 
     Hue[1.3215044354574859`, 1, 0.9216519373210902], 
     Hue[1.339369499452534, 1, 1.1096890556334245`], 
     Hue[1.205323472545334, 1, 0.9216113528552787], 
     Hue[1.199093794182699, 1, 1.1093799150171209`], 
     Hue[1.1692262039693668`, 1, 1.2970108295391356`], 
     Hue[1.104282543129458, 1, 1.1094712033580956`], 
     Hue[1.0390696688195369`, 1, 1.1093077639523974`], 
     Hue[0.5086562009140185, 1, -17.27618334189528], 
     Hue[1.4459588003565527`, 1, -17.089062133554293`], 
     Hue[0.5057478742280035, 1, -16.91062086407678], 
     Hue[1.4459588003565529`, 1, -16.714819716872324`], 
     Hue[0.5057478742280035, 1, -16.53637844739481], 
     Hue[1.4459588003565527`, 1, -16.34057730019035], 
     Hue[0.5062223906873005, 1, -16.16071983016143], 
     Hue[1.4459588003565527`, 1, -15.966334883508381`], 
     Hue[0.5065782780317736, 1, -15.7854152630659], 
     Hue[1.4459588003565527`, 1, -15.592092466826411`], 
     Hue[0.5104930388209756, 1, -15.399489191834807`], 
     Hue[1.4459588003565527`, 1, -15.217850050144438`], 
     Hue[0.5104930388209756, 1, -15.025246775152837`], 
     Hue[1.4459588003565527`, 1, -14.843607633462467`], 
     Hue[0.5104930388209756, 1, -14.65100435847086], 
     Hue[1.4459588003565524`, 1, -14.469365216780494`], 
     Hue[0.5104930388209756, 1, -14.276761941788891`], 
     Hue[1.445958800356552, 1, -14.095122800098519`], 
     Hue[0.5104930388209759, 1, -13.902519525106912`], 
     Hue[1.4479180941239718`, 1, -13.715032845655884`], 
     Hue[0.5114114577744544, 1, -13.525536075099625`], 
     Hue[1.44791809412397, 1, -13.340790428973895`], 
     Hue[0.5114114577744551, 1, -13.151293658417627`], 
     Hue[1.4479180941239658`, 1, -12.966548012291888`], 
     Hue[0.5114114577744564, 1, -12.777051241735599`], 
     Hue[1.4479180941239562`, 1, -12.592305595609833`], 
     Hue[0.5114114577744595, 1, -12.402808825053496`], 
     Hue[1.4479180941239358`, 1, -12.21806317892768], 
     Hue[0.5114114577744664, 1, -12.028566408371242`], 
     Hue[1.4488977410076016`, 1, -11.840896993364977`], 
     Hue[0.5118706672512219, 1, -11.652953475025985`], 
     Hue[1.448897741007503, 1, -11.466654576682123`], 
     Hue[0.5118706672512563, 1, -11.278711058342633`], 
     Hue[1.4488977410072865`, 1, -11.092412159998208`], 
     Hue[0.5118706672513323, 1, -10.904468641657628`], 
     Hue[1.4493875644486711`, 1, -10.716707858871766`], 
     Hue[0.5139447633881632, 1, -10.524036058042523`], 
     Hue[1.4497549320290308`, 1, -10.341369028850186`], 
     Hue[0.5141112268239285, 1, -10.149296829055467`], 
     Hue[1.4537959754222862`, 1, -9.95506606551476], 
     Hue[0.5141667146366817, 1, -9.77488880824407], 
     Hue[1.4537959754175513`, 1, -9.580823648785488], 
     Hue[0.5141667146388305, 1, -9.400646391490245], 
     Hue[1.4537959754071408`, 1, -9.206581231999515], 
     Hue[0.5141667146435549, 1, -9.026403974650288], 
     Hue[1.4537959753842506`, 1, -8.83233881508887], 
     Hue[0.5159423246332887, 1, -8.646862226518882], 
     Hue[1.4537959753339216`, 1, -8.458096397904109], 
     Hue[0.5159423246592703, 1, -8.272619809065388], 
     Hue[1.4537959752232616`, 1, -8.08385398011664], 
     Hue[0.5159423247163963, 1, -7.898377390687046], 
     Hue[1.4537959749799505`, 1, -7.709611561003983], 
     Hue[0.5159423248420014, 1, -7.524134970275212], 
     Hue[1.4537959744449758`, 1, -7.335369138977588], 
     Hue[0.5159423251181725, 1, -7.14989254539229], 
     Hue[1.4537959732687118`, 1, -6.961126710544691], 
     Hue[0.5168301307821359, 1, -6.7730004449650165`], 
     Hue[1.4537959706824282`, 1, -6.586884268025632], 
     Hue[0.5168301321992222, 1, -6.398757988437537], 
     Hue[1.4557552590700356`, 1, -6.206794255103631], 
     Hue[0.517702633648936, 1, -6.021911501700185], 
     Hue[1.4557552469345665`, 1, -5.832551711512087], 
     Hue[0.5177026408930362, 1, -5.647668891445613], 
     Hue[1.4557552202519546`, 1, -5.458309015790443], 
     Hue[0.5181389066227886, 1, -5.272124056420271], 
     Hue[1.4557551615840523`, 1, -5.084065985575744], 
     Hue[0.5183570679847729, 1, -4.897229704148053], 
     Hue[1.4557550325887911`, 1, -4.70982221989995], 
     Hue[0.5220652983643128, 1, -4.511918222535034], 
     Hue[1.4567344039319976`, 1, -4.3326530251522195`], 
     Hue[0.518990543664144, 1, -4.1468484217614625`], 
     Hue[1.4567337899936892`, 1, -3.958404035133502], 
     Hue[0.5224639908102946, 1, -3.7622307452250556`], 
     Hue[1.457222283294394, 1, -3.5826851763350493`], 
     Hue[0.522664070221496, 1, -3.3873719425502076`], 
     Hue[1.4574642722175395`, 1, -3.207679797128204], 
     Hue[0.5227659615847317, 1, -3.012783111209492], 
     Hue[1.4576415425418863`, 1, -2.8328186881295565`], 
     Hue[0.5228458671169838, 1, -2.6382091666426746`], 
     Hue[1.461609004479794, 1, -2.446534550777449], 
     Hue[0.5209593203920984, 1, -2.2693910551084953`], 
     Hue[1.4615800206860192`, 1, -2.071940646914131], 
     Hue[0.5211377984700472, 1, -1.8941641608568032`], 
     Hue[1.4615161420855265`, 1, -1.6969245454818267`], 
     Hue[0.5211892847402915, 1, -1.5187729915008326`], 
     Hue[1.4613749555171454`, 1, -1.3209768337921142`], 
     Hue[0.5209377232900834, 1, -1.1430835985774401`], 
     Hue[1.4568533748401329`, 1, -0.9556162672504154], 
     Hue[0.5196352155017714, 1, -0.767839404644078], 
     Hue[1.4543387147407656`, 1, -0.5785888933142165], 
     Hue[0.5176429510353406, 1, -0.38856336807408276`], 
     Hue[1.447392852161281, 1, -0.20228757143134124`], 
     Hue[0.5091109671465819, 1, -0.014335284013591076`], 
     Hue[0.5753520489784494, 1, 0.17134604569330936`], 
     Hue[1.4883260639440037`, 1, 0.3584959386620723], 
     Hue[0.5558982975407871, 1, 0.5474720683733473], 
     Hue[1.4407478475216724`, 1, 0.7342912592228235], 
     Hue[1.4945671090198809`, 1, 0.9218219213318573], 
     Hue[0.5715109446578666, 1, 1.1093744989312242`], 
     Hue[1.3535779759076618`, 1, 1.2980496430733888`], 
     Hue[0.9857020507802604, 1, 1.2970730774786026`], 
     Hue[1.004822659610949, 1, 1.1094764978125486`], 
     Hue[0.6340510020289498, 1, -17.27618334189528], 
     Hue[0.5713536014714842, 1, -17.089062133554293`], 
     Hue[0.6311426753429346, 1, -16.91062086407678], 
     Hue[0.5713536014714842, 1, -16.714819716872324`], 
     Hue[0.6311426753429346, 1, -16.53637844739481], 
     Hue[0.5713536014714842, 1, -16.34057730019035], 
     Hue[0.6316171918022317, 1, -16.16071983016143], 
     Hue[0.5713536014714842, 1, -15.966334883508381`], 
     Hue[0.6319730791467048, 1, -15.7854152630659], 
     Hue[0.5713536014714842, 1, -15.592092466826411`], 
     Hue[0.6358878399359068, 1, -15.399489191834807`], 
     Hue[0.5713536014714842, 1, -15.217850050144438`], 
     Hue[0.6358878399359069, 1, -15.025246775152837`], 
     Hue[0.5713536014714844, 1, -14.843607633462467`], 
     Hue[0.6358878399359073, 1, -14.651004358470864`], 
     Hue[0.5713536014714846, 1, -14.469365216780494`], 
     Hue[0.6358878399359078, 1, -14.276761941788891`], 
     Hue[0.5713536014714852, 1, -14.095122800098519`], 
     Hue[0.6358878399359094, 1, -13.902519525106916`], 
     Hue[0.5733128952389073, 1, -13.715032845655884`], 
     Hue[0.6368062588893912, 1, -13.525536075099632`], 
     Hue[0.5733128952389098, 1, -13.340790428973897`], 
     Hue[0.636806258889398, 1, -13.151293658417643`], 
     Hue[0.5733128952389157, 1, -12.966548012291891`], 
     Hue[0.636806258889413, 1, -12.777051241735634`], 
     Hue[0.5733128952389288, 1, -12.592305595609842`], 
     Hue[0.636806258889446, 1, -12.40280882505358], 
     Hue[0.5733128952389572, 1, -12.2180631789277], 
     Hue[0.6368062588895185, 1, -12.028566408371422`], 
     Hue[0.5742925421227327, 1, -11.840896993365021`], 
     Hue[0.6372654683664187, 1, -11.652953475026385`], 
     Hue[0.5742925421228731, 1, -11.466654576682219`], 
     Hue[0.6372654683667709, 1, -11.278711058343514`], 
     Hue[0.5742925421231819, 1, -11.092412159998418`], 
     Hue[0.637265468367545, 1, -10.904468641659564`], 
     Hue[0.5747823655657276, 1, -10.71670785887225], 
     Hue[0.6393395645059287, 1, -10.524036058046942`], 
     Hue[0.575149733148645, 1, -10.34136902885128], 
     Hue[0.6395060279450941, 1, -10.149296829065216`], 
     Hue[0.5791907765477535, 1, -9.95506606551803], 
     Hue[0.6395615157653223, 1, -9.774888808265523], 
     Hue[0.5791907765556484, 1, -9.580823648792679], 
     Hue[0.6395615157839041, 1, -9.400646391537414], 
     Hue[0.5791907765730072, 1, -9.206581232015326], 
     Hue[0.6395615158247603, 1, -9.026403974754004], 
     Hue[0.5791907766111744, 1, -8.832338815123633], 
     Hue[0.6413371258947016, 1, -8.64686222675438], 
     Hue[0.5791907766950934, 1, -8.458096397980544], 
     Hue[0.6413371260962744, 1, -8.272619809583178], 
     Hue[0.5791907768796087, 1, -8.083853980284697], 
     Hue[0.6413371265394779, 1, -7.898377391825529], 
     Hue[0.5791907772853078, 1, -7.70961156137349], 
     Hue[0.6413371275139619, 1, -7.524134972778428], 
     Hue[0.5791907781773291, 1, -7.335369139790035], 
     Hue[0.6413371296565864, 1, -7.149892550896179], 
     Hue[0.5791907801386409, 1, -6.961126712331041], 
     Hue[0.6422249394436165, 1, -6.77300045726009], 
     Hue[0.5791907844510318, 1, -6.5868842719533305`], 
     Hue[0.6422249499069592, 1, -6.3987580154710555`], 
     Hue[0.5811500883133731, 1, -6.2067942648807275`], 
     Hue[0.6430974713371481, 1, -6.021911562065578], 
     Hue[0.5811501098962126, 1, -5.832551733009269], 
     Hue[0.6430975224226634, 1, -5.6476690241727505`], 
     Hue[0.5811501573510318, 1, -5.458309063056938], 
     Hue[0.6435338847636931, 1, -5.272124350501811], 
     Hue[0.5811502616914241, 1, -5.084066089502142], 
     Hue[0.6437522585681187, 1, -4.897230353235751], 
     Hue[0.5811504911083717, 1, -4.709822448407015], 
     Hue[0.6474609643611784, 1, -4.511919743902134], 
     Hue[0.5821306583636904, 1, -4.332653557393664], 
     Hue[0.6443872309319045, 1, -4.146851594715065], 
     Hue[0.5821317865975528, 1, -3.958405205418207], 
     Hue[0.6478629774583453, 1, -3.762238150171995], 
     Hue[0.5826241295822198, 1, -3.5826878222816854`], 
     Hue[0.6480680790857528, 1, -3.3873882799923525`], 
     Hue[0.5828745855567294, 1, -3.207685695806414], 
     Hue[0.6481810142487573, 1, -3.0128190990555037`], 
     Hue[0.5830704898805656, 1, -2.832831794005245], 
     Hue[0.6482852095773497, 1, -2.638288422647607], 
     Hue[0.5870805373302208, 1, -2.4465698560712967`], 
     Hue[0.6464516026089404, 1, -2.269559933941226], 
     Hue[0.5871436485383057, 1, -2.0720183816578333`], 
     Hue[0.6501147596321174, 1, -1.8845194900183408`], 
     Hue[0.5872827021329288, 1, -1.6970959868629094`], 
     Hue[0.650435620145696, 1, -1.509583853490682], 
     Hue[0.5875898478552346, 1, -1.3213563367000833`], 
     Hue[0.6511444030296434, 1, -1.1338205109096091`], 
     Hue[0.5842579740343241, 1, -0.9556117054611042], 
     Hue[0.6510712266091383, 1, -0.7609949701555823], 
     Hue[0.5836620241724748, 1, -0.5799953797653676], 
     Hue[0.6498641233621515, 1, -0.3924295174227148], 
     Hue[0.5825563696003457, 1, -0.20164560965941591`], 
     Hue[0.6535977862949898, 1, -0.012262123533038238`], 
     Hue[0.6539262335740617, 1, 0.3585352757836693], 
     Hue[0.6481827716186735, 1, 0.7341289125128676], 
     Hue[0.8524215914333906, 1, 1.1096968994495984`], 
     Hue[0.9426434887542339, 1, 1.1093012484538183`], 
     Hue[0.9116175485573769, 1, 1.297004517778448], 
     Hue[0.9727526883175246, 1, 1.1093992726551616`], 
     Hue[0.9891763122918733, 1, 1.1095536693484014`], 
     Hue[0.7594458031438815, 1, -17.27618334189528], 
     Hue[0.6967484025864157, 1, -17.089062133554293`], 
     Hue[0.7565374764578661, 1, -16.91062086407678], 
     Hue[0.6967484025864157, 1, -16.714819716872324`], 
     Hue[0.7565374764578661, 1, -16.53637844739481], 
     Hue[0.6967484025864157, 1, -16.34057730019035], 
     Hue[0.7570119929171635, 1, -16.16071983016143], 
     Hue[0.6967484025864157, 1, -15.966334883508381`], 
     Hue[0.7573678802616365, 1, -15.7854152630659], 
     Hue[0.6967484025864157, 1, -15.592092466826411`], 
     Hue[0.7612826410508383, 1, -15.399489191834807`], 
     Hue[0.6967484025864158, 1, -15.217850050144438`], 
     Hue[0.7612826410508385, 1, -15.025246775152837`], 
     Hue[0.6967484025864161, 1, -14.843607633462467`], 
     Hue[0.7612826410508389, 1, -14.651004358470864`], 
     Hue[0.6967484025864166, 1, -14.469365216780497`], 
     Hue[0.7612826410508398, 1, -14.276761941788894`], 
     Hue[0.6967484025864177, 1, -14.095122800098524`], 
     Hue[0.7612826410508415, 1, -13.902519525106923`], 
     Hue[0.6987076963538412, 1, -13.715032845655893`], 
     Hue[0.7622010600043245, 1, -13.52553607509965], 
     Hue[0.6987076963538469, 1, -13.340790428973916`], 
     Hue[0.7622010600043334, 1, -13.151293658417679`], 
     Hue[0.6987076963538594, 1, -12.966548012291932`], 
     Hue[0.7622010600043532, 1, -12.777051241735714`], 
     Hue[0.6987076963538872, 1, -12.592305595609934`], 
     Hue[0.7622010600043965, 1, -12.402808825053754`], 
     Hue[0.698707696353948, 1, -12.218063178927903`], 
     Hue[0.7622010600044918, 1, -12.028566408371804`], 
     Hue[0.6996873432377944, 1, -11.840896993365472`], 
     Hue[0.762660269481442, 1, -11.652953475027227`], 
     Hue[0.699687343238091, 1, -11.466654576683213`], 
     Hue[0.7626602694819042, 1, -11.278711058345365`], 
     Hue[0.6996873432387434, 1, -11.092412160000604`], 
     Hue[0.7626602694829204, 1, -10.904468641663637`], 
     Hue[0.7001771666820434, 1, -10.716707858877086`], 
     Hue[0.7647343656218095, 1, -10.524036058056055`], 
     Hue[0.7005445342666191, 1, -10.34136902886196], 
     Hue[0.7649008290621074, 1, -10.14929682908528], 
     Hue[0.7045855776693402, 1, -9.955066065542626], 
     Hue[0.7649563168848276, 1, -9.774888808309658], 
     Hue[0.7045855776852123, 1, -9.580823648846762], 
     Hue[0.7649563169088922, 1, -9.400646391634456], 
     Hue[0.7045855777201109, 1, -9.206581232134235], 
     Hue[0.7649563169618038, 1, -9.02640397496737], 
     Hue[0.7045855777968435, 1, -8.832338815385082], 
     Hue[0.7667319270570208, 1, -8.646862227230383], 
     Hue[0.7045855779655574, 1, -8.458096398555401], 
     Hue[0.7667319273153982, 1, -8.272619810629779], 
     Hue[0.7045855783365133, 1, -8.083853981548652], 
     Hue[0.7667319278834999, 1, -7.89837739412672], 
     Hue[0.7045855791521443, 1, -7.709611564152584], 
     Hue[0.7667319291326004, 1, -7.524134977838119], 
     Hue[0.7045855809454946, 1, -7.335369145900509], 
     Hue[0.766731931879032, 1, -7.149892562021061], 
     Hue[0.7045855848885831, 1, -6.961126725766307], 
     Hue[0.7676197429612786, 1, -6.773000481897889], 
     Hue[0.7045855935583605, 1, -6.586884301493817], 
     Hue[0.7676197563048391, 1, -6.398758069642863], 
     Hue[0.7065449069465057, 1, -6.206794331285407], 
     Hue[0.7684922839115298, 1, -6.021911682018682], 
     Hue[0.7065449495288905, 1, -5.832551879015107], 
     Hue[0.7684923487337731, 1, -5.647669287916988], 
     Hue[0.7065450431559721, 1, -5.4583093840842105`], 
     Hue[0.7689287408958061, 1, -5.272124932447748], 
     Hue[0.7065452490165174, 1, -5.084066795354708], 
     Hue[0.7691471802275432, 1, -4.89723163502665], 
     Hue[0.7065457016482783, 1, -4.70982400038968], 
     Hue[0.7728560141730451, 1, -4.511922646730739], 
     Hue[0.7075263581501847, 1, -4.332657007449702], 
     Hue[0.7697826088082986, 1, -4.146857823052282], 
     Hue[0.7075285636358071, 1, -3.9584127912747284`], 
     Hue[0.7732589719684324, 1, -3.762252227902316], 
     Hue[0.7080232712790533, 1, -3.5827045934751744`], 
     Hue[0.7734654940316545, 1, -3.3874192822561318`], 
     Hue[0.7082789258130677, 1, -3.207722674643131], 
     Hue[0.7735815497522863, 1, -3.012887321150698], 
     Hue[0.7085168809540258, 1, -2.832821931102055], 
     Hue[0.7737050329695525, 1, -2.63840142773906], 
     Hue[0.7125210409316904, 1, -2.446757100797666], 
     Hue[0.7719783966301569, 1, -2.26957710260874], 
     Hue[0.71263890009662, 1, -2.0724304227864048`], 
     Hue[0.7755681602521582, 1, -1.8852549108521839`], 
     Hue[0.7128981869852999, 1, -1.698003602707481], 
     Hue[0.7759581228679642, 1, -1.5112025547534318`], 
     Hue[0.7134689925191251, 1, -1.3233599239108809`], 
     Hue[0.7768144333915589, 1, -1.1373877685054479`], 
     Hue[0.714727390652147, 1, -0.9482556303005605], 
     Hue[0.7786916623745628, 1, -0.7641323581025286], 
     Hue[0.717509898314423, 1, -0.5722180958120011], 
     Hue[0.7827902719123945, 1, -0.3922825995522152], 
     Hue[0.7215737799236659, 1, -0.20002817930946026`], 
     Hue[0.7962068542031817, 1, -0.013287128658944214`], 
     Hue[0.7318092589744042, 1, 0.17226192253280714`], 
     Hue[0.8247884042324307, 1, 0.35904434476908975`], 
     Hue[0.7605100926824659, 1, 0.546199551629023], 
     Hue[0.884840604258813, 1, -17.27618334189528], 
     Hue[0.8221432037013471, 1, -17.089062133554293`], 
     Hue[0.8819322775727978, 1, -16.91062086407678], 
     Hue[0.8221432037013471, 1, -16.714819716872324`], 
     Hue[0.8819322775727978, 1, -16.53637844739481], 
     Hue[0.8221432037013471, 1, -16.34057730019035], 
     Hue[0.8824067940320949, 1, -16.16071983016143], 
     Hue[0.8221432037013471, 1, -15.966334883508381`], 
     Hue[0.8827626813765679, 1, -15.7854152630659], 
     Hue[0.8221432037013472, 1, -15.592092466826411`], 
     Hue[0.8866774421657697, 1, -15.399489191834807`], 
     Hue[0.8221432037013473, 1, -15.217850050144438`], 
     Hue[0.8866774421657698, 1, -15.025246775152837`], 
     Hue[0.8221432037013475, 1, -14.843607633462467`], 
     Hue[0.8866774421657702, 1, -14.651004358470864`], 
     Hue[0.822143203701348, 1, -14.469365216780497`], 
     Hue[0.8866774421657706, 1, -14.276761941788898`], 
     Hue[0.8221432037013492, 1, -14.09512280009853], 
     Hue[0.8866774421657718, 1, -13.902519525106932`], 
     Hue[0.8241024974687726, 1, -13.715032845655905`], 
     Hue[0.8875958611192533, 1, -13.525536075099664`], 
     Hue[0.8241024974687781, 1, -13.340790428973941`], 
     Hue[0.8875958611192591, 1, -13.151293658417712`], 
     Hue[0.8241024974687898, 1, -12.96654801229199], 
     Hue[0.887595861119272, 1, -12.777051241735789`], 
     Hue[0.8241024974688159, 1, -12.592305595610055`], 
     Hue[0.8875958611193002, 1, -12.402808825053915`], 
     Hue[0.8241024974688733, 1, -12.21806317892817], 
     Hue[0.8875958611193623, 1, -12.02856640837216], 
     Hue[0.8250821443527103, 1, -11.840896993366067`], 
     Hue[0.8880550705962381, 1, -11.652953475028015`], 
     Hue[0.8250821443529883, 1, -11.46665457668452], 
     Hue[0.888055070596538, 1, -11.2787110583471], 
     Hue[0.8250821443535997, 1, -11.09241216000348], 
     Hue[0.8880550705971973, 1, -10.90446864166745], 
     Hue[0.825571967796803, 1, -10.716707858883426`], 
     Hue[0.890129166735246, 1, -10.52403605806449], 
     Hue[0.8259393353811603, 1, -10.34136902887593], 
     Hue[0.8902956301737422, 1, -10.149296829103836`], 
     Hue[0.8299803787831235, 1, -9.955066065574055], 
     Hue[0.890351117992503, 1, -9.774888808350466], 
     Hue[0.8299803787976195, 1, -9.580823648915862], 
     Hue[0.8903511180078691, 1, -9.40064639172418], 
     Hue[0.8299803788294923, 1, -9.20658123228617], 
     Hue[0.8903511180416553, 1, -9.026403975164648], 
     Hue[0.8299803788995718, 1, -8.83233881571915], 
     Hue[0.8921267280923204, 1, -8.646862227666384], 
     Hue[0.8299803790536576, 1, -8.458096399289921], 
     Hue[0.892126728255241, 1, -8.272619811588429], 
     Hue[0.8299803793924502, 1, -8.08385398316366], 
     Hue[0.892126728613459, 1, -7.898377396234529], 
     Hue[0.8299803801373629, 1, -7.70961156770355], 
     Hue[0.8921267294010825, 1, -7.524134982472616], 
     Hue[0.8299803817752227, 1, -7.33536915370811], 
     Hue[0.8921267311328521, 1, -7.149892572211058], 
     Hue[0.82998038537643, 1, -6.961126742933097], 
     Hue[0.8930145399191968, 1, -6.773000504359384], 
     Hue[0.8299803932945033, 1, -6.586884339238912], 
     Hue[0.8930145482796301, 1, -6.398758119029567], 
     Hue[0.8319397046459789, 1, -6.206794415185439], 
     Hue[0.893887064619055, 1, -6.021911790871232], 
     Hue[0.8319397431341444, 1, -5.832552063488402], 
     Hue[0.8938871049783615, 1, -5.647669527253993], 
     Hue[0.8319398277590945, 1, -5.458309789690658], 
     Hue[0.8943234425979393, 1, -5.272125459317295], 
     Hue[0.8319400138261179, 1, -5.084067687172481], 
     Hue[0.8945417619281335, 1, -4.897232794159468], 
     Hue[0.8319404229359291, 1, -4.709825961252629], 
     Hue[0.8982503012525769, 1, -4.511925220371656], 
     Hue[0.8329209737109976, 1, -4.332661342139542], 
     Hue[0.8951763374516227, 1, -4.1468634363437324`], 
     Hue[0.8329229567264651, 1, -3.9584223220443224`], 
     Hue[0.8986512712977086, 1, -3.762264682064319], 
     Hue[0.8334171506215292, 1, -3.582725605106484], 
     Hue[0.8988547758167048, 1, -3.38744667800158], 
     Hue[0.8336716722523339, 1, -3.207768934475892], 
     Hue[0.8989641940836002, 1, -3.0129475658885676`], 
     Hue[0.8339358111610635, 1, -2.8328381344937537`], 
     Hue[0.8990847191159039, 1, -2.638499111411175], 
     Hue[0.8379036026910065, 1, -2.446985758085538], 
     Hue[0.89739354397142, 1, -2.2696359053205244`], 
     Hue[0.8380066762927595, 1, -2.072933066159468], 
     Hue[0.9008298665637148, 1, -1.8858967753029823`], 
     Hue[0.8382330175399362, 1, -1.6991082353026743`], 
     Hue[0.9010597187404998, 1, -1.5126104369045927`], 
     Hue[0.8387292812222199, 1, -1.325786049425172], 
     Hue[0.9015618617853156, 1, -1.1404668793304367`], 
     Hue[0.8398136730979101, 1, -0.9535767933099557], 
     Hue[0.904294592229419, 1, -0.7660386220514848], 
     Hue[0.8441424374493935, 1, -0.5782640943027955], 
     Hue[0.9121549338508534, 1, -0.38629782031494364`], 
     Hue[0.8531483122351348, 1, -0.2039123836622787], 
     Hue[0.9236924429140801, 1, -0.016796090739660485`], 
     Hue[0.8748114668955543, 1, 0.1717603662646645], 
     Hue[0.9538346451793375, 1, 0.35960045416642283`], 
     Hue[0.9281407470590506, 1, 0.5472230230658147], 
     Hue[0.9238349400425253, 1, 0.7343165951416055], 
     Hue[0.9826519410620869, 1, 0.921666152359766], 
     Hue[1.0102354053737443`, 1, -17.27618334189528], 
     Hue[0.9475380048162788, 1, -17.089062133554293`], 
     Hue[1.0073270786877293`, 1, -16.91062086407678], 
     Hue[0.9475380048162788, 1, -16.714819716872324`], 
     Hue[1.0073270786877293`, 1, -16.53637844739481], 
     Hue[0.9475380048162788, 1, -16.34057730019035], 
     Hue[1.0078015951470263`, 1, -16.16071983016143], 
     Hue[0.9475380048162788, 1, -15.966334883508381`], 
     Hue[1.0081574824914994`, 1, -15.7854152630659], 
     Hue[0.9475380048162788, 1, -15.592092466826411`], 
     Hue[1.0120722432807014`, 1, -15.399489191834807`], 
     Hue[0.9475380048162789, 1, -15.217850050144438`], 
     Hue[1.0120722432807014`, 1, -15.025246775152837`], 
     Hue[0.9475380048162789, 1, -14.843607633462467`], 
     Hue[1.0120722432807014`, 1, -14.651004358470868`], 
     Hue[0.9475380048162791, 1, -14.469365216780501`], 
     Hue[1.0120722432807012`, 1, -14.276761941788898`], 
     Hue[0.9475380048162796, 1, -14.095122800098533`], 
     Hue[1.0120722432807012`, 1, -13.902519525106934`], 
     Hue[0.9494972985837011, 1, -13.715032845655912`], 
     Hue[1.0129906622341796`, 1, -13.52553607509967], 
     Hue[0.949497298583703, 1, -13.340790428973959`], 
     Hue[1.0129906622341789`, 1, -13.151293658417725`], 
     Hue[0.9494972985837071, 1, -12.966548012292026`], 
     Hue[1.012990662234177, 1, -12.777051241735814`], 
     Hue[0.9494972985837163, 1, -12.592305595610137`], 
     Hue[1.0129906622341736`, 1, -12.402808825053972`], 
     Hue[0.9494972985837363, 1, -12.218063178928347`], 
     Hue[1.0129906622341658`, 1, -12.028566408372285`], 
     Hue[0.9504769454674898, 1, -11.840896993366453`], 
     Hue[1.013449871710887, 1, -11.652953475028285`], 
     Hue[0.9504769454675854, 1, -11.466654576685372`], 
     Hue[1.013449871710848, 1, -11.278711058347694`], 
     Hue[0.9504769454677955, 1, -11.092412160005349`], 
     Hue[1.0134498717107618`, 1, -10.904468641668753`], 
     Hue[0.9509667689101071, 1, -10.716707858887533`], 
     Hue[1.0155239678471197`, 1, -10.524036058067278`], 
     Hue[0.9513341364924988, 1, -10.341369028884959`], 
     Hue[1.0156904312819408`, 1, -10.14929682910995], 
     Hue[0.9553751798897807, 1, -9.955066065593794], 
     Hue[1.015745919092624, 1, -9.774888808363897], 
     Hue[0.955375179894358, 1, -9.580823648959262], 
     Hue[1.0157459190902365`, 1, -9.400646391753712], 
     Hue[0.9553751799044223, 1, -9.206581232381598], 
     Hue[1.0157459190849871`, 1, -9.026403975229583], 
     Hue[0.9553751799265511, 1, -8.832338815928965], 
     Hue[1.017521529047528, 1, -8.64686222780545], 
     Hue[0.9553751799752062, 1, -8.458096399751252], 
     Hue[1.0175215290189827`, 1, -8.272619811894197], 
     Hue[0.9553751800821852, 1, -8.083853984177999], 
     Hue[1.0175215289562196`, 1, -7.898377396906828], 
     Hue[0.9553751803174034, 1, -7.709611569933803], 
     Hue[1.0175215288182207`, 1, -7.524134983950813], 
     Hue[0.9553751808345838, 1, -7.335369158611832], 
     Hue[1.0175215285147983`, 1, -7.149892575461215], 
     Hue[0.9553751819717227, 1, -6.961126753715043], 
     Hue[1.0184093327670944`, 1, -6.773000511408044], 
     Hue[0.9553751844719808, 1, -6.586884362945471], 
     Hue[1.0184093312176086`, 1, -6.398758134527647], 
     Hue[0.9573344834245271, 1, -6.206794467138635], 
     Hue[1.0192818254857958`, 1, -6.021911824476591], 
     Hue[0.95733449513746, 1, -5.8325521777192755`], 
     Hue[1.01928181759852, 1, -5.647669601142965], 
     Hue[0.9573345208909854, 1, -5.458310040852993], 
     Hue[1.0197180484541728`, 1, -5.2721256206279365`], 
     Hue[0.9573345775158622, 1, -5.084068239408928], 
     Hue[1.0199361329716217`, 1, -4.897233147563978], 
     Hue[0.957334702018019, 1, -4.709827175464853], 
     Hue[1.0236441285254139`, 1, -4.511925948209542], 
     Hue[0.9583146144152457, 1, -4.33266400705252], 
     Hue[1.0205690488938424`, 1, -4.146865126812239], 
     Hue[0.958315206425488, 1, -3.9584281813385003`], 
     Hue[1.0240413498654635`, 1, -3.7622681741031716`], 
     Hue[0.9588063113321924, 1, -3.58273847546039], 
     Hue[1.0242391775535316`, 1, -3.3874543261931684`], 
     Hue[0.9590540382268645, 1, -3.2077972164773287`], 
     Hue[1.024336114010151, 1, -3.012964346838827], 
     Hue[0.9632228835485587, 1, -2.8212035322389832`], 
     Hue[1.0223033060754658`, 1, -2.6448814086238155`], 
     Hue[0.9632354966645751, 1, -2.4471211405332944`], 
     Hue[1.022698564992429, 1, -2.269661680149343], 
     Hue[0.9632631996101154, 1, -2.073230396166413], 
     Hue[1.025978617762759, 1, -1.8860686679030942`], 
     Hue[0.9633239668688391, 1, -1.6997603470992988`], 
     Hue[1.0259146611531125`, 1, -1.512986701536221], 
     Hue[0.9634568855488864, 1, -1.3272119941254632`], 
     Hue[1.0257751297863955`, 1, -1.141286139058071], 
     Hue[0.9656833346257748, 1, -0.9509297534400158], 
     Hue[1.0278314696803608`, 1, -0.7654968257981749], 
     Hue[0.9679492422560334, 1, -0.5799355578969183], 
     Hue[1.0322764246753222`, 1, -0.3877053131068293], 
     Hue[0.9758367402425763, 1, -0.20393193386367425`], 
     Hue[1.0377832090492196`, 1, -0.017001856894416134`], 
     Hue[0.9912855405057167, 1, 0.1707951411661185], 
     Hue[1.0504175011224757`, 1, 0.3601428561611], 
     Hue[1.0193931322763148`, 1, 0.546169158089726], 
     Hue[1.0072437936645735`, 1, 0.7338937886736852], 
     Hue[1.0143937258153777`, 1, 0.9217817368369039], 
     Hue[1.135630206488676, 1, -17.27618334189528], 
     Hue[1.0729328059312102`, 1, -17.089062133554293`], 
     Hue[1.1327218798026606`, 1, -16.91062086407678], 
     Hue[1.0729328059312102`, 1, -16.714819716872324`], 
     Hue[1.1327218798026608`, 1, -16.53637844739481], 
     Hue[1.0729328059312102`, 1, -16.34057730019035], 
     Hue[1.133196396261958, 1, -16.16071983016143], 
     Hue[1.0729328059312102`, 1, -15.966334883508381`], 
     Hue[1.133552283606431, 1, -15.7854152630659], 
     Hue[1.0729328059312102`, 1, -15.592092466826411`], 
     Hue[1.1374670443956327`, 1, -15.399489191834807`], 
     Hue[1.0729328059312102`, 1, -15.217850050144438`], 
     Hue[1.1374670443956325`, 1, -15.025246775152837`], 
     Hue[1.07293280593121, 1, -14.843607633462467`], 
     Hue[1.1374670443956323`, 1, -14.651004358470864`], 
     Hue[1.0729328059312098`, 1, -14.469365216780501`], 
     Hue[1.1374670443956316`, 1, -14.276761941788898`], 
     Hue[1.0729328059312093`, 1, -14.095122800098533`], 
     Hue[1.1374670443956303`, 1, -13.90251952510693], 
     Hue[1.074892099698629, 1, -13.715032845655912`], 
     Hue[1.138385463349106, 1, -13.525536075099662`], 
     Hue[1.0748920996986264`, 1, -13.340790428973955`], 
     Hue[1.138385463349099, 1, -13.151293658417709`], 
     Hue[1.0748920996986202`, 1, -12.966548012292021`], 
     Hue[1.138385463349084, 1, -12.777051241735775`], 
     Hue[1.074892099698607, 1, -12.592305595610126`], 
     Hue[1.1383854633490507`, 1, -12.402808825053889`], 
     Hue[1.074892099698578, 1, -12.218063178928327`], 
     Hue[1.1383854633489776`, 1, -12.0285664083721], 
     Hue[1.075871746582222, 1, -11.840896993366405`], 
     Hue[1.138844672825555, 1, -11.652953475027877`], 
     Hue[1.0758717465820788`, 1, -11.466654576685263`], 
     Hue[1.1388446728251997`, 1, -11.278711058346797`], 
     Hue[1.075871746581764, 1, -11.09241216000511], 
     Hue[1.138844672824419, 1, -10.904468641666782`], 
     Hue[1.0763615700229154`, 1, -10.716707858886988`], 
     Hue[1.1409187689592322`, 1, -10.524036058062775`], 
     Hue[1.0767289376027516`, 1, -10.341369028883724`], 
     Hue[1.1410852323906713`, 1, -10.149296829100017`], 
     Hue[1.0807699809941878`, 1, -9.955066065590211], 
     Hue[1.1411407201939188`, 1, -9.774888808342038], 
     Hue[1.080769980986149, 1, -9.580823648951387], 
     Hue[1.1411407201751844`, 1, -9.400646391705651], 
     Hue[1.080769980968474, 1, -9.20658123236428], 
     Hue[1.141140720133993, 1, -9.026403975123907], 
     Hue[1.0807699809296116`, 1, -8.832338815890889], 
     Hue[1.1429163300167682`, 1, -8.646862227565627], 
     Hue[1.0807699808441635`, 1, -8.458096399667529], 
     Hue[1.1429163298135787`, 1, -8.27261981136689], 
     Hue[1.0807699806562867`, 1, -8.083853983993919], 
     Hue[1.142916329366821, 1, -7.898377395747429], 
     Hue[1.0807699802431965`, 1, -7.709611569529062], 
     Hue[1.1429163283845218`, 1, -7.524134981401613], 
     Hue[1.0807699793349237`, 1, -7.335369157721915], 
     Hue[1.1429163262247142`, 1, -7.149892569856218], 
     Hue[1.0807699773378794`, 1, -6.961126751758358], 
     Hue[1.1438041263767251`, 1, -6.773000498890102], 
     Hue[1.0807699729469236`, 1, -6.586884358643253], 
     Hue[1.1438041158304297`, 1, -6.398758107004108], 
     Hue[1.0827292564449538`, 1, -6.2067944565290585`], 
     Hue[1.1446765902299507`, 1, -6.021911763031186], 
     Hue[1.0827292344802475`, 1, -5.83255215439172], 
     Hue[1.1446765387440434`, 1, -5.6476694660413544`], 
     Hue[1.0827291861858817`, 1, -5.458309989562113], 
     Hue[1.1451126735298645`, 1, -5.272125321320166], 
     Hue[1.0827290799999125`, 1, -5.084068126634536], 
     Hue[1.1453305467967985`, 1, -4.897232486982558], 
     Hue[1.0827288465267755`, 1, -4.709826927506042], 
     Hue[1.1490380698660827`, 1, -4.511924401345557], 
     Hue[1.083707964085766, 1, -4.332663431824768], 
     Hue[1.1459619745333371`, 1, -4.1468618983424355`], 
     Hue[1.0837068162509411`, 1, -3.9584269166027015`], 
     Hue[1.1494319904387684`, 1, -3.7622606465183717`], 
     Hue[1.084194077153132, 1, -3.5827356216104453`], 
     Hue[1.1496248264934916`, 1, -3.3874377214680296`], 
     Hue[1.084433351055061, 1, -3.2077908616475383`], 
     Hue[1.1497107881089847`, 1, -3.012927783251601], 
     Hue[1.0885828701166258`, 1, -2.8211864706073007`], 
     Hue[1.1476540836107483`, 1, -2.6448037291546242`], 
     Hue[1.088553773566342, 1, -2.44708365031061], 
     Hue[1.1479513493658733`, 1, -2.26962478050004], 
     Hue[1.0884898582813287`, 1, -2.0731480795832153`], 
     Hue[1.1511587962660181`, 1, -1.885670201050696], 
     Hue[1.0883496159366854`, 1, -1.6995799057407617`], 
     Hue[1.1508381283764, 1, -1.5121139813698632`], 
     Hue[1.0880426566511983`, 1, -1.326817895408744], 
     Hue[1.150136320627425, 1, -1.1393835761244102`], 
     Hue[1.0892939251265514`, 1, -0.9500007741771459], 
     Hue[1.1493806014548136`, 1, -0.7660941958338976], 
     Hue[1.0887462056026336`, 1, -0.5799861197120342], 
     Hue[1.1486898666656316`, 1, -0.39078935352667266`], 
     Hue[1.0917795568507678`, 1, -0.2012027828194498], 
     Hue[1.1463540590776125`, 1, -0.015968800707332198`], 
     Hue[1.093722408653327, 1, 0.1715177239456963], 
     Hue[1.1399390803526712`, 1, 0.35874724697406846`], 
     Hue[1.0943621110163964`, 1, 0.5462739524403954], 
     Hue[1.0618232973351802`, 1, 0.7342445360879375], 
     Hue[1.04075532255034, 1, 0.9216122859221723], 
     Hue[1.2610250076036076`, 1, -17.27618334189528], 
     Hue[1.198327607046142, 1, -17.089062133554293`], 
     Hue[1.2581166809175925`, 1, -16.91062086407678], 
     Hue[1.198327607046142, 1, -16.714819716872324`], 
     Hue[1.2581166809175923`, 1, -16.53637844739481], 
     Hue[1.198327607046142, 1, -16.34057730019035], 
     Hue[1.2585911973768895`, 1, -16.16071983016143], 
     Hue[1.198327607046142, 1, -15.966334883508381`], 
     Hue[1.2589470847213624`, 1, -15.7854152630659], 
     Hue[1.198327607046142, 1, -15.592092466826411`], 
     Hue[1.2628618455105645`, 1, -15.399489191834807`], 
     Hue[1.1983276070461417`, 1, -15.217850050144438`], 
     Hue[1.2628618455105642`, 1, -15.025246775152837`], 
     Hue[1.1983276070461415`, 1, -14.843607633462467`], 
     Hue[1.2628618455105638`, 1, -14.651004358470864`], 
     Hue[1.198327607046141, 1, -14.469365216780497`], 
     Hue[1.262861845510563, 1, -14.276761941788894`], 
     Hue[1.19832760704614, 1, -14.095122800098528`], 
     Hue[1.2628618455105611`, 1, -13.902519525106921`], 
     Hue[1.200286900813558, 1, -13.715032845655903`], 
     Hue[1.2637802644640357`, 1, -13.525536075099646`], 
     Hue[1.2002869008135522`, 1, -13.340790428973937`], 
     Hue[1.2637802644640266`, 1, -13.151293658417673`], 
     Hue[1.2002869008135395`, 1, -12.966548012291979`], 
     Hue[1.2637802644640068`, 1, -12.777051241735697`], 
     Hue[1.2002869008135117`, 1, -12.592305595610034`], 
     Hue[1.2637802644639637`, 1, -12.402808825053715`], 
     Hue[1.2002869008134507`, 1, -12.218063178928121`], 
     Hue[1.2637802644638683`, 1, -12.028566408371717`], 
     Hue[1.201266547697025, 1, -11.840896993365948`], 
     Hue[1.2642394739403977`, 1, -11.652953475027033`], 
     Hue[1.2012665476967275`, 1, -11.46665457668426], 
     Hue[1.2642394739399359`, 1, -11.278711058344939`], 
     Hue[1.201266547696073, 1, -11.092412160002905`], 
     Hue[1.2642394739389204`, 1, -10.904468641662696`], 
     Hue[1.2017563711364787`, 1, -10.716707858882112`], 
     Hue[1.2663135700732449`, 1, -10.524036058053634`], 
     Hue[1.202123738714676, 1, -10.341369028872954`], 
     Hue[1.266480033503588, 1, -10.149296829079894`], 
     Hue[1.2061647821025465`, 1, -9.95506606556542], 
     Hue[1.2665355213044234`, 1, -9.77488880829777], 
     Hue[1.206164782086629, 1, -9.580823648896876], 
     Hue[1.2665355212803826`, 1, -9.400646391608317], 
     Hue[1.2061647820516306`, 1, -9.206581232244423], 
     Hue[1.266535521227523, 1, -9.026403974909897], 
     Hue[1.2061647819746786`, 1, -8.832338815627356], 
     Hue[1.268311131085897, 1, -8.646862227088246], 
     Hue[1.2061647818054817`, 1, -8.458096399088094], 
     Hue[1.2683111308278028`, 1, -8.272619810317257], 
     Hue[1.2061647814334644`, 1, -8.083853982719898], 
     Hue[1.268311130260324, 1, -7.898377393439568], 
     Hue[1.2061647806154994`, 1, -7.709611566727838], 
     Hue[1.2683111290125928`, 1, -7.524134976327255], 
     Hue[1.2061647788170176`, 1, -7.335369151562786], 
     Hue[1.2683111262691718`, 1, -7.149892558699086], 
     Hue[1.206164774862646, 1, -6.9611267382161115`], 
     Hue[1.2691989251709541`, 1, -6.773000474182366], 
     Hue[1.2061647661680608`, 1, -6.586884328867547], 
     Hue[1.2691989118427673`, 1, -6.398758052678531], 
     Hue[1.2081240402633115`, 1, -6.206794389608914], 
     Hue[1.270071380284768, 1, -6.021911642744679], 
     Hue[1.2081239975647233`, 1, -5.832552007252606], 
     Hue[1.2700713155407684`, 1, -5.647669201564159], 
     Hue[1.2081239036821856`, 1, -5.458309666043525], 
     Hue[1.2705074215645185`, 1, -5.272124737774589], 
     Hue[1.2081236972601754`, 1, -5.084067415306407], 
     Hue[1.2707252316320043`, 1, -4.897231201689614], 
     Hue[1.2081232433949378`, 1, -4.709825363494553], 
     Hue[1.2744326319335544`, 1, -4.51192149131638], 
     Hue[1.2091018780349256`, 1, -4.332659955419437], 
     Hue[1.2713562195605084`, 1, -4.146855653337989], 
     Hue[1.2090996667187677`, 1, -3.9584192730576646`], 
     Hue[1.2748256447026545`, 1, -3.762246534634782], 
     Hue[1.2095845934537095`, 1, -3.582718724896117], 
     Hue[1.275017115436185, 1, -3.3874066457089222`], 
     Hue[1.2098187354401668`, 1, -3.2077536127670667`], 
     Hue[1.2751000744704535`, 1, -3.012859406205024], 
     Hue[1.2100322720937353`, 1, -2.832821159007099], 
     Hue[1.2751600817539253`, 1, -2.6383119465999343`], 
     Hue[1.2139034678454759`, 1, -2.446895318751057], 
     Hue[1.273266933774163, 1, -2.2694529567602535`], 
     Hue[1.2137854430335184`, 1, -2.0727343281953985`], 
     Hue[1.276496575769598, 1, -1.8849343539054673`], 
     Hue[1.213526081276987, 1, -1.6986718140364523`], 
     Hue[1.2761064098961779`, 1, -1.5104977314421706`], 
     Hue[1.2129565099693793`, 1, -1.3248291413556517`], 
     Hue[1.2752474331833792`, 1, -1.1358380902568472`], 
     Hue[1.2117075872922214`, 1, -0.9514857665721561], 
     Hue[1.2733536178025928`, 1, -0.7607259019745953], 
     Hue[1.2087433419527551`, 1, -0.5800636903592931], 
     Hue[1.2690715832593924`, 1, -0.38511726924754175`], 
     Hue[1.2048523662359534`, 1, -0.20395156970619532`], 
     Hue[1.2574904184443512`, 1, -0.016828832721411224`], 
     Hue[1.1956442439290889`, 1, 0.1718955508304182], 
     Hue[1.2377256698295411`, 1, 0.35843373657444344`], 
     Hue[1.1750487353848231`, 1, 0.5462326068419994], 
     Hue[1.1980349555587884`, 1, 0.7343838501428578], 
     Hue[1.1212996417350527`, 1, 0.7339538242634607], 
     Hue[1.1281278940725286`, 1, 0.9217433104864527], 
     Hue[1.0756629649766376`, 1, 0.9218582906294694], 
     Hue[1.3864198087185393`, 1, -17.27618334189528], 
     Hue[1.3237224081610734`, 1, -17.089062133554293`], 
     Hue[1.383511482032524, 1, -16.91062086407678], 
     Hue[1.3237224081610734`, 1, -16.714819716872324`], 
     Hue[1.383511482032524, 1, -16.53637844739481], 
     Hue[1.3237224081610734`, 1, -16.34057730019035], 
     Hue[1.3839859984918212`, 1, -16.16071983016143], 
     Hue[1.3237224081610734`, 1, -15.966334883508381`], 
     Hue[1.3843418858362941`, 1, -15.7854152630659], 
     Hue[1.3237224081610734`, 1, -15.592092466826411`], 
     Hue[1.388256646625496, 1, -15.399489191834807`], 
     Hue[1.3237224081610732`, 1, -15.217850050144438`], 
     Hue[1.388256646625496, 1, -15.025246775152837`], 
     Hue[1.323722408161073, 1, -14.843607633462467`], 
     Hue[1.3882566466254955`, 1, -14.651004358470864`], 
     Hue[1.3237224081610726`, 1, -14.469365216780497`], 
     Hue[1.388256646625495, 1, -14.276761941788891`], 
     Hue[1.3237224081610715`, 1, -14.095122800098522`], 
     Hue[1.3882566466254938`, 1, -13.902519525106914`], 
     Hue[1.3256817019284899`, 1, -13.715032845655891`], 
     Hue[1.38917506557897, 1, -13.52553607509963], 
     Hue[1.3256817019284843`, 1, -13.34079042897391], 
     Hue[1.3891750655789643`, 1, -13.15129365841764], 
     Hue[1.3256817019284726`, 1, -12.966548012291923`], 
     Hue[1.3891750655789517`, 1, -12.777051241735624`], 
     Hue[1.3256817019284468`, 1, -12.592305595609913`], 
     Hue[1.3891750655789237`, 1, -12.402808825053553`], 
     Hue[1.3256817019283895`, 1, -12.218063178927853`], 
     Hue[1.3891750655788622`, 1, -12.028566408371361`], 
     Hue[1.326661348811974, 1, -11.840896993365355`], 
     Hue[1.389634275055467, 1, -11.652953475026248`], 
     Hue[1.3266613488116974`, 1, -11.466654576682952`], 
     Hue[1.3896342750551707`, 1, -11.278711058343212`], 
     Hue[1.3266613488110892`, 1, -11.092412160000032`], 
     Hue[1.3896342750545192`, 1, -10.904468641658902`], 
     Hue[1.3271511722516034`, 1, -10.716707858875777`], 
     Hue[1.3917083711896996`, 1, -10.524036058045244`], 
     Hue[1.3275185398300446`, 1, -10.341369028858997`], 
     Hue[1.3918748346218779`, 1, -10.149296829061436`], 
     Hue[1.3315595832187306`, 1, -9.955066065534027], 
     Hue[1.3919303224267465`, 1, -9.774888808257181], 
     Hue[1.3315595832043141`, 1, -9.580823648827852], 
     Hue[1.3919303224115662`, 1, -9.40064639151907], 
     Hue[1.3315595831726168`, 1, -9.20658123209266], 
     Hue[1.391930322378189, 1, -9.026403974713668], 
     Hue[1.331559583102923, 1, -8.832338815293669], 
     Hue[1.393705932281906, 1, -8.646862226654621], 
     Hue[1.3315595829496851`, 1, -8.458096398354407], 
     Hue[1.3937059321210017`, 1, -8.27261980936384], 
     Hue[1.3315595826127566`, 1, -8.083853981106717], 
     Hue[1.3937059317672167`, 1, -7.898377391343263], 
     Hue[1.3315595818719428`, 1, -7.709611563180888], 
     Hue[1.3937059309893398`, 1, -7.524134971718053], 
     Hue[1.3315595802430953`, 1, -7.335369143764013], 
     Hue[1.3937059292790006`, 1, -7.149892548564703], 
     Hue[1.331559576661703, 1, -6.961126721068736], 
     Hue[1.394593730517369, 1, -6.773000451845076], 
     Hue[1.3315595687871975`, 1, -6.5868842911651395`], 
     Hue[1.3945937222615772`, 1, -6.398758003564913], 
     Hue[1.3335188450724547`, 1, -6.206794305814145], 
     Hue[1.3954662021679776`, 1, -6.021911534501746], 
     Hue[1.3335188068022035`, 1, -5.832551823010733], 
     Hue[1.3954661623194657`, 1, -5.64766896356736], 
     Hue[1.3335187226563132`, 1, -5.4583092609457955`], 
     Hue[1.3959023238386643`, 1, -5.2721242138733055`], 
     Hue[1.3335185376422514`, 1, -5.084066524606613], 
     Hue[1.3961202560025994`, 1, -4.897230049103649], 
     Hue[1.3335181308458748`, 1, -4.709823405087051], 
     Hue[1.3998279556078268`, 1, -4.511918932984051], 
     Hue[1.3344968790746516`, 1, -4.332655626412119], 
     Hue[1.3967521117209498`, 1, -4.1468500718985455`], 
     Hue[1.3344949073727226`, 1, -3.95840975471586], 
     Hue[1.4002229887211068`, 1, -3.762234154222279], 
     Hue[1.3349803854173112`, 1, -3.58269774097779], 
     Hue[1.4004175258982532`, 1, -3.3873794101499666`], 
     Hue[1.335215741371086, 1, -3.207707413027717], 
     Hue[1.4005072282420383`, 1, -3.0127995021199325`], 
     Hue[1.3354090161269623`, 1, -2.832787996713397], 
     Hue[1.4005727526182072`, 1, -2.6382080287546863`], 
     Hue[1.3393111818235457`, 1, -2.446666947008297], 
     Hue[1.3986163936036033`, 1, -2.2694731436984403`], 
     Hue[1.3392085226664092`, 1, -2.0722320836699897`], 
     Hue[1.3987054228418045`, 1, -1.8942285376220978`], 
     Hue[1.3389825105830344`, 1, -1.6975669513444693`], 
     Hue[1.4017970416333467`, 1, -1.509086018645737], 
     Hue[1.3384841565002579`, 1, -1.3223971578613785`], 
     Hue[1.3977693731925418`, 1, -1.143348260466652], 
     Hue[1.337381563800563, 1, -0.9461258537042427], 
     Hue[1.396007266710562, 1, -0.7665005340062341], 
     Hue[1.3309319673754734`, 1, -0.5800737362070114], 
     Hue[1.3907440898676677`, 1, -0.39081841935835415`], 
     Hue[1.3231901365943128`, 1, -0.20467921863397875`], 
     Hue[1.378286392453703, 1, -0.016994442277794564`], 
     Hue[1.434679695561245, 1, 0.1742366505770272], 
     Hue[1.306993615847277, 1, 0.17230820013308945`], 
     Hue[1.3529975067231457`, 1, 0.359196906037645], 
     Hue[1.3983501497961313`, 1, 0.5482394626044355], 
     Hue[1.2731346544505517`, 1, 0.5465461055847625], 
     Hue[1.3018980781004807`, 1, 0.7340596209442063], 
     Hue[1.3250692585362978`, 1, 0.9219704845549686], 
     Hue[1.3436713576125605`, 1, 1.1093975999154313`], 
     Hue[1.2077447838273576`, 1, 0.9218337713247667], 
     Hue[1.201999956118762, 1, 1.1093125037114395`], 
     Hue[1.1733346737421666`, 1, 1.2973470161088287`], 
     Hue[1.1062792592803958`, 1, 1.1092919170504285`], 
     Hue[1.040590820520259, 1, 1.1093128472980605`], 
     Hue[0.5118146098334707, 1, -17.27618334189528], 
     Hue[1.449117209276005, 1, -17.089062133554293`], 
     Hue[0.5089062831474553, 1, -16.91062086407678], 
     Hue[1.449117209276005, 1, -16.714819716872324`], 
     Hue[0.5089062831474553, 1, -16.53637844739481], 
     Hue[1.449117209276005, 1, -16.34057730019035], 
     Hue[0.5093807996067526, 1, -16.16071983016143], 
     Hue[1.449117209276005, 1, -15.966334883508381`], 
     Hue[0.5097366869512256, 1, -15.7854152630659], 
     Hue[1.4491172092760047`, 1, -15.592092466826411`], 
     Hue[0.5136514477404275, 1, -15.399489191834807`], 
     Hue[1.4491172092760047`, 1, -15.217850050144438`], 
     Hue[0.5136514477404275, 1, -15.025246775152837`], 
     Hue[1.4491172092760047`, 1, -14.843607633462467`], 
     Hue[0.5136514477404275, 1, -14.65100435847086], 
     Hue[1.4491172092760045`, 1, -14.469365216780494`], 
     Hue[0.5136514477404275, 1, -14.276761941788891`], 
     Hue[1.4491172092760043`, 1, -14.095122800098519`], 
     Hue[0.5136514477404277, 1, -13.902519525106912`], 
     Hue[1.4510765030434245`, 1, -13.715032845655884`], 
     Hue[0.5145698666939069, 1, -13.525536075099625`], 
     Hue[1.4510765030434225`, 1, -13.340790428973895`], 
     Hue[0.5145698666939078, 1, -13.151293658417627`], 
     Hue[1.4510765030434185`, 1, -12.966548012291888`], 
     Hue[0.5145698666939096, 1, -12.777051241735599`], 
     Hue[1.4510765030434098`, 1, -12.592305595609833`], 
     Hue[0.5145698666939136, 1, -12.402808825053498`], 
     Hue[1.4510765030433903`, 1, -12.218063178927679`], 
     Hue[0.5145698666939222, 1, -12.028566408371242`], 
     Hue[1.452056149927059, 1, -11.840896993364971`], 
     Hue[0.5150290761706822, 1, -11.652953475025987`], 
     Hue[1.4520561499269662`, 1, -11.466654576682112`], 
     Hue[0.5150290761707259, 1, -11.278711058342639`], 
     Hue[1.4520561499267628`, 1, -11.092412159998185`], 
     Hue[0.515029076170822, 1, -10.904468641657639`], 
     Hue[1.452545973368176, 1, -10.716707858871718`], 
     Hue[0.5171031723076982, 1, -10.524036058042546`], 
     Hue[1.452913340948599, 1, -10.341369028850076`], 
     Hue[0.517269635743562, 1, -10.149296829055523`], 
     Hue[1.4569543843420019`, 1, -9.955066065514533], 
     Hue[0.5173251235565326, 1, -9.774888808244189], 
     Hue[1.4569543843375823`, 1, -9.580823648784992], 
     Hue[0.5173251235591587, 1, -9.400646391490502], 
     Hue[1.4569543843278652`, 1, -9.206581231998422], 
     Hue[0.5173251235649325, 1, -9.026403974650858], 
     Hue[1.4569543843065, 1, -8.832338815086466], 
     Hue[0.5191007335570161, 1, -8.646862226520293], 
     Hue[1.4569543842595238`, 1, -8.458096397898824], 
     Hue[0.5191007335881224, 1, -8.272619809068487], 
     Hue[1.456954384156236, 1, -8.083853980105019], 
     Hue[0.5191007336565163, 1, -7.898377390693864], 
     Hue[1.4569543839291341`, 1, -7.70961156097843], 
     Hue[0.5191007338068958, 1, -7.524134970290205], 
     Hue[1.4569543834297989`, 1, -7.335369138921405], 
     Hue[0.5191007341375393, 1, -7.149892545425254], 
     Hue[1.4569543823318967`, 1, -6.961126710421159], 
     Hue[0.519988539922362, 1, -6.773000445041573], 
     Hue[1.456954379917909, 1, -6.586884267754019], 
     Hue[0.5199885416040961, 1, -6.398757988605864], 
     Hue[1.4589136686953963`, 1, -6.206794254524922], 
     Hue[0.5208610436408652, 1, -6.0219115020898775`], 
     Hue[1.458913657406119, 1, -5.832551710239663], 
     Hue[0.520861052170574, 1, -5.647668892302441], 
     Hue[1.458913632584054, 1, -5.458309012992726], 
     Hue[0.5212973207395097, 1, -5.272124058351902], 
     Hue[1.4589135780069946`, 1, -5.08406597942431], 
     Hue[0.5215154883453337, 1, -4.897229708447824], 
     Hue[1.4589134580064163`, 1, -4.709822206374545], 
     Hue[0.5252237329502154, 1, -4.511918233999694], 
     Hue[1.459892849411644, 1, -4.33265299590063], 
     Hue[0.522149008087518, 1, -4.146848443290974], 
     Hue[1.4598922793000797`, 1, -3.958403970815443], 
     Hue[0.5256225240792182, 1, -3.762230801720322], 
     Hue[1.46038086965814, 1, -3.582685036101851], 
     Hue[0.525822752853922, 1, -3.387372067956628], 
     Hue[1.4606230720728348`, 1, -3.207679490072338], 
     Hue[0.5259249727039774, 1, -3.0127833882976836`], 
     Hue[1.4608008123954521`, 1, -2.8328180149824957`], 
     Hue[0.5260056009304714, 1, -2.6382097783035388`], 
     Hue[1.4647693670387962`, 1, -2.4465331776353], 
     Hue[0.5241206143899235, 1, -2.2693922827779796`], 
     Hue[1.4647427281366676`, 1, -2.071937623266746], 
     Hue[0.5243025630113218, 1, -1.8941668872434778`], 
     Hue[1.4646840168868682`, 1, -1.696917875561503], 
     Hue[0.5243617010275308, 1, -1.5187790151054499`], 
     Hue[1.46455424815842, 1, -1.3209620625242822`], 
     Hue[0.5241270310888348, 1, -1.1430967422984037`], 
     Hue[1.460056531054482, 1, -0.9555805922916696], 
     Hue[0.522861781113918, 1, -0.7678667246785909], 
     Hue[1.4575956689673175`, 1, -0.5785053813158862], 
     Hue[0.5209530479209363, 1, -0.3886185316614572], 
     Hue[1.4507660286393058`, 1, -0.20207519887494785`], 
     Hue[0.5126045671434745, 1, -0.014403637547257153`], 
     Hue[0.5790898728845861, 1, 0.17102266976239244`], 
     Hue[1.4922197758692985`, 1, 0.3586302288142108], 
     Hue[0.56007994513389, 1, 0.5463073649401253], 
     Hue[1.4448692300091928`, 1, 0.7338696416210355], 
     Hue[0.5000982413613833, 1, 0.9218263666459587], 
     Hue[0.580605811719906, 1, 1.1092999837540214`], 
     Hue[1.3592462520142572`, 1, 1.299448451447279], 
     Hue[0.9839014114626472, 1, 1.2971635334770346`], 
     Hue[1.0041611670271673`, 1, 1.1093357939731308`], 
     Hue[0.6372094109484021, 1, -17.27618334189528], 
     Hue[0.5745120103909366, 1, -17.089062133554293`], 
     Hue[0.6343010842623871, 1, -16.91062086407678], 
     Hue[0.5745120103909366, 1, -16.714819716872324`], 
     Hue[0.6343010842623871, 1, -16.53637844739481], 
     Hue[0.5745120103909366, 1, -16.34057730019035], 
     Hue[0.6347756007216845, 1, -16.16071983016143], 
     Hue[0.5745120103909367, 1, -15.966334883508381`], 
     Hue[0.6351314880661574, 1, -15.7854152630659], 
     Hue[0.5745120103909367, 1, -15.592092466826411`], 
     Hue[0.6390462488553592, 1, -15.399489191834807`], 
     Hue[0.5745120103909367, 1, -15.217850050144438`], 
     Hue[0.6390462488553594, 1, -15.025246775152837`], 
     Hue[0.5745120103909368, 1, -14.843607633462467`], 
     Hue[0.6390462488553597, 1, -14.651004358470864`], 
     Hue[0.5745120103909371, 1, -14.469365216780494`], 
     Hue[0.6390462488553603, 1, -14.276761941788891`], 
     Hue[0.5745120103909376, 1, -14.095122800098519`], 
     Hue[0.6390462488553618, 1, -13.902519525106916`], 
     Hue[0.5764713041583593, 1, -13.715032845655884`], 
     Hue[0.6399646678088434, 1, -13.525536075099634`], 
     Hue[0.5764713041583622, 1, -13.340790428973898`], 
     Hue[0.6399646678088504, 1, -13.151293658417643`], 
     Hue[0.5764713041583682, 1, -12.966548012291893`], 
     Hue[0.6399646678088656, 1, -12.777051241735636`], 
     Hue[0.5764713041583818, 1, -12.592305595609844`], 
     Hue[0.6399646678088992, 1, -12.402808825053583`], 
     Hue[0.5764713041584115, 1, -12.218063178927702`], 
     Hue[0.6399646678089728, 1, -12.028566408371429`], 
     Hue[0.5774509510421897, 1, -11.840896993365028`], 
     Hue[0.6404238772858759, 1, -11.6529534750264], 
     Hue[0.5774509510423356, 1, -11.466654576682235`], 
     Hue[0.6404238772862338, 1, -11.278711058343552`], 
     Hue[0.5774509510426566, 1, -11.092412159998451`], 
     Hue[0.640423877287021, 1, -10.904468641659648`], 
     Hue[0.577940774485229, 1, -10.716707858872326`], 
     Hue[0.6424979734254335, 1, -10.524036058047134`], 
     Hue[0.578308142068205, 1, -10.34136902885145], 
     Hue[0.6426644368646616, 1, -10.149296829065637`], 
     Hue[0.5823491854674456, 1, -9.955066065518427], 
     Hue[0.6427199246850273, 1, -9.774888808266448], 
     Hue[0.5823491854756274, 1, -9.580823648793553], 
     Hue[0.6427199247039121, 1, -9.40064639153945], 
     Hue[0.5823491854936169, 1, -9.206581232017244], 
     Hue[0.6427199247454347, 1, -9.026403974758479], 
     Hue[0.5823491855331708, 1, -8.832338815127853], 
     Hue[0.6444955348168344, 1, -8.646862226764418], 
     Hue[0.5823491856201395, 1, -8.458096397989825], 
     Hue[0.6444955350216204, 1, -8.272619809605253], 
     Hue[0.5823491858113595, 1, -8.083853980305106], 
     Hue[0.6444955354718886, 1, -7.898377391874063], 
     Hue[0.5823491862318004, 1, -7.709611561418366], 
     Hue[0.644495536461906, 1, -7.524134972885137], 
     Hue[0.5823491871562353, 1, -7.335369139888706], 
     Hue[0.6444955386386846, 1, -7.149892551130807], 
     Hue[0.5823491891888158, 1, -6.961126712547988], 
     Hue[0.6453833485006086, 1, -6.773000457781158], 
     Hue[0.5823491936579068, 1, -6.5868842724303365`], 
     Hue[0.645383359128824, 1, -6.398758016616742], 
     Hue[0.5843084978681885, 1, -6.206794265965954], 
     Hue[0.646255880920516, 1, -6.021911564609379], 
     Hue[0.5843085202126556, 1, -5.832551735395385], 
     Hue[0.6462559328018846, 1, -5.6476690297658765`], 
     Hue[0.5843085693420869, 1, -5.458309068303363], 
     Hue[0.6466922968902498, 1, -5.272124362859621], 
     Hue[0.5843086773644994, 1, -5.084066101037627], 
     Hue[0.6469106745362829, 1, -4.897230380473397], 
     Hue[0.5843089148772265, 1, -4.709822473770533], 
     Hue[0.6506193886613141, 1, -4.511919806288673], 
     Hue[0.5852891000182965, 1, -4.332653614108532], 
     Hue[0.6475456738867991, 1, -4.146851727325193], 
     Hue[0.5852902674932796, 1, -3.958405330121841], 
     Hue[0.651021460665612, 1, -3.7622384530954367`], 
     Hue[0.5857826969641693, 1, -3.582688098788142], 
     Hue[0.6512266512646596, 1, -3.3873889475191126`], 
     Hue[0.5860333431279724, 1, -3.207686306380549], 
     Hue[0.6513397820283857, 1, -3.012820568534732], 
     Hue[0.58622966582162, 1, -2.8328331410414718`], 
     Hue[0.6514444072992394, 1, -2.6382916571324238`], 
     Hue[0.5902406497432756, 1, -2.4465730228376366`], 
     Hue[0.649611752881361, 1, -2.2695669041905004`], 
     Hue[0.5903058044577232, 1, -2.0720253535247704`], 
     Hue[0.6532769633422062, 1, -1.884535432881335], 
     Hue[0.5904493568436227, 1, -1.6971113597778873`], 
     Hue[0.6536023608945789, 1, -1.5096190085454244`], 
     Hue[0.5907664215896054, 1, -1.3213903499741677`], 
     Hue[0.654321072599282, 1, -1.1338982968990312`], 
     Hue[0.5874697814072822, 1, -0.9556425364377648], 
     Hue[0.6542752927976733, 1, -0.7611492811041143], 
     Hue[0.5869082322704909, 1, -0.5801509827947071], 
     Hue[0.6532249726866939, 1, -0.39248125201898953`], 
     Hue[0.5859102232495444, 1, -0.2019867946724685], 
     Hue[0.6569452370963776, 1, -0.013095370079695856`], 
     Hue[0.6584666783089397, 1, 0.3587591960635882], 
     Hue[0.655226638526342, 1, 0.7346691229903993], 
     Hue[0.8473451342383822, 1, 1.109576801168299], 
     Hue[0.9414818601549322, 1, 1.1094053825630203`], 
     Hue[0.909253751887528, 1, 1.2970821317326624`], 
     Hue[0.9722313970561802, 1, 1.1093819413253416`], 
     Hue[0.9888399394207114, 1, 1.1097342025954633`], 
     Hue[0.762604212063334, 1, -17.27618334189528], 
     Hue[0.6999068115058678, 1, -17.089062133554293`], 
     Hue[0.7596958853773188, 1, -16.91062086407678], 
     Hue[0.6999068115058678, 1, -16.714819716872324`], 
     Hue[0.7596958853773188, 1, -16.53637844739481], 
     Hue[0.6999068115058678, 1, -16.34057730019035], 
     Hue[0.7601704018366156, 1, -16.16071983016143], 
     Hue[0.6999068115058678, 1, -15.966334883508381`], 
     Hue[0.7605262891810886, 1, -15.7854152630659], 
     Hue[0.6999068115058679, 1, -15.592092466826411`], 
     Hue[0.764441049970291, 1, -15.399489191834807`], 
     Hue[0.699906811505868, 1, -15.217850050144438`], 
     Hue[0.7644410499702913, 1, -15.025246775152837`], 
     Hue[0.6999068115058682, 1, -14.843607633462467`], 
     Hue[0.7644410499702916, 1, -14.651004358470864`], 
     Hue[0.6999068115058688, 1, -14.469365216780497`], 
     Hue[0.7644410499702925, 1, -14.276761941788894`], 
     Hue[0.69990681150587, 1, -14.095122800098524`], 
     Hue[0.7644410499702943, 1, -13.902519525106925`], 
     Hue[0.7018661052732936, 1, -13.715032845655893`], 
     Hue[0.7653594689237768, 1, -13.52553607509965], 
     Hue[0.7018661052732994, 1, -13.340790428973916`], 
     Hue[0.7653594689237858, 1, -13.15129365841768], 
     Hue[0.7018661052733121, 1, -12.966548012291934`], 
     Hue[0.7653594689238055, 1, -12.777051241735716`], 
     Hue[0.7018661052733399, 1, -12.592305595609938`], 
     Hue[0.7653594689238488, 1, -12.402808825053757`], 
     Hue[0.7018661052734012, 1, -12.218063178927908`], 
     Hue[0.765359468923944, 1, -12.028566408371814`], 
     Hue[0.7028457521572486, 1, -11.840896993365488`], 
     Hue[0.7658186784008938, 1, -11.65295347502725], 
     Hue[0.7028457521575473, 1, -11.466654576683245`], 
     Hue[0.7658186784013552, 1, -11.278711058345417`], 
     Hue[0.7028457521582037, 1, -11.092412160000675`], 
     Hue[0.7658186784023695, 1, -10.904468641663748`], 
     Hue[0.7033355756015125, 1, -10.716707858877243`], 
     Hue[0.7678927745412534, 1, -10.5240360580563], 
     Hue[0.7037029431861073, 1, -10.341369028862308`], 
     Hue[0.7680592379815414, 1, -10.14929682908582], 
     Hue[0.7077439865888667, 1, -9.955066065543413], 
     Hue[0.7681147258042386, 1, -9.774888808310846], 
     Hue[0.7077439866048282, 1, -9.58082364884849], 
     Hue[0.7681147258282535, 1, -9.400646391637068], 
     Hue[0.7077439866399231, 1, -9.206581232138037], 
     Hue[0.7681147258810556, 1, -9.026403974973112], 
     Hue[0.7077439867170872, 1, -8.832338815393442], 
     Hue[0.7698903359759794, 1, -8.646862227243133], 
     Hue[0.7077439868867499, 1, -8.458096398573781], 
     Hue[0.769890336233765, 1, -8.272619810657819], 
     Hue[0.7077439872597923, 1, -8.083853981589067], 
     Hue[0.7698903368005652, 1, -7.898377394188368], 
     Hue[0.7077439880800105, 1, -7.709611564241443], 
     Hue[0.7698903380468043, 1, -7.524134977973666], 
     Hue[0.7077439898834471, 1, -7.335369146095883], 
     Hue[0.7698903407869445, 1, -7.149892562319089], 
     Hue[0.7077439938487127, 1, -6.961126726195885], 
     Hue[0.770778151853985, 1, -6.773000482556402], 
     Hue[0.707744002567251, 1, -6.586884302438344], 
     Hue[0.7707781651654841, 1, -6.398758071090756], 
     Hue[0.7097033160563573, 1, -6.2067943333950435`], 
     Hue[0.771650692695091, 1, -6.021911685217529], 
     Hue[0.7097033588669786, 1, -5.832551883653625], 
     Hue[0.7716507573544372, 1, -5.647669294950381], 
     Hue[0.7097034529958884, 1, -5.4583093942830505`], 
     Hue[0.7720871491422578, 1, -5.2721249479492585`], 
     Hue[0.70970365995981, 1, -5.084066817779193], 
     Hue[0.772305587649527, 1, -4.897231669150881], 
     Hue[0.70970411501756, 1, -4.709824049695088], 
     Hue[0.7760144191236844, 1, -4.511922723273975], 
     Hue[0.7106847766886406, 1, -4.332657116707347], 
     Hue[0.7729410102380326, 1, -4.146857988591965], 
     Hue[0.7106869937037856, 1, -3.958413031504268], 
     Hue[0.7764173613384672, 1, -3.762252598721239], 
     Hue[0.7111817262899982, 1, -3.582705123736922], 
     Hue[0.7766238595589383, 1, -3.3874200984324174`], 
     Hue[0.7114374356042945, 1, -3.207723842845109], 
     Hue[0.7767398627675077, 1, -3.012889116584109], 
     Hue[0.7116755106811985, 1, -2.832824504206811], 
     Hue[0.7768632298878687, 1, -2.6384053769334086`], 
     Hue[0.7156798985330846, 1, -2.446762936447911], 
     Hue[0.7751363759398671, 1, -2.269585701703293], 
     Hue[0.7157982925214075, 1, -2.072443258154826], 
     Hue[0.7787254586490786, 1, -1.885274153358323], 
     Hue[0.7160587437211503, 1, -1.6980318451892231`], 
     Hue[0.7791140564352204, 1, -1.5112448278861434`], 
     Hue[0.7166320528467238, 1, -1.3234221219888258`], 
     Hue[0.7799672378563746, 1, -1.137480538535187], 
     Hue[0.717895680510072, 1, -0.9483928624273343], 
     Hue[0.7818369737493076, 1, -0.7643354410139958], 
     Hue[0.7206883307474822, 1, -0.5725220144530536], 
     Hue[0.7876286904800736, 1, -0.38807651085475947`], 
     Hue[0.7247702917939566, 1, -0.2006964058346079], 
     Hue[0.7992658708614662, 1, -0.014246293435249191`], 
     Hue[0.7350193563981648, 1, 0.17078696949813776`], 
     Hue[0.8290287375807578, 1, 0.3597444449005892], 
     Hue[0.7659952800859264, 1, 0.5463789688102246], 
     Hue[0.8879990131782657, 1, -17.27618334189528], 
     Hue[0.8253016126207995, 1, -17.089062133554293`], 
     Hue[0.88509068649225, 1, -16.91062086407678], 
     Hue[0.8253016126207995, 1, -16.714819716872324`], 
     Hue[0.88509068649225, 1, -16.53637844739481], 
     Hue[0.8253016126207995, 1, -16.34057730019035], 
     Hue[0.8855652029515473, 1, -16.16071983016143], 
     Hue[0.8253016126207995, 1, -15.966334883508381`], 
     Hue[0.8859210902960203, 1, -15.7854152630659], 
     Hue[0.8253016126207996, 1, -15.592092466826411`], 
     Hue[0.8898358510852222, 1, -15.399489191834807`], 
     Hue[0.8253016126207997, 1, -15.217850050144438`], 
     Hue[0.8898358510852222, 1, -15.025246775152837`], 
     Hue[0.8253016126207999, 1, -14.843607633462467`], 
     Hue[0.8898358510852226, 1, -14.651004358470864`], 
     Hue[0.8253016126208004, 1, -14.469365216780497`], 
     Hue[0.8898358510852231, 1, -14.276761941788898`], 
     Hue[0.8253016126208015, 1, -14.09512280009853], 
     Hue[0.8898358510852242, 1, -13.902519525106932`], 
     Hue[0.827260906388225, 1, -13.715032845655905`], 
     Hue[0.8907542700387059, 1, -13.525536075099664`], 
     Hue[0.8272609063882304, 1, -13.340790428973941`], 
     Hue[0.8907542700387115, 1, -13.151293658417714`], 
     Hue[0.8272609063882421, 1, -12.966548012291991`], 
     Hue[0.8907542700387241, 1, -12.77705124173579], 
     Hue[0.8272609063882679, 1, -12.592305595610059`], 
     Hue[0.8907542700387517, 1, -12.402808825053919`], 
     Hue[0.8272609063883246, 1, -12.218063178928178`], 
     Hue[0.8907542700388122, 1, -12.028566408372168`], 
     Hue[0.8282405532721604, 1, -11.84089699336608], 
     Hue[0.891213479515685, 1, -11.65295347502803], 
     Hue[0.8282405532724355, 1, -11.466654576684551`], 
     Hue[0.8912134795159777, 1, -11.278711058347133`], 
     Hue[0.8282405532730406, 1, -11.092412160003546`], 
     Hue[0.8912134795166216, 1, -10.90446864166752], 
     Hue[0.8287303767162295, 1, -10.716707858883572`], 
     Hue[0.8932875756546345, 1, -10.524036058064647`], 
     Hue[0.8290977443005558, 1, -10.341369028876251`], 
     Hue[0.8934540390930529, 1, -10.149296829104177`], 
     Hue[0.8331387877024417, 1, -9.955066065574767], 
     Hue[0.893509526911644, 1, -9.774888808351214], 
     Hue[0.8331387877167767, 1, -9.580823648917429], 
     Hue[0.893509526926637, 1, -9.400646391725829], 
     Hue[0.8331387877482956, 1, -9.206581232289615], 
     Hue[0.8935095269596024, 1, -9.026403975168273], 
     Hue[0.8331387878175971, 1, -8.83233881572672], 
     Hue[0.8952851370083962, 1, -8.646862227674333], 
     Hue[0.8331387879699721, 1, -8.458096399306568], 
     Hue[0.8952851371672687, 1, -8.27261981160591], 
     Hue[0.8331387883050031, 1, -8.083853983200264], 
     Hue[0.8952851375165859, 1, -7.898377396272962], 
     Hue[0.8331387890416451, 1, -7.709611567784026], 
     Hue[0.8952851382846394, 1, -7.524134982557119], 
     Hue[0.8331387906613201, 1, -7.3353691538850585`], 
     Hue[0.8952851399733797, 1, -7.149892572396857], 
     Hue[0.833138794222544, 1, -6.961126743322159], 
     Hue[0.8961729486633782, 1, -6.773000504767283], 
     Hue[0.8331388020527043, 1, -6.5868843400943495`], 
     Hue[0.8961729568137098, 1, -6.398758119926426], 
     Hue[0.835098113198665, 1, -6.206794417076281], 
     Hue[0.8970454726828913, 1, -6.021911792840051], 
     Hue[0.8350981512471772, 1, -5.832552067645847], 
     Hue[0.8970455120165474, 1, -5.647669531582885], 
     Hue[0.8350982349054484, 1, -5.458309798831739], 
     Hue[0.8974818473608968, 1, -5.272125468827493], 
     Hue[0.8350984188470045, 1, -5.084067707271202], 
     Hue[0.8977001616864518, 1, -4.897232815060959], 
     Hue[0.8350988232834722, 1, -4.709826005444107], 
     Hue[0.9014086891928255, 1, -4.511925265965016], 
     Hue[0.8360793634653968, 1, -4.332661439553609], 
     Hue[0.898334701771237, 1, -4.146863537261733], 
     Hue[0.836081323506606, 1, -3.958422536228193], 
     Hue[0.9018095783577335, 1, -3.7622649022620642`], 
     Hue[0.8365754661130468, 1, -3.582726076618874], 
     Hue[0.9020129602961121, 1, -3.387447161887465], 
     Hue[0.8368298748842533, 1, -3.207769971779576], 
     Hue[0.9021221090093103, 1, -3.0129486293841294`], 
     Hue[0.8370937645843459, 1, -2.83284041629463], 
     Hue[0.9022420408161533, 1, -2.6385014483089257`], 
     Hue[0.8410609427020195, 1, -2.446990821322088], 
     Hue[0.9005496075457682, 1, -2.2696410603428596`], 
     Hue[0.8411627335281269, 1, -2.0729441898051624`], 
     Hue[0.9039829322196292, 1, -1.8859079970870545`], 
     Hue[0.8413862487968692, 1, -1.69913264951953], 
     Hue[0.9042063913299307, 1, -1.5126350107323672`], 
     Hue[0.8418762726876068, 1, -1.3258395187737648`], 
     Hue[0.9046945243214859, 1, -1.1405204318274846`], 
     Hue[0.8429468220835271, 1, -0.9536933402207042], 
     Hue[0.9073957079319427, 1, -0.7661535057179216], 
     Hue[0.8472428786467683, 1, -0.5785162960273793], 
     Hue[0.9151818676631508, 1, -0.38653433201157616`], 
     Hue[0.8561690155126863, 1, -0.2044445743817509], 
     Hue[0.9267389029095637, 1, -0.016748217749305017`], 
     Hue[0.877616058245991, 1, 0.17072037701046017`], 
     Hue[0.956284460736124, 1, 0.3589869031157348], 
     Hue[0.9307191469977905, 1, 0.5466072723468868], 
     Hue[0.9270592068824746, 1, 0.733934791487241], 
     Hue[0.9838850284270948, 1, 0.9216171171737799], 
     Hue[1.0133938142931969`, 1, -17.27618334189528], 
     Hue[0.9506964137357312, 1, -17.089062133554293`], 
     Hue[1.0104854876071816`, 1, -16.91062086407678], 
     Hue[0.9506964137357312, 1, -16.714819716872324`], 
     Hue[1.0104854876071816`, 1, -16.53637844739481], 
     Hue[0.9506964137357312, 1, -16.34057730019035], 
     Hue[1.010960004066479, 1, -16.16071983016143], 
     Hue[0.9506964137357312, 1, -15.966334883508381`], 
     Hue[1.0113158914109521`, 1, -15.7854152630659], 
     Hue[0.9506964137357313, 1, -15.592092466826411`], 
     Hue[1.0152306522001537`, 1, -15.399489191834807`], 
     Hue[0.9506964137357313, 1, -15.217850050144438`], 
     Hue[1.0152306522001537`, 1, -15.025246775152837`], 
     Hue[0.9506964137357314, 1, -14.843607633462467`], 
     Hue[1.0152306522001537`, 1, -14.651004358470868`], 
     Hue[0.9506964137357315, 1, -14.469365216780501`], 
     Hue[1.0152306522001537`, 1, -14.276761941788898`], 
     Hue[0.9506964137357319, 1, -14.095122800098533`], 
     Hue[1.0152306522001535`, 1, -13.902519525106934`], 
     Hue[0.9526557075031538, 1, -13.715032845655912`], 
     Hue[1.0161490711536316`, 1, -13.52553607509967], 
     Hue[0.9526557075031555, 1, -13.340790428973959`], 
     Hue[1.0161490711536307`, 1, -13.151293658417725`], 
     Hue[0.9526557075031594, 1, -12.966548012292026`], 
     Hue[1.0161490711536287`, 1, -12.777051241735814`], 
     Hue[0.952655707503168, 1, -12.592305595610139`], 
     Hue[1.0161490711536243`, 1, -12.40280882505397], 
     Hue[0.9526557075031868, 1, -12.218063178928348`], 
     Hue[1.0161490711536145`, 1, -12.028566408372285`], 
     Hue[0.9536353543869374, 1, -11.840896993366458`], 
     Hue[1.0166082806303316`, 1, -11.652953475028282`], 
     Hue[0.953635354387027, 1, -11.466654576685382`], 
     Hue[1.0166082806302832`, 1, -11.278711058347689`], 
     Hue[0.9536353543872241, 1, -11.09241216000537], 
     Hue[1.016608280630177, 1, -10.904468641668744`], 
     Hue[0.9541251778295069, 1, -10.716707858887583`], 
     Hue[1.0186823767664897`, 1, -10.524036058067251`], 
     Hue[0.954492545411835, 1, -10.341369028885063`], 
     Hue[1.0188488402012124`, 1, -10.149296829109892`], 
     Hue[0.9585335888089695, 1, -9.955066065594012], 
     Hue[1.0189043280116783`, 1, -9.774888808363768], 
     Hue[0.9585335888132306, 1, -9.580823648959743], 
     Hue[1.0189043280088141`, 1, -9.400646391753426], 
     Hue[0.9585335888225994, 1, -9.206581232382652], 
     Hue[1.0189043280025163`, 1, -9.026403975228954], 
     Hue[0.958533588843199, 1, -8.832338815931287], 
     Hue[1.0206799379627098`, 1, -8.646862227803913], 
     Hue[0.9585335888884916, 1, -8.458096399756354], 
     Hue[1.0206799379290459`, 1, -8.272619811890817], 
     Hue[0.9585335889880781, 1, -8.08385398418922], 
     Hue[1.020679937855028, 1, -7.898377396899398], 
     Hue[0.9585335892070415, 1, -7.709611569958473], 
     Hue[1.0206799376922828`, 1, -7.524134983934478], 
     Hue[0.9585335896884822, 1, -7.335369158666077], 
     Hue[1.0206799373344506`, 1, -7.149892575425295], 
     Hue[0.9585335907470394, 1, -6.961126753834313], 
     Hue[1.0215677414660385`, 1, -6.7730005113249545`], 
     Hue[0.9585335930745176, 1, -6.586884363207714], 
     Hue[1.0215677396522234`, 1, -6.398758134344954], 
     Hue[0.9604928916361821, 1, -6.206794467696411], 
     Hue[1.0224402333341205`, 1, -6.0219118240551595`], 
     Hue[0.9604929025006596, 1, -5.832552178945671], 
     Hue[1.0224402241628554`, 1, -5.647669600216352], 
     Hue[0.960492926388664, 1, -5.458310043549502], 
     Hue[1.0228764521830511`, 1, -5.272125618542508], 
     Hue[0.9604929789117762, 1, -5.0840682453378], 
     Hue[1.0230945304649048`, 1, -4.897233142925677], 
     Hue[0.960493094395305, 1, -4.709827188500753], 
     Hue[1.0268025118182007`, 1, -4.511925935985771], 
     Hue[0.961472986679847, 1, -4.332664035218687], 
     Hue[1.0237274023855922`, 1, -4.146865103641739], 
     Hue[0.9614735347519586, 1, -3.9584282432665043`], 
     Hue[1.0271996346389076`, 1, -3.7622681139376253`], 
     Hue[0.9619645423685614, 1, -3.5827386104013197`], 
     Hue[1.0273973132365002`, 1, -3.38745419273293], 
     Hue[0.9622120552996845, 1, -3.2077975117932906`], 
     Hue[1.0274939219036683`, 1, -3.012964052152367], 
     Hue[0.9663804026629902, 1, -2.821204129319752], 
     Hue[1.025460407896729, 1, -2.6448808188215365`], 
     Hue[0.9663919497723863, 1, -2.4471224524649458`], 
     Hue[1.025854095125754, 1, -2.26966035936377], 
     Hue[0.966417311261529, 1, -2.073233276468957], 
     Hue[1.0291305929744303`, 1, -1.8860653099185327`], 
     Hue[0.9664729418781826, 1, -1.6997666594920922`], 
     Hue[1.029058957510465, 1, -1.5129793541691676`], 
     Hue[0.9665946221794022, 1, -1.3272257744933327`], 
     Hue[1.0289026693616745`, 1, -1.141270155885836], 
     Hue[0.9687959585095073, 1, -0.950958284671674], 
     Hue[1.0309219391972162`, 1, -0.7654589684835269], 
     Hue[0.9710073877986614, 1, -0.5799936576625608], 
     Hue[1.035285158909879, 1, -0.38760904936983875`], 
     Hue[0.9787720429654522, 1, -0.20402753536585583`], 
     Hue[1.0405366824516713`, 1, -0.017014654432870646`], 
     Hue[0.9939483829815808, 1, 0.17072648138895263`], 
     Hue[1.0528748341717127`, 1, 0.3608467177467448], 
     Hue[1.0214665891341896`, 1, 0.5465871092961012], 
     Hue[1.0087803670216686`, 1, 0.7341376687469793], 
     Hue[1.0150267987220831`, 1, 0.9217654617684384], 
     Hue[1.1387886154081293`, 1, -17.27618334189528], 
     Hue[1.076091214850663, 1, -17.089062133554293`], 
     Hue[1.135880288722114, 1, -16.91062086407678], 
     Hue[1.076091214850663, 1, -16.714819716872324`], 
     Hue[1.135880288722114, 1, -16.53637844739481], 
     Hue[1.076091214850663, 1, -16.34057730019035], 
     Hue[1.1363548051814114`, 1, -16.16071983016143], 
     Hue[1.076091214850663, 1, -15.966334883508381`], 
     Hue[1.1367106925258843`, 1, -15.7854152630659], 
     Hue[1.076091214850663, 1, -15.592092466826411`], 
     Hue[1.140625453315086, 1, -15.399489191834807`], 
     Hue[1.076091214850663, 1, -15.217850050144438`], 
     Hue[1.140625453315086, 1, -15.025246775152837`], 
     Hue[1.0760912148506627`, 1, -14.843607633462467`], 
     Hue[1.1406254533150855`, 1, -14.651004358470864`], 
     Hue[1.0760912148506625`, 1, -14.469365216780501`], 
     Hue[1.140625453315085, 1, -14.276761941788898`], 
     Hue[1.076091214850662, 1, -14.095122800098531`], 
     Hue[1.1406254533150835`, 1, -13.90251952510693], 
     Hue[1.0780505086180812`, 1, -13.715032845655912`], 
     Hue[1.1415438722685576`, 1, -13.52553607509966], 
     Hue[1.0780505086180783`, 1, -13.340790428973955`], 
     Hue[1.1415438722685507`, 1, -13.151293658417707`], 
     Hue[1.078050508618072, 1, -12.966548012292021`], 
     Hue[1.1415438722685354`, 1, -12.777051241735773`], 
     Hue[1.0780505086180583`, 1, -12.592305595610126`], 
     Hue[1.1415438722685014`, 1, -12.402808825053885`], 
     Hue[1.078050508618028, 1, -12.218063178928324`], 
     Hue[1.1415438722684272`, 1, -12.028566408372091`], 
     Hue[1.0790301555016701`, 1, -11.840896993366398`], 
     Hue[1.142003081745003, 1, -11.652953475027859`], 
     Hue[1.0790301555015216`, 1, -11.466654576685247`], 
     Hue[1.142003081744642, 1, -11.278711058346758`], 
     Hue[1.0790301555011945`, 1, -11.092412160005075`], 
     Hue[1.1420030817438485`, 1, -10.904468641666696`], 
     Hue[1.0795199789423193`, 1, -10.716707858886911`], 
     Hue[1.1440771778786325`, 1, -10.524036058062583`], 
     Hue[1.0798873465220973`, 1, -10.341369028883552`], 
     Hue[1.1442436413100103`, 1, -10.149296829099594`], 
     Hue[1.083928389913402, 1, -9.955066065589808], 
     Hue[1.144299129113122, 1, -9.774888808341105], 
     Hue[1.083928389905078, 1, -9.5808236489505], 
     Hue[1.1442991290940883`, 1, -9.400646391703598], 
     Hue[1.0839283898867758`, 1, -9.206581232362327], 
     Hue[1.1442991290522384`, 1, -9.026403975119395], 
     Hue[1.083928389846534, 1, -8.832338815886592], 
     Hue[1.1460747389335748`, 1, -8.64686222755551], 
     Hue[1.0839283897580536`, 1, -8.458096399658082], 
     Hue[1.1460747387272125`, 1, -8.272619811344645], 
     Hue[1.0839283895635092`, 1, -8.083853983973148], 
     Hue[1.1460747382734782`, 1, -7.898377395698515], 
     Hue[1.0839283891357592`, 1, -7.709611569483388], 
     Hue[1.1460747372758397`, 1, -7.524134981294066], 
     Hue[1.0839283881952533`, 1, -7.33536915762149], 
     Hue[1.146074735082305, 1, -7.149892569619744], 
     Hue[1.083928386127337, 1, -6.96112675153755], 
     Hue[1.1469625351603776`, 1, -6.773000498364987], 
     Hue[1.0839283815805534`, 1, -6.586884358157758], 
     Hue[1.1469625244512944`, 1, -6.398758105849524], 
     Hue[1.0858876647326825`, 1, -6.206794455425072], 
     Hue[1.147834998493977, 1, -6.021911760467853], 
     Hue[1.0858876420107118`, 1, -5.8325521519643555`], 
     Hue[1.147834946222393, 1, -5.647669460405286], 
     Hue[1.0858875920513282`, 1, -5.458309984225006], 
     Hue[1.148271079283451, 1, -5.27212530886804], 
     Hue[1.0858874822044438`, 1, -5.084068114899723], 
     Hue[1.1484889487584176`, 1, -4.897232459537761], 
     Hue[1.085887240681971, 1, -4.709826901704516], 
     Hue[1.1521964636128859`, 1, -4.5119243385078285`], 
     Hue[1.0868663404606678`, 1, -4.332663374145673], 
     Hue[1.1491203498593527`, 1, -4.146861764736631], 
     Hue[1.0868651536143683`, 1, -3.958426789785225], 
     Hue[1.152590326077989, 1, -3.7622603414383047`], 
     Hue[1.087352328547345, 1, -3.5827353404809656`], 
     Hue[1.1527830743652996`, 1, -3.3874370492768353`], 
     Hue[1.0875914134189129`, 1, -3.207790241050504], 
     Hue[1.152868842996141, 1, -3.012926303882203], 
     Hue[1.0917405094613561`, 1, -2.821185009734779], 
     Hue[1.1508117102299713`, 1, -2.644800547955951], 
     Hue[1.0917104906950157`, 1, -2.4470804401256503`], 
     Hue[1.1511080392007638`, 1, -2.269617762498388], 
     Hue[1.0916445488371824`, 1, -2.0731410303177187`], 
     Hue[1.1543134543622149`, 1, -1.8856542227197524`], 
     Hue[1.0914998560735423`, 1, -1.6995644499926696`], 
     Hue[1.1539882781647979`, 1, -1.5120789493280837`], 
     Hue[1.0911831379828536`, 1, -1.3267841222953851`], 
     Hue[1.1532765128166496`, 1, -1.1393070323401904`], 
     Hue[1.0924128963768442`, 1, -0.9499251897138263], 
     Hue[1.1524987625280294`, 1, -0.7659267949216395], 
     Hue[1.0918184647217857`, 1, -0.5798223089076406], 
     Hue[1.151759009990133, 1, -0.39042157609593975`], 
     Hue[1.0947490007124794`, 1, -0.20082843547367424`], 
     Hue[1.1493118128674362`, 1, -0.015167711940116346`], 
     Hue[1.0960870748026972`, 1, 0.17094926615223371`], 
     Hue[1.1422133013968736`, 1, 0.3585304326687989], 
     Hue[1.0963945659216623`, 1, 0.5469532865434619], 
     Hue[1.0631596371233103`, 1, 0.7339894462206431], 
     Hue[1.0415169209318613`, 1, 0.9221158863614395], 
     Hue[1.264183416523061, 1, -17.27618334189528], 
     Hue[1.2014860159655942`, 1, -17.089062133554293`], 
     Hue[1.2612750898370457`, 1, -16.91062086407678], 
     Hue[1.2014860159655942`, 1, -16.714819716872324`], 
     Hue[1.2612750898370457`, 1, -16.53637844739481], 
     Hue[1.2014860159655942`, 1, -16.34057730019035], 
     Hue[1.261749606296343, 1, -16.16071983016143], 
     Hue[1.201486015965594, 1, -15.966334883508381`], 
     Hue[1.262105493640816, 1, -15.7854152630659], 
     Hue[1.201486015965594, 1, -15.592092466826411`], 
     Hue[1.2660202544300172`, 1, -15.399489191834807`], 
     Hue[1.201486015965594, 1, -15.217850050144438`], 
     Hue[1.266020254430017, 1, -15.025246775152837`], 
     Hue[1.2014860159655938`, 1, -14.843607633462467`], 
     Hue[1.2660202544300165`, 1, -14.651004358470864`], 
     Hue[1.2014860159655931`, 1, -14.469365216780497`], 
     Hue[1.2660202544300159`, 1, -14.276761941788894`], 
     Hue[1.201486015965592, 1, -14.095122800098528`], 
     Hue[1.2660202544300139`, 1, -13.902519525106921`], 
     Hue[1.2034453097330104`, 1, -13.715032845655903`], 
     Hue[1.2669386733834878`, 1, -13.525536075099646`], 
     Hue[1.2034453097330047`, 1, -13.340790428973937`], 
     Hue[1.2669386733834789`, 1, -13.151293658417671`], 
     Hue[1.203445309732992, 1, -12.966548012291977`], 
     Hue[1.2669386733834591`, 1, -12.777051241735695`], 
     Hue[1.203445309732964, 1, -12.59230559561003], 
     Hue[1.2669386733834158`, 1, -12.40280882505371], 
     Hue[1.2034453097329025`, 1, -12.218063178928114`], 
     Hue[1.2669386733833208`, 1, -12.028566408371708`], 
     Hue[1.2044249566164758`, 1, -11.840896993365934`], 
     Hue[1.2673978828598509`, 1, -11.652953475027008`], 
     Hue[1.2044249566161762`, 1, -11.466654576684228`], 
     Hue[1.26739788285939, 1, -11.278711058344888`], 
     Hue[1.2044249566155178`, 1, -11.092412160002834`], 
     Hue[1.2673978828583765`, 1, -10.904468641662584`], 
     Hue[1.2049147800559155`, 1, -10.716707858881954`], 
     Hue[1.2694719789927058`, 1, -10.524036058053388`], 
     Hue[1.2052821476340936`, 1, -10.341369028872606`], 
     Hue[1.2696384424230607`, 1, -10.149296829079354`], 
     Hue[1.209323191021927, 1, -9.955066065564631], 
     Hue[1.2696939302239219`, 1, -9.774888808296582], 
     Hue[1.2093231910059234`, 1, -9.58082364889514], 
     Hue[1.2696939301999355`, 1, -9.400646391605708], 
     Hue[1.2093231909707356`, 1, -9.20658123224061], 
     Hue[1.2696939301471957`, 1, -9.026403974904161], 
     Hue[1.209323190893367, 1, -8.832338815618973], 
     Hue[1.2714695400058864`, 1, -8.646862227075507], 
     Hue[1.209323190723255, 1, -8.458096399069662], 
     Hue[1.2714695397484348`, 1, -8.272619810289253], 
     Hue[1.2093231903492245`, 1, -8.083853982679374], 
     Hue[1.2714695391823692`, 1, -7.898377393377992], 
     Hue[1.2093231895268335`, 1, -7.709611566638734], 
     Hue[1.2714695379377448`, 1, -7.524134976191871], 
     Hue[1.20932318771862, 1, -7.335369151366872], 
     Hue[1.2714695352011551`, 1, -7.149892558401414], 
     Hue[1.209323183742851, 1, -6.9611267377853485`], 
     Hue[1.2723573341193415`, 1, -6.773000473524675], 
     Hue[1.2093231750012192`, 1, -6.586884327920419], 
     Hue[1.272357320825839, 1, -6.39875805123245], 
     Hue[1.2112824489993879`, 1, -6.206794387493743], 
     Hue[1.2732297893507387`, 1, -6.021911639550012], 
     Hue[1.2112824060809806`, 1, -5.832552002601922], 
     Hue[1.2732297247823738`, 1, -5.647669194539957], 
     Hue[1.2112823117151197`, 1, -5.45830965581794], 
     Hue[1.2736658312084583`, 1, -5.272124722293757], 
     Hue[1.2112821042304063`, 1, -5.08406739282315], 
     Hue[1.2738836421622195`, 1, -4.897231167611339], 
     Hue[1.2112816480285387`, 1, -4.709825314060069], 
     Hue[1.2775910450756953`, 1, -4.511921414894039], 
     Hue[1.212260277698288, 1, -4.332659845883617], 
     Hue[1.2745146365177578`, 1, -4.146855488026594], 
     Hue[1.2122580552855478`, 1, -3.9584190322199406`], 
     Hue[1.2779840743938955`, 1, -3.7622461644034315`], 
     Hue[1.2127429580280462`, 1, -3.582718193325685], 
     Hue[1.2781755704131808`, 1, -3.38740583081092], 
     Hue[1.2129770472853125`, 1, -3.2077524417807153`], 
     Hue[1.2782585850362254`, 1, -3.0128576134723044`], 
     Hue[1.213190468421646, 1, -2.832818579727066], 
     Hue[1.278318714808788, 1, -2.6383080025803327`], 
     Hue[1.2170614451984867`, 1, -2.446889473322491], 
     Hue[1.2764257957504421`, 1, -2.2694443659313945`], 
     Hue[1.2169429000118779`, 1, -2.0727214799072815`], 
     Hue[1.2796561336704515`, 1, -1.8849151173288254`], 
     Hue[1.216682382445005, 1, -1.698643584629046], 
     Hue[1.2792673115024038`, 1, -1.5104553987944127`], 
     Hue[1.2161102137457274`, 1, -1.3247671725627648`], 
     Hue[1.2784111596736443`, 1, -1.135744838648843], 
     Hue[1.2148553115111769`, 1, -0.9513500077986332], 
     Hue[1.2765229227612094`, 1, -0.7605200660713292], 
     Hue[1.2118765408643177`, 1, -0.5797682642232558], 
     Hue[1.272249928334876, 1, -0.38466150564033863`], 
     Hue[1.207949754820661, 1, -0.20330348109589247`], 
     Hue[1.2604851050173986`, 1, -0.016505450372540142`], 
     Hue[1.1980521378652533`, 1, 0.17089062463089544`], 
     Hue[1.2404547360022335`, 1, 0.3587961628265901], 
     Hue[1.1772587900354834`, 1, 0.5461973170689334], 
     Hue[1.2002489559994574`, 1, 0.7340776308075776], 
     Hue[1.1229717702584097`, 1, 0.7338914116562333], 
     Hue[1.1297491320986202`, 1, 0.9221246871220596], 
     Hue[1.0767332972429908`, 1, 0.9216006405146484], 
     Hue[1.3895782176379927`, 1, -17.27618334189528], 
     Hue[1.326880817080526, 1, -17.089062133554293`], 
     Hue[1.386669890951977, 1, -16.91062086407678], 
     Hue[1.326880817080526, 1, -16.714819716872324`], 
     Hue[1.386669890951977, 1, -16.53637844739481], 
     Hue[1.326880817080526, 1, -16.34057730019035], 
     Hue[1.3871444074112746`, 1, -16.16071983016143], 
     Hue[1.326880817080526, 1, -15.966334883508381`], 
     Hue[1.3875002947557478`, 1, -15.7854152630659], 
     Hue[1.3268808170805257`, 1, -15.592092466826411`], 
     Hue[1.391415055544949, 1, -15.399489191834807`], 
     Hue[1.3268808170805257`, 1, -15.217850050144438`], 
     Hue[1.391415055544949, 1, -15.025246775152837`], 
     Hue[1.3268808170805255`, 1, -14.843607633462467`], 
     Hue[1.3914150555449485`, 1, -14.651004358470864`], 
     Hue[1.326880817080525, 1, -14.469365216780497`], 
     Hue[1.391415055544948, 1, -14.276761941788891`], 
     Hue[1.326880817080524, 1, -14.095122800098522`], 
     Hue[1.391415055544947, 1, -13.902519525106914`], 
     Hue[1.3288401108479424`, 1, -13.715032845655891`], 
     Hue[1.3923334744984222`, 1, -13.52553607509963], 
     Hue[1.3288401108479373`, 1, -13.34079042897391], 
     Hue[1.3923334744984166`, 1, -13.151293658417638`], 
     Hue[1.3288401108479255`, 1, -12.966548012291923`], 
     Hue[1.3923334744984042`, 1, -12.777051241735622`], 
     Hue[1.3288401108478998`, 1, -12.59230559560991], 
     Hue[1.392333474498377, 1, -12.40280882505355], 
     Hue[1.3288401108478434`, 1, -12.218063178927846`], 
     Hue[1.3923334744983171`, 1, -12.028566408371354`], 
     Hue[1.3298197577314288`, 1, -11.840896993365341`], 
     Hue[1.3927926839749258`, 1, -11.652953475026232`], 
     Hue[1.3298197577311552`, 1, -11.466654576682922`], 
     Hue[1.3927926839746365`, 1, -11.27871105834318], 
     Hue[1.3298197577305535`, 1, -11.092412159999967`], 
     Hue[1.3927926839740006`, 1, -10.90446864165883], 
     Hue[1.3303095811710826`, 1, -10.716707858875631`], 
     Hue[1.394866780109216, 1, -10.52403605804509], 
     Hue[1.3306769487495542`, 1, -10.34136902885868], 
     Hue[1.395033243541473, 1, -10.1492968290611], 
     Hue[1.3347179921383199`, 1, -9.95506606553332], 
     Hue[1.3950887313465137`, 1, -9.77488880825644], 
     Hue[1.3347179921240673`, 1, -9.580823648826295], 
     Hue[1.3950887313317095`, 1, -9.40064639151744], 
     Hue[1.3347179920927301`, 1, -9.206581232089235], 
     Hue[1.3950887312991593`, 1, -9.026403974710087], 
     Hue[1.334717992023828, 1, -8.83233881528614], 
     Hue[1.3968643412047625`, 1, -8.646862226646773], 
     Hue[1.3347179918723309`, 1, -8.458096398337851], 
     Hue[1.3968643410479378`, 1, -8.27261980934658], 
     Hue[1.3347179915392302`, 1, -8.083853981070321], 
     Hue[1.3968643407031225`, 1, -7.898377391305314], 
     Hue[1.3347179908068325`, 1, -7.7096115631008635`], 
     Hue[1.396864339944968, 1, -7.5241349716346155`], 
     Hue[1.3347179891964895`, 1, -7.3353691435880615`], 
     Hue[1.3968643382779926`, 1, -7.149892548381248], 
     Hue[1.334717985655784, 1, -6.961126720681867], 
     Hue[1.3977521396134402`, 1, -6.773000451442386], 
     Hue[1.3347179778707376`, 1, -6.586884290314519], 
     Hue[1.3977521315693655`, 1, -6.39875800267951], 
     Hue[1.3366772543649414`, 1, -6.206794303934257], 
     Hue[1.39862461194955, 1, -6.02191153255836], 
     Hue[1.3366772165418568`, 1, -5.832551818877369], 
     Hue[1.3986245731344848`, 1, -5.647668959294381], 
     Hue[1.3366771333791632`, 1, -5.45830925185765], 
     Hue[1.3990607369460295`, 1, -5.272124204486612], 
     Hue[1.336676950526879, 1, -5.08406650462423], 
     Hue[1.3992786741522472`, 1, -4.897230028474234], 
     Hue[1.336676548483643, 1, -4.709823361151106], 
     Hue[1.4029863856571672`, 1, -4.511918888012989], 
     Hue[1.3376553074816453`, 1, -4.332655529568], 
     Hue[1.39991056557412, 1, -4.146849972300579], 
     Hue[1.3376533591394053`, 1, -3.9584095417788863`], 
     Hue[1.403381500230303, 1, -3.7622339370234874`], 
     Hue[1.3381388893176824`, 1, -3.582697272199068], 
     Hue[1.4035761608713557`, 1, -3.387378932797411], 
     Hue[1.3383743599683076`, 1, -3.2077063816107563`], 
     Hue[1.4036661347440005`, 1, -3.0127984526432234`], 
     Hue[1.3385678876531755`, 1, -2.832785727347173], 
     Hue[1.4037322567116148`, 1, -2.6382057208936507`], 
     Hue[1.342470675364123, 1, -2.44666190877144], 
     Hue[1.401777161929052, 1, -2.269468040910029], 
     Hue[1.3423693149732219`, 1, -2.072220996839091], 
     Hue[1.4018690325826582`, 1, -1.8942173030309577`], 
     Hue[1.3421461531196384`, 1, -1.6975425303132223`], 
     Hue[1.4049673138150849`, 1, -1.509061426903927], 
     Hue[1.3416540394145169`, 1, -1.3223432492467546`], 
     Hue[1.400952946401536, 1, -1.1432932328940273`], 
     Hue[1.3405650354165244`, 1, -0.9460062899233574], 
     Hue[1.3992208625234555`, 1, -0.7663770537283625], 
     Hue[1.334019971238443, 1, -0.5801906115416786], 
     Hue[1.3939652257795483`, 1, -0.39071106378171794`], 
     Hue[1.3264505595513763`, 1, -0.20408000662714], 
     Hue[1.38148186169083, 1, -0.0170159496490776], 
     Hue[1.43829188938079, 1, 0.17479340060993898`], 
     Hue[1.309661921974266, 1, 0.17105451354614176`], 
     Hue[1.3562038957948173`, 1, 0.35927401854952434`], 
     Hue[1.4015474839577673`, 1, 0.5466735326494491], 
     Hue[1.2758405001236128`, 1, 0.5461388415932668], 
     Hue[1.3049938817231874`, 1, 0.7343183604493762], 
     Hue[1.3286066206130087`, 1, 0.9217268881060485], 
     Hue[1.3480422177625098`, 1, 1.1093519079347263`], 
     Hue[1.210183395637621, 1, 0.921599168930944], 
     Hue[1.204923266782775, 1, 1.1093844578385919`], 
     Hue[1.1776108389429032`, 1, 1.297002487957064], 
     Hue[1.1080187657088139`, 1, 1.110260225619777], 
     Hue[1.0418005286497818`, 1, 1.109774992419503], 
     Hue[0.5149730187529238, 1, -17.27618334189528], 
     Hue[1.4522756181954577`, 1, -17.089062133554293`], 
     Hue[0.5120646920669086, 1, -16.91062086407678], 
     Hue[1.4522756181954577`, 1, -16.714819716872324`], 
     Hue[0.5120646920669086, 1, -16.53637844739481], 
     Hue[1.4522756181954577`, 1, -16.34057730019035], 
     Hue[0.5125392085262059, 1, -16.16071983016143], 
     Hue[1.4522756181954577`, 1, -15.966334883508381`], 
     Hue[0.5128950958706789, 1, -15.7854152630659], 
     Hue[1.4522756181954577`, 1, -15.592092466826411`], 
     Hue[0.5168098566598807, 1, -15.399489191834807`], 
     Hue[1.4522756181954577`, 1, -15.217850050144438`], 
     Hue[0.5168098566598807, 1, -15.025246775152837`], 
     Hue[1.4522756181954575`, 1, -14.843607633462467`], 
     Hue[0.5168098566598808, 1, -14.65100435847086], 
     Hue[1.4522756181954573`, 1, -14.469365216780494`], 
     Hue[0.5168098566598809, 1, -14.276761941788891`], 
     Hue[1.452275618195457, 1, -14.095122800098519`], 
     Hue[0.5168098566598811, 1, -13.902519525106912`], 
     Hue[1.4542349119628768`, 1, -13.715032845655882`], 
     Hue[0.5177282756133594, 1, -13.525536075099625`], 
     Hue[1.454234911962875, 1, -13.340790428973895`], 
     Hue[0.5177282756133605, 1, -13.151293658417627`], 
     Hue[1.4542349119628712`, 1, -12.966548012291888`], 
     Hue[0.5177282756133627, 1, -12.777051241735599`], 
     Hue[1.454234911962863, 1, -12.592305595609831`], 
     Hue[0.5177282756133674, 1, -12.402808825053498`], 
     Hue[1.4542349119628448`, 1, -12.218063178927675`], 
     Hue[0.5177282756133781, 1, -12.028566408371242`], 
     Hue[1.4552145588465166`, 1, -11.840896993364968`], 
     Hue[0.5181874850901429, 1, -11.652953475025987`], 
     Hue[1.4552145588464298`, 1, -11.466654576682103`], 
     Hue[0.5181874850901957, 1, -11.278711058342644`], 
     Hue[1.4552145588462393`, 1, -11.092412159998164`], 
     Hue[0.5181874850903119, 1, -10.90446864165765], 
     Hue[1.4557043822876812`, 1, -10.71670785887167], 
     Hue[0.5202615812272321, 1, -10.524036058042576`], 
     Hue[1.4560717498681677`, 1, -10.341369028849975`], 
     Hue[0.5204280446631954, 1, -10.149296829055586`], 
     Hue[1.4601127932617186`, 1, -9.955066065514323], 
     Hue[0.5204835324763827, 1, -9.774888808244329], 
     Hue[1.4601127932576163`, 1, -9.580823648784527], 
     Hue[0.520483532479485, 1, -9.400646391490815], 
     Hue[1.4601127932485967`, 1, -9.206581231997404], 
     Hue[0.5204835324863062, 1, -9.026403974651542], 
     Hue[1.4601127932287647`, 1, -8.832338815084228], 
     Hue[0.5222591424807346, 1, -8.646862226521957], 
     Hue[1.4601127931851599`, 1, -8.458096397893904], 
     Hue[0.5222591425169532, 1, -8.272619809072145], 
     Hue[1.4601127930892848`, 1, -8.0838539800942], 
     Hue[0.5222591425965877, 1, -7.8983773907019055`], 
     Hue[1.4601127928784816`, 1, -7.7096115609546425`], 
     Hue[0.5222591427716825, 1, -7.524134970307883], 
     Hue[1.4601127924149826`, 1, -7.335369138869104], 
     Hue[0.5222591431566684, 1, -7.149892545464126], 
     Hue[1.4601127913958745`, 1, -6.961126710306165], 
     Hue[0.5231469490620366, 1, -6.77300044513119], 
     Hue[1.4601127891551333`, 1, -6.586884267501175], 
     Hue[0.523146951007756, 1, -6.398757988802906], 
     Hue[1.4620720783244656`, 1, -6.206794253988133], 
     Hue[0.5240194536299921, 1, -6.021911502543008], 
     Hue[1.462072067885826, 1, -5.832551709059411], 
     Hue[0.5240194634419506, 1, -5.6476688932987535`], 
     Hue[1.4620720449340832`, 1, -5.458309010397668], 
     Hue[0.524455734842365, 1, -5.272124060590952], 
     Hue[1.4620719944693594`, 1, -5.084065973718471], 
     Hue[0.5246739086750535, 1, -4.897229713424333], 
     Hue[1.4620718835107218`, 1, -4.709822193828888], 
     Hue[0.5283821674548373, 1, -4.511918246982164], 
     Hue[1.4630512950785848`, 1, -4.3326529688200415`], 
     Hue[0.5253074723568119, 1, -4.146848468103433], 
     Hue[1.4630507690183028`, 1, -3.958403911270949], 
     Hue[0.5287810569479958, 1, -3.7622308655691414`], 
     Hue[1.463539456919435, 1, -3.5826849064056754`], 
     Hue[0.5289814345984873, 1, -3.3873722095499215`], 
     Hue[1.463781873893199, 1, -3.2076792062321866`], 
     Hue[0.5290839818615629, 1, -3.0127837010021974`], 
     Hue[1.4639600865574578`, 1, -2.8328173929685647`], 
     Hue[0.5291653304125148, 1, -2.6382104683404792`], 
     Hue[1.467929738353546, 1, -2.4465319205332383`], 
     Hue[0.5272818996406528, 1, -2.2693936812213416`], 
     Hue[1.4679054548961192`, 1, -2.0719348551202277`], 
     Hue[0.5274673080935025, 1, -1.8941699902296996`], 
     Hue[1.4678519344214769`, 1, -1.696911769165532], 
     Hue[0.5275340741155469, 1, -1.5187858706571247`], 
     Hue[1.467733636120442, 1, -1.320948538800918], 
     Hue[0.5273162435277955, 1, -1.1431117307451324`], 
     Hue[1.463259922022839, 1, -0.955547609899918], 
     Hue[0.5260881429582129, 1, -0.7678981605876778], 
     Hue[1.4608531919832333`, 1, -0.5784278924564712], 
     Hue[0.5242627085816237, 1, -0.38868308942442575`], 
     Hue[1.454140758854797, 1, -0.20187637515522328`], 
     Hue[0.5160975278844087, 1, -0.014493915101209787`], 
     Hue[0.5839460466011812, 1, 0.17358714767069916`], 
     Hue[1.4961145350793186`, 1, 0.35871080625786655`], 
     Hue[0.5646852491009047, 1, 0.5461254184110552], 
     Hue[1.449158576875048, 1, 0.7339421344628321], 
     Hue[0.505681862560611, 1, 0.9217379975277402], 
     Hue[0.5901902482463284, 1, 1.1093024381642955`], 
     Hue[1.3647701149118991`, 1, 1.2979948998062865`], 
     Hue[0.9820747890067584, 1, 1.2970095958367505`], 
     Hue[1.0036628575345605`, 1, 1.109444825476447], 
     Hue[0.6403678198678555, 1, -17.27618334189528], 
     Hue[0.5776704193103888, 1, -17.089062133554293`], 
     Hue[0.6374594931818404, 1, -16.91062086407678], 
     Hue[0.5776704193103888, 1, -16.714819716872324`], 
     Hue[0.6374594931818404, 1, -16.53637844739481], 
     Hue[0.5776704193103888, 1, -16.34057730019035], 
     Hue[0.6379340096411377, 1, -16.16071983016143], 
     Hue[0.5776704193103888, 1, -15.966334883508381`], 
     Hue[0.6382898969856107, 1, -15.7854152630659], 
     Hue[0.5776704193103888, 1, -15.592092466826411`], 
     Hue[0.6422046577748126, 1, -15.399489191834807`], 
     Hue[0.577670419310389, 1, -15.217850050144438`], 
     Hue[0.6422046577748126, 1, -15.025246775152837`], 
     Hue[0.577670419310389, 1, -14.843607633462467`], 
     Hue[0.642204657774813, 1, -14.651004358470864`], 
     Hue[0.5776704193103892, 1, -14.469365216780494`], 
     Hue[0.6422046577748137, 1, -14.276761941788891`], 
     Hue[0.5776704193103899, 1, -14.095122800098519`], 
     Hue[0.6422046577748151, 1, -13.902519525106916`], 
     Hue[0.5796297130778122, 1, -13.715032845655884`], 
     Hue[0.6431230767282957, 1, -13.525536075099634`], 
     Hue[0.5796297130778152, 1, -13.340790428973898`], 
     Hue[0.6431230767283027, 1, -13.151293658417645`], 
     Hue[0.5796297130778214, 1, -12.966548012291893`], 
     Hue[0.6431230767283183, 1, -12.777051241735638`], 
     Hue[0.5796297130778354, 1, -12.592305595609846`], 
     Hue[0.6431230767283522, 1, -12.402808825053587`], 
     Hue[0.5796297130778663, 1, -12.218063178927705`], 
     Hue[0.6431230767284271, 1, -12.028566408371438`], 
     Hue[0.5806093599616464, 1, -11.840896993365034`], 
     Hue[0.6435822862053334, 1, -11.65295347502642], 
     Hue[0.5806093599617977, 1, -11.46665457668225], 
     Hue[0.6435822862056972, 1, -11.278711058343593`], 
     Hue[0.5806093599621307, 1, -11.092412159998487`], 
     Hue[0.643582286206497, 1, -10.904468641659735`], 
     Hue[0.58109918340473, 1, -10.716707858872406`], 
     Hue[0.6456563823449366, 1, -10.524036058047328`], 
     Hue[0.5814665509877637, 1, -10.341369028851624`], 
     Hue[0.6458228457842259, 1, -10.149296829066063`], 
     Hue[0.5855075943871344, 1, -9.955066065518839], 
     Hue[0.6458783336047271, 1, -9.77488880826739], 
     Hue[0.5855075943955999, 1, -9.580823648794457], 
     Hue[0.6458783336239077, 1, -9.40064639154152], 
     Hue[0.585507594414213, 1, -9.206581232019234], 
     Hue[0.6458783336660805, 1, -9.026403974763024], 
     Hue[0.5855075944551383, 1, -8.832338815132227], 
     Hue[0.6476539437389015, 1, -8.646862226774614], 
     Hue[0.585507594545122, 1, -8.458096397999437], 
     Hue[0.6476539439468199, 1, -8.27261980962767], 
     Hue[0.5855075947429715, 1, -8.083853980326241], 
     Hue[0.6476539444039757, 1, -7.898377391923355], 
     Hue[0.5855075951779888, 1, -7.7096115614648335`], 
     Hue[0.6476539454091367, 1, -7.524134972993514], 
     Hue[0.5855075961344733, 1, -7.335369139990875], 
     Hue[0.647653947619212, 1, -7.1498925513691], 
     Hue[0.585507598237522, 1, -6.961126712772635], 
     Hue[0.6485417575541101, 1, -6.7730004583102685`], 
     Hue[0.585507602861553, 1, -6.586884272924273], 
     Hue[0.6485417683430128, 1, -6.3987580177801116`], 
     Hue[0.5874669074156638, 1, -6.2067942670885925`], 
     Hue[0.6494142904868394, 1, -6.021911567191998], 
     Hue[0.587466930512959, 1, -5.832551737863765], 
     Hue[0.6494143431436299, 1, -5.647669035444353], 
     Hue[0.5874669812976551, 1, -5.458309073730666], 
     Hue[0.6498507089340096, 1, -5.272124375404934], 
     Hue[0.5874670929595476, 1, -5.084066112970814], 
     Hue[0.650069090321959, 1, -4.897230408123127], 
     Hue[0.5874673384745182, 1, -4.7098225000084915`], 
     Hue[0.6537778125436199, 1, -4.51191986957382], 
     Hue[0.5884475412893602, 1, -4.332653672750929], 
     Hue[0.6507041159532696, 1, -4.146851861924887], 
     Hue[0.5884487475456598, 1, -3.95840545906366], 
     Hue[0.6541799418440664, 1, -3.7622387603587093`], 
     Hue[0.5889412624762812, 1, -3.5826883846251327`], 
     Hue[0.6543852189726833, 1, -3.3873896245827337`], 
     Hue[0.5891920965700412, 1, -3.2076869374842127`], 
     Hue[0.6544985399648156, 1, -3.0128220589752006`], 
     Hue[0.5893888326509902, 1, -2.832834533244897], 
     Hue[0.6546035833495887, 1, -2.638294937684602], 
     Hue[0.5934007407425332, 1, -2.446576289898351], 
     Hue[0.6527718564161669, 1, -2.2695739761461846`], 
     Hue[0.5934679131729355, 1, -2.072032546080025], 
     Hue[0.6564390600515015, 1, -1.8845515970578959`], 
     Hue[0.5936159071773406, 1, -1.6971272187391253`], 
     Hue[0.6567688650427728, 1, -1.5096546487080775`], 
     Hue[0.5939427629607408, 1, -1.3214254358505466`], 
     Hue[0.657497215474449, 1, -1.1339771420154754`], 
     Hue[0.5946685426332969, 1, -0.9439655789599546], 
     Hue[0.655281005540565, 1, -0.767631232195759], 
     Hue[0.5911768449887334, 1, -0.5773593835852988], 
     Hue[0.6566969907684599, 1, -0.3922245819994761], 
     Hue[0.5892614846259495, 1, -0.20233993211070356`], 
     Hue[0.6602864570194691, 1, -0.013938797433049821`], 
     Hue[0.6636354233799571, 1, 0.3602747558284862], 
     Hue[0.6615750480421161, 1, 0.7340112982960377], 
     Hue[0.8419524801741471, 1, 1.1093256610110505`], 
     Hue[0.9403485482744265, 1, 1.109285146270565], 
     Hue[0.9068439278881797, 1, 1.2971117959729248`], 
     Hue[0.9717037721698263, 1, 1.1093473412679515`], 
     Hue[0.9884636454404422, 1, 1.109436759310692], 
     Hue[0.7657626209827872, 1, -17.27618334189528], 
     Hue[0.7030652204253205, 1, -17.089062133554293`], 
     Hue[0.7628542942967715, 1, -16.91062086407678], 
     Hue[0.7030652204253205, 1, -16.714819716872324`], 
     Hue[0.7628542942967715, 1, -16.53637844739481], 
     Hue[0.7030652204253205, 1, -16.34057730019035], 
     Hue[0.7633288107560694, 1, -16.16071983016143], 
     Hue[0.7030652204253205, 1, -15.966334883508381`], 
     Hue[0.7636846981005424, 1, -15.7854152630659], 
     Hue[0.7030652204253205, 1, -15.592092466826411`], 
     Hue[0.7675994588897438, 1, -15.399489191834807`], 
     Hue[0.7030652204253207, 1, -15.217850050144438`], 
     Hue[0.7675994588897439, 1, -15.025246775152837`], 
     Hue[0.7030652204253209, 1, -14.843607633462467`], 
     Hue[0.7675994588897443, 1, -14.651004358470864`], 
     Hue[0.7030652204253214, 1, -14.469365216780497`], 
     Hue[0.7675994588897451, 1, -14.276761941788894`], 
     Hue[0.7030652204253227, 1, -14.095122800098524`], 
     Hue[0.767599458889747, 1, -13.902519525106925`], 
     Hue[0.7050245141927464, 1, -13.715032845655895`], 
     Hue[0.768517877843229, 1, -13.525536075099652`], 
     Hue[0.7050245141927521, 1, -13.340790428973918`], 
     Hue[0.7685178778432379, 1, -13.15129365841768], 
     Hue[0.7050245141927649, 1, -12.966548012291936`], 
     Hue[0.7685178778432575, 1, -12.777051241735718`], 
     Hue[0.7050245141927929, 1, -12.592305595609941`], 
     Hue[0.7685178778433008, 1, -12.40280882505376], 
     Hue[0.7050245141928546, 1, -12.218063178927915`], 
     Hue[0.7685178778433958, 1, -12.028566408371823`], 
     Hue[0.7060041610767023, 1, -11.840896993365503`], 
     Hue[0.7689770873203456, 1, -11.652953475027271`], 
     Hue[0.7060041610770025, 1, -11.466654576683279`], 
     Hue[0.768977087320806, 1, -11.278711058345467`], 
     Hue[0.7060041610776628, 1, -11.092412160000746`], 
     Hue[0.7689770873218182, 1, -10.904468641663856`], 
     Hue[0.7064939845209807, 1, -10.7167078588774], 
     Hue[0.7710511834606949, 1, -10.524036058056547`], 
     Hue[0.7068613521055931, 1, -10.341369028862655`], 
     Hue[0.7712176469009712, 1, -10.149296829086358`], 
     Hue[0.7109023955083886, 1, -9.955066065544203], 
     Hue[0.7712731347236423, 1, -9.77488880831203], 
     Hue[0.7109023955244331, 1, -9.58082364885023], 
     Hue[0.7712731347475981, 1, -9.400646391639672], 
     Hue[0.7109023955597105, 1, -9.20658123214186], 
     Hue[0.7712731348002702, 1, -9.026403974978841], 
     Hue[0.7109023956372758, 1, -8.832338815401847], 
     Hue[0.7730487448948543, 1, -8.646862227255856], 
     Hue[0.7109023958078207, 1, -8.45809639859226], 
     Hue[0.7730487451519464, 1, -8.272619810685786], 
     Hue[0.7109023961828023, 1, -8.083853981629698], 
     Hue[0.773048745717222, 1, -7.898377394249862], 
     Hue[0.710902397007285, 1, -7.709611564330783], 
     Hue[0.773048746960109, 1, -7.524134978108873], 
     Hue[0.7109023988200975, 1, -7.335369146292318], 
     Hue[0.7730487496928786, 1, -7.149892562616377], 
     Hue[0.7109024028059785, 1, -6.961126726627788], 
     Hue[0.7739365607423183, 1, -6.7730004832132025`], 
     Hue[0.7109024115698446, 1, -6.586884303387984], 
     Hue[0.7739365740165138, 1, -6.398758072534882], 
     Hue[0.7128617251521446, 1, -6.206794335515542], 
     Hue[0.7748091014574109, 1, -6.021911688407699], 
     Hue[0.7128617681741432, 1, -5.832551888316022], 
     Hue[0.7748091659283967, 1, -5.647669301964694], 
     Hue[0.7128618627678127, 1, -5.458309404534395], 
     Hue[0.7752455572857752, 1, -5.27212496340786], 
     Hue[0.7128620707536066, 1, -5.084066840319121], 
     Hue[0.7754639948449196, 1, -4.897231703179706], 
     Hue[0.7128625280581404, 1, -4.709824099254317], 
     Hue[0.7791728235661832, 1, -4.511922799567079], 
     Hue[0.7138431944987615, 1, -4.332657226513125], 
     Hue[0.7760994105685992, 1, -4.14685815365543], 
     Hue[0.7138454221703312, 1, -3.958413272938877], 
     Hue[0.7795757482468666, 1, -3.7622529683090855`], 
     Hue[0.7143401777661428, 1, -3.582705656623391], 
     Hue[0.7797822196682983, 1, -3.387420911876811], 
     Hue[0.7145959376079953, 1, -3.2077250167883067`], 
     Hue[0.7798981638648439, 1, -3.012890905977674], 
     Hue[0.7148341232544562, 1, -2.8328270898686636`], 
     Hue[0.7800214005941891, 1, -2.638409312763063], 
     Hue[0.7188387172354535, 1, -2.4467687974526955`], 
     Hue[0.7782942981771821, 1, -2.2695942735109647`], 
     Hue[0.7189575993623123, 1, -2.072456148909189], 
     Hue[0.7818826294216834, 1, -1.8852933255586517`], 
     Hue[0.7192191120148119, 1, -1.6980602076963398`], 
     Hue[0.7822697098990374, 1, -1.5112869424904096`], 
     Hue[0.7197946975728855, 1, -1.3234845754497429`], 
     Hue[0.7831194289733354, 1, -1.1375729410601931`], 
     Hue[0.7210630506600122, 1, -0.948530614420076], 
     Hue[0.7849809494563055, 1, -0.7645376257151293], 
     Hue[0.7238647148059125, 1, -0.5728268701034709], 
     Hue[0.7907498285821446, 1, -0.3885190910274554], 
     Hue[0.7279622553823213, 1, -0.2013658366988016], 
     Hue[0.8023189472128052, 1, -0.015197670565709087`], 
     Hue[0.7390773049836924, 1, 0.1711879392367054], 
     Hue[0.8325035959498546, 1, 0.35907980492077685`], 
     Hue[0.7712606178247788, 1, 0.5462865581677828], 
     Hue[0.8911574220977183, 1, -17.27618334189528], 
     Hue[0.8284600215402522, 1, -17.089062133554293`], 
     Hue[0.8882490954117033, 1, -16.91062086407678], 
     Hue[0.8284600215402522, 1, -16.714819716872324`], 
     Hue[0.8882490954117033, 1, -16.53637844739481], 
     Hue[0.8284600215402522, 1, -16.34057730019035], 
     Hue[0.8887236118710006, 1, -16.16071983016143], 
     Hue[0.8284600215402522, 1, -15.966334883508381`], 
     Hue[0.8890794992154736, 1, -15.7854152630659], 
     Hue[0.8284600215402523, 1, -15.592092466826411`], 
     Hue[0.8929942600046754, 1, -15.399489191834807`], 
     Hue[0.8284600215402524, 1, -15.217850050144438`], 
     Hue[0.8929942600046755, 1, -15.025246775152837`], 
     Hue[0.8284600215402527, 1, -14.843607633462467`], 
     Hue[0.8929942600046759, 1, -14.651004358470864`], 
     Hue[0.8284600215402531, 1, -14.469365216780497`], 
     Hue[0.8929942600046763, 1, -14.276761941788898`], 
     Hue[0.8284600215402542, 1, -14.09512280009853], 
     Hue[0.8929942600046775, 1, -13.902519525106932`], 
     Hue[0.8304193153076771, 1, -13.715032845655905`], 
     Hue[0.893912678958158, 1, -13.525536075099664`], 
     Hue[0.8304193153076824, 1, -13.340790428973941`], 
     Hue[0.8939126789581635, 1, -13.151293658417714`], 
     Hue[0.830419315307694, 1, -12.966548012291993`], 
     Hue[0.8939126789581757, 1, -12.77705124173579], 
     Hue[0.8304193153077195, 1, -12.592305595610062`], 
     Hue[0.8939126789582026, 1, -12.402808825053922`], 
     Hue[0.8304193153077757, 1, -12.218063178928183`], 
     Hue[0.8939126789582618, 1, -12.028566408372175`], 
     Hue[0.8313989621916106, 1, -11.840896993366094`], 
     Hue[0.8943718884351316, 1, -11.652953475028045`], 
     Hue[0.8313989621918828, 1, -11.466654576684581`], 
     Hue[0.8943718884354173, 1, -11.278711058347165`], 
     Hue[0.8313989621924812, 1, -11.092412160003612`], 
     Hue[0.8943718884360452, 1, -10.90446864166759], 
     Hue[0.8318887856356555, 1, -10.716707858883714`], 
     Hue[0.8964459845740207, 1, -10.524036058064796`], 
     Hue[0.8322561532199491, 1, -10.341369028876567`], 
     Hue[0.8966124480123618, 1, -10.14929682910451], 
     Hue[0.8362971966217548, 1, -9.95506606557547], 
     Hue[0.896667935830781, 1, -9.774888808351948], 
     Hue[0.8362971966359234, 1, -9.580823648918978], 
     Hue[0.8966679358453947, 1, -9.400646391727436], 
     Hue[0.8362971966670759, 1, -9.206581232293019], 
     Hue[0.8966679358775265, 1, -9.02640397517181], 
     Hue[0.836297196735572, 1, -8.832338815734206], 
     Hue[0.8984435459244202, 1, -8.646862227682083], 
     Hue[0.8362971968861762, 1, -8.458096399323026], 
     Hue[0.8984435460791821, 1, -8.272619811622945], 
     Hue[0.8362971972173138, 1, -8.083853983236448], 
     Hue[0.8984435464194611, 1, -7.89837739631042], 
     Hue[0.836297197945395, 1, -7.709611567863591], 
     Hue[0.8984435471676421, 1, -7.524134982639482], 
     Hue[0.8362971995462474, 1, -7.335369154059998], 
     Hue[0.8984435488126881, 1, -7.149892572577948], 
     Hue[0.8362972030660852, 1, -6.9611267437067985`], 
     Hue[0.8993313574048831, 1, -6.773000505164721], 
     Hue[0.8362972108052491, 1, -6.5868843409400695`], 
     Hue[0.8993313653419034, 1, -6.398758120800285], 
     Hue[0.8382565217388509, 1, -6.206794418945028], 
     Hue[0.9002038807338059, 1, -6.021911794757809], 
     Hue[0.838256559332726, 1, -5.832552071754713], 
     Hue[0.9002039190263218, 1, -5.647669535799509], 
     Hue[0.8382566419913734, 1, -5.458309807866012], 
     Hue[0.9006402520614413, 1, -5.272125478089658], 
     Hue[0.8382568237350252, 1, -5.084067727135077], 
     Hue[0.9008585613076043, 1, -4.8972328354157835`], 
     Hue[0.8382572233388818, 1, -4.709826049119224], 
     Hue[0.9045670768340666, 1, -4.511925310306943], 
     Hue[0.8392377525758863, 1, -4.3326615358134655`], 
     Hue[0.9014930654286645, 1, -4.146863635518526], 
     Hue[0.8392396888710071, 1, -3.9584227478741996`], 
     Hue[0.9049678839738469, 1, -3.762265116384091], 
     Hue[0.8397337784881362, 1, -3.582726542505015], 
     Hue[0.905171141602883, 1, -3.387447632386465], 
     Hue[0.8399880706608341, 1, -3.207770996660578], 
     Hue[0.9052800169634603, 1, -3.0129496634166957`], 
     Hue[0.8402517029304197, 1, -2.8328426706635117`], 
     Hue[0.9053993472033942, 1, -2.638503720369351], 
     Hue[0.8442182492819263, 1, -2.446995820226795], 
     Hue[0.9037056373573861, 1, -2.269646075502588], 
     Hue[0.8443187173787958, 1, -2.0729551718389665`], 
     Hue[0.907135924565386, 1, -1.885918900507925], 
     Hue[0.844539319286392, 1, -1.6991567515859665`], 
     Hue[0.907352904043337, 1, -1.5126588860748649`], 
     Hue[0.8450229134961489, 1, -1.325892298069357], 
     Hue[0.9078268416034557, 1, -1.1405724558937693`], 
     Hue[0.8460792136919938, 1, -0.9538083526802217], 
     Hue[0.9104960984333691, 1, -0.7662650098408901], 
     Hue[0.8503417165996987, 1, -0.5787649496218561], 
     Hue[0.9182073836370185, 1, -0.3867632282219984], 
     Hue[0.860175672691254, 1, -0.20233843803667906`], 
     Hue[0.9296765793406969, 1, -0.01696731556541331], 
     Hue[0.8808405826690642, 1, 0.17069686400663497`], 
     Hue[0.958746060377358, 1, 0.3584424089860706], 
     Hue[0.9340942714891347, 1, 0.5476325132349549], 
     Hue[0.9306114583096586, 1, 0.7341351109240237], 
     Hue[0.9854107990327602, 1, 0.922140672744149], 
     Hue[1.01655222321265, 1, -17.27618334189528], 
     Hue[0.9538548226551834, 1, -17.089062133554293`], 
     Hue[1.013643896526635, 1, -16.91062086407678], 
     Hue[0.9538548226551834, 1, -16.714819716872324`], 
     Hue[1.013643896526635, 1, -16.53637844739481], 
     Hue[0.9538548226551834, 1, -16.34057730019035], 
     Hue[1.0141184129859322`, 1, -16.16071983016143], 
     Hue[0.9538548226551834, 1, -15.966334883508381`], 
     Hue[1.0144743003304053`, 1, -15.7854152630659], 
     Hue[0.9538548226551834, 1, -15.592092466826411`], 
     Hue[1.0183890611196071`, 1, -15.399489191834807`], 
     Hue[0.9538548226551835, 1, -15.217850050144438`], 
     Hue[1.0183890611196071`, 1, -15.025246775152837`], 
     Hue[0.9538548226551835, 1, -14.843607633462467`], 
     Hue[1.018389061119607, 1, -14.651004358470868`], 
     Hue[0.9538548226551837, 1, -14.469365216780501`], 
     Hue[1.018389061119607, 1, -14.276761941788898`], 
     Hue[0.9538548226551841, 1, -14.095122800098533`], 
     Hue[1.0183890611196067`, 1, -13.902519525106934`], 
     Hue[0.9558141164226058, 1, -13.715032845655914`], 
     Hue[1.0193074800730835`, 1, -13.52553607509967], 
     Hue[0.9558141164226075, 1, -13.340790428973959`], 
     Hue[1.0193074800730824`, 1, -13.151293658417725`], 
     Hue[0.9558141164226112, 1, -12.966548012292026`], 
     Hue[1.0193074800730801`, 1, -12.777051241735814`], 
     Hue[0.9558141164226192, 1, -12.592305595610139`], 
     Hue[1.0193074800730748`, 1, -12.40280882505397], 
     Hue[0.9558141164226367, 1, -12.21806317892835], 
     Hue[1.0193074800730633`, 1, -12.028566408372283`], 
     Hue[0.9567937633063845, 1, -11.840896993366464`], 
     Hue[1.0197666895497772`, 1, -11.652953475028282`], 
     Hue[0.9567937633064681, 1, -11.46665457668539], 
     Hue[1.0197666895497197`, 1, -11.278711058347684`], 
     Hue[0.9567937633066522, 1, -11.092412160005393`], 
     Hue[1.0197666895495936`, 1, -10.90446864166873], 
     Hue[0.9572835867489067, 1, -10.716707858887627`], 
     Hue[1.0218407856858598`, 1, -10.52403605806722], 
     Hue[0.9576509543311703, 1, -10.341369028885161`], 
     Hue[1.0220072491204848`, 1, -10.149296829109822`], 
     Hue[0.9616919977281564, 1, -9.955066065594215], 
     Hue[1.0220627369307347`, 1, -9.774888808363613], 
     Hue[0.9616919977320995, 1, -9.58082364896019], 
     Hue[1.0220627369273947`, 1, -9.40064639175309], 
     Hue[0.9616919977407691, 1, -9.206581232383632], 
     Hue[1.022062736920051, 1, -9.026403975228213], 
     Hue[0.9616919977598313, 1, -8.832338815933442], 
     Hue[1.0238383468779046`, 1, -8.646862227802123], 
     Hue[0.9616919978017439, 1, -8.458096399761091], 
     Hue[1.0238383468391352`, 1, -8.272619811886884], 
     Hue[0.9616919978938983, 1, -8.083853984199635], 
     Hue[1.0238383467538916`, 1, -7.898377396890745], 
     Hue[0.9616919980965207, 1, -7.709611569981374], 
     Hue[1.0238383465664644`, 1, -7.524134983915457], 
     Hue[0.9616919985420324, 1, -7.335369158716429], 
     Hue[1.023838346154363, 1, -7.149892575383471], 
     Hue[0.9616919995215908, 1, -6.961126753945021], 
     Hue[1.0247261501655793`, 1, -6.77300051122882], 
     Hue[0.9616920016753726, 1, -6.586884363451133], 
     Hue[1.0247261480881489`, 1, -6.398758134133583], 
     Hue[0.9636512998442686, 1, -6.206794468212158], 
     Hue[1.0255986411854576`, 1, -6.021911823570375], 
     Hue[0.963651309856012, 1, -5.83255218007966], 
     Hue[1.0255986307338145`, 1, -5.647669599150443], 
     Hue[0.9636513318690884, 1, -5.458310046042831], 
     Hue[1.026034855926817, 1, -5.2721256161500865`], 
     Hue[0.9636513802697522, 1, -5.084068250819937], 
     Hue[1.0262529279912767`, 1, -4.897233137611595], 
     Hue[0.9636514866891758, 1, -4.7098272005544075`], 
     Hue[1.029960895197306, 1, -4.511925922246721], 
     Hue[0.9646313587643969, 1, -4.332664061208509], 
     Hue[1.026885756042308, 1, -4.146865077193241], 
     Hue[0.964631862682568, 1, -3.958428300409442], 
     Hue[1.0303579198367945`, 1, -3.762268046431858], 
     Hue[0.9651227725428506, 1, -3.5827387347814055`], 
     Hue[1.030555449860459, 1, -3.3874540431183293`], 
     Hue[0.9653700704866103, 1, -3.2077977838473597`], 
     Hue[1.0306517318740436`, 1, -3.012963721935667], 
     Hue[0.9695379179848251, 1, -2.821204673599981], 
     Hue[1.0286175138933125`, 1, -2.6448801517556184`], 
     Hue[0.9695483945525917, 1, -2.44712364837753], 
     Hue[1.0290031838926073`, 1, -2.2696781271302777`], 
     Hue[0.9695714046572147, 1, -2.0732359020389035`], 
     Hue[1.0322825916812237`, 1, -1.8860615723132732`], 
     Hue[0.9696218770098055, 1, -1.6997724135403705`], 
     Hue[1.0322033050257444`, 1, -1.5129711760359414`], 
     Hue[0.9697322723800663, 1, -1.3272383355809725`], 
     Hue[1.0320303190366533`, 1, -1.1412523648141748`], 
     Hue[0.9719084068346983, 1, -0.9509841368003353], 
     Hue[1.0340126621525587`, 1, -0.765417177579486], 
     Hue[0.9740651895297494, 1, -0.5800459914826395], 
     Hue[1.0382944981377642`, 1, -0.3875043356149366], 
     Hue[0.9817068350447693, 1, -0.2041108261369391], 
     Hue[1.0433724376578628`, 1, -0.016754760991719797`], 
     Hue[0.9966109686929119, 1, 0.1706825798504723], 
     Hue[1.05446518778206, 1, 0.3584024072039794], 
     Hue[1.023392503940506, 1, 0.546530119032561], 
     Hue[1.0102058175284474`, 1, 0.7340484773914528], 
     Hue[1.01578360926954, 1, 0.922461428977247], 
     Hue[1.1419470243275818`, 1, -17.27618334189528], 
     Hue[1.079249623770115, 1, -17.089062133554293`], 
     Hue[1.139038697641566, 1, -16.91062086407678], 
     Hue[1.079249623770115, 1, -16.714819716872324`], 
     Hue[1.139038697641566, 1, -16.53637844739481], 
     Hue[1.079249623770115, 1, -16.34057730019035], 
     Hue[1.1395132141008641`, 1, -16.16071983016143], 
     Hue[1.079249623770115, 1, -15.966334883508381`], 
     Hue[1.139869101445337, 1, -15.7854152630659], 
     Hue[1.079249623770115, 1, -15.592092466826411`], 
     Hue[1.1437838622345382`, 1, -15.399489191834807`], 
     Hue[1.079249623770115, 1, -15.217850050144438`], 
     Hue[1.143783862234538, 1, -15.025246775152837`], 
     Hue[1.079249623770115, 1, -14.843607633462467`], 
     Hue[1.1437838622345378`, 1, -14.651004358470864`], 
     Hue[1.0792496237701146`, 1, -14.469365216780501`], 
     Hue[1.143783862234537, 1, -14.276761941788898`], 
     Hue[1.0792496237701141`, 1, -14.095122800098531`], 
     Hue[1.1437838622345355`, 1, -13.90251952510693], 
     Hue[1.0812089175375337`, 1, -13.715032845655912`], 
     Hue[1.1447022811880103`, 1, -13.52553607509966], 
     Hue[1.0812089175375308`, 1, -13.340790428973955`], 
     Hue[1.1447022811880032`, 1, -13.151293658417707`], 
     Hue[1.0812089175375243`, 1, -12.966548012292021`], 
     Hue[1.1447022811879877`, 1, -12.777051241735771`], 
     Hue[1.0812089175375101`, 1, -12.592305595610124`], 
     Hue[1.1447022811879533`, 1, -12.402808825053881`], 
     Hue[1.0812089175374786`, 1, -12.21806317892832], 
     Hue[1.1447022811878778`, 1, -12.028566408372086`], 
     Hue[1.0821885644211178`, 1, -11.840896993366389`], 
     Hue[1.1451614906644505`, 1, -11.652953475027843`], 
     Hue[1.0821885644209637`, 1, -11.46665457668523], 
     Hue[1.1451614906640837`, 1, -11.278711058346719`], 
     Hue[1.0821885644206248`, 1, -11.09241216000504], 
     Hue[1.1451614906632777`, 1, -10.90446864166661], 
     Hue[1.0826783878617239`, 1, -10.71670785888683], 
     Hue[1.1472355867980342`, 1, -10.524036058062388`], 
     Hue[1.083045755441443, 1, -10.341369028883374`], 
     Hue[1.1474020502293518`, 1, -10.149296829099164`], 
     Hue[1.0870867988326194`, 1, -9.955066065589389], 
     Hue[1.147457538032331, 1, -9.774888808340156], 
     Hue[1.0870867988240134`, 1, -9.580823648949579], 
     Hue[1.1474575380130057`, 1, -9.400646391701516], 
     Hue[1.0870867988050912`, 1, -9.206581232360303], 
     Hue[1.147457537970514, 1, -9.026403975114814], 
     Hue[1.0870867987634862`, 1, -8.832338815882146], 
     Hue[1.1492331478504478`, 1, -8.646862227545236], 
     Hue[1.087086798672008, 1, -8.458096399648307], 
     Hue[1.1492331476409938`, 1, -8.272619811322059], 
     Hue[1.087086798470873, 1, -8.083853983951654], 
     Hue[1.1492331471804615`, 1, -7.898377395648851], 
     Hue[1.0870867980286314`, 1, -7.70961156943613], 
     Hue[1.1492331461678769`, 1, -7.5241349811848695`], 
     Hue[1.0870867970562628`, 1, -7.335369157517584], 
     Hue[1.149233143941479, 1, -7.149892569379657], 
     Hue[1.0870867949182892`, 1, -6.961126751309087], 
     Hue[1.1501209439475473`, 1, -6.773000497831933], 
     Hue[1.0870867902174681`, 1, -6.586884357655432], 
     Hue[1.1501209330798932`, 1, -6.398758104677483], 
     Hue[1.089046073027876, 1, -6.20679445428389], 
     Hue[1.1509934067751764`, 1, -6.021911757866208], 
     Hue[1.0890460495575887`, 1, -5.83255214945521], 
     Hue[1.1509933537385, 1, -5.64766945468498], 
     Hue[1.0890459979528622`, 1, -5.458309978708084], 
     Hue[1.1514294851204525`, 1, -5.2721252962308744`], 
     Hue[1.0890458844883202`, 1, -5.08406810276954], 
     Hue[1.1516473509038825`, 1, -4.897232431686302], 
     Hue[1.0890456350116227`, 1, -4.709826875033684], 
     Hue[1.1553548577804706`, 1, -4.511924274783893], 
     Hue[1.0900247172254696`, 1, -4.332663314550549], 
     Hue[1.1522787260802874`, 1, -4.1468616291675975`], 
     Hue[1.0900234918350369`, 1, -3.958426658754986], 
     Hue[1.1557486637599754`, 1, -3.762260032078304], 
     Hue[1.0905105818415721`, 1, -3.5827350500779476`], 
     Hue[1.1559413267376624`, 1, -3.3874363676797064`], 
     Hue[1.0907494799763362`, 1, -3.207789600052835], 
     Hue[1.156026907786924, 1, -3.0129248038346566`], 
     Hue[1.0948981586659365`, 1, -2.821183503579279], 
     Hue[1.1539693581441532`, 1, -2.6447973210424456`], 
     Hue[1.0948672294776571`, 1, -2.4470771304091468`], 
     Hue[1.154264775985462, 1, -2.2696106440158434`], 
     Hue[1.094799286882817, 1, -2.0731337623709685`], 
     Hue[1.157468219184909, 1, -1.8856380251026115`], 
     Hue[1.094650200042932, 1, -1.699548514205867], 
     Hue[1.1571386612973198`, 1, -1.5120434336385415`], 
     Hue[1.0943238448124077`, 1, -1.3267492974981996`], 
     Hue[1.156417211712174, 1, -1.139229418141985], 
     Hue[1.0955323652254239`, 1, -0.9498473005284003], 
     Hue[1.1556180164672147`, 1, -0.7657570122422444], 
     Hue[1.09489176973422, 1, -0.5796535057633907], 
     Hue[1.1540806067236742`, 1, -0.39247687114600294`], 
     Hue[1.0977206692197605`, 1, -0.20044331996644793`], 
     Hue[1.1516351739995605`, 1, -0.016649380380218348`], 
     Hue[1.0988390079689245`, 1, 0.17180144962715704`], 
     Hue[1.144914161256854, 1, 0.3602584781504198], 
     Hue[1.0981498445849627`, 1, 0.5461520718717794], 
     Hue[1.064583490518335, 1, 0.734287917633548], 
     Hue[1.04223674676777, 1, 0.9216276323539467], 
     Hue[1.267341825442513, 1, -17.27618334189528], 
     Hue[1.2046444248850467`, 1, -17.089062133554293`], 
     Hue[1.2644334987564978`, 1, -16.91062086407678], 
     Hue[1.2046444248850467`, 1, -16.714819716872324`], 
     Hue[1.2644334987564978`, 1, -16.53637844739481], 
     Hue[1.2046444248850467`, 1, -16.34057730019035], 
     Hue[1.2649080152157952`, 1, -16.16071983016143], 
     Hue[1.2046444248850467`, 1, -15.966334883508381`], 
     Hue[1.265263902560268, 1, -15.7854152630659], 
     Hue[1.2046444248850467`, 1, -15.592092466826411`], 
     Hue[1.26917866334947, 1, -15.399489191834807`], 
     Hue[1.2046444248850467`, 1, -15.217850050144438`], 
     Hue[1.2691786633494697`, 1, -15.025246775152837`], 
     Hue[1.2046444248850463`, 1, -14.843607633462467`], 
     Hue[1.2691786633494693`, 1, -14.651004358470864`], 
     Hue[1.2046444248850459`, 1, -14.469365216780497`], 
     Hue[1.2691786633494684`, 1, -14.276761941788894`], 
     Hue[1.2046444248850448`, 1, -14.095122800098528`], 
     Hue[1.2691786633494666`, 1, -13.902519525106921`], 
     Hue[1.2066037186524625`, 1, -13.715032845655902`], 
     Hue[1.2700970823029405`, 1, -13.525536075099645`], 
     Hue[1.2066037186524567`, 1, -13.340790428973936`], 
     Hue[1.2700970823029316`, 1, -13.15129365841767], 
     Hue[1.2066037186524439`, 1, -12.966548012291977`], 
     Hue[1.2700970823029119`, 1, -12.777051241735693`], 
     Hue[1.206603718652416, 1, -12.592305595610028`], 
     Hue[1.2700970823028688`, 1, -12.402808825053704`], 
     Hue[1.206603718652354, 1, -12.218063178928109`], 
     Hue[1.270097082302774, 1, -12.028566408371697`], 
     Hue[1.207583365535927, 1, -11.840896993365918`], 
     Hue[1.2705562917793045`, 1, -11.652953475026987`], 
     Hue[1.2075833655356258`, 1, -11.466654576684196`], 
     Hue[1.2705562917788447`, 1, -11.278711058344838`], 
     Hue[1.2075833655349637`, 1, -11.092412160002763`], 
     Hue[1.270556291777834, 1, -10.904468641662474`], 
     Hue[1.2080731889753533`, 1, -10.716707858881795`], 
     Hue[1.2726303879121694`, 1, -10.524036058053143`], 
     Hue[1.2084405565535132`, 1, -10.34136902887226], 
     Hue[1.2727968513425376`, 1, -10.149296829078818`], 
     Hue[1.2124815999413132`, 1, -9.95506606556384], 
     Hue[1.2728523391434279`, 1, -9.7748888082954], 
     Hue[1.2124815999252299`, 1, -9.580823648893398], 
     Hue[1.2728523391195055`, 1, -9.400646391603106], 
     Hue[1.2124815998898664`, 1, -9.206581232236777], 
     Hue[1.2728523390669062`, 1, -9.02640397489844], 
     Hue[1.212481599812112, 1, -8.832338815610548], 
     Hue[1.2746279489259598`, 1, -8.646862227062805], 
     Hue[1.2124815996411513`, 1, -8.458096399051136], 
     Hue[1.2746279486692522`, 1, -8.272619810261324], 
     Hue[1.2124815992652551`, 1, -8.083853982638638], 
     Hue[1.2746279481048226`, 1, -7.8983773933165855`], 
     Hue[1.212481598438762, 1, -7.7096115665491665`], 
     Hue[1.2746279468637953`, 1, -7.524134976056852], 
     Hue[1.2124815966215288`, 1, -7.33536915116994], 
     Hue[1.2746279441351147`, 1, -7.1498925581045425`], 
     Hue[1.2124815926259285`, 1, -6.961126737352347], 
     Hue[1.275515743072095, 1, -6.77300047286883], 
     Hue[1.2124815838406924`, 1, -6.586884326968366], 
     Hue[1.2755157298185118`, 1, -6.398758049790422], 
     Hue[1.2144408577495631`, 1, -6.206794385368129], 
     Hue[1.276388198437922, 1, -6.021911636364653], 
     Hue[1.2144408146282384`, 1, -5.832551997928275], 
     Hue[1.276388134070619, 1, -5.647669187536217], 
     Hue[1.2144407198162162`, 1, -5.458309645541868], 
     Hue[1.2768242409551847`, 1, -5.272124706858879], 
     Hue[1.214440511350508, 1, -5.084067370228879], 
     Hue[1.277042052918699, 1, -4.897231133635166], 
     Hue[1.2144400529916644`, 1, -4.709825264381492], 
     Hue[1.280749458725126, 1, -4.5119213387368164`], 
     Hue[1.2154186780917557`, 1, -4.332659735821165], 
     Hue[1.2776730545725605`, 1, -4.146855323223719], 
     Hue[1.215416445457609, 1, -3.9584187902241688`], 
     Hue[1.281142506542692, 1, -3.76224579547488], 
     Hue[1.2159013261453495`, 1, -3.5827176592330856`], 
     Hue[1.2813340307994108`, 1, -3.387405018799713], 
     Hue[1.2161353669348278`, 1, -3.2077512652731146`], 
     Hue[1.2814171075024179`, 1, -3.0128558271059154`], 
     Hue[1.2163486819384746`, 1, -2.832815988351154], 
     Hue[1.281477374046732, 1, -2.638304072579917], 
     Hue[1.220219461491891, 1, -2.4468836034167314`], 
     Hue[1.2795847147744983`, 1, -2.2694358034756563`], 
     Hue[1.220100442555781, 1, -2.0727085774369005`], 
     Hue[1.2828158193466375`, 1, -1.884895951840807], 
     Hue[1.2198388714864867`, 1, -1.6986152343359964`], 
     Hue[1.282428494561654, 1, -1.5104132184921564`], 
     Hue[1.2192643293186496`, 1, -1.3247049295416968`], 
     Hue[1.2815755073971784`, 1, -1.1356519027410494`], 
     Hue[1.218003934731692, 1, -0.9512136057781715], 
     Hue[1.279693604458052, 1, -0.7603148298743452], 
     Hue[1.2150116793253747`, 1, -0.5794712286167787], 
     Hue[1.275431342372417, 1, -0.3842065858263972], 
     Hue[1.2110513058341377`, 1, -0.20265107648641578`], 
     Hue[1.2633024541118485`, 1, -0.016858373262555792`], 
     Hue[1.2008591789294902`, 1, 0.17149425591777245`], 
     Hue[1.2430466404923175`, 1, 0.35844218184504184`], 
     Hue[1.1794765052413076`, 1, 0.5461387963201573], 
     Hue[1.2025346513950579`, 1, 0.7343840327079226], 
     Hue[1.1247060959821218`, 1, 0.734385965136927], 
     Hue[1.1314100929229873`, 1, 0.9216378054627106], 
     Hue[1.0778113174845079`, 1, 0.9215967274067449], 
     Hue[1.3927366265574448`, 1, -17.27618334189528], 
     Hue[1.330039225999978, 1, -17.089062133554293`], 
     Hue[1.3898282998714295`, 1, -16.91062086407678], 
     Hue[1.330039225999978, 1, -16.714819716872324`], 
     Hue[1.3898282998714295`, 1, -16.53637844739481], 
     Hue[1.330039225999978, 1, -16.34057730019035], 
     Hue[1.390302816330727, 1, -16.16071983016143], 
     Hue[1.330039225999978, 1, -15.966334883508381`], 
     Hue[1.3906587036751998`, 1, -15.7854152630659], 
     Hue[1.330039225999978, 1, -15.592092466826411`], 
     Hue[1.3945734644644017`, 1, -15.399489191834807`], 
     Hue[1.3300392259999778`, 1, -15.217850050144438`], 
     Hue[1.3945734644644014`, 1, -15.025246775152837`], 
     Hue[1.3300392259999776`, 1, -14.843607633462467`], 
     Hue[1.3945734644644012`, 1, -14.651004358470864`], 
     Hue[1.3300392259999771`, 1, -14.469365216780497`], 
     Hue[1.3945734644644008`, 1, -14.276761941788891`], 
     Hue[1.330039225999976, 1, -14.095122800098522`], 
     Hue[1.3945734644643997`, 1, -13.902519525106914`], 
     Hue[1.3319985197673947`, 1, -13.715032845655891`], 
     Hue[1.3954918834178744`, 1, -13.525536075099629`], 
     Hue[1.3319985197673894`, 1, -13.340790428973909`], 
     Hue[1.395491883417869, 1, -13.151293658417638`], 
     Hue[1.3319985197673778`, 1, -12.966548012291922`], 
     Hue[1.395491883417857, 1, -12.77705124173562], 
     Hue[1.3319985197673525`, 1, -12.592305595609906`], 
     Hue[1.3954918834178305`, 1, -12.402808825053546`], 
     Hue[1.3319985197672968`, 1, -12.21806317892784], 
     Hue[1.395491883417772, 1, -12.028566408371347`], 
     Hue[1.3329781666508835`, 1, -11.840896993365329`], 
     Hue[1.3959510928943846`, 1, -11.65295347502622], 
     Hue[1.3329781666506129`, 1, -11.466654576682894`], 
     Hue[1.3959510928941026`, 1, -11.27871105834315], 
     Hue[1.3329781666500178`, 1, -11.0924121599999], 
     Hue[1.3959510928934826`, 1, -10.904468641658763`], 
     Hue[1.3334679900905617`, 1, -10.716707858875488`], 
     Hue[1.3980251890287345`, 1, -10.524036058044942`], 
     Hue[1.333835357669067, 1, -10.341369028858363`], 
     Hue[1.3981916524610705`, 1, -10.14929682906077], 
     Hue[1.3378764010579134`, 1, -9.95506606553262], 
     Hue[1.3982471402662846`, 1, -9.774888808255717], 
     Hue[1.3378764010438302`, 1, -9.580823648824756], 
     Hue[1.3982471402518626`, 1, -9.400646391515854], 
     Hue[1.3378764010128654`, 1, -9.206581232085849], 
     Hue[1.3982471402201524`, 1, -9.026403974706597], 
     Hue[1.337876400944782, 1, -8.832338815278698], 
     Hue[1.40002275012767, 1, -8.646862226639128], 
     Hue[1.3378764007950856`, 1, -8.45809639832149], 
     Hue[1.4000227499749867`, 1, -8.272619809329768], 
     Hue[1.3378764004659438`, 1, -8.083853981034347], 
     Hue[1.4000227496392772`, 1, -7.89837739126835], 
     Hue[1.3378763997422505`, 1, -7.709611563021769], 
     Hue[1.4000227489011434`, 1, -7.524134971553338], 
     Hue[1.3378763981510464`, 1, -7.335369143414154], 
     Hue[1.4000227472781885`, 1, -7.14989254820254], 
     Hue[1.3378763946524221`, 1, -6.961126720299492], 
     Hue[1.4009105487121538`, 1, -6.773000451050236], 
     Hue[1.3378763869599004`, 1, -6.586884289473782], 
     Hue[1.4009105408829639`, 1, -6.39875800181728], 
     Hue[1.3398356636698545`, 1, -6.206794302076831], 
     Hue[1.4017830217438734`, 1, -6.021911530666414], 
     Hue[1.3398356263088314`, 1, -5.832551814793395], 
     Hue[1.401782983977541, 1, -5.647668955134505], 
     Hue[1.3398355441620846`, 1, -5.458309242878098], 
     Hue[1.402219150114981, 1, -5.272124195349791], 
     Hue[1.3398353635435867`, 1, -5.084066484880615], 
     Hue[1.4024370924372396`, 1, -4.897230008395525], 
     Hue[1.33983496641182, 1, -4.709823317740138], 
     Hue[1.4061448160013554`, 1, -4.511918844302171], 
     Hue[1.3408137365287112`, 1, -4.332655433897057], 
     Hue[1.4030690200806724`, 1, -4.14684987538337], 
     Hue[1.3408118123134751`, 1, -3.9584093314213407`], 
     Hue[1.4065400131635133`, 1, -3.7622337259432808`], 
     Hue[1.3412973963163795`, 1, -3.582696809137465], 
     Hue[1.40673479897424, 1, -3.387378468927027], 
     Hue[1.3415329853829001`, 1, -3.2077053628133783`], 
     Hue[1.4068250481279705`, 1, -3.012797432844195], 
     Hue[1.341726774181452, 1, -2.8327834858184966`], 
     Hue[1.4068917759445152`, 1, -2.638203478359163], 
     Hue[1.3456302022129045`, 1, -2.4466569357322365`], 
     Hue[1.404937963767752, 1, -2.269463078912425], 
     Hue[1.3455301806380913`, 1, -2.0722100532011885`], 
     Hue[1.4050327162400058`, 1, -1.8942063789254362`], 
     Hue[1.3453099575427099`, 1, -1.6975184233493235`], 
     Hue[1.4081377483817727`, 1, -1.5090375440615593`], 
     Hue[1.3448242811394637`, 1, -1.3222900273595817`], 
     Hue[1.404136886298498, 1, -1.1432397124893037`], 
     Hue[1.343749309856463, 1, -0.9458882167973606], 
     Hue[1.4024352969042617`, 1, -0.7662568937035383], 
     Hue[1.337230706017802, 1, -0.5799288995687344], 
     Hue[1.3972442290575413`, 1, -0.3904340686666168], 
     Hue[1.3297152097843674`, 1, -0.20348641645043197`], 
     Hue[1.3848885260223673`, 1, -0.01634757088015326], 
     Hue[1.441915882231768, 1, 0.1753425104749985], 
     Hue[1.3127830408043244`, 1, 0.17154787897494184`], 
     Hue[1.3594692512489197`, 1, 0.35952772060642957`], 
     Hue[1.405043919629085, 1, 0.5462569626664913], 
     Hue[1.2786467801850587`, 1, 0.5462205050918488], 
     Hue[1.3080356779324622`, 1, 0.7340148537778464], 
     Hue[1.3321986062944011`, 1, 0.9216679635293102], 
     Hue[1.3525044759100655`, 1, 1.109725359034867], 
     Hue[1.2126491979095546`, 1, 0.9216089359455659], 
     Hue[1.207883589663384, 1, 1.1093481387715847`], 
     Hue[1.1817746882501523`, 1, 1.297128519280647], 
     Hue[1.1101560761460567`, 1, 1.1096634889073667`], 
     Hue[1.0434325428881537`, 1, 1.109584103528543], 
     Hue[0.5181314276723764, 1, -17.27618334189528], 
     Hue[1.4554340271149098`, 1, -17.089062133554293`], 
     Hue[0.5152231009863607, 1, -16.91062086407678], 
     Hue[1.4554340271149098`, 1, -16.714819716872324`], 
     Hue[0.5152231009863607, 1, -16.53637844739481], 
     Hue[1.4554340271149098`, 1, -16.34057730019035], 
     Hue[0.5156976174456587, 1, -16.16071983016143], 
     Hue[1.4554340271149098`, 1, -15.966334883508381`], 
     Hue[0.5160535047901316, 1, -15.7854152630659], 
     Hue[1.4554340271149098`, 1, -15.592092466826411`], 
     Hue[0.519968265579333, 1, -15.399489191834807`], 
     Hue[1.4554340271149098`, 1, -15.217850050144438`], 
     Hue[0.519968265579333, 1, -15.025246775152837`], 
     Hue[1.4554340271149098`, 1, -14.843607633462467`], 
     Hue[0.519968265579333, 1, -14.65100435847086], 
     Hue[1.4554340271149095`, 1, -14.469365216780494`], 
     Hue[0.5199682655793331, 1, -14.276761941788891`], 
     Hue[1.455434027114909, 1, -14.095122800098519`], 
     Hue[0.5199682655793333, 1, -13.902519525106912`], 
     Hue[1.4573933208823295`, 1, -13.715032845655882`], 
     Hue[0.5208866845328117, 1, -13.525536075099625`], 
     Hue[1.457393320882328, 1, -13.340790428973895`], 
     Hue[0.520886684532813, 1, -13.151293658417627`], 
     Hue[1.4573933208823244`, 1, -12.966548012291886`], 
     Hue[0.5208866845328155, 1, -12.777051241735599`], 
     Hue[1.4573933208823167`, 1, -12.592305595609831`], 
     Hue[0.5208866845328213, 1, -12.402808825053498`], 
     Hue[1.4573933208822996`, 1, -12.218063178927673`], 
     Hue[0.5208866845328337, 1, -12.028566408371242`], 
     Hue[1.4583729677659738`, 1, -11.840896993364963`], 
     Hue[0.5213458940096025, 1, -11.65295347502599], 
     Hue[1.458372967765893, 1, -11.466654576682094`], 
     Hue[0.5213458940096646, 1, -11.278711058342651`], 
     Hue[1.4583729677657156`, 1, -11.092412159998142`], 
     Hue[0.5213458940098009, 1, -10.904468641657663`], 
     Hue[1.4588627912071872`, 1, -10.716707858871628`], 
     Hue[0.5234199901467661, 1, -10.52403605804261], 
     Hue[1.459230158787737, 1, -10.34136902884988], 
     Hue[0.5235864535828277, 1, -10.149296829055661`], 
     Hue[1.4632712021814371`, 1, -9.955066065514128], 
     Hue[0.5236419413962317, 1, -9.774888808244494], 
     Hue[1.4632712021776537`, 1, -9.5808236487841], 
     Hue[0.523641941399809, 1, -9.400646391491177], 
     Hue[1.463271202169335, 1, -9.206581231996463], 
     Hue[0.5236419414076747, 1, -9.02640397465234], 
     Hue[1.4632712021510443`, 1, -8.832338815082156], 
     Hue[0.5254175514044397, 1, -8.646862226523872], 
     Hue[1.463271202110828, 1, -8.458096397889351], 
     Hue[0.5254175514457563, 1, -8.272619809076357], 
     Hue[1.4632712020224035`, 1, -8.083853980084191], 
     Hue[0.5254175515366003, 1, -7.898377390711166], 
     Hue[1.4632712018279816`, 1, -7.70961156093263], 
     Hue[0.5254175517363415, 1, -7.524134970328245], 
     Hue[1.4632712014005014`, 1, -7.335369138820705], 
     Hue[0.525417552175518, 1, -7.1498925455088935`], 
     Hue[1.4632712004605888`, 1, -6.961126710199751], 
     Hue[0.5263053582010708, 1, -6.773000445233831], 
     Hue[1.4632711983939768`, 1, -6.586884267267202], 
     Hue[0.5263053604100094, 1, -6.398757989028586], 
     Hue[1.4652304879569644`, 1, -6.206794253493476], 
     Hue[0.5271778636158964, 1, -6.021911503059401], 
     Hue[1.4652304783730736`, 1, -5.832551707971793], 
     Hue[0.5271778747062402, 1, -5.64766889443416], 
     Hue[1.4652304573006913`, 1, -5.458309008006291], 
     Hue[0.5276141489293118, 1, -5.272124063136539], 
     Hue[1.4652304109681769`, 1, -5.084065968460472], 
     Hue[0.5278323289694378, 1, -4.897229719075619], 
     Hue[1.4652303090951773`, 1, -4.709822182267915], 
     Hue[0.5315406018681004, 1, -4.51191826147733], 
     Hue[1.4662097409183492`, 1, -4.332652943921121], 
     Hue[0.5284659364502255, 1, -4.146848496189067], 
     Hue[1.4662092591165383`, 1, -3.958403856523473], 
     Hue[0.5319395893678107, 1, -3.7622309367463638`], 
     Hue[1.4666980450080358`, 1, -3.5826847872976124`], 
     Hue[0.5321401153477239, 1, -3.387372367274298], 
     Hue[1.4669406775238507`, 1, -3.2076789457196098`], 
     Hue[0.5322429888209808, 1, -3.0127840491997473`], 
     Hue[1.4671193646869027`, 1, -2.832816822333119], 
     Hue[0.5323250550424343, 1, -2.638211236481074], 
     Hue[1.4710901176498667`, 1, -2.4465307799681666`], 
     Hue[0.530443175008554, 1, -2.2693952498848544`], 
     Hue[1.4710681992573271`, 1, -2.071932343573642], 
     Hue[0.5306320312067403, 1, -1.8941734685787608`], 
     Hue[1.4710198909124979`, 1, -1.6969062287422074`], 
     Hue[0.5307063984340143, 1, -1.5187935553841807`], 
     Hue[1.4709131109839924`, 1, -1.3209362681613455`], 
     Hue[0.5305053481288013, 1, -1.1431285576664092`], 
     Hue[1.4664635293140722`, 1, -0.9555173341890193], 
     Hue[0.5293693302092998, 1, -0.7677706573795706], 
     Hue[1.4641112412739636`, 1, -0.5783564631722529], 
     Hue[0.5275718648165195, 1, -0.3887570082889986], 
     Hue[1.457516941206724, 1, -0.2016912128726318], 
     Hue[0.5195896732232448, 1, -0.014606056148507296`], 
     Hue[0.5875324891619835, 1, 0.17282362094380055`], 
     Hue[0.5000098177287721, 1, 0.3587375845513985], 
     Hue[0.5701568971012114, 1, 0.5479380201792818], 
     Hue[1.4535386660562228`, 1, 0.7341983825445575], 
     Hue[0.5113365271662145, 1, 0.9216072451158401], 
     Hue[0.600615685624569, 1, 1.109750092300307], 
     Hue[1.3707656913346031`, 1, 1.3010970839782923`], 
     Hue[0.9803006405818251, 1, 1.297024965536648], 
     Hue[1.0030701670950184`, 1, 1.1093123591647427`], 
     Hue[0.6435262287873076, 1, -17.27618334189528], 
     Hue[0.5808288282298415, 1, -17.089062133554293`], 
     Hue[0.6406179021012925, 1, -16.91062086407678], 
     Hue[0.5808288282298415, 1, -16.714819716872324`], 
     Hue[0.6406179021012925, 1, -16.53637844739481], 
     Hue[0.5808288282298415, 1, -16.34057730019035], 
     Hue[0.6410924185605897, 1, -16.16071983016143], 
     Hue[0.5808288282298415, 1, -15.966334883508381`], 
     Hue[0.6414483059050634, 1, -15.7854152630659], 
     Hue[0.5808288282298415, 1, -15.592092466826411`], 
     Hue[0.6453630666942647, 1, -15.399489191834807`], 
     Hue[0.5808288282298416, 1, -15.217850050144438`], 
     Hue[0.6453630666942649, 1, -15.025246775152837`], 
     Hue[0.5808288282298417, 1, -14.843607633462467`], 
     Hue[0.6453630666942651, 1, -14.651004358470864`], 
     Hue[0.5808288282298419, 1, -14.469365216780494`], 
     Hue[0.6453630666942658, 1, -14.276761941788891`], 
     Hue[0.5808288282298426, 1, -14.095122800098519`], 
     Hue[0.6453630666942672, 1, -13.902519525106916`], 
     Hue[0.582788121997265, 1, -13.715032845655884`], 
     Hue[0.6462814856477486, 1, -13.525536075099634`], 
     Hue[0.5827881219972679, 1, -13.340790428973898`], 
     Hue[0.6462814856477557, 1, -13.151293658417645`], 
     Hue[0.5827881219972746, 1, -12.966548012291893`], 
     Hue[0.6462814856477713, 1, -12.77705124173564], 
     Hue[0.5827881219972891, 1, -12.592305595609847`], 
     Hue[0.646281485647806, 1, -12.402808825053588`], 
     Hue[0.582788121997321, 1, -12.218063178927707`], 
     Hue[0.646281485647882, 1, -12.028566408371445`], 
     Hue[0.5837677688811036, 1, -11.840896993365043`], 
     Hue[0.6467406951247908, 1, -11.652953475026438`], 
     Hue[0.5837677688812604, 1, -11.466654576682267`], 
     Hue[0.6467406951251602, 1, -11.278711058343632`], 
     Hue[0.5837677688816051, 1, -11.092412159998524`], 
     Hue[0.6467406951259724, 1, -10.904468641659822`], 
     Hue[0.5842575923242306, 1, -10.716707858872486`], 
     Hue[0.6488147912644384, 1, -10.524036058047525`], 
     Hue[0.5846249599073211, 1, -10.341369028851805`], 
     Hue[0.648981254703788, 1, -10.149296829066499`], 
     Hue[0.588666003306821, 1, -9.955066065519263], 
     Hue[0.6490367425244202, 1, -9.774888808268344], 
     Hue[0.5886660033155667, 1, -9.580823648795393], 
     Hue[0.6490367425438888, 1, -9.400646391543617], 
     Hue[0.5886660033347964, 1, -9.20658123202129], 
     Hue[0.6490367425866951, 1, -9.026403974767643], 
     Hue[0.5886660033770768, 1, -8.832338815136746], 
     Hue[0.6508123526608984, 1, -8.646862226784965], 
     Hue[0.5886660034700402, 1, -8.458096398009376], 
     Hue[0.6508123528718674, 1, -8.272619809650424], 
     Hue[0.5886660036744413, 1, -8.08385398034809], 
     Hue[0.6508123533357306, 1, -7.898377391973383], 
     Hue[0.5886660041238636, 1, -7.709611561512877], 
     Hue[0.6508123543556394, 1, -7.524134973103517], 
     Hue[0.5886660051120208, 1, -7.335369140096508], 
     Hue[0.6508123565981412, 1, -7.149892551610962], 
     Hue[0.5886660072847094, 1, -6.96112671300489], 
     Hue[0.6517001666040662, 1, -6.773000458847213], 
     Hue[0.5886660120618599, 1, -6.586884273434941], 
     Hue[0.6517001775494073, 1, -6.398758018960708], 
     Hue[0.5906253169555506, 1, -6.206794268248205], 
     Hue[0.6525727000358644, 1, -6.021911569812417], 
     Hue[0.590625340796578, 1, -5.8325517404134395`], 
     Hue[0.6525727534473402, 1, -5.647669041205944], 
     Hue[0.5906253932165395, 1, -5.458309079336709], 
     Hue[0.6530091208937417, 1, -5.2721243881328075`], 
     Hue[0.5906255084739387, 1, -5.084066125297003], 
     Hue[0.6532275059224442, 1, -4.897230436174053], 
     Hue[0.5906257618944655, 1, -4.709822527110557], 
     Hue[0.6569362360022017, 1, -4.511919933732652], 
     Hue[0.5916059821641417, 1, -4.332653733297764], 
     Hue[0.6538625571182612, 1, -4.146851998461138], 
     Hue[0.591607226726681, 1, -3.9584055921928787`], 
     Hue[0.6573384209652539, 1, -3.762239071840794], 
     Hue[0.5920998260568817, 1, -3.582688679680058], 
     Hue[0.6575437821473027, 1, -3.387390310916503], 
     Hue[0.5923508457472324, 1, -3.2076875888687093`], 
     Hue[0.6576572879206487, 1, -3.0128235697895764`], 
     Hue[0.5925479900700722, 1, -2.8328359700664745`], 
     Hue[0.6577627374265269, 1, -2.638298263010359], 
     Hue[0.5965608096649695, 1, -2.446579655962741], 
     Hue[0.6559319125470358, 1, -2.2695811470143354`], 
     Hue[0.5966299732239937, 1, -2.072039956471203], 
     Hue[0.6596010483136332, 1, -1.8845679761378744`], 
     Hue[0.5967823499137273, 1, -1.6971435574044829`], 
     Hue[0.6599351294313813, 1, -1.5096907597273785`], 
     Hue[0.597118864838287, 1, -1.321461580039293], 
     Hue[0.6606728248172913, 1, -1.1340570141618824`], 
     Hue[0.5978659916496493, 1, -0.9440461265818358], 
     Hue[0.6584774048282276, 1, -0.7678023823740732], 
     Hue[0.5944209679429611, 1, -0.5775281110063017], 
     Hue[0.6600532374691626, 1, -0.3922861117236127], 
     Hue[0.5926100691827066, 1, -0.2027048292483684], 
     Hue[0.6636213944144498, 1, -0.014791956758225089`], 
     Hue[0.6678136605883778, 1, 0.3597109818674984], 
     Hue[0.6686896779332613, 1, 0.7343233805965589], 
     Hue[0.8358860076363499, 1, 1.1092972275225157`], 
     Hue[0.9391540588973948, 1, 1.1092904029032746`], 
     Hue[0.9043652547185517, 1, 1.2972419396286465`], 
     Hue[0.9711698197443439, 1, 1.1092949918719415`], 
     Hue[0.988109767760387, 1, 1.1094317470511716`], 
     Hue[0.7689210299022393, 1, -17.27618334189528], 
     Hue[0.7062236293447732, 1, -17.089062133554293`], 
     Hue[0.7660127032162243, 1, -16.91062086407678], 
     Hue[0.7062236293447732, 1, -16.714819716872324`], 
     Hue[0.7660127032162243, 1, -16.53637844739481], 
     Hue[0.7062236293447732, 1, -16.34057730019035], 
     Hue[0.7664872196755216, 1, -16.16071983016143], 
     Hue[0.7062236293447732, 1, -15.966334883508381`], 
     Hue[0.7668431070199946, 1, -15.7854152630659], 
     Hue[0.7062236293447732, 1, -15.592092466826411`], 
     Hue[0.7707578678091965, 1, -15.399489191834807`], 
     Hue[0.7062236293447735, 1, -15.217850050144438`], 
     Hue[0.7707578678091966, 1, -15.025246775152837`], 
     Hue[0.7062236293447737, 1, -14.843607633462467`], 
     Hue[0.7707578678091971, 1, -14.651004358470864`], 
     Hue[0.7062236293447742, 1, -14.469365216780497`], 
     Hue[0.7707578678091979, 1, -14.276761941788894`], 
     Hue[0.7062236293447754, 1, -14.095122800098524`], 
     Hue[0.7707578678091997, 1, -13.902519525106925`], 
     Hue[0.7081829231121985, 1, -13.715032845655895`], 
     Hue[0.7716762867626812, 1, -13.525536075099652`], 
     Hue[0.7081829231122043, 1, -13.340790428973918`], 
     Hue[0.7716762867626901, 1, -13.151293658417682`], 
     Hue[0.7081829231122172, 1, -12.966548012291938`], 
     Hue[0.7716762867627096, 1, -12.777051241735721`], 
     Hue[0.7081829231122454, 1, -12.592305595609943`], 
     Hue[0.7716762867627527, 1, -12.402808825053766`], 
     Hue[0.7081829231123073, 1, -12.218063178927922`], 
     Hue[0.7716762867628475, 1, -12.028566408371834`], 
     Hue[0.7091625699961563, 1, -11.840896993365517`], 
     Hue[0.7721354962397974, 1, -11.652953475027296`], 
     Hue[0.7091625699964583, 1, -11.466654576683311`], 
     Hue[0.7721354962402566, 1, -11.278711058345516`], 
     Hue[0.709162569997122, 1, -11.09241216000082], 
     Hue[0.7721354962412661, 1, -10.904468641663966`], 
     Hue[0.7096523934404472, 1, -10.71670785887756], 
     Hue[0.774209592380136, 1, -10.524036058056788`], 
     Hue[0.7100197610250771, 1, -10.341369028863005`], 
     Hue[0.7743760558203978, 1, -10.149296829086897`], 
     Hue[0.7140608044279048, 1, -9.955066065545], 
     Hue[0.7744315436430373, 1, -9.774888808313213], 
     Hue[0.7140608044440259, 1, -9.580823648851975], 
     Hue[0.7744315436669243, 1, -9.40064639164227], 
     Hue[0.7140608044794718, 1, -9.206581232145702], 
     Hue[0.7744315437194454, 1, -9.026403974984555], 
     Hue[0.7140608045574077, 1, -8.832338815410294], 
     Hue[0.7762071538136441, 1, -8.646862227268539], 
     Hue[0.7140608047287675, 1, -8.458096398610834], 
     Hue[0.7762071540699416, 1, -8.272619810713673], 
     Hue[0.714060805105541, 1, -8.083853981670535], 
     Hue[0.7762071546334699, 1, -7.898377394311178], 
     Hue[0.7140608059339633, 1, -7.709611564420569], 
     Hue[0.7762071558725153, 1, -7.52413497824369], 
     Hue[0.714060807755438, 1, -7.33536914648973], 
     Hue[0.7762071585968383, 1, -7.149892562912805], 
     Hue[0.7140608117603646, 1, -6.961126727061846], 
     Hue[0.777094969626291, 1, -6.7730004838680316`], 
     Hue[0.7140608205661071, 1, -6.586884304342357], 
     Hue[0.7770949828579553, 1, -6.398758073974671], 
     Hue[0.7160201342337988, 1, -6.206794337646065], 
     Hue[0.7779675101985503, 1, -6.021911691587935], 
     Hue[0.7160201774502324, 1, -5.832551893000463], 
     Hue[0.7779675744557866, 1, -5.647669308957164], 
     Hue[0.71602027247141, 1, -5.458309414834207], 
     Hue[0.7784039653266636, 1, -5.2721249788174624`], 
     Hue[0.7160204813971702, 1, -5.0840668629656145`], 
     Hue[0.778622401814399, 1, -4.897231737099724], 
     Hue[0.7160209407683973, 1, -4.709824149047849], 
     Hue[0.7823312275023029, 1, -4.511922875580009], 
     Hue[0.7170016115770458, 1, -4.332657336823793], 
     Hue[0.7792578098033821, 1, -4.146858318177675], 
     Hue[0.7170038490277473, 1, -3.9584135154834748`], 
     Hue[0.7827341327023052, 1, -3.762253336520314], 
     Hue[0.7174986256907372, 1, -3.5827061919247134`], 
     Hue[0.7829405743789841, 1, -3.3874217222690035`], 
     Hue[0.7177544317875687, 1, -3.207726196010338], 
     Hue[0.7830564530868869, 1, -3.0128926886268648`], 
     Hue[0.7179927185938646, 1, -2.8328296870689726`], 
     Hue[0.7831795451829506, 1, -2.6384132336787722`], 
     Hue[0.7219974968788013, 1, -2.446774681502128], 
     Hue[0.7814521635367555, 1, -2.2696028146592537`], 
     Hue[0.722116820272406, 1, -2.0724690899643976`], 
     Hue[0.7850396730724077, 1, -1.885312419920855], 
     Hue[0.7223792911270526, 1, -1.6980886790181182`], 
     Hue[0.78542508441603, 1, -1.5113288820686386`], 
     Hue[0.7229569251870149, 1, -1.32354725950311], 
     Hue[0.7862710095336921, 1, -1.1376649401276968`], 
     Hue[0.7242294983441417, 1, -0.9486688311284346], 
     Hue[0.7881235968024716, 1, -0.7647388348303836], 
     Hue[0.7270390472362451, 1, -0.5731325388380459], 
     Hue[0.793868104548688, 1, -0.38895899708491166`], 
     Hue[0.731149676266254, 1, -0.2020361939526225], 
     Hue[0.8053661561512724, 1, -0.01614096547760857], 
     Hue[0.7436901727485854, 1, 0.17281677753295832`], 
     Hue[0.8359720049994798, 1, 0.3584602033985881], 
     Hue[0.7767826833092535, 1, 0.54659878385129], 
     Hue[0.894315831017171, 1, -17.27618334189528], 
     Hue[0.8316184304597044, 1, -17.089062133554293`], 
     Hue[0.8914075043311553, 1, -16.91062086407678], 
     Hue[0.8316184304597044, 1, -16.714819716872324`], 
     Hue[0.8914075043311555, 1, -16.53637844739481], 
     Hue[0.8316184304597044, 1, -16.34057730019035], 
     Hue[0.8918820207904533, 1, -16.16071983016143], 
     Hue[0.8316184304597044, 1, -15.966334883508381`], 
     Hue[0.8922379081349263, 1, -15.7854152630659], 
     Hue[0.8316184304597045, 1, -15.592092466826411`], 
     Hue[0.8961526689241276, 1, -15.399489191834807`], 
     Hue[0.8316184304597045, 1, -15.217850050144438`], 
     Hue[0.8961526689241277, 1, -15.025246775152837`], 
     Hue[0.8316184304597047, 1, -14.843607633462467`], 
     Hue[0.8961526689241279, 1, -14.651004358470864`], 
     Hue[0.8316184304597053, 1, -14.469365216780497`], 
     Hue[0.8961526689241285, 1, -14.276761941788898`], 
     Hue[0.8316184304597063, 1, -14.09512280009853], 
     Hue[0.8961526689241296, 1, -13.902519525106932`], 
     Hue[0.8335777242271298, 1, -13.715032845655905`], 
     Hue[0.8970710878776099, 1, -13.525536075099666`], 
     Hue[0.833577724227135, 1, -13.340790428973943`], 
     Hue[0.8970710878776154, 1, -13.151293658417714`], 
     Hue[0.8335777242271465, 1, -12.966548012291994`], 
     Hue[0.8970710878776273, 1, -12.777051241735792`], 
     Hue[0.8335777242271717, 1, -12.592305595610064`], 
     Hue[0.8970710878776536, 1, -12.402808825053926`], 
     Hue[0.8335777242272273, 1, -12.218063178928189`], 
     Hue[0.8970710878777111, 1, -12.028566408372182`], 
     Hue[0.8345573711110601, 1, -11.840896993366108`], 
     Hue[0.8975302973545777, 1, -11.652953475028058`], 
     Hue[0.8345573711113292, 1, -11.46665457668461], 
     Hue[0.897530297354856, 1, -11.278711058347195`], 
     Hue[0.834557371111921, 1, -11.092412160003676`], 
     Hue[0.897530297355468, 1, -10.904468641667657`], 
     Hue[0.8350471945550806, 1, -10.716707858883858`], 
     Hue[0.8996043934934066, 1, -10.524036058064945`], 
     Hue[0.8354145621393407, 1, -10.341369028876882`], 
     Hue[0.899770856931668, 1, -10.149296829104834`], 
     Hue[0.8394556055410639, 1, -9.955066065576167], 
     Hue[0.899826344749912, 1, -9.77488880835266], 
     Hue[0.8394556055550603, 1, -9.580823648920507], 
     Hue[0.8998263447641408, 1, -9.400646391729005], 
     Hue[0.8394556055858343, 1, -9.206581232296381], 
     Hue[0.8998263447954262, 1, -9.026403975175253], 
     Hue[0.839455605653498, 1, -8.8323388157416], 
     Hue[0.9016019548403924, 1, -8.646862227689626], 
     Hue[0.8394556058022721, 1, -8.458096399339288], 
     Hue[0.9016019549909826, 1, -8.272619811639531], 
     Hue[0.8394556061293857, 1, -8.083853983272205], 
     Hue[0.9016019553220894, 1, -7.89837739634689], 
     Hue[0.8394556068486196, 1, -7.709611567942207], 
     Hue[0.9016019560501032, 1, -7.524134982719668], 
     Hue[0.8394556084300189, 1, -7.335369154232857], 
     Hue[0.901601957650807, 1, -7.149892572754257], 
     Hue[0.8394556119070846, 1, -6.961126744086868], 
     Hue[0.9024897661437802, 1, -6.7730005055515425`], 
     Hue[0.8394556195522044, 1, -6.586884341775739], 
     Hue[0.9024897738643632, 1, -6.3987581216508005`], 
     Hue[0.841414930266687, 1, -6.206794420790947], 
     Hue[0.90336228877214, 1, -6.021911796623751], 
     Hue[0.8414149673911204, 1, -5.832552075813385], 
     Hue[0.9033623260084359, 1, -5.647669539902206], 
     Hue[0.8414150490175925, 1, -5.458309816789918], 
     Hue[0.9037986567012335, 1, -5.272125487100139], 
     Hue[0.8414152284917688, 1, -5.084067746756286], 
     Hue[0.9040169607952517, 1, -4.897232855215924], 
     Hue[0.8414156231056498, 1, -4.709826092260779], 
     Hue[0.9077254641846776, 1, -4.511925353379977], 
     Hue[0.842396141050268, 1, -4.3326616308812005`], 
     Hue[0.9046514284417274, 1, -4.146863731075422], 
     Hue[0.8423980528368227, 1, -3.958422956898999], 
     Hue[0.9081261881867294, 1, -3.762265324346097], 
     Hue[0.8428920877848227, 1, -3.582727002581474], 
     Hue[0.9083293198266414, 1, -3.3874480893133745`], 
     Hue[0.8431462596660414, 1, -3.2077720087154615`], 
     Hue[0.9084379181432849, 1, -3.012950667579445], 
     Hue[0.8473304199670435, 1, -2.8211487495492857`], 
     Hue[0.9064300024407375, 1, -2.6448499630905387`], 
     Hue[0.8473755228654304, 1, -2.447000752835181], 
     Hue[0.9068616343421169, 1, -2.269650948833629], 
     Hue[0.8474746288026317, 1, -2.0729660079560075`], 
     Hue[0.9102888457280751, 1, -1.8859294813158727`], 
     Hue[0.847692231124473, 1, -1.6991805321066502`], 
     Hue[0.9104992615364705, 1, -1.5126820537416046`], 
     Hue[0.8481692083466245, 1, -1.3259443669913067`], 
     Hue[0.9109588237648214, 1, -1.140622932050084], 
     Hue[0.8492108584635725, 1, -0.9539217876291863], 
     Hue[0.9135957858410525, 1, -0.7663730952718135], 
     Hue[0.8534389759552259, 1, -0.5790099681719005], 
     Hue[0.9212315297015539, 1, -0.3869844407079066], 
     Hue[0.8631881583971907, 1, -0.20285369414943943`], 
     Hue[0.9327148160938098, 1, -0.01688937851273775], 
     Hue[0.884660635789331, 1, 0.17211711886339554`], 
     Hue[0.9615079068293046, 1, 0.35871223555550347`], 
     Hue[0.9362469523777677, 1, 0.5463374146435788], 
     Hue[0.9337493850363481, 1, 0.7339986196700736], 
     Hue[0.9864661897870588, 1, 0.9220073106131493], 
     Hue[1.0197106321321023`, 1, -17.27618334189528], 
     Hue[0.9570132315746361, 1, -17.089062133554293`], 
     Hue[1.016802305446087, 1, -16.91062086407678], 
     Hue[0.9570132315746361, 1, -16.714819716872324`], 
     Hue[1.016802305446087, 1, -16.53637844739481], 
     Hue[0.9570132315746361, 1, -16.34057730019035], 
     Hue[1.017276821905385, 1, -16.16071983016143], 
     Hue[0.9570132315746361, 1, -15.966334883508381`], 
     Hue[1.017632709249858, 1, -15.7854152630659], 
     Hue[0.9570132315746361, 1, -15.592092466826411`], 
     Hue[1.0215474700390592`, 1, -15.399489191834807`], 
     Hue[0.9570132315746361, 1, -15.217850050144438`], 
     Hue[1.0215474700390592`, 1, -15.025246775152837`], 
     Hue[0.9570132315746362, 1, -14.843607633462467`], 
     Hue[1.0215474700390592`, 1, -14.651004358470868`], 
     Hue[0.9570132315746364, 1, -14.469365216780501`], 
     Hue[1.021547470039059, 1, -14.276761941788898`], 
     Hue[0.9570132315746367, 1, -14.095122800098533`], 
     Hue[1.0215474700390588`, 1, -13.902519525106934`], 
     Hue[0.9589725253420585, 1, -13.715032845655914`], 
     Hue[1.0224658889925362`, 1, -13.52553607509967], 
     Hue[0.95897252534206, 1, -13.340790428973959`], 
     Hue[1.0224658889925349`, 1, -13.151293658417725`], 
     Hue[0.9589725253420633, 1, -12.966548012292028`], 
     Hue[1.022465888992532, 1, -12.777051241735814`], 
     Hue[0.9589725253420708, 1, -12.59230559561014], 
     Hue[1.022465888992526, 1, -12.40280882505397], 
     Hue[0.9589725253420872, 1, -12.218063178928352`], 
     Hue[1.0224658889925125`, 1, -12.028566408372281`], 
     Hue[0.9599521722258322, 1, -11.840896993366467`], 
     Hue[1.0229250984692217`, 1, -11.652953475028278`], 
     Hue[0.9599521722259099, 1, -11.4666545766854], 
     Hue[1.0229250984691551`, 1, -11.278711058347676`], 
     Hue[0.9599521722260809, 1, -11.092412160005411`], 
     Hue[1.0229250984690088`, 1, -10.904468641668716`], 
     Hue[0.960441995668306, 1, -10.716707858887668`], 
     Hue[1.0249991946052301`, 1, -10.524036058067184`], 
     Hue[0.960809363250505, 1, -10.341369028885255`], 
     Hue[1.025165658039757, 1, -10.14929682910974], 
     Hue[0.9648504066473425, 1, -9.955066065594401], 
     Hue[1.0252211458497917`, 1, -9.774888808363437], 
     Hue[0.964850406650966, 1, -9.580823648960601], 
     Hue[1.0252211458459775`, 1, -9.400646391752701], 
     Hue[0.9648504066589331, 1, -9.206581232384536], 
     Hue[1.0252211458375906`, 1, -9.02640397522736], 
     Hue[0.9648504066764505, 1, -8.832338815935428], 
     Hue[1.0269967557931103`, 1, -8.646862227800083], 
     Hue[0.9648504067149665, 1, -8.458096399765461], 
     Hue[1.0269967557492508`, 1, -8.272619811882395], 
     Hue[0.9648504067996526, 1, -8.083853984209242], 
     Hue[1.0269967556528152`, 1, -7.898377396880876], 
     Hue[0.9648504069858543, 1, -7.709611570002495], 
     Hue[1.0269967554407797`, 1, -7.524134983893759], 
     Hue[0.9648504073952612, 1, -7.335369158762867], 
     Hue[1.0269967549745713`, 1, -7.149892575335763], 
     Hue[0.9648504082954352, 1, -6.961126754047128], 
     Hue[1.0278845588658014`, 1, -6.773000511119682], 
     Hue[0.9648504102746726, 1, -6.586884363675638], 
     Hue[1.027884556525574, 1, -6.398758133893618], 
     Hue[0.9668097080490653, 1, -6.206794468685676], 
     Hue[1.028757049040229, 1, -6.021911823022427], 
     Hue[0.9668097172041321, 1, -5.8325521811207945`], 
     Hue[1.0287570373123238`, 1, -5.647669597945658], 
     Hue[0.9668097373336116, 1, -5.458310048331998], 
     Hue[1.0291932596875082`, 1, -5.272125613451616], 
     Hue[0.9668097815927666, 1, -5.084068255853178], 
     Hue[1.0294113255552246`, 1, -4.897233131623825], 
     Hue[0.9668098789061776, 1, -4.709827211621071], 
     Hue[1.0331192786727874`, 1, -4.511925906997804], 
     Hue[0.9677897306834016, 1, -4.33266408501175], 
     Hue[1.0300441098857491`, 1, -4.146865047477161], 
     Hue[0.9677901902492085, 1, -3.9584283527448116`], 
     Hue[1.0335162055078393`, 1, -3.762267971612448], 
     Hue[0.9682810019254386, 1, -3.5827388485516805`], 
     Hue[1.0337135875326138`, 1, -3.387453877408256], 
     Hue[0.9685280839426404, 1, -3.2077980325324793`], 
     Hue[1.0338095441570159`, 1, -3.0129633563186173`], 
     Hue[0.97269542986568, 1, -2.821205164865691], 
     Hue[1.0317746245776966`, 1, -2.6448794076881077`], 
     Hue[0.9727048317772977, 1, -2.4471247278018433`], 
     Hue[1.0321587339083804`, 1, -2.269676467179478], 
     Hue[0.9727254814899801, 1, -2.0732382718507507`], 
     Hue[1.035434616392755, 1, -1.8860574565413215`], 
     Hue[0.9727707759624223, 1, -1.6997776070188098`], 
     Hue[1.0353477091654693`, 1, -1.5129621702715024`], 
     Hue[0.9728698441718641, 1, -1.3272496726355276`], 
     Hue[1.0351580905859818`, 1, -1.1412327724439215`], 
     Hue[0.9750206969457881, 1, -0.9510073005212532], 
     Hue[1.0371036635827582`, 1, -0.765371467472419], 
     Hue[0.9771226834715125, 1, -0.5800925425619727], 
     Hue[1.0413044934309652`, 1, -0.3873912019436996], 
     Hue[0.9846411869729289, 1, -0.20418178632740958`], 
     Hue[1.0460484573038191`, 1, -0.016992079485561584`], 
     Hue[0.9996864629414797, 1, 0.17189469816490233`], 
     Hue[1.056737956583503, 1, 0.35844517002618037`], 
     Hue[1.0254689087102207`, 1, 0.5470297507396683], 
     Hue[1.0117435113655064`, 1, 0.7343825525242704], 
     Hue[1.016301735852983, 1, 0.9217968635044342], 
     Hue[1.1451054332470345`, 1, -17.27618334189528], 
     Hue[1.0824080326895678`, 1, -17.089062133554293`], 
     Hue[1.1421971065610184`, 1, -16.91062086407678], 
     Hue[1.0824080326895678`, 1, -16.714819716872324`], 
     Hue[1.1421971065610184`, 1, -16.53637844739481], 
     Hue[1.0824080326895678`, 1, -16.34057730019035], 
     Hue[1.1426716230203167`, 1, -16.16071983016143], 
     Hue[1.0824080326895678`, 1, -15.966334883508381`], 
     Hue[1.1430275103647891`, 1, -15.7854152630659], 
     Hue[1.0824080326895678`, 1, -15.592092466826411`], 
     Hue[1.1469422711539903`, 1, -15.399489191834807`], 
     Hue[1.0824080326895678`, 1, -15.217850050144438`], 
     Hue[1.14694227115399, 1, -15.025246775152837`], 
     Hue[1.0824080326895675`, 1, -14.843607633462467`], 
     Hue[1.1469422711539898`, 1, -14.651004358470864`], 
     Hue[1.0824080326895673`, 1, -14.469365216780501`], 
     Hue[1.1469422711539892`, 1, -14.276761941788898`], 
     Hue[1.0824080326895666`, 1, -14.095122800098531`], 
     Hue[1.1469422711539878`, 1, -13.90251952510693], 
     Hue[1.0843673264569857`, 1, -13.715032845655912`], 
     Hue[1.1478606901074624`, 1, -13.52553607509966], 
     Hue[1.0843673264569826`, 1, -13.340790428973955`], 
     Hue[1.147860690107455, 1, -13.151293658417705`], 
     Hue[1.084367326456976, 1, -12.96654801229202], 
     Hue[1.1478606901074393`, 1, -12.77705124173577], 
     Hue[1.0843673264569613`, 1, -12.592305595610123`], 
     Hue[1.1478606901074044`, 1, -12.402808825053876`], 
     Hue[1.084367326456929, 1, -12.218063178928317`], 
     Hue[1.1478606901073278`, 1, -12.028566408372077`], 
     Hue[1.085346973340566, 1, -11.840896993366382`], 
     Hue[1.1483198995838986`, 1, -11.652953475027823`], 
     Hue[1.0853469733404066`, 1, -11.466654576685213`], 
     Hue[1.1483198995835264`, 1, -11.278711058346678`], 
     Hue[1.085346973340056, 1, -11.092412160005003`], 
     Hue[1.148319899582708, 1, -10.904468641666522`], 
     Hue[1.0858367967811284`, 1, -10.716707858886748`], 
     Hue[1.1503939957174378`, 1, -10.524036058062189`], 
     Hue[1.086204164360791, 1, -10.341369028883191`], 
     Hue[1.1505604591486966`, 1, -10.149296829098727`], 
     Hue[1.0902452077518392`, 1, -9.955066065588957], 
     Hue[1.1506159469515467`, 1, -9.774888808339195], 
     Hue[1.0902452077429545`, 1, -9.580823648948627], 
     Hue[1.1506159469319368`, 1, -9.4006463916994], 
     Hue[1.0902452077234197`, 1, -9.206581232358213], 
     Hue[1.1506159468888202`, 1, -9.026403975110165], 
     Hue[1.0902452076804676`, 1, -8.832338815877552], 
     Hue[1.1523915567673897`, 1, -8.646862227534813], 
     Hue[1.0902452075860283`, 1, -8.458096399638208], 
     Hue[1.1523915565549263`, 1, -8.27261981129914], 
     Hue[1.0902452073783813`, 1, -8.08385398392945], 
     Hue[1.1523915560877778`, 1, -7.89837739559846], 
     Hue[1.0902452069218225`, 1, -7.709611569387309], 
     Hue[1.1523915550606454`, 1, -7.524134981074073], 
     Hue[1.090245205917974, 1, -7.335369157410235], 
     Hue[1.152391552802261, 1, -7.149892569136045], 
     Hue[1.0902452037107848`, 1, -6.961126751073061], 
     Hue[1.1532793527382872`, 1, -6.773000497291148], 
     Hue[1.0902451988577777`, 1, -6.586884357136472], 
     Hue[1.153279341716342, 1, -6.398758103488448], 
     Hue[1.0922044813307794`, 1, -6.206794453105963], 
     Hue[1.1541518150737993`, 1, -6.021911755227276], 
     Hue[1.0922044571214184`, 1, -5.832552146865268], 
     Hue[1.1541517612929169`, 1, -5.647669448882691], 
     Hue[1.092204403891671, 1, -5.458309973013516], 
     Hue[1.154587891042084, 1, -5.272125283413644], 
     Hue[1.092204286854154, 1, -5.084068090248764], 
     Hue[1.1548057532358607`, 1, -4.897232403439146], 
     Hue[1.0922040295214752`, 1, -4.709826847504049], 
     Hue[1.1585132523746462`, 1, -4.511924210198844], 
     Hue[1.0931830943928333`, 1, -4.332663253062864], 
     Hue[1.1554371032090194`, 1, -4.146861491688722], 
     Hue[1.0931818309407864`, 1, -3.958426523563581], 
     Hue[1.158907003512784, 1, -3.7622597185601787`], 
     Hue[1.0936688370970937`, 1, -3.5827347505157174`], 
     Hue[1.1590995836722398`, 1, -3.387435676944979], 
     Hue[1.0939075508621294`, 1, -3.2077889389067913`], 
     Hue[1.1591849826169038`, 1, -3.012923283699302], 
     Hue[1.0980558180294264`, 1, -2.82118195273308], 
     Hue[1.1571270276532049`, 1, -2.6447940496830498`], 
     Hue[1.0980239905713924`, 1, -2.4470737224603516`], 
     Hue[1.1574215603795457`, 1, -2.2696034278468016`], 
     Hue[1.0979540738610203`, 1, -2.0731262785851863`], 
     Hue[1.1606230921751983`, 1, -1.8856216145338547`], 
     Hue[1.097800651007203, 1, -1.6995321045600378`], 
     Hue[1.1602892809632135`, 1, -1.512007448074461], 
     Hue[1.097464784044639, 1, -1.326713434272493], 
     Hue[1.159558424421545, 1, -1.1391507630681985`], 
     Hue[1.0967333369010714`, 1, -0.9555938413013518], 
     Hue[1.1595695869763851`, 1, -0.7630097100883448], 
     Hue[1.0979661526262405`, 1, -0.5794797662562383], 
     Hue[1.1571542770374734`, 1, -0.3921016116304661], 
     Hue[1.100694628875296, 1, -0.20004753683808696`], 
     Hue[1.1546022219444674`, 1, -0.01583000716552152], 
     Hue[1.1015952123199166`, 1, 0.17267608528246015`], 
     Hue[1.146952038336628, 1, 0.35889724704844783`], 
     Hue[1.1001035299741586`, 1, 0.5463736401124468], 
     Hue[1.0659353946887207`, 1, 0.7340765207359904], 
     Hue[1.0429943199352183`, 1, 0.9218289218998198], 
     Hue[1.2705002343619658`, 1, -17.27618334189528], 
     Hue[1.207802833804499, 1, -17.089062133554293`], 
     Hue[1.2675919076759505`, 1, -16.91062086407678], 
     Hue[1.207802833804499, 1, -16.714819716872324`], 
     Hue[1.2675919076759505`, 1, -16.53637844739481], 
     Hue[1.207802833804499, 1, -16.34057730019035], 
     Hue[1.268066424135248, 1, -16.16071983016143], 
     Hue[1.207802833804499, 1, -15.966334883508381`], 
     Hue[1.2684223114797204`, 1, -15.7854152630659], 
     Hue[1.2078028338044988`, 1, -15.592092466826411`], 
     Hue[1.2723370722689227`, 1, -15.399489191834807`], 
     Hue[1.2078028338044988`, 1, -15.217850050144438`], 
     Hue[1.2723370722689225`, 1, -15.025246775152837`], 
     Hue[1.2078028338044986`, 1, -14.843607633462467`], 
     Hue[1.272337072268922, 1, -14.651004358470864`], 
     Hue[1.207802833804498, 1, -14.469365216780497`], 
     Hue[1.2723370722689211`, 1, -14.276761941788894`], 
     Hue[1.2078028338044968`, 1, -14.095122800098528`], 
     Hue[1.2723370722689193`, 1, -13.902519525106921`], 
     Hue[1.2097621275719146`, 1, -13.715032845655902`], 
     Hue[1.2732554912223932`, 1, -13.525536075099645`], 
     Hue[1.2097621275719088`, 1, -13.340790428973936`], 
     Hue[1.2732554912223844`, 1, -13.15129365841767], 
     Hue[1.209762127571896, 1, -12.966548012291975`], 
     Hue[1.2732554912223648`, 1, -12.777051241735691`], 
     Hue[1.2097621275718677`, 1, -12.592305595610025`], 
     Hue[1.2732554912223217`, 1, -12.402808825053699`], 
     Hue[1.2097621275718056`, 1, -12.218063178928102`], 
     Hue[1.2732554912222271`, 1, -12.028566408371686`], 
     Hue[1.2107417744553783`, 1, -11.840896993365904`], 
     Hue[1.2737147006987577`, 1, -11.652953475026964`], 
     Hue[1.2107417744550757`, 1, -11.466654576684162`], 
     Hue[1.2737147006982992`, 1, -11.278711058344788`], 
     Hue[1.2107417744544102`, 1, -11.092412160002691`], 
     Hue[1.273714700697291, 1, -10.904468641662366`], 
     Hue[1.2112315978947916`, 1, -10.716707858881636`], 
     Hue[1.2757887968316342`, 1, -10.524036058052902`], 
     Hue[1.2115989654729353`, 1, -10.341369028871908`], 
     Hue[1.2759552602620174`, 1, -10.149296829078281`], 
     Hue[1.2156400088607047`, 1, -9.955066065563042], 
     Hue[1.2760107480629412`, 1, -9.77488880829422], 
     Hue[1.2156400088445476`, 1, -9.580823648891647], 
     Hue[1.276010748039092, 1, -9.40064639160051], 
     Hue[1.2156400088090227`, 1, -9.206581232232928], 
     Hue[1.2760107479866543`, 1, -9.026403974892734], 
     Hue[1.215640008730913, 1, -8.832338815602082], 
     Hue[1.2777863578461175`, 1, -8.646862227050143], 
     Hue[1.215640008559171, 1, -8.45809639903252], 
     Hue[1.2777863575902553`, 1, -8.272619810233481], 
     Hue[1.2156400081815573`, 1, -8.083853982597708], 
     Hue[1.2777863570276837`, 1, -7.898377393255367], 
     Hue[1.2156400073512874`, 1, -7.709611566459171], 
     Hue[1.2777863557907423`, 1, -7.524134975922249], 
     Hue[1.2156400055257504`, 1, -7.335369150972064], 
     Hue[1.2777863530710452`, 1, -7.149892557808587], 
     Hue[1.215640001511892, 1, -6.961126736917277], 
     Hue[1.278674152029203, 1, -6.773000472215084], 
     Hue[1.2156399926865114`, 1, -6.586884326011764], 
     Hue[1.2786741388207585`, 1, -6.398758048353014], 
     Hue[1.217599266513905, 1, -6.206794383232906], 
     Hue[1.2795466075462505`, 1, -6.021911633189853], 
     Hue[1.2175992232066446`, 1, -5.832551993233505], 
     Hue[1.279546543405358, 1, -5.647669180555697], 
     Hue[1.2175991279857983`, 1, -5.458309635219351], 
     Hue[1.2799826508043721`, 1, -5.272124691476034], 
     Hue[1.2175989186211902`, 1, -5.084067347532492], 
     Hue[1.280200463900719, 1, -4.8972310997744755`], 
     Hue[1.217598458285874, 1, -4.709825214478385], 
     Hue[1.2839078728799849`, 1, -4.511921262874703], 
     Hue[1.2185770792186863`, 1, -4.332659625275421], 
     Hue[1.2808314737213202`, 1, -4.146855158994267], 
     Hue[1.2185748372423357`, 1, -3.9584185471656443`], 
     Hue[1.284300941139903, 1, -3.762245427994417], 
     Hue[1.2190596978217, 1, -3.5827171228286323`], 
     Hue[1.284492496574633, 1, -3.3874042099951085`], 
     Hue[1.219293694423924, 1, -3.207750083707502], 
     Hue[1.284575641824445, 1, -3.012854047809494], 
     Hue[1.2194992617580487`, 1, -2.832836232936746], 
     Hue[1.284632951142498, 1, -2.638309442382524], 
     Hue[1.223377516881697, 1, -2.446877711343654], 
     Hue[1.2827436906484306`, 1, -2.2694272727682447`], 
     Hue[1.223258071013118, 1, -2.0726956258569453`], 
     Hue[1.285975632310187, 1, -1.8848768650071424`], 
     Hue[1.22299554918982, 1, -1.6985867742809273`], 
     Hue[1.2855899580534098`, 1, -1.510371207233191], 
     Hue[1.2224188585342293`, 1, -1.3246424366023672`], 
     Hue[1.2847404743660484`, 1, -1.1355593195386768`], 
     Hue[1.2211534615480506`, 1, -0.9510766132089017], 
     Hue[1.2828656597858663`, 1, -0.76011027602167], 
     Hue[1.2179132074066135`, 1, -0.5799220996099657], 
     Hue[1.2785202450105924`, 1, -0.38406650791710417`], 
     Hue[1.2137092576702337`, 1, -0.20353488693609], 
     Hue[1.2662946226782517`, 1, -0.0165909280619716], 
     Hue[1.2033786251229055`, 1, 0.17089305900460594`], 
     Hue[1.2459655012407618`, 1, 0.3596095990008006], 
     Hue[1.1817805767572516`, 1, 0.5465643276679351], 
     Hue[1.2048550454309856`, 1, 0.7348782030892222], 
     Hue[1.1263691662675348`, 1, 0.7339788866233112], 
     Hue[1.1330655560077458`, 1, 0.9220583070602433], 
     Hue[1.0788942215558057`, 1, 0.9219805278067894], 
     Hue[1.3958950354768969`, 1, -17.27618334189528], 
     Hue[1.33319763491943, 1, -17.089062133554293`], 
     Hue[1.3929867087908818`, 1, -16.91062086407678], 
     Hue[1.33319763491943, 1, -16.714819716872324`], 
     Hue[1.3929867087908818`, 1, -16.53637844739481], 
     Hue[1.33319763491943, 1, -16.34057730019035], 
     Hue[1.393461225250179, 1, -16.16071983016143], 
     Hue[1.33319763491943, 1, -15.966334883508381`], 
     Hue[1.3938171125946526`, 1, -15.7854152630659], 
     Hue[1.33319763491943, 1, -15.592092466826411`], 
     Hue[1.3977318733838537`, 1, -15.399489191834807`], 
     Hue[1.3331976349194299`, 1, -15.217850050144438`], 
     Hue[1.3977318733838537`, 1, -15.025246775152837`], 
     Hue[1.3331976349194297`, 1, -14.843607633462467`], 
     Hue[1.3977318733838535`, 1, -14.651004358470864`], 
     Hue[1.3331976349194292`, 1, -14.469365216780497`], 
     Hue[1.397731873383853, 1, -14.276761941788891`], 
     Hue[1.3331976349194283`, 1, -14.095122800098522`], 
     Hue[1.3977318733838517`, 1, -13.902519525106914`], 
     Hue[1.3351569286868474`, 1, -13.71503284565589], 
     Hue[1.3986502923373274`, 1, -13.525536075099629`], 
     Hue[1.3351569286868423`, 1, -13.340790428973909`], 
     Hue[1.3986502923373219`, 1, -13.151293658417636`], 
     Hue[1.335156928686831, 1, -12.96654801229192], 
     Hue[1.3986502923373103`, 1, -12.777051241735618`], 
     Hue[1.3351569286868057`, 1, -12.592305595609904`], 
     Hue[1.3986502923372843`, 1, -12.402808825053544`], 
     Hue[1.3351569286867506`, 1, -12.218063178927835`], 
     Hue[1.3986502923372275`, 1, -12.028566408371343`], 
     Hue[1.3361365755703387`, 1, -11.840896993365314`], 
     Hue[1.3991095018138435`, 1, -11.652953475026205`], 
     Hue[1.3361365755700714`, 1, -11.466654576682863`], 
     Hue[1.3991095018135689`, 1, -11.27871105834312], 
     Hue[1.3361365755694832`, 1, -11.092412159999837`], 
     Hue[1.3991095018129651`, 1, -10.904468641658697`], 
     Hue[1.336626399010042, 1, -10.716707858875347`], 
     Hue[1.4011835979482539`, 1, -10.524036058044796`], 
     Hue[1.3369937665885818`, 1, -10.341369028858054`], 
     Hue[1.4013500613806702`, 1, -10.149296829060452`], 
     Hue[1.341034809977512, 1, -9.955066065531927], 
     Hue[1.4014055491860602`, 1, -9.774888808255014], 
     Hue[1.3410348099636038`, 1, -9.580823648823236], 
     Hue[1.401405549172026, 1, -9.400646391514309], 
     Hue[1.3410348099330236`, 1, -9.206581232082506], 
     Hue[1.4014055491411683`, 1, -9.026403974703198], 
     Hue[1.341034809865786, 1, -8.832338815271347], 
     Hue[1.4031811590506273`, 1, -8.646862226631686], 
     Hue[1.341034809717949, 1, -8.45809639830533], 
     Hue[1.4031811589021452`, 1, -8.27261980931341], 
     Hue[1.3410348093928957`, 1, -8.083853980998812], 
     Hue[1.4031811585756735`, 1, -7.898377391232379], 
     Hue[1.341034808678192, 1, -7.709611562943636], 
     Hue[1.4031811578578512`, 1, -7.524134971474251], 
     Hue[1.3410348071067535`, 1, -7.335369143242361], 
     Hue[1.403181156279556, 1, -7.149892548028652], 
     Hue[1.341034803651588, 1, -6.961126719921766], 
     Hue[1.4040689578134389`, 1, -6.77300045066878], 
     Hue[1.3410347960546203`, 1, -6.5868842886432635`], 
     Hue[1.404068950202217, 1, -6.398758000978561], 
     Hue[1.3429940729870407`, 1, -6.206794300242599], 
     Hue[1.404941431550604, 1, -6.021911528826655], 
     Hue[1.3429940361027923`, 1, -5.8325518107604175`], 
     Hue[1.4049413948478766`, 1, -5.647668951089371], 
     Hue[1.3429939550043422`, 1, -5.458309234010675], 
     Hue[1.4053775633438452`, 1, -5.2721241864664385`], 
     Hue[1.3429937766907596`, 1, -5.084066465383537], 
     Hue[1.4055955108538891`, 1, -4.89722998887543], 
     Hue[1.3429933846268574`, 1, -4.709823274871242], 
     Hue[1.4093032466319562`, 1, -4.511918801868811], 
     Hue[1.3439721662079231`, 1, -4.332655339436966], 
     Hue[1.406227475222654, 1, -4.146849781185086], 
     Hue[1.3439702668775055`, 1, -3.95840912372607], 
     Hue[1.4096985274797735`, 1, -3.7622335210648012`], 
     Hue[1.3444559063747834`, 1, -3.58269635197537], 
     Hue[1.4098934401166427`, 1, -3.38737801872157], 
     Hue[1.344691617529631, 1, -3.207704357036956], 
     Hue[1.4099839681952357`, 1, -3.012796443124837], 
     Hue[1.3448856755238319`, 1, -2.832781273010897], 
     Hue[1.4100513098794107`, 1, -2.638201302036209], 
     Hue[1.3487897619302143`, 1, -2.446652029853258], 
     Hue[1.40809879817625, 1, -2.26945825966858], 
     Hue[1.348691118696314, 1, -2.072199257086064], 
     Hue[1.40818354877791, 1, -1.8942344238422313`], 
     Hue[1.3484739217410509`, 1, -1.6974946400435684`], 
     Hue[1.4113083405675488`, 1, -1.5090143797393603`], 
     Hue[1.3479948770825951`, 1, -1.3222375136304347`], 
     Hue[1.4073211827062972`, 1, -1.143187721358099], 
     Hue[1.3469343772777425`, 1, -0.9457716831126286], 
     Hue[1.405650547229762, 1, -0.7661401063608311], 
     Hue[1.3404432291761887`, 1, -0.5796702503675781], 
     Hue[1.4005251898066842`, 1, -0.3901643941111548], 
     Hue[1.3325072120543506`, 1, -0.20450306734532275`], 
     Hue[1.3880513666107297`, 1, -0.01653771374353208], 
     Hue[1.445536050531015, 1, 0.17583281925234273`], 
     Hue[1.315574752754296, 1, 0.17070651469808262`], 
     Hue[1.362760856792522, 1, 0.3598209737108339], 
     Hue[1.4089861429111696`, 1, 0.547537892141761], 
     Hue[1.2814556493143363`, 1, 0.546216859057329], 
     Hue[1.3111254086315896`, 1, 0.7338817789370173], 
     Hue[1.3358239557305804`, 1, 0.9215977917184764], 
     Hue[1.3569538474755618`, 1, 1.1094555843142002`], 
     Hue[1.3761846610722568`, 1, 1.2971791740618808`], 
     Hue[1.2151410167069223`, 1, 0.9217248443812355], 
     Hue[1.2108683518172347`, 1, 1.1093719068484624`], 
     Hue[1.1859936374808606`, 1, 1.2970311764172426`], 
     Hue[1.1121814100060397`, 1, 1.109614858768943], 
     Hue[1.0447165519853137`, 1, 1.1099435157669266`], 
     Hue[0.5212898365918291, 1, -17.27618334189528], 
     Hue[1.4585924360343625`, 1, -17.089062133554293`], 
     Hue[0.5183815099058129, 1, -16.91062086407678], 
     Hue[1.4585924360343625`, 1, -16.714819716872324`], 
     Hue[0.5183815099058129, 1, -16.53637844739481], 
     Hue[1.4585924360343625`, 1, -16.34057730019035], 
     Hue[0.5188560263651114, 1, -16.16071983016143], 
     Hue[1.4585924360343625`, 1, -15.966334883508381`], 
     Hue[0.5192119137095839, 1, -15.7854152630659], 
     Hue[1.4585924360343625`, 1, -15.592092466826411`], 
     Hue[0.523126674498785, 1, -15.399489191834807`], 
     Hue[1.4585924360343623`, 1, -15.217850050144438`], 
     Hue[0.523126674498785, 1, -15.025246775152837`], 
     Hue[1.4585924360343623`, 1, -14.843607633462467`], 
     Hue[0.523126674498785, 1, -14.65100435847086], 
     Hue[1.4585924360343623`, 1, -14.469365216780494`], 
     Hue[0.5231266744987852, 1, -14.276761941788891`], 
     Hue[1.4585924360343618`, 1, -14.095122800098519`], 
     Hue[0.5231266744987855, 1, -13.902519525106912`], 
     Hue[1.4605517298017818`, 1, -13.715032845655882`], 
     Hue[0.524045093452264, 1, -13.525536075099625`], 
     Hue[1.4605517298017803`, 1, -13.340790428973895`], 
     Hue[0.5240450934522654, 1, -13.151293658417627`], 
     Hue[1.460551729801777, 1, -12.966548012291886`], 
     Hue[0.5240450934522685, 1, -12.777051241735599`], 
     Hue[1.4605517298017698`, 1, -12.59230559560983], 
     Hue[0.5240450934522749, 1, -12.4028088250535], 
     Hue[1.460551729801754, 1, -12.218063178927672`], 
     Hue[0.5240450934522893, 1, -12.028566408371244`], 
     Hue[1.461531376685431, 1, -11.84089699336496], 
     Hue[0.5245043029290629, 1, -11.652953475025994`], 
     Hue[1.4615313766853562`, 1, -11.466654576682085`], 
     Hue[0.5245043029291341, 1, -11.278711058342658`], 
     Hue[1.4615313766851918`, 1, -11.092412159998124`], 
     Hue[0.5245043029292904, 1, -10.90446864165768], 
     Hue[1.4620212001266932`, 1, -10.716707858871587`], 
     Hue[0.5265783990663004, 1, -10.524036058042647`], 
     Hue[1.4623885677073076`, 1, -10.34136902884979], 
     Hue[0.5267448625024602, 1, -10.149296829055746`], 
     Hue[1.4664296111011565`, 1, -9.95506606551395], 
     Hue[0.5268003503160796, 1, -9.774888808244683], 
     Hue[1.4664296110976933`, 1, -9.580823648783706], 
     Hue[0.5268003503201306, 1, -9.400646391491591], 
     Hue[1.4664296110900787`, 1, -9.206581231995596], 
     Hue[0.5268003503290377, 1, -9.02640397465325], 
     Hue[1.4664296110733364`, 1, -8.832338815080256], 
     Hue[0.5285759603281313, 1, -8.64686222652604], 
     Hue[1.4664296110365245`, 1, -8.458096397885168], 
     Hue[0.5285759603745297, 1, -8.272619809081121], 
     Hue[1.4664296109555852`, 1, -8.08385398007499], 
     Hue[0.5285759604765473, 1, -7.898377390721643], 
     Hue[1.4664296107776218`, 1, -7.7096115609124025`], 
     Hue[0.5285759607008562, 1, -7.524134970351278], 
     Hue[1.4664296103863286`, 1, -7.3353691387762305`], 
     Hue[0.5285759611940505, 1, -7.149892545559539], 
     Hue[1.4664296095259814`, 1, -6.9611267101019605`], 
     Hue[0.5294637673393794, 1, -6.7730004453494566`], 
     Hue[1.4664296076343124`, 1, -6.586884267052189], 
     Hue[0.5294637698106672, 1, -6.398757989282814], 
     Hue[1.4683888975926118`, 1, -6.206794253041146], 
     Hue[0.5303362735981569, 1, -6.02191150363885], 
     Hue[1.4683888888672438`, 1, -5.832551706977241], 
     Hue[0.530336285962519, 1, -5.647668895708212], 
     Hue[1.4683888696825207`, 1, -5.4583090058195385`], 
     Hue[0.5307725629983163, 1, -5.272124065987663], 
     Hue[1.4683888275004617`, 1, -5.084065963652385], 
     Hue[0.5309907492240081, 1, -4.8972297253994554`], 
     Hue[1.4683887347532194`, 1, -4.7098221716961834`], 
     Hue[0.5346990361799657, 1, -4.511918277479483], 
     Hue[1.4693681869163964`, 1, -4.332652921213673], 
     Hue[0.5316244003460311, 1, -4.146848527536814], 
     Hue[1.4693677495628146`, 1, -3.9584038065945775`], 
     Hue[0.5350981212900219, 1, -3.7622310152239526`], 
     Hue[1.469856633853372, 1, -3.5826846788245863`], 
     Hue[0.5352987949945578, 1, -3.3873725410676148`], 
     Hue[1.470099482809296, 1, -3.2076787086372764`], 
     Hue[0.5354019933465899, 1, -3.0127844327530537`], 
     Hue[1.470278646441217, 1, -2.8328163033012492`], 
     Hue[0.5354847743014743, 1, -2.6382120824220676`], 
     Hue[1.4742505041504144`, 1, -2.446529756390926], 
     Hue[0.5336044393618329, 1, -2.2693969881474034`], 
     Hue[1.474230959506198, 1, -2.071930089624204], 
     Hue[0.533796729850049, 1, -1.8941773209044055`], 
     Hue[1.4741878825671768`, 1, -1.6969012565130648`], 
     Hue[0.53390463655825, 1, -1.518724709984428], 
     Hue[1.4740926642928782`, 1, -1.3209252556324353`], 
     Hue[0.5336943324611664, 1, -1.1431472160456388`], 
     Hue[1.4696673343970728`, 1, -0.9554897781196694], 
     Hue[0.5325952177814801, 1, -0.7678103644637002], 
     Hue[1.4673697740371656`, 1, -0.5782911270806785], 
     Hue[0.5308804487426466, 1, -0.38884025041674497`], 
     Hue[1.4598481104353014`, 1, -0.20474732803196094`], 
     Hue[0.5225148619521858, 1, -0.01638343523774255], 
     Hue[0.5911027607624051, 1, 0.17200815402419145`], 
     Hue[0.5039050990552523, 1, 0.35871053495092997`], 
     Hue[0.5743002698283344, 1, 0.5465041121529405], 
     Hue[1.4579279190534873`, 1, 0.734334041180881], 
     Hue[0.5172776601337095, 1, 0.9220133251774061], 
     Hue[0.6110881935519126, 1, 1.1093304278084353`], 
     Hue[0.9785831987853004, 1, 1.297287374176849], 
     Hue[1.0025941648873757`, 1, 1.1093787977548066`], 
     Hue[0.6466846377067603, 1, -17.27618334189528], 
     Hue[0.5839872371492936, 1, -17.089062133554293`], 
     Hue[0.6437763110207453, 1, -16.91062086407678], 
     Hue[0.5839872371492936, 1, -16.714819716872324`], 
     Hue[0.6437763110207453, 1, -16.53637844739481], 
     Hue[0.5839872371492936, 1, -16.34057730019035], 
     Hue[0.6442508274800425, 1, -16.16071983016143], 
     Hue[0.5839872371492936, 1, -15.966334883508381`], 
     Hue[0.6446067148245149, 1, -15.7854152630659], 
     Hue[0.5839872371492936, 1, -15.592092466826411`], 
     Hue[0.6485214756137174, 1, -15.399489191834807`], 
     Hue[0.5839872371492937, 1, -15.217850050144438`], 
     Hue[0.6485214756137175, 1, -15.025246775152837`], 
     Hue[0.5839872371492938, 1, -14.843607633462467`], 
     Hue[0.6485214756137179, 1, -14.651004358470864`], 
     Hue[0.5839872371492941, 1, -14.469365216780494`], 
     Hue[0.6485214756137185, 1, -14.276761941788891`], 
     Hue[0.5839872371492947, 1, -14.095122800098519`], 
     Hue[0.6485214756137201, 1, -13.902519525106916`], 
     Hue[0.5859465309167178, 1, -13.715032845655884`], 
     Hue[0.6494398945672013, 1, -13.525536075099634`], 
     Hue[0.5859465309167209, 1, -13.340790428973898`], 
     Hue[0.6494398945672085, 1, -13.151293658417647`], 
     Hue[0.5859465309167278, 1, -12.966548012291893`], 
     Hue[0.6494398945672245, 1, -12.777051241735641`], 
     Hue[0.5859465309167428, 1, -12.592305595609849`], 
     Hue[0.6494398945672596, 1, -12.402808825053594`], 
     Hue[0.5859465309167757, 1, -12.21806317892771], 
     Hue[0.6494398945673368, 1, -12.028566408371454`], 
     Hue[0.5869261778005607, 1, -11.84089699336505], 
     Hue[0.6498991040442476, 1, -11.652953475026457`], 
     Hue[0.5869261778007229, 1, -11.466654576682284`], 
     Hue[0.6498991040446225, 1, -11.278711058343672`], 
     Hue[0.5869261778010793, 1, -11.092412159998563`], 
     Hue[0.6498991040454468, 1, -10.90446864165991], 
     Hue[0.58741600124373, 1, -10.71670785887257], 
     Hue[0.651973200183939, 1, -10.524036058047724`], 
     Hue[0.5877833688268772, 1, -10.341369028851991`], 
     Hue[0.6521396636233465, 1, -10.14929682906694], 
     Hue[0.5918244122265046, 1, -9.955066065519702], 
     Hue[0.6521951514441062, 1, -9.774888808269314], 
     Hue[0.5918244122355273, 1, -9.580823648796358], 
     Hue[0.6521951514638553, 1, -9.400646391545747], 
     Hue[0.5918244122553656, 1, -9.20658123202341], 
     Hue[0.6521951515072781, 1, -9.026403974772325], 
     Hue[0.5918244122989846, 1, -8.832338815141412], 
     Hue[0.6539707615828267, 1, -8.646862226795461], 
     Hue[0.5918244123948913, 1, -8.458096398019636], 
     Hue[0.6539707617967632, 1, -8.272619809673506], 
     Hue[0.5918244126057632, 1, -8.083853980370648], 
     Hue[0.6539707622671511, 1, -7.898377392024131], 
     Hue[0.5918244130694137, 1, -7.709611561562473], 
     Hue[0.6539707633014062, 1, -7.524134973215097], 
     Hue[0.5918244140888547, 1, -7.33536914020556], 
     Hue[0.6539707655754512, 1, -7.149892551856298], 
     Hue[0.5918244163303277, 1, -6.961126713244666], 
     Hue[0.6548585756504269, 1, -6.773000459391782], 
     Hue[0.591824421258716, 1, -6.586884273962143], 
     Hue[0.6548585867478964, 1, -6.398758020158066], 
     Hue[0.5937837264876057, 1, -6.206794269444335], 
     Hue[0.6557311095673422, 1, -6.021911572469607], 
     Hue[0.5937837510629768, 1, -5.8325517430434015`], 
     Hue[0.6557311637124696, 1, -5.647669047048383], 
     Hue[0.5937838050975601, 1, -5.458309085119284], 
     Hue[0.6561675327682494, 1, -5.272124401038232], 
     Hue[0.5937839239050762, 1, -5.08406613801134], 
     Hue[0.656385921335106, 1, -4.897230464615127], 
     Hue[0.593784185131359, 1, -4.709822555066057], 
     Hue[0.660094659031335, 1, -4.511919998739901], 
     Hue[0.594764422630056, 1, -4.332653795725191], 
     Hue[0.6570209973690773, 1, -4.146852136880172], 
     Hue[0.5947657050086712, 1, -3.9584057294570645`], 
     Hue[0.6604968980015318, 1, -3.7622393874190108`], 
     Hue[0.5952583876450598, 1, -3.5826889838366913`], 
     Hue[0.6607023407277814, 1, -3.3873910062500583`], 
     Hue[0.5955095905255259, 1, -3.2076882602773553`], 
     Hue[0.6608160257624239, 1, -3.0128251003825106`], 
     Hue[0.5957071377839802, 1, -2.8328374509395706`], 
     Hue[0.6609218692368644, 1, -2.6383016317983063`], 
     Hue[0.5997208558563119, 1, -2.4465831197010486`], 
     Hue[0.6590919206264327, 1, -2.269588413962185], 
     Hue[0.5997919831703835, 1, -2.07204758175979], 
     Hue[0.6627629267255297, 1, -1.8845845636272294`], 
     Hue[0.5999486818761057, 1, -1.6971603692413033`], 
     Hue[0.6631011509987822, 1, -1.5097273271703038`], 
     Hue[0.6002947201926087, 1, -1.3214987678260186`], 
     Hue[0.6638478940139079, 1, -1.134137880855442], 
     Hue[0.6010628840487415, 1, -0.9441289841567846], 
     Hue[0.66188547227428, 1, -0.7673633305318688], 
     Hue[0.5976638905465578, 1, -0.5777019537440451], 
     Hue[0.6633779315228909, 1, -0.3924325007782494], 
     Hue[0.5959558942221146, 1, -0.20308128778821977`], 
     Hue[0.6669500016498967, 1, -0.015654398631085975`], 
     Hue[0.6716510471238429, 1, 0.3584479964586772], 
     Hue[0.6755189035941536, 1, 0.7340751530432825], 
     Hue[0.8290823982161392, 1, 1.1093924505564252`], 
     Hue[0.9379325137501836, 1, 1.1092821713265493`], 
     Hue[0.901858823649368, 1, 1.2971583253035417`], 
     Hue[0.9706180088501196, 1, 1.1093419467527206`], 
     Hue[0.9877851235920095, 1, 1.1098883378080784`], 
     Hue[0.7720794388216915, 1, -17.27618334189528], 
     Hue[0.709382038264226, 1, -17.089062133554293`], 
     Hue[0.7691711121356763, 1, -16.91062086407678], 
     Hue[0.709382038264226, 1, -16.714819716872324`], 
     Hue[0.7691711121356763, 1, -16.53637844739481], 
     Hue[0.709382038264226, 1, -16.34057730019035], 
     Hue[0.7696456285949738, 1, -16.16071983016143], 
     Hue[0.709382038264226, 1, -15.966334883508381`], 
     Hue[0.7700015159394473, 1, -15.7854152630659], 
     Hue[0.709382038264226, 1, -15.592092466826411`], 
     Hue[0.7739162767286486, 1, -15.399489191834807`], 
     Hue[0.7093820382642262, 1, -15.217850050144438`], 
     Hue[0.7739162767286488, 1, -15.025246775152837`], 
     Hue[0.7093820382642264, 1, -14.843607633462467`], 
     Hue[0.7739162767286492, 1, -14.651004358470864`], 
     Hue[0.7093820382642269, 1, -14.469365216780497`], 
     Hue[0.77391627672865, 1, -14.276761941788894`], 
     Hue[0.7093820382642281, 1, -14.095122800098524`], 
     Hue[0.7739162767286518, 1, -13.902519525106925`], 
     Hue[0.7113413320316513, 1, -13.715032845655895`], 
     Hue[0.7748346956821338, 1, -13.525536075099652`], 
     Hue[0.7113413320316572, 1, -13.340790428973918`], 
     Hue[0.7748346956821427, 1, -13.151293658417682`], 
     Hue[0.7113413320316699, 1, -12.96654801229194], 
     Hue[0.7748346956821622, 1, -12.777051241735723`], 
     Hue[0.7113413320316984, 1, -12.592305595609947`], 
     Hue[0.7748346956822052, 1, -12.402808825053771`], 
     Hue[0.7113413320317606, 1, -12.21806317892793], 
     Hue[0.7748346956822997, 1, -12.028566408371844`], 
     Hue[0.7123209789156097, 1, -11.840896993365533`], 
     Hue[0.7752939051592489, 1, -11.652953475027317`], 
     Hue[0.7123209789159132, 1, -11.466654576683343`], 
     Hue[0.7752939051597068, 1, -11.278711058345566`], 
     Hue[0.7123209789165803, 1, -11.092412160000892`], 
     Hue[0.7752939051607133, 1, -10.904468641664076`], 
     Hue[0.7128108023599127, 1, -10.716707858877719`], 
     Hue[0.7773680012995753, 1, -10.524036058057032`], 
     Hue[0.7131781699445588, 1, -10.341369028863358`], 
     Hue[0.777534464739821, 1, -10.149296829087431`], 
     Hue[0.7172192133474161, 1, -9.955066065545797], 
     Hue[0.7775899525624244, 1, -9.774888808314392], 
     Hue[0.7172192133636075, 1, -9.58082364885373], 
     Hue[0.7775899525862333, 1, -9.400646391644864], 
     Hue[0.7172192133992081, 1, -9.206581232149562], 
     Hue[0.7775899526385829, 1, -9.026403974990252], 
     Hue[0.717219213477484, 1, -8.83233881541878], 
     Hue[0.7793655627323491, 1, -8.64686222728118], 
     Hue[0.7172192136495912, 1, -8.45809639862949], 
     Hue[0.7793655629877511, 1, -8.272619810741467], 
     Hue[0.717219214028008, 1, -8.083853981711554], 
     Hue[0.7793655635493103, 1, -7.898377394372292], 
     Hue[0.7172192148600437, 1, -7.709611564510763], 
     Hue[0.7793655647840261, 1, -7.524134978378064], 
     Hue[0.7172192166894633, 1, -7.335369146688046], 
     Hue[0.7793655674988295, 1, -7.1498925632082555`], 
     Hue[0.7172192207118586, 1, -6.961126727497887], 
     Hue[0.780253378505916, 1, -6.7730004845206295`], 
     Hue[0.7172192295560096, 1, -6.586884305301094], 
     Hue[0.7802533916898386, 1, -6.398758075409556], 
     Hue[0.7191785433012551, 1, -6.206794339785775], 
     Hue[0.7811259189185797, 1, -6.021911694756984], 
     Hue[0.7191785866951047, 1, -5.832551897705104], 
     Hue[0.7811259829367618, 1, -5.647669315925039], 
     Hue[0.7191786821063704, 1, -5.458309425178431], 
     Hue[0.7815623732652689, 1, -5.272124994172], 
     Hue[0.7191788918898205, 1, -5.084066885709754], 
     Hue[0.7817808085587337, 1, -4.897231770897576], 
     Hue[0.7191793531468371, 1, -4.709824199056076], 
     Hue[0.785489630934008, 1, -4.511922951282831], 
     Hue[0.7201600279202814, 1, -4.332657447595909], 
     Hue[0.7824162079461956, 1, -4.146858482093912], 
     Hue[0.7201622742689725, 1, -3.958413759042543], 
     Hue[0.7858925147144212, 1, -3.762253703209929], 
     Hue[0.7206570700484339, 1, -3.5827067294300674`], 
     Hue[0.7860989237123689, 1, -3.387422529289891], 
     Hue[0.7209129181094931, 1, -3.207727380046741], 
     Hue[0.7862147304809014, 1, -3.0128944638298227`], 
     Hue[0.7211512966262797, 1, -2.8328322947845797`], 
     Hue[0.7863376637588683, 1, -2.638417138137232], 
     Hue[0.7251562373185381, 1, -2.446780586277405], 
     Hue[0.7846099722355961, 1, -2.269611321788081], 
     Hue[0.7252759549387113, 1, -2.072482076216345], 
     Hue[0.7881965901535017, 1, -1.8853314289450138`], 
     Hue[0.7255392803936613, 1, -1.6981172479048692`], 
     Hue[0.788580181251434, 1, -1.5113706302005288`], 
     Hue[0.7261187343452085, 1, -1.3236101492864976`], 
     Hue[0.7894219825629177, 1, -1.1377564999836924`], 
     Hue[0.7273950211787366, 1, -0.9488074573120433], 
     Hue[0.791264923585111, 1, -0.7649389915548779], 
     Hue[0.7302113256350935, 1, -0.5734388968765003], 
     Hue[0.7969835415059585, 1, -0.38939606958126194`], 
     Hue[0.7343325619185365, 1, -0.20270720159227862`], 
     Hue[0.8093004160541765, 1, -0.014907911672155105`], 
     Hue[0.7468633430257197, 1, 0.1713327138591877], 
     Hue[0.8397726777521591, 1, 0.35852571058204064`], 
     Hue[0.7822407529370381, 1, 0.5468692626595325], 
     Hue[0.8974742399366238, 1, -17.27618334189528], 
     Hue[0.834776839379157, 1, -17.089062133554293`], 
     Hue[0.8945659132506075, 1, -16.91062086407678], 
     Hue[0.8347768393791571, 1, -16.714819716872324`], 
     Hue[0.8945659132506075, 1, -16.53637844739481], 
     Hue[0.8347768393791571, 1, -16.34057730019035], 
     Hue[0.895040429709906, 1, -16.16071983016143], 
     Hue[0.8347768393791571, 1, -15.966334883508381`], 
     Hue[0.8953963170543785, 1, -15.7854152630659], 
     Hue[0.8347768393791571, 1, -15.592092466826411`], 
     Hue[0.8993110778435798, 1, -15.399489191834807`], 
     Hue[0.8347768393791573, 1, -15.217850050144438`], 
     Hue[0.8993110778435798, 1, -15.025246775152837`], 
     Hue[0.8347768393791575, 1, -14.843607633462467`], 
     Hue[0.8993110778435801, 1, -14.651004358470868`], 
     Hue[0.8347768393791579, 1, -14.469365216780497`], 
     Hue[0.8993110778435806, 1, -14.276761941788898`], 
     Hue[0.834776839379159, 1, -14.09512280009853], 
     Hue[0.8993110778435817, 1, -13.902519525106932`], 
     Hue[0.8367361331465819, 1, -13.715032845655907`], 
     Hue[0.900229496797062, 1, -13.525536075099666`], 
     Hue[0.836736133146587, 1, -13.340790428973943`], 
     Hue[0.9002294967970672, 1, -13.151293658417716`], 
     Hue[0.8367361331465983, 1, -12.966548012291994`], 
     Hue[0.9002294967970789, 1, -12.777051241735794`], 
     Hue[0.8367361331466233, 1, -12.592305595610068`], 
     Hue[0.9002294967971044, 1, -12.402808825053926`], 
     Hue[0.8367361331466783, 1, -12.218063178928196`], 
     Hue[0.9002294967971605, 1, -12.028566408372187`], 
     Hue[0.8377157800305096, 1, -11.84089699336612], 
     Hue[0.9006887062740242, 1, -11.652953475028072`], 
     Hue[0.8377157800307755, 1, -11.46665457668464], 
     Hue[0.9006887062742951, 1, -11.278711058347225`], 
     Hue[0.8377157800313603, 1, -11.092412160003741`], 
     Hue[0.9006887062748907, 1, -10.904468641667723`], 
     Hue[0.8382056034745048, 1, -10.716707858883998`], 
     Hue[0.902762802412792, 1, -10.52403605806509], 
     Hue[0.8385729710587297, 1, -10.34136902887719], 
     Hue[0.9029292658509727, 1, -10.149296829105149`], 
     Hue[0.8426140144603679, 1, -9.955066065576855], 
     Hue[0.902984753669039, 1, -9.774888808353353], 
     Hue[0.8426140144741865, 1, -9.580823648922019], 
     Hue[0.9029847536828772, 1, -9.400646391730529], 
     Hue[0.8426140145045699, 1, -9.206581232299705], 
     Hue[0.9029847537133039, 1, -9.026403975178606], 
     Hue[0.8426140145713746, 1, -8.832338815748905], 
     Hue[0.904760363756315, 1, -8.646862227696962], 
     Hue[0.8426140147182599, 1, -8.458096399355348], 
     Hue[0.9047603639026743, 1, -8.272619811655662], 
     Hue[0.8426140150412209, 1, -8.083853983307517], 
     Hue[0.9047603642244786, 1, -7.898377396382357], 
     Hue[0.8426140157513241, 1, -7.709611568019848], 
     Hue[0.9047603649320384, 1, -7.524134982797647], 
     Hue[0.8426140173126475, 1, -7.335369154403568], 
     Hue[0.9047603664877697, 1, -7.149892572925713], 
     Hue[0.8426140207455719, 1, -6.961126744462216], 
     Hue[0.9056481748801407, 1, -6.7730005059275955`], 
     Hue[0.8426140282936367, 1, -6.586884342601026], 
     Hue[0.9056481823812463, 1, -6.398758122477638], 
     Hue[0.8445733387823271, 1, -6.206794422613311], 
     Hue[0.9065206967982419, 1, -6.021911798437143], 
     Hue[0.8445733754226988, 1, -5.832552079820262], 
     Hue[0.906520732963654, 1, -5.647669543889359], 
     Hue[0.8445734559848508, 1, -5.458309825599944], 
     Hue[0.9069570612819596, 1, -5.272125495855391], 
     Hue[0.844573633118874, 1, -5.084067766127102], 
     Hue[0.9071753601531096, 1, -4.897232874453583], 
     Hue[0.8445740225873802, 1, -4.7098261348517845`], 
     Hue[0.9108838512531534, 1, -4.511925395167155], 
     Hue[0.8455545288965931, 1, -4.332661724719382], 
     Hue[0.9078097908285047, 1, -4.146863823894792], 
     Hue[0.8455564154217562, 1, -3.958423163220284], 
     Hue[0.9112844910376121, 1, -3.7622655260661997`], 
     Hue[0.8460503940423428, 1, -3.5827274566671026`], 
     Hue[0.9114874950582261, 1, -3.3874485324883343`], 
     Hue[0.8463044419865029, 1, -3.2077730075458364`], 
     Hue[0.9115958127486802, 1, -3.0129516414773168`], 
     Hue[0.8504882978241468, 1, -2.8211509628000124`], 
     Hue[0.9095873040781198, 1, -2.6448521187839127`], 
     Hue[0.8505327639001719, 1, -2.447005617208945], 
     Hue[0.9100175994486168, 1, -2.2696556784256225`], 
     Hue[0.8506304687857531, 1, -2.0729766939091974`], 
     Hue[0.9134416978622438, 1, -1.8859397353874814`], 
     Hue[0.8508449864882681, 1, -1.699203981814401], 
     Hue[0.9136454685234411, 1, -1.512704504817177], 
     Hue[0.8513151620678431, 1, -1.3259957055058138`], 
     Hue[0.9140904810580546, 1, -1.1406718414091757`], 
     Hue[0.8523417672028755, 1, -0.9540336026608254], 
     Hue[0.9166947924785211, 1, -0.7664777241164273], 
     Hue[0.8565346818371183, 1, -0.5792512663081466], 
     Hue[0.9242543540594605, 1, -0.38719790372239604`], 
     Hue[0.8661975646119113, 1, -0.203360074576882], 
     Hue[0.9357042428593544, 1, -0.0169177553880151], 
     Hue[0.8874440678344246, 1, 0.17114355334568698`], 
     Hue[0.9640904003979772, 1, 0.35856835217105953`], 
     Hue[0.9389912870933763, 1, 0.5462913698890955], 
     Hue[0.9368487343956191, 1, 0.7339800048994153], 
     Hue[0.9873690428832036, 1, 0.9216742135531899], 
     Hue[1.022869041051555, 1, -17.27618334189528], 
     Hue[0.9601716404940882, 1, -17.089062133554293`], 
     Hue[1.0199607143655398`, 1, -16.91062086407678], 
     Hue[0.9601716404940882, 1, -16.714819716872324`], 
     Hue[1.0199607143655398`, 1, -16.53637844739481], 
     Hue[0.9601716404940882, 1, -16.34057730019035], 
     Hue[1.0204352308248372`, 1, -16.16071983016143], 
     Hue[0.9601716404940882, 1, -15.966334883508381`], 
     Hue[1.0207911181693108`, 1, -15.7854152630659], 
     Hue[0.9601716404940883, 1, -15.592092466826411`], 
     Hue[1.024705878958512, 1, -15.399489191834807`], 
     Hue[0.9601716404940883, 1, -15.217850050144438`], 
     Hue[1.024705878958512, 1, -15.025246775152837`], 
     Hue[0.9601716404940883, 1, -14.843607633462467`], 
     Hue[1.024705878958512, 1, -14.651004358470868`], 
     Hue[0.9601716404940885, 1, -14.469365216780501`], 
     Hue[1.0247058789585117`, 1, -14.276761941788898`], 
     Hue[0.9601716404940888, 1, -14.095122800098533`], 
     Hue[1.0247058789585115`, 1, -13.902519525106934`], 
     Hue[0.9621309342615111, 1, -13.715032845655914`], 
     Hue[1.0256242979119887`, 1, -13.52553607509967], 
     Hue[0.9621309342615125, 1, -13.340790428973959`], 
     Hue[1.0256242979119872`, 1, -13.151293658417725`], 
     Hue[0.9621309342615156, 1, -12.966548012292028`], 
     Hue[1.025624297911984, 1, -12.777051241735812`], 
     Hue[0.9621309342615225, 1, -12.59230559561014], 
     Hue[1.0256242979119772`, 1, -12.402808825053969`], 
     Hue[0.9621309342615376, 1, -12.218063178928354`], 
     Hue[1.0256242979119619`, 1, -12.02856640837228], 
     Hue[0.9631105811452799, 1, -11.84089699336647], 
     Hue[1.0260835073886663`, 1, -11.652953475028275`], 
     Hue[0.9631105811453516, 1, -11.466654576685409`], 
     Hue[1.0260835073885906`, 1, -11.27871105834767], 
     Hue[0.9631105811455093, 1, -11.09241216000543], 
     Hue[1.0260835073884242`, 1, -10.9044686416687], 
     Hue[0.9636004045877047, 1, -10.716707858887707`], 
     Hue[1.028157603524601, 1, -10.524036058067143`], 
     Hue[0.9639677721698391, 1, -10.341369028885339`], 
     Hue[1.0283240669590297`, 1, -10.14929682910965], 
     Hue[0.9680088155665274, 1, -9.955066065594574], 
     Hue[1.0283795547688495`, 1, -9.774888808363237], 
     Hue[0.96800881556983, 1, -9.580823648960976], 
     Hue[1.0283795547645622`, 1, -9.400646391752263], 
     Hue[0.9680088155770913, 1, -9.206581232385364], 
     Hue[1.0283795547551355`, 1, -9.02640397522639], 
     Hue[0.968008815593057, 1, -8.832338815937247], 
     Hue[1.0301551647083311`, 1, -8.64686222779779], 
     Hue[0.9680088156281611, 1, -8.458096399769458], 
     Hue[1.0301551646593985`, 1, -8.272619811877354], 
     Hue[0.9680088157053457, 1, -8.083853984218035], 
     Hue[1.030155164551809, 1, -7.898377396869795], 
     Hue[0.9680088158750533, 1, -7.709611570021827], 
     Hue[1.0301551643152487`, 1, -7.5241349838693905`], 
     Hue[0.9680088162481942, 1, -7.335369158805377], 
     Hue[1.0301551637951172`, 1, -7.149892575282185], 
     Hue[0.9680088170686295, 1, -6.961126754140593], 
     Hue[1.031042967566793, 1, -6.773000510997582], 
     Hue[0.9680088188725428, 1, -6.586884363881136], 
     Hue[1.0310429649646902`, 1, -6.398758133625151], 
     Hue[0.969968116250855, 1, -6.206794469116775], 
     Hue[1.0319154568988524`, 1, -6.021911822411535], 
     Hue[0.96996812454564, 1, -5.832552182068664], 
     Hue[1.031915443899304, 1, -5.647669596602472], 
     Hue[0.9699681427835954, 1, -5.458310050416102], 
     Hue[1.032351663467157, 1, -5.272125610448156], 
     Hue[0.9699681828838125, 1, -5.084068260435543], 
     Hue[1.0325697231612194`, 1, -4.897233124964725], 
     Hue[0.9699682710528891, 1, -4.709827221696384], 
     Hue[1.036277662254665, 1, -4.5119258902450206`], 
     Hue[0.9709481024514306, 1, -4.3326641066190374`], 
     Hue[1.0332024639376056`, 1, -4.146865014505198], 
     Hue[0.9709485174839141, 1, -3.958428400252009], 
     Hue[1.0366744917005737`, 1, -3.762267889508852], 
     Hue[0.9714392305870172, 1, -3.58273895166736], 
     Hue[1.0368717263597562`, 1, -3.3874536956679346`], 
     Hue[0.9716860958234562, 1, -3.207798257750788], 
     Hue[1.036967358987417, 1, -3.0129629554450394`], 
     Hue[0.9758529386585245, 1, -2.821205602923751], 
     Hue[1.0349317404605283`, 1, -2.6448785869112994`], 
     Hue[0.9758612622215658, 1, -2.447125690314394], 
     Hue[1.0353142955023955`, 1, -2.2696746383872073`], 
     Hue[0.9758795434590503, 1, -2.073240384978921], 
     Hue[1.038586669608648, 1, -1.8860529642038777`], 
     Hue[0.9759196424484847, 1, -1.6997822379190215`], 
     Hue[1.0384921753750427`, 1, -1.5129523403284455`], 
     Hue[0.9760073456042363, 1, -1.3272597813679463`], 
     Hue[1.038285995741862, 1, -1.1412113860459658`], 
     Hue[0.9781328462387809, 1, -0.9510277674999295], 
     Hue[1.0401949684420877`, 1, -0.7653218539068385], 
     Hue[0.9801799057224178, 1, -0.580133295970999], 
     Hue[1.0443151957426389`, 1, -0.3872696809265934], 
     Hue[0.9875751692785781, 1, -0.2042403990451831], 
     Hue[1.0488873957405465`, 1, -0.016698965925431075`], 
     Hue[1.0023475912401687`, 1, 0.1719041822112467], 
     Hue[1.0589926509274123`, 1, 0.3584315835965358], 
     Hue[1.0271796327012728`, 1, 0.5462606233900124], 
     Hue[1.0130360488288748`, 1, 0.733892388445994], 
     Hue[1.0169043498691555`, 1, 0.9216095122637706], 
     Hue[1.1482638421664884`, 1, -17.27618334189528], 
     Hue[1.0855664416090205`, 1, -17.089062133554293`], 
     Hue[1.1453555154804733`, 1, -16.91062086407678], 
     Hue[1.0855664416090205`, 1, -16.714819716872324`], 
     Hue[1.1453555154804733`, 1, -16.53637844739481], 
     Hue[1.0855664416090205`, 1, -16.34057730019035], 
     Hue[1.1458300319397705`, 1, -16.16071983016143], 
     Hue[1.0855664416090205`, 1, -15.966334883508381`], 
     Hue[1.146185919284243, 1, -15.7854152630659], 
     Hue[1.0855664416090205`, 1, -15.592092466826411`], 
     Hue[1.1501006800734463`, 1, -15.399489191834807`], 
     Hue[1.0855664416090205`, 1, -15.217850050144438`], 
     Hue[1.1501006800734463`, 1, -15.025246775152837`], 
     Hue[1.0855664416090203`, 1, -14.843607633462467`], 
     Hue[1.150100680073446, 1, -14.651004358470864`], 
     Hue[1.08556644160902, 1, -14.469365216780501`], 
     Hue[1.1501006800734452`, 1, -14.276761941788898`], 
     Hue[1.0855664416090194`, 1, -14.095122800098531`], 
     Hue[1.1501006800734437`, 1, -13.90251952510693], 
     Hue[1.0875257353764385`, 1, -13.715032845655912`], 
     Hue[1.1510190990269171`, 1, -13.52553607509966], 
     Hue[1.0875257353764352`, 1, -13.340790428973955`], 
     Hue[1.15101909902691, 1, -13.151293658417705`], 
     Hue[1.0875257353764283`, 1, -12.96654801229202], 
     Hue[1.1510190990268938`, 1, -12.777051241735768`], 
     Hue[1.0875257353764132`, 1, -12.59230559561012], 
     Hue[1.1510190990268585`, 1, -12.402808825053873`], 
     Hue[1.0875257353763796`, 1, -12.218063178928313`], 
     Hue[1.1510190990267808`, 1, -12.028566408372068`], 
     Hue[1.088505382260015, 1, -11.840896993366375`], 
     Hue[1.1514783085033478`, 1, -11.652953475027806`], 
     Hue[1.0885053822598503`, 1, -11.466654576685196`], 
     Hue[1.1514783085029703`, 1, -11.278711058346639`], 
     Hue[1.088505382259488, 1, -11.092412160004963`], 
     Hue[1.15147830850214, 1, -10.904468641666432`], 
     Hue[1.0889952057005337`, 1, -10.71670785888666], 
     Hue[1.1535524046368462`, 1, -10.524036058061986`], 
     Hue[1.0893625732801415`, 1, -10.341369028883001`], 
     Hue[1.1537188680680477`, 1, -10.149296829098283`], 
     Hue[1.0934036166710634`, 1, -9.955066065588511], 
     Hue[1.1537743558707698`, 1, -9.77488880833822], 
     Hue[1.0934036166619037`, 1, -9.580823648947648], 
     Hue[1.1537743558508835`, 1, -9.400646391697254], 
     Hue[1.093403616641764, 1, -9.206581232356058], 
     Hue[1.1537743558071587`, 1, -9.026403975105447], 
     Hue[1.093403616597482, 1, -8.832338815872813], 
     Hue[1.1555499656844042`, 1, -8.646862227524242], 
     Hue[1.0934036165001182`, 1, -8.45809639962779], 
     Hue[1.1555499654690153`, 1, -8.272619811275899], 
     Hue[1.0934036162860414`, 1, -8.08385398390654], 
     Hue[1.1555499649954344`, 1, -7.898377395547359], 
     Hue[1.093403615815345, 1, -7.709611569336938], 
     Hue[1.1555499639541587`, 1, -7.524134980961718], 
     Hue[1.093403614780412, 1, -7.33536915729949], 
     Hue[1.1555499616646772`, 1, -7.149892568889006], 
     Hue[1.0934036125048765`, 1, -6.96112675082956], 
     Hue[1.1564377615326507`, 1, -6.77300049674285], 
     Hue[1.0934036075015947`, 1, -6.5868843566010815`], 
     Hue[1.1564377503607552`, 1, -6.398758102282886], 
     Hue[1.0953628896416372`, 1, -6.206794451891753], 
     Hue[1.1573102233900925`, 1, -6.0219117525520955`], 
     Hue[1.0953628647027362`, 1, -5.832552144195553], 
     Hue[1.157310168886183, 1, -5.6476694430007], 
     Hue[1.0953628098689296`, 1, -5.458309967143545], 
     Hue[1.1577462970495276`, 1, -5.2721252704213954`], 
     Hue[1.0953626893045274`, 1, -5.0840680773423275`], 
     Hue[1.1579641557569482`, 1, -4.89723237480742], 
     Hue[1.0953624242172046`, 1, -4.70982681912645], 
     Hue[1.1616716474010575`, 1, -4.511924144778115], 
     Hue[1.0963414719752629`, 1, -4.33266318970683], 
     Hue[1.1585954812580705`, 1, -4.14686135235414], 
     Hue[1.0963401709591087`, 1, -3.958426384264242], 
     Hue[1.1620653453636578`, 1, -3.7622594010073787`], 
     Hue[1.0968270943744194`, 1, -3.582734441912212], 
     Hue[1.1622578452288985`, 1, -3.3874349773445918`], 
     Hue[1.0970656262093894`, 1, -3.207788257872572], 
     Hue[1.1623430676177051`, 1, -3.012921744074397], 
     Hue[1.1012134878468964`, 1, -2.8211803578060426`], 
     Hue[1.1602847190485555`, 1, -2.644790735164233], 
     Hue[1.101180774624617, 1, -2.447070217617136], 
     Hue[1.1605783930239617`, 1, -2.2695961168242675`], 
     Hue[1.101108911195578, 1, -2.073118581887277], 
     Hue[1.1637780747321624`, 1, -1.8856049974326659`], 
     Hue[1.1009512120878489`, 1, -1.6995152274199261`], 
     Hue[1.163440140261383, 1, -1.5119710065976124`], 
     Hue[1.1006059624989006`, 1, -1.3266765462749686`], 
     Hue[1.1627001578634721`, 1, -1.1390710970831524`], 
     Hue[1.0998539818517883`, 1, -0.9555137868422878], 
     Hue[1.1610878351569636`, 1, -0.7678027736583206], 
     Hue[1.1010416450940728`, 1, -0.5793011481300665], 
     Hue[1.1602303267323368`, 1, -0.3917212339432401], 
     Hue[1.1036709458968677`, 1, -0.1996411899832664], 
     Hue[1.1575741013842133`, 1, -0.014998678172205793`], 
     Hue[1.1035805845214972`, 1, 0.17069077485336992`], 
     Hue[1.1492627137999185`, 1, 0.35876968744324944`], 
     Hue[1.1021914552088483`, 1, 0.5472974220702865], 
     Hue[1.0672954191215764`, 1, 0.7338848905163999], 
     Hue[1.0437398324894571`, 1, 0.9216170410712197]},
   VertexNormals->CompressedData["
1:eJzsvXk8Ff37xy9LuyiizVJKaCFtCvO2tCohW4u9hLRYKolIKJWohFZL1kiJ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    "]],
  Axes->True,
  AxesLabel->{
    FormBox["Re", TraditionalForm], 
    FormBox["Im", TraditionalForm], 
    FormBox["Abs", TraditionalForm]},
  BaseStyle->{FontSize -> 10},
  BoxRatios->{1, 1, 0.4},
  ImageSize->{360., 292.8149603358042},
  Lighting->"Neutral",
  Method->{"RotationControl" -> "Globe"},
  PlotLabel->FormBox["\"Abs value from function\"", TraditionalForm],
  PlotRange->{{-1, 1}, {-1, 1}, {0, 4}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], Automatic},
  ViewPoint->{0.9705284641825763, -2.8857161696454914`, 1.4767249874157233`},
  ViewVertical->{0., 0., 1.}]], "Output",
 CellChangeTimes->{{3.618630769541375*^9, 3.6186308227450666`*^9}, {
   3.618630866965561*^9, 3.618630876057435*^9}, 3.6186309689090853`*^9, 
   3.61863144914007*^9, 3.6186317954131823`*^9, 3.618633886788992*^9, {
   3.6186339796055107`*^9, 3.6186339900948677`*^9}, 3.6186340442805243`*^9, {
   3.618634290655411*^9, 3.61863433073564*^9}, {3.61863495733377*^9, 
   3.618634964696012*^9}, 3.6218323614177856`*^9, {3.621833630859976*^9, 
   3.621833659197509*^9}, 3.627285725457847*^9, 
   3.627286103676835*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1060, 867},
WindowMargins->{{101, Automatic}, {Automatic, 32}},
FrontEndVersion->"9.0 for Linux x86 (64-bit) (February 7, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 140, 3, 93, "Title"],
Cell[722, 27, 410, 7, 71, "Text"],
Cell[CellGroupData[{
Cell[1157, 38, 779, 18, 59, "Input"],
Cell[1939, 58, 633, 14, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2609, 77, 132, 1, 81, "Section"],
Cell[2744, 80, 202, 4, 31, "Text"],
Cell[CellGroupData[{
Cell[2971, 88, 751, 19, 77, "Input"],
Cell[3725, 109, 1784, 36, 330, "Output"]
}, Open  ]],
Cell[5524, 148, 215, 4, 31, "Text"],
Cell[CellGroupData[{
Cell[5764, 156, 1089, 28, 77, "Input"],
Cell[6856, 186, 1900, 38, 360, "Output"]
}, Open  ]],
Cell[8771, 227, 223, 4, 31, "Text"],
Cell[CellGroupData[{
Cell[9019, 235, 1162, 32, 99, "Input"],
Cell[10184, 269, 1843, 37, 338, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12064, 311, 736, 21, 55, "Input"],
Cell[12803, 334, 25388, 429, 250, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[38240, 769, 96, 1, 81, "Section"],
Cell[38339, 772, 16, 0, 31, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38392, 777, 95, 1, 81, "Section"],
Cell[CellGroupData[{
Cell[38512, 782, 5273, 124, 517, "Input"],
Cell[43788, 908, 409139, 7496, 365, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[452964, 8409, 5023, 123, 407, "Input"],
Cell[457990, 8534, 2989300, 52362, 308, 2963283, 51935, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
